import { css, LitElement, html } from 'lit-element';
import { ifDefined } from 'lit-html/directives/if-defined';
import Popper from 'popper.js/dist/esm/popper';
import { installMediaQueryWatcher } from 'pwa-helpers/media-query';

function _taggedTemplateLiteral(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
}

function _templateObject() {
  const data = _taggedTemplateLiteral(["\n\n    :host {\n        --blue: #007bff;\n        --indigo: #6610f2;\n        --purple: #6f42c1;\n        --pink: #e83e8c;\n        --red: #dc3545;\n        --orange: #fd7e14;\n        --yellow: #ffc107;\n        --green: #28a745;\n        --teal: #20c997;\n        --cyan: #17a2b8;\n        --white: #fff;\n        --gray: #6c757d;\n        --gray-dark: #343a40;\n        --primary: #007bff;\n        --secondary: #6c757d;\n        --success: #28a745;\n        --info: #17a2b8;\n        --warning: #ffc107;\n        --danger: #dc3545;\n        --light: #f8f9fa;\n        --dark: #343a40;\n        --breakpoint-xs: 0;\n        --breakpoint-sm: 576px;\n        --breakpoint-md: 768px;\n        --breakpoint-lg: 992px;\n        --breakpoint-xl: 1200px;\n        --font-family-sans-serif: -apple-system, BlinkMacSystemFont, \"Segoe UI\", Roboto, \"Helvetica Neue\", Arial, sans-serif, \"Apple Color Emoji\", \"Segoe UI Emoji\", \"Segoe UI Symbol\", \"Noto Color Emoji\";\n        --font-family-monospace: SFMono-Regular, Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;\n        -webkit-text-size-adjust: 100%;\n        -ms-text-size-adjust: 100%;\n        -ms-overflow-style: scrollbar;\n        -webkit-tap-highlight-color: rgba(0, 0, 0, 0);\n\n        margin: 0;\n        font-family: -apple-system, BlinkMacSystemFont, \"Segoe UI\", Roboto, \"Helvetica Neue\", Arial, sans-serif, \"Apple Color Emoji\", \"Segoe UI Emoji\", \"Segoe UI Symbol\", \"Noto Color Emoji\";\n        font-size: 1rem;\n        font-weight: 400;\n        line-height: 1.5;\n        color: #212529;\n        text-align: left;\n        background-color: #fff;\n    }\n\n    @-ms-viewport {\n        width: device-width;\n    }\n"]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}
const DefaultThemeCss = css(_templateObject());

function _templateObject$1() {
  const data = _taggedTemplateLiteral(["\n    \n    code {\n        font-size: 87.5%;\n        color: #e83e8c;\n        word-break: break-word;\n    }\n\n    a > code {\n        color: inherit;\n    }\n\n    kbd {\n        padding: 0.2rem 0.4rem;\n        font-size: 87.5%;\n        color: #fff;\n        background-color: #212529;\n        border-radius: 0.2rem;\n    }\n\n    kbd kbd {\n        padding: 0;\n        font-size: 100%;\n        font-weight: 700;\n    }\n\n    pre {\n        display: block;\n        font-size: 87.5%;\n        color: #212529;\n    }\n\n    pre code {\n        font-size: inherit;\n        color: inherit;\n        word-break: normal;\n    }\n\n    .pre-scrollable {\n        max-height: 340px;\n        overflow-y: scroll;\n    }\n"]);

  _templateObject$1 = function _templateObject() {
    return data;
  };

  return data;
}
const BsContentCodeCss = css(_templateObject$1());

function _templateObject$2() {
  const data = _taggedTemplateLiteral(["\n    \n    .figure {\n        display: inline-block;\n    }\n\n    .figure-img {\n        margin-bottom: 0.5rem;\n        line-height: 1;\n    }\n\n    .figure-caption {\n        font-size: 90%;\n        color: #6c757d;\n    }\n"]);

  _templateObject$2 = function _templateObject() {
    return data;
  };

  return data;
}
const BsContentFiguresCss = css(_templateObject$2());

function _templateObject$3() {
  const data = _taggedTemplateLiteral(["\n    \n    .img-fluid {\n        max-width: 100%;\n        height: auto;\n    }\n\n    .img-thumbnail {\n        padding: 0.25rem;\n        background-color: #fff;\n        border: 1px solid #dee2e6;\n        border-radius: 0.25rem;\n        max-width: 100%;\n        height: auto;\n    }\n"]);

  _templateObject$3 = function _templateObject() {
    return data;
  };

  return data;
}
const BsContentImageCss = css(_templateObject$3());

function _templateObject$4() {
  const data = _taggedTemplateLiteral(["\n\n    *,\n    *::before,\n    *::after {\n        box-sizing: border-box;\n    }\n\n    article, aside, figcaption, figure, footer, header, hgroup, main, nav, section {\n        display: block;\n    }\n\n    [tabindex=\"-1\"]:focus {\n        outline: 0 !important;\n    }\n\n    hr {\n        box-sizing: content-box;\n        height: 0;\n        overflow: visible;\n    }\n\n    h1, h2, h3, h4, h5, h6 {\n        margin-top: 0;\n        margin-bottom: 0.5rem;\n    }\n\n    p {\n        margin-top: 0;\n        margin-bottom: 1rem;\n    }\n\n    abbr[title],\n    abbr[data-original-title] {\n        text-decoration: underline;\n        -webkit-text-decoration: underline dotted;\n        text-decoration: underline dotted;\n        cursor: help;\n        border-bottom: 0;\n    }\n\n    address {\n        margin-bottom: 1rem;\n        font-style: normal;\n        line-height: inherit;\n    }\n\n    ol,\n    ul,\n    dl {\n        margin-top: 0;\n        margin-bottom: 1rem;\n    }\n\n    ol ol,\n    ul ul,\n    ol ul,\n    ul ol {\n        margin-bottom: 0;\n    }\n\n    dt {\n        font-weight: 700;\n    }\n\n    dd {\n        margin-bottom: .5rem;\n        margin-left: 0;\n    }\n\n    blockquote {\n        margin: 0 0 1rem;\n    }\n\n    dfn {\n        font-style: italic;\n    }\n\n    b,\n    strong {\n        font-weight: bolder;\n    }\n\n    small {\n        font-size: 80%;\n    }\n\n    sub,\n    sup {\n        position: relative;\n        font-size: 75%;\n        line-height: 0;\n        vertical-align: baseline;\n    }\n\n    sub {\n        bottom: -.25em;\n    }\n\n    sup {\n        top: -.5em;\n    }\n\n    a {\n        color: #007bff;\n        text-decoration: none;\n        background-color: transparent;\n        -webkit-text-decoration-skip: objects;\n    }\n\n    a:hover {\n        color: #0056b3;\n        text-decoration: underline;\n    }\n\n    a:not([href]):not([tabindex]) {\n        color: inherit;\n        text-decoration: none;\n    }\n\n    a:not([href]):not([tabindex]):hover, a:not([href]):not([tabindex]):focus {\n        color: inherit;\n        text-decoration: none;\n    }\n\n    a:not([href]):not([tabindex]):focus {\n        outline: 0;\n    }\n\n    pre,\n    code,\n    kbd,\n    samp {\n        font-family: SFMono-Regular, Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;\n        font-size: 1em;\n    }\n\n    pre {\n        margin-top: 0;\n        margin-bottom: 1rem;\n        overflow: auto;\n        -ms-overflow-style: scrollbar;\n    }\n\n    figure {\n        margin: 0 0 1rem;\n    }\n\n    img {\n        vertical-align: middle;\n        border-style: none;\n    }\n\n    svg {\n        overflow: hidden;\n        vertical-align: middle;\n    }\n\n    table {\n        border-collapse: collapse;\n    }\n\n    caption {\n        padding-top: 0.75rem;\n        padding-bottom: 0.75rem;\n        color: #6c757d;\n        text-align: left;\n        caption-side: bottom;\n    }\n\n    th {\n        text-align: inherit;\n    }\n\n    label {\n        display: inline-block;\n        margin-bottom: 0.5rem;\n    }\n\n    button {\n        border-radius: 0;\n    }\n\n    button:focus {\n        outline: 1px dotted;\n        outline: 5px auto -webkit-focus-ring-color;\n    }\n\n    input,\n    button,\n    select,\n    optgroup,\n    textarea {\n        margin: 0;\n        font-family: inherit;\n        font-size: inherit;\n        line-height: inherit;\n    }\n\n    button,\n    input {\n        overflow: visible;\n    }\n\n    button,\n    select {\n        text-transform: none;\n    }\n\n    button,\n    html [type=\"button\"],\n    [type=\"reset\"],\n    [type=\"submit\"] {\n        -webkit-appearance: button;\n    }\n\n    button::-moz-focus-inner,\n    [type=\"button\"]::-moz-focus-inner,\n    [type=\"reset\"]::-moz-focus-inner,\n    [type=\"submit\"]::-moz-focus-inner {\n        padding: 0;\n        border-style: none;\n    }\n\n    input[type=\"radio\"],\n    input[type=\"checkbox\"] {\n        box-sizing: border-box;\n        padding: 0;\n    }\n\n    input[type=\"date\"],\n    input[type=\"time\"],\n    input[type=\"datetime-local\"],\n    input[type=\"month\"] {\n        -webkit-appearance: listbox;\n    }\n\n    textarea {\n        overflow: auto;\n        resize: vertical;\n    }\n\n    fieldset {\n        min-width: 0;\n        padding: 0;\n        margin: 0;\n        border: 0;\n    }\n\n    legend {\n        display: block;\n        width: 100%;\n        max-width: 100%;\n        padding: 0;\n        margin-bottom: .5rem;\n        font-size: 1.5rem;\n        line-height: inherit;\n        color: inherit;\n        white-space: normal;\n    }\n\n    progress {\n        vertical-align: baseline;\n    }\n\n    [type=\"number\"]::-webkit-inner-spin-button,\n    [type=\"number\"]::-webkit-outer-spin-button {\n        height: auto;\n    }\n\n    [type=\"search\"] {\n        outline-offset: -2px;\n        -webkit-appearance: none;\n    }\n\n    [type=\"search\"]::-webkit-search-cancel-button,\n    [type=\"search\"]::-webkit-search-decoration {\n        -webkit-appearance: none;\n    }\n\n    ::-webkit-file-upload-button {\n        font: inherit;\n        -webkit-appearance: button;\n    }\n\n    output {\n        display: inline-block;\n    }\n\n    summary {\n        display: list-item;\n        cursor: pointer;\n    }\n\n    template {\n        display: none;\n    }\n\n    [hidden] {\n        display: none !important;\n    }\n"]);

  _templateObject$4 = function _templateObject() {
    return data;
  };

  return data;
}
const BsContentRebootCss = css(_templateObject$4());

function _templateObject$5() {
  const data = _taggedTemplateLiteral(["\n    \n    .table {\n        width: 100%;\n        margin-bottom: 1rem;\n        background-color: transparent;\n    }\n\n    .table th,\n    .table td {\n        padding: 0.75rem;\n        vertical-align: top;\n        border-top: 1px solid #dee2e6;\n    }\n\n    .table thead th {\n        vertical-align: bottom;\n        border-bottom: 2px solid #dee2e6;\n    }\n\n    .table tbody + tbody {\n        border-top: 2px solid #dee2e6;\n    }\n\n    .table .table {\n        background-color: #fff;\n    }\n\n    .table-sm th, .table-sm td {\n        padding: 0.3rem;\n    }\n\n    .table-bordered {\n        border: 1px solid #dee2e6;\n    }\n\n    .table-bordered th,\n    .table-bordered td {\n        border: 1px solid #dee2e6;\n    }\n\n    .table-bordered thead th,\n    .table-bordered thead td {\n        border-bottom-width: 2px;\n    }\n\n    .table-borderless th,\n    .table-borderless td,\n    .table-borderless thead th,\n    .table-borderless tbody + tbody {\n        border: 0;\n    }\n\n    .table-striped tbody tr:nth-of-type(odd) {\n        background-color: rgba(0, 0, 0, 0.05);\n    }\n\n    .table-hover tbody tr:hover {\n        background-color: rgba(0, 0, 0, 0.075);\n    }\n\n    .table-primary,\n    .table-primary > th,\n    .table-primary > td {\n        background-color: #b8daff;\n    }\n\n    .table-hover .table-primary:hover {\n        background-color: #9fcdff;\n    }\n\n    .table-hover .table-primary:hover > td,\n    .table-hover .table-primary:hover > th {\n        background-color: #9fcdff;\n    }\n\n    .table-secondary,\n    .table-secondary > th,\n    .table-secondary > td {\n        background-color: #d6d8db;\n    }\n\n    .table-hover .table-secondary:hover {\n        background-color: #c8cbcf;\n    }\n\n    .table-hover .table-secondary:hover > td,\n    .table-hover .table-secondary:hover > th {\n        background-color: #c8cbcf;\n    }\n\n    .table-success,\n    .table-success > th,\n    .table-success > td {\n        background-color: #c3e6cb;\n    }\n\n    .table-hover .table-success:hover {\n        background-color: #b1dfbb;\n    }\n\n    .table-hover .table-success:hover > td,\n    .table-hover .table-success:hover > th {\n        background-color: #b1dfbb;\n    }\n\n    .table-info,\n    .table-info > th,\n    .table-info > td {\n        background-color: #bee5eb;\n    }\n\n    .table-hover .table-info:hover {\n        background-color: #abdde5;\n    }\n\n    .table-hover .table-info:hover > td,\n    .table-hover .table-info:hover > th {\n        background-color: #abdde5;\n    }\n\n    .table-warning,\n    .table-warning > th,\n    .table-warning > td {\n        background-color: #ffeeba;\n    }\n\n    .table-hover .table-warning:hover {\n        background-color: #ffe8a1;\n    }\n\n    .table-hover .table-warning:hover > td,\n    .table-hover .table-warning:hover > th {\n        background-color: #ffe8a1;\n    }\n\n    .table-danger,\n    .table-danger > th,\n    .table-danger > td {\n        background-color: #f5c6cb;\n    }\n\n    .table-hover .table-danger:hover {\n        background-color: #f1b0b7;\n    }\n\n    .table-hover .table-danger:hover > td,\n    .table-hover .table-danger:hover > th {\n        background-color: #f1b0b7;\n    }\n\n    .table-light,\n    .table-light > th,\n    .table-light > td {\n        background-color: #fdfdfe;\n    }\n\n    .table-hover .table-light:hover {\n        background-color: #ececf6;\n    }\n\n    .table-hover .table-light:hover > td,\n    .table-hover .table-light:hover > th {\n        background-color: #ececf6;\n    }\n\n    .table-dark,\n    .table-dark > th,\n    .table-dark > td {\n        background-color: #c6c8ca;\n    }\n\n    .table-hover .table-dark:hover {\n        background-color: #b9bbbe;\n    }\n\n    .table-hover .table-dark:hover > td,\n    .table-hover .table-dark:hover > th {\n        background-color: #b9bbbe;\n    }\n\n    .table-active,\n    .table-active > th,\n    .table-active > td {\n        background-color: rgba(0, 0, 0, 0.075);\n    }\n\n    .table-hover .table-active:hover {\n        background-color: rgba(0, 0, 0, 0.075);\n    }\n\n    .table-hover .table-active:hover > td,\n    .table-hover .table-active:hover > th {\n        background-color: rgba(0, 0, 0, 0.075);\n    }\n\n    .table .thead-dark th {\n    color: #fff;\n        background-color: #212529;\n        border-color: #32383e;\n    }\n\n    .table .thead-light th {\n    color: #495057;\n        background-color: #e9ecef;\n        border-color: #dee2e6;\n    }\n\n    .table-dark {\n    color: #fff;\n        background-color: #212529;\n    }\n\n    .table-dark th,\n    .table-dark td,\n    .table-dark thead th {\n        border-color: #32383e;\n    }\n\n    .table-dark.table-bordered {\n        border: 0;\n    }\n\n    .table-dark.table-striped tbody tr:nth-of-type(odd) {\n        background-color: rgba(255, 255, 255, 0.05);\n    }\n\n    .table-dark.table-hover tbody tr:hover {\n        background-color: rgba(255, 255, 255, 0.075);\n    }\n\n    @media (max-width: 575.98px) {\n        .table-responsive-sm {\n            display: block;\n            width: 100%;\n            overflow-x: auto;\n            -webkit-overflow-scrolling: touch;\n            -ms-overflow-style: -ms-autohiding-scrollbar;\n        }\n        .table-responsive-sm > .table-bordered {\n            border: 0;\n        }\n    }\n\n    @media (max-width: 767.98px) {\n        .table-responsive-md {\n            display: block;\n            width: 100%;\n            overflow-x: auto;\n            -webkit-overflow-scrolling: touch;\n            -ms-overflow-style: -ms-autohiding-scrollbar;\n        }\n        .table-responsive-md > .table-bordered {\n            border: 0;\n        }\n    }\n\n    @media (max-width: 991.98px) {\n        .table-responsive-lg {\n            display: block;\n            width: 100%;\n            overflow-x: auto;\n            -webkit-overflow-scrolling: touch;\n            -ms-overflow-style: -ms-autohiding-scrollbar;\n        }\n        .table-responsive-lg > .table-bordered {\n            border: 0;\n        }\n    }\n\n    @media (max-width: 1199.98px) {\n        .table-responsive-xl {\n            display: block;\n            width: 100%;\n            overflow-x: auto;\n            -webkit-overflow-scrolling: touch;\n            -ms-overflow-style: -ms-autohiding-scrollbar;\n        }\n        .table-responsive-xl > .table-bordered {\n            border: 0;\n        }\n    }\n\n    .table-responsive {\n        display: block;\n        width: 100%;\n        overflow-x: auto;\n        -webkit-overflow-scrolling: touch;\n        -ms-overflow-style: -ms-autohiding-scrollbar;\n    }\n\n    .table-responsive > .table-bordered {\n        border: 0;\n    }\n"]);

  _templateObject$5 = function _templateObject() {
    return data;
  };

  return data;
}
const BsContenTableCss = css(_templateObject$5());

function _templateObject$6() {
  const data = _taggedTemplateLiteral(["\n    \n    h1, h2, h3, h4, h5, h6,\n    .h1, .h2, .h3, .h4, .h5, .h6 {\n        margin-bottom: 0.5rem;\n        font-family: inherit;\n        font-weight: 500;\n        line-height: 1.2;\n        color: inherit;\n    }\n    \n    h1, .h1 {\n        font-size: 2.5rem;\n    }\n    \n    h2, .h2 {\n        font-size: 2rem;\n    }\n    \n    h3, .h3 {\n        font-size: 1.75rem;\n    }\n    \n    h4, .h4 {\n        font-size: 1.5rem;\n    }\n    \n    h5, .h5 {\n        font-size: 1.25rem;\n    }\n    \n    h6, .h6 {\n        font-size: 1rem;\n    }\n    \n    .lead {\n        font-size: 1.25rem;\n        font-weight: 300;\n    }\n    \n    .display-1 {\n        font-size: 6rem;\n        font-weight: 300;\n        line-height: 1.2;\n    }\n    \n    .display-2 {\n        font-size: 5.5rem;\n        font-weight: 300;\n        line-height: 1.2;\n    }\n    \n    .display-3 {\n        font-size: 4.5rem;\n        font-weight: 300;\n        line-height: 1.2;\n    }\n    \n    .display-4 {\n        font-size: 3.5rem;\n        font-weight: 300;\n        line-height: 1.2;\n    }\n    \n    hr {\n        margin-top: 1rem;\n        margin-bottom: 1rem;\n        border: 0;\n        border-top: 1px solid rgba(0, 0, 0, 0.1);\n    }\n    \n    small, .small {\n        font-size: 80%;\n        font-weight: 400;\n    }\n    \n    mark, .mark {\n        padding: 0.2em;\n        background-color: #fcf8e3;\n    }\n    \n    .list-unstyled {\n        padding-left: 0;\n        list-style: none;\n    }\n    \n    .list-inline {\n        padding-left: 0;\n        list-style: none;\n    }\n    \n    .list-inline-item {\n        display: inline-block;\n    }\n\n    .list-inline-item:not(:last-child) {\n        margin-right: 0.5rem;\n    }\n    \n    .initialism {\n        font-size: 90%;\n        text-transform: uppercase;\n    }\n    \n    .blockquote {\n        margin-bottom: 1rem;\n        font-size: 1.25rem;\n    }\n    \n    .blockquote-footer {\n        display: block;\n        font-size: 80%;\n        color: #6c757d;\n    }\n    \n    .blockquote-footer::before {\n        content: \"\\2014 \\00A0\";\n    }\n"], ["\n    \n    h1, h2, h3, h4, h5, h6,\n    .h1, .h2, .h3, .h4, .h5, .h6 {\n        margin-bottom: 0.5rem;\n        font-family: inherit;\n        font-weight: 500;\n        line-height: 1.2;\n        color: inherit;\n    }\n    \n    h1, .h1 {\n        font-size: 2.5rem;\n    }\n    \n    h2, .h2 {\n        font-size: 2rem;\n    }\n    \n    h3, .h3 {\n        font-size: 1.75rem;\n    }\n    \n    h4, .h4 {\n        font-size: 1.5rem;\n    }\n    \n    h5, .h5 {\n        font-size: 1.25rem;\n    }\n    \n    h6, .h6 {\n        font-size: 1rem;\n    }\n    \n    .lead {\n        font-size: 1.25rem;\n        font-weight: 300;\n    }\n    \n    .display-1 {\n        font-size: 6rem;\n        font-weight: 300;\n        line-height: 1.2;\n    }\n    \n    .display-2 {\n        font-size: 5.5rem;\n        font-weight: 300;\n        line-height: 1.2;\n    }\n    \n    .display-3 {\n        font-size: 4.5rem;\n        font-weight: 300;\n        line-height: 1.2;\n    }\n    \n    .display-4 {\n        font-size: 3.5rem;\n        font-weight: 300;\n        line-height: 1.2;\n    }\n    \n    hr {\n        margin-top: 1rem;\n        margin-bottom: 1rem;\n        border: 0;\n        border-top: 1px solid rgba(0, 0, 0, 0.1);\n    }\n    \n    small, .small {\n        font-size: 80%;\n        font-weight: 400;\n    }\n    \n    mark, .mark {\n        padding: 0.2em;\n        background-color: #fcf8e3;\n    }\n    \n    .list-unstyled {\n        padding-left: 0;\n        list-style: none;\n    }\n    \n    .list-inline {\n        padding-left: 0;\n        list-style: none;\n    }\n    \n    .list-inline-item {\n        display: inline-block;\n    }\n\n    .list-inline-item:not(:last-child) {\n        margin-right: 0.5rem;\n    }\n    \n    .initialism {\n        font-size: 90%;\n        text-transform: uppercase;\n    }\n    \n    .blockquote {\n        margin-bottom: 1rem;\n        font-size: 1.25rem;\n    }\n    \n    .blockquote-footer {\n        display: block;\n        font-size: 80%;\n        color: #6c757d;\n    }\n    \n    .blockquote-footer::before {\n        content: \"\\\\2014 \\\\00A0\";\n    }\n"]);

  _templateObject$6 = function _templateObject() {
    return data;
  };

  return data;
}
const BsContentTypographyCss = css(_templateObject$6());

function _templateObject$7() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([xs]), \n    :host([xs-1]), \n    :host([xs-2]), \n    :host([xs-3]), \n    :host([xs-4]), \n    :host([xs-5]), \n    :host([xs-6]), \n    :host([xs-7]), \n    :host([xs-8]), \n    :host([xs-9]), \n    :host([xs-10]), \n    :host([xs-11]),\n    :host([xs-12]), \n    :host([xs-auto]) {\n        display: block;\n        position: relative;\n        width: 100%;\n        min-height: 1px;\n        padding-right: 15px;\n        padding-left: 15px;\n    }\n\n    :host([xs-auto]) {\n        -ms-flex: 0 0 auto;\n        flex: 0 0 auto;\n        width: auto;\n        max-width: none;\n    }\n\n    :host([xs]) {\n        -ms-flex-preferred-size: 0;\n        flex-basis: 0;\n        -ms-flex-positive: 1;\n        flex-grow: 1;\n        max-width: 100%;\n    }\n\n    :host([xs-1]) {\n        -ms-flex: 0 0 8.333333%;\n        flex: 0 0 8.333333%;\n        max-width: 8.333333%;\n    }\n    \n    :host([xs-2]) {\n        -ms-flex: 0 0 16.666667%;\n        flex: 0 0 16.666667%;\n        max-width: 16.666667%;\n    }\n\n    :host([xs-3]) {\n        -ms-flex: 0 0 25%;\n        flex: 0 0 25%;\n        max-width: 25%;\n    }\n\n    :host([xs-4]) {\n        -ms-flex: 0 0 33.333333%;\n        flex: 0 0 33.333333%;\n        max-width: 33.333333%;\n    }\n\n    :host([xs-5]) {\n        -ms-flex: 0 0 41.666667%;\n        flex: 0 0 41.666667%;\n        max-width: 41.666667%;\n    }\n\n    :host([xs-6]) {\n        -ms-flex: 0 0 50%;\n        flex: 0 0 50%;\n        max-width: 50%;\n    }\n    \n    :host([xs-7]) {\n        -ms-flex: 0 0 58.333333%;\n        flex: 0 0 58.333333%;\n        max-width: 58.333333%;\n    }\n\n    :host([xs-8]) {\n        -ms-flex: 0 0 66.666667%;\n        flex: 0 0 66.666667%;\n        max-width: 66.666667%;\n    }\n\n    :host([xs-9]) {\n        -ms-flex: 0 0 75%;\n        flex: 0 0 75%;\n        max-width: 75%;\n    }\n    \n    :host([xs-10]) {\n        -ms-flex: 0 0 83.333333%;\n        flex: 0 0 83.333333%;\n        max-width: 83.333333%;\n    }\n    \n    :host([xs-11]) {\n        -ms-flex: 0 0 91.666667%;\n        flex: 0 0 91.666667%;\n        max-width: 91.666667%;\n    }\n    \n    :host([xs-12]) {\n        -ms-flex: 0 0 100%;\n        flex: 0 0 100%;\n        max-width: 100%;\n    }\n\n    :host([order-xs-first]) {\n        -ms-flex-order: -1;\n        order: -1;\n    }\n\n    :host([order-xs-last]) {\n        -ms-flex-order: 13;\n        order: 13;\n    }\n\n    :host([order-xs-0]) {\n        -ms-flex-order: 0;\n        order: 0;\n    }\n\n    :host([order-xs-1]) {\n        -ms-flex-order: 1;\n        order: 1;\n    }\n\n    :host([order-xs-2]) {\n        -ms-flex-order: 2;\n        order: 2;\n    }\n\n    :host([order-xs-3]) {\n        -ms-flex-order: 3;\n        order: 3;\n    }\n\n    :host([order-xs-4]) {\n        -ms-flex-order: 4;\n        order: 4;\n    }\n\n    :host([order-xs-5]) {\n        -ms-flex-order: 5;\n        order: 5;\n    }\n\n    :host([order-xs-6]) {\n        -ms-flex-order: 6;\n        order: 6;\n    }\n\n    :host([order-xs-7]) {\n        -ms-flex-order: 7;\n        order: 7;\n    }\n\n    :host([order-xs-8]) {\n        -ms-flex-order: 8;\n        order: 8;\n    }\n\n    :host([order-xs-9]) {\n        -ms-flex-order: 9;\n        order: 9;\n    }\n\n    :host([order-xs-10]) {\n        -ms-flex-order: 10;\n        order: 10;\n    }\n\n    :host([order-xs-11]) {\n        -ms-flex-order: 11;\n        order: 11;\n    }\n\n    :host([order-xs-12]) {\n        -ms-flex-order: 12;\n        order: 12;\n    }\n\n    :host([offset-xs-1]) {\n        margin-left: 8.333333%;\n    }\n\n    :host([offset-xs-2]) {\n        margin-left: 16.666667%;\n    }\n\n    :host([offset-xs-2]) {\n        margin-left: 25%;\n    }\n\n    :host([offset-xs-4]) {\n        margin-left: 33.333333%;\n    }\n\n    :host([offset-xs-5]) {\n        margin-left: 41.666667%;\n    }\n\n    :host([offset-xs-6]) {\n        margin-left: 50%;\n    }\n\n    :host([offset-xs-7]) {\n        margin-left: 58.333333%;\n    }\n\n    :host([offset-xs-8]) {\n        margin-left: 66.666667%;\n    }\n\n    :host([offset-xs-9]) {\n        margin-left: 75%;\n    }\n\n    :host([offset-xs-10]) {\n        margin-left: 83.333333%;\n    }\n\n    :host([offset-xs-11]) {\n        margin-left: 91.666667%;\n    }\n"]);

  _templateObject$7 = function _templateObject() {
    return data;
  };

  return data;
}
const BsColumnExtraSmallCss = css(_templateObject$7());

function _templateObject$8() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([sm]), \n    :host([sm-1]), \n    :host([sm-2]), \n    :host([sm-3]), \n    :host([sm-4]), \n    :host([sm-5]), \n    :host([sm-6]), \n    :host([sm-7]), \n    :host([sm-8]), \n    :host([sm-9]), \n    :host([sm-10]), \n    :host([sm-11]), \n    :host([sm-12]), \n    :host([sm-auto]) {\n        display: block;\n        position: relative;\n        width: 100%;\n        min-height: 1px;\n        padding-right: 15px;\n        padding-left: 15px;\n    }\n    \n    @media (min-width: 576px) {\n        \n        :host([sm-auto]) {\n            -ms-flex: 0 0 auto;\n            flex: 0 0 auto;\n            width: auto;\n            max-width: none;\n        }\n        \n        :host([sm]) {\n            -ms-flex-preferred-size: 0;\n            flex-basis: 0;\n            -ms-flex-positive: 1;\n            flex-grow: 1;\n            max-width: 100%;\n        }\n        \n        :host([sm-1]) {\n            -ms-flex: 0 0 8.333333%;\n            flex: 0 0 8.333333%;\n            max-width: 8.333333%;\n        }\n\n        :host([sm-2]) {\n            -ms-flex: 0 0 16.666667%;\n            flex: 0 0 16.666667%;\n            max-width: 16.666667%;\n        }\n        \n        :host([sm-3]) {\n            -ms-flex: 0 0 25%;\n            flex: 0 0 25%;\n            max-width: 25%;\n        }\n\n        :host([sm-4]) {\n            -ms-flex: 0 0 33.333333%;\n            flex: 0 0 33.333333%;\n            max-width: 33.333333%;\n        }\n\n        :host([sm-5]) {\n            -ms-flex: 0 0 41.666667%;\n            flex: 0 0 41.666667%;\n            max-width: 41.666667%;\n        }\n        \n        :host([sm-6]) {\n            -ms-flex: 0 0 50%;\n            flex: 0 0 50%;\n            max-width: 50%;\n        }\n\n        :host([sm-7]) {\n            -ms-flex: 0 0 58.333333%;\n            flex: 0 0 58.333333%;\n            max-width: 58.333333%;\n        }\n\n        :host([sm-8]) {\n            -ms-flex: 0 0 66.666667%;\n            flex: 0 0 66.666667%;\n            max-width: 66.666667%;\n        }\n        \n        :host([sm-9]) {\n            -ms-flex: 0 0 75%;\n            flex: 0 0 75%;\n            max-width: 75%;\n        }\n\n        :host([sm-10]) {\n            -ms-flex: 0 0 83.333333%;\n            flex: 0 0 83.333333%;\n            max-width: 83.333333%;\n        }\n        \n        :host([sm-11]) {\n            -ms-flex: 0 0 91.666667%;\n            flex: 0 0 91.666667%;\n            max-width: 91.666667%;\n        }\n\n        :host([sm-12]) {\n            -ms-flex: 0 0 100%;\n            flex: 0 0 100%;\n            max-width: 100%;\n        }\n        \n        :host([order-sm-first]) {\n            -ms-flex-order: -1;\n            order: -1;\n        }\n\n        :host([order-sm-last]) {\n            -ms-flex-order: 13;\n            order: 13;\n        }\n        \n        :host([order-sm-0]) {\n            -ms-flex-order: 0;\n            order: 0;\n        }\n\n        :host([order-sm-1]) {\n            -ms-flex-order: 1;\n            order: 1;\n        }\n\n        :host([order-sm-2]) {\n            -ms-flex-order: 2;\n            order: 2;\n        }\n\n        :host([order-sm-3]) {\n            -ms-flex-order: 3;\n            order: 3;\n        }\n\n        :host([order-sm-4]) {\n            -ms-flex-order: 4;\n            order: 4;\n        }\n\n        :host([order-sm-5]) {\n            -ms-flex-order: 5;\n            order: 5;\n        }\n\n        :host([order-sm-6]) {\n            -ms-flex-order: 6;\n            order: 6;\n        }\n\n        :host([order-sm-7]) {\n            -ms-flex-order: 7;\n            order: 7;\n        }\n\n        :host([order-sm-8]) {\n            -ms-flex-order: 8;\n            order: 8;\n        }\n\n        :host([order-sm-9]) {\n            -ms-flex-order: 9;\n            order: 9;\n        }\n\n        :host([order-sm-10]) {\n            -ms-flex-order: 10;\n            order: 10;\n        }\n\n        :host([order-sm-11]) {\n            -ms-flex-order: 11;\n            order: 11;\n        }\n\n        :host([order-sm-12]) {\n            -ms-flex-order: 12;\n            order: 12;\n        }\n\n        :host([offset-sm-0]) {\n            margin-left: 0;\n        }\n\n        :host([offset-sm-1]) {\n            margin-left: 8.333333%;\n        }\n\n        :host([offset-sm-2]) {\n            margin-left: 16.666667%;\n        }\n        \n        :host([offset-sm-3]) {\n            margin-left: 25%;\n        }\n        \n        :host([offset-sm-4]) {\n            margin-left: 33.333333%;\n        }\n\n        :host([offset-sm-5]) {\n            margin-left: 41.666667%;\n        }\n\n        :host([offset-sm-6]) {\n            margin-left: 50%;\n        }\n\n        :host([offset-sm-7]) {\n            margin-left: 58.333333%;\n        }\n\n        :host([offset-sm-8]) {\n            margin-left: 66.666667%;\n        }\n\n        :host([offset-sm-9]) {\n            margin-left: 75%;\n        }\n\n        :host([offset-sm-10]) {\n            margin-left: 83.333333%;\n        }\n\n        :host([offset-sm-11]) {\n            margin-left: 91.666667%;\n        }\n    }\n"]);

  _templateObject$8 = function _templateObject() {
    return data;
  };

  return data;
}
const BsColumnSmallCss = css(_templateObject$8());

function _templateObject$9() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([md]), \n    :host([md-1]), \n    :host([md-2]), \n    :host([md-3]), \n    :host([md-4]), \n    :host([md-5]), \n    :host([md-6]), \n    :host([md-7]), \n    :host([md-8]), \n    :host([md-9]), \n    :host([md-10]), \n    :host([md-11]), \n    :host([md-12]), \n    :host([md-auto]) {\n        display: block;\n        position: relative;\n        width: 100%;\n        min-height: 1px;\n        padding-right: 15px;\n        padding-left: 15px;\n    }\n    \n    @media (min-width: 768px) {\n        \n        :host([md-auto]) {\n            -ms-flex: 0 0 auto;\n            flex: 0 0 auto;\n            width: auto;\n            max-width: none;\n        }\n        \n        :host([md]) {\n            -ms-flex-preferred-size: 0;\n            flex-basis: 0;\n            -ms-flex-positive: 1;\n            flex-grow: 1;\n            max-width: 100%;\n        }\n\n        :host([md-1]) {\n            -ms-flex: 0 0 8.333333%;\n            flex: 0 0 8.333333%;\n            max-width: 8.333333%;\n        }\n\n        :host([md-2]) {\n            -ms-flex: 0 0 16.666667%;\n            flex: 0 0 16.666667%;\n            max-width: 16.666667%;\n        }\n\n        :host([md-3]) {\n            -ms-flex: 0 0 25%;\n            flex: 0 0 25%;\n            max-width: 25%;\n        }\n\n        :host([md-4]) {\n            -ms-flex: 0 0 33.333333%;\n            flex: 0 0 33.333333%;\n            max-width: 33.333333%;\n        }\n\n        :host([md-5]) {\n            -ms-flex: 0 0 41.666667%;\n            flex: 0 0 41.666667%;\n            max-width: 41.666667%;\n        }\n        \n        :host([md-6]) {\n            -ms-flex: 0 0 50%;\n            flex: 0 0 50%;\n            max-width: 50%;\n        }\n\n        :host([md-7]) {\n            -ms-flex: 0 0 58.333333%;\n            flex: 0 0 58.333333%;\n            max-width: 58.333333%;\n        }\n\n        :host([md-8]) {\n            -ms-flex: 0 0 66.666667%;\n            flex: 0 0 66.666667%;\n            max-width: 66.666667%;\n        }\n\n        :host([md-9]) {\n            -ms-flex: 0 0 75%;\n            flex: 0 0 75%;\n            max-width: 75%;\n        }\n\n        :host([md-10]) {\n            -ms-flex: 0 0 83.333333%;\n            flex: 0 0 83.333333%;\n            max-width: 83.333333%;\n        }\n\n        :host([md-11]) {\n            -ms-flex: 0 0 91.666667%;\n            flex: 0 0 91.666667%;\n            max-width: 91.666667%;\n        }\n\n        :host([md-12]) {\n            -ms-flex: 0 0 100%;\n            flex: 0 0 100%;\n            max-width: 100%;\n        }\n\n        :host([order-md-first]) {\n            -ms-flex-order: -1;\n            order: -1;\n        }\n\n        :host([order-md-last]) {\n            -ms-flex-order: 13;\n            order: 13;\n        }\n\n        :host([order-md-0]) {\n            -ms-flex-order: 0;\n            order: 0;\n        }\n\n        :host([order-md-1]) {\n            -ms-flex-order: 1;\n            order: 1;\n        }\n\n        :host([order-md-2]) {\n            -ms-flex-order: 2;\n            order: 2;\n        }\n\n        :host([order-md-3]) {\n            -ms-flex-order: 3;\n            order: 3;\n        }\n\n        :host([order-md-4]) {\n            -ms-flex-order: 4;\n            order: 4;\n        }\n\n        :host([order-md-5]) {\n            -ms-flex-order: 5;\n            order: 5;\n        }\n\n        :host([order-md-6]) {\n            -ms-flex-order: 6;\n            order: 6;\n        }\n\n        :host([order-md-7]) {\n            -ms-flex-order: 7;\n            order: 7;\n        }\n\n        :host([order-md-8]) {\n            -ms-flex-order: 8;\n            order: 8;\n        }\n\n        :host([order-md-9]) {\n            -ms-flex-order: 9;\n            order: 9;\n        }\n\n        :host([order-md-10]) {\n            -ms-flex-order: 10;\n            order: 10;\n        }\n\n        :host([order-md-11]) {\n            -ms-flex-order: 11;\n            order: 11;\n        }\n\n        :host([order-md-12]) {\n            -ms-flex-order: 12;\n            order: 12;\n        }\n\n        :host([offset-md-0]) {\n            margin-left: 0;\n        }\n\n        :host([offset-md-1]) {\n            margin-left: 8.333333%;\n        }\n\n        :host([offset-md-2]) {\n            margin-left: 16.666667%;\n        }\n\n        :host([offset-md-3]) {\n            margin-left: 25%;\n        }\n\n        :host([offset-md-4]) {\n            margin-left: 33.333333%;\n        }\n\n        :host([offset-md-5]) {\n            margin-left: 41.666667%;\n        }\n\n        :host([offset-md-6]) {\n            margin-left: 50%;\n        }\n\n        :host([offset-md-7]) {\n            margin-left: 58.333333%;\n        }\n\n        :host([offset-md-8]) {\n            margin-left: 66.666667%;\n        }\n\n        :host([offset-md-9]) {\n            margin-left: 75%;\n        }\n\n        :host([offset-md-10]) {\n            margin-left: 83.333333%;\n        }\n\n        :host([offset-md-11]) {\n            margin-left: 91.666667%;\n        }\n    }\n"]);

  _templateObject$9 = function _templateObject() {
    return data;
  };

  return data;
}
const BsColumnMediumCss = css(_templateObject$9());

function _templateObject$a() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([lg]), \n    :host([lg-1]), \n    :host([lg-2]), \n    :host([lg-3]), \n    :host([lg-4]), \n    :host([lg-5]), \n    :host([lg-6]), \n    :host([lg-7]), \n    :host([lg-8]), \n    :host([lg-9]), \n    :host([lg-10]), \n    :host([lg-11]), \n    :host([lg-12]), \n    :host([lg-auto]) {\n        display: block;\n        position: relative;\n        width: 100%;\n        min-height: 1px;\n        padding-right: 15px;\n        padding-left: 15px;\n    }\n    \n    @media (min-width: 992px) {\n        \n        :host([lg-auto]) {\n            -ms-flex: 0 0 auto;\n            flex: 0 0 auto;\n            width: auto;\n            max-width: none;\n        }\n        \n        :host([lg]) {\n            -ms-flex-preferred-size: 0;\n            flex-basis: 0;\n            -ms-flex-positive: 1;\n            flex-grow: 1;\n            max-width: 100%;\n        }\n\n        :host([lg-1]) {\n            -ms-flex: 0 0 8.333333%;\n            flex: 0 0 8.333333%;\n            max-width: 8.333333%;\n        }\n\n        :host([lg-2]) {\n            -ms-flex: 0 0 16.666667%;\n            flex: 0 0 16.666667%;\n            max-width: 16.666667%;\n        }\n\n        :host([lg-3]) {\n            -ms-flex: 0 0 25%;\n            flex: 0 0 25%;\n            max-width: 25%;\n        }\n\n        :host([lg-4]) {\n            -ms-flex: 0 0 33.333333%;\n            flex: 0 0 33.333333%;\n            max-width: 33.333333%;\n        }\n\n        :host([lg-5]) {\n            -ms-flex: 0 0 41.666667%;\n            flex: 0 0 41.666667%;\n            max-width: 41.666667%;\n        }\n\n        :host([lg-6]) {\n            -ms-flex: 0 0 50%;\n            flex: 0 0 50%;\n            max-width: 50%;\n        }\n\n        :host([lg-7]) {\n            -ms-flex: 0 0 58.333333%;\n            flex: 0 0 58.333333%;\n            max-width: 58.333333%;\n        }\n\n        :host([lg-8]) {\n            -ms-flex: 0 0 66.666667%;\n            flex: 0 0 66.666667%;\n            max-width: 66.666667%;\n        }\n\n        :host([lg-9]) {\n            -ms-flex: 0 0 75%;\n            flex: 0 0 75%;\n            max-width: 75%;\n        }\n\n        :host([lg-10]) {\n            -ms-flex: 0 0 83.333333%;\n            flex: 0 0 83.333333%;\n            max-width: 83.333333%;\n        }\n\n        :host([lg-11]) {\n            -ms-flex: 0 0 91.666667%;\n            flex: 0 0 91.666667%;\n            max-width: 91.666667%;\n        }\n\n        :host([lg-12]) {\n            -ms-flex: 0 0 100%;\n            flex: 0 0 100%;\n            max-width: 100%;\n        }\n\n        :host([order-lg-first]) {\n            -ms-flex-order: -1;\n            order: -1;\n        }\n\n        :host([order-lg-last]) {\n            -ms-flex-order: 13;\n            order: 13;\n        }\n\n        :host([order-lg-0]) {\n            -ms-flex-order: 0;\n            order: 0;\n        }\n\n        :host([order-lg-1]) {\n            -ms-flex-order: 1;\n            order: 1;\n        }\n\n        :host([order-lg-2]) {\n            -ms-flex-order: 2;\n            order: 2;\n        }\n\n        :host([order-lg-3]) {\n            -ms-flex-order: 3;\n            order: 3;\n        }\n\n        :host([order-lg-4]) {\n            -ms-flex-order: 4;\n            order: 4;\n        }\n\n        :host([order-lg-5]) {\n            -ms-flex-order: 5;\n            order: 5;\n        }\n\n        :host([order-lg-6]) {\n            -ms-flex-order: 6;\n            order: 6;\n        }\n\n        :host([order-lg-7]) {\n            -ms-flex-order: 7;\n            order: 7;\n        }\n\n        :host([order-lg-8]) {\n            -ms-flex-order: 8;\n            order: 8;\n        }\n\n        :host([order-lg-9]) {\n            -ms-flex-order: 9;\n            order: 9;\n        }\n\n        :host([order-lg-10]) {\n            -ms-flex-order: 10;\n            order: 10;\n        }\n\n        :host([order-lg-11]) {\n            -ms-flex-order: 11;\n            order: 11;\n        }\n\n        :host([order-lg-12]) {\n            -ms-flex-order: 12;\n            order: 12;\n        }\n\n        :host([offset-lg-0]) {\n            margin-left: 0;\n        }\n\n        :host([offset-lg-1]) {\n            margin-left: 8.333333%;\n        }\n\n        :host([offset-lg-2]) {\n            margin-left: 16.666667%;\n        }\n\n        :host([offset-lg-3]) {\n            margin-left: 25%;\n        }\n\n        :host([offset-lg-4]) {\n            margin-left: 33.333333%;\n        }\n\n        :host([offset-lg-5]) {\n            margin-left: 41.666667%;\n        }\n\n        :host([offset-lg-6]) {\n            margin-left: 50%;\n        }\n\n        :host([offset-lg-7]) {\n            margin-left: 58.333333%;\n        }\n\n        :host([offset-lg-8]) {\n            margin-left: 66.666667%;\n        }\n\n        :host([offset-lg-9]) {\n            margin-left: 75%;\n        }\n\n        :host([offset-lg-10]) {\n            margin-left: 83.333333%;\n        }\n\n        :host([offset-lg-11]) {\n            margin-left: 91.666667%;\n        }\n    }\n"]);

  _templateObject$a = function _templateObject() {
    return data;
  };

  return data;
}
const BsColumnLargeCss = css(_templateObject$a());

function _templateObject$b() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([xl]), \n    :host([xl-1]), \n    :host([xl-2]), \n    :host([xl-3]), \n    :host([xl-4]), \n    :host([xl-5]), \n    :host([xl-6]), \n    :host([xl-7]), \n    :host([xl-8]), \n    :host([xl-9]), \n    :host([xl-10]), \n    :host([xl-11]), \n    :host([xl-12]), \n    :host([xl-auto]) {\n        display: block;\n        position: relative;\n        width: 100%;\n        min-height: 1px;\n        padding-right: 15px;\n        padding-left: 15px;\n    }\n    \n    @media (min-width: 1200px) {\n        \n        :host([xl-auto]) {\n            -ms-flex: 0 0 auto;\n            flex: 0 0 auto;\n            width: auto;\n            max-width: none;\n        }\n        \n        :host([xl]) {\n            -ms-flex-preferred-size: 0;\n            flex-basis: 0;\n            -ms-flex-positive: 1;\n            flex-grow: 1;\n            max-width: 100%;\n        }\n\n        :host([xl-1]) {\n            -ms-flex: 0 0 8.333333%;\n            flex: 0 0 8.333333%;\n            max-width: 8.333333%;\n        }\n        \n        :host([xl-2]) {\n            -ms-flex: 0 0 16.666667%;\n            flex: 0 0 16.666667%;\n            max-width: 16.666667%;\n        }\n        \n        :host([xl-3]) {\n            -ms-flex: 0 0 25%;\n            flex: 0 0 25%;\n            max-width: 25%;\n        }\n        \n        :host([xl-4]) {\n            -ms-flex: 0 0 33.333333%;\n            flex: 0 0 33.333333%;\n            max-width: 33.333333%;\n        }\n        \n        :host([xl-5]) {\n            -ms-flex: 0 0 41.666667%;\n            flex: 0 0 41.666667%;\n            max-width: 41.666667%;\n        }\n        \n        :host([xl-6]) {\n            -ms-flex: 0 0 50%;\n            flex: 0 0 50%;\n            max-width: 50%;\n        }\n        \n        :host([xl-7]) {\n            -ms-flex: 0 0 58.333333%;\n            flex: 0 0 58.333333%;\n            max-width: 58.333333%;\n        }\n        \n        :host([xl-8]) {\n            -ms-flex: 0 0 66.666667%;\n            flex: 0 0 66.666667%;\n            max-width: 66.666667%;\n        }\n        \n        :host([xl-9]) {\n            -ms-flex: 0 0 75%;\n            flex: 0 0 75%;\n            max-width: 75%;\n        }\n        \n        :host([xl-10]) {\n            -ms-flex: 0 0 83.333333%;\n            flex: 0 0 83.333333%;\n            max-width: 83.333333%;\n        }\n        \n        :host([xl-11]) {\n            -ms-flex: 0 0 91.666667%;\n            flex: 0 0 91.666667%;\n            max-width: 91.666667%;\n        }\n        \n        :host([xl-12]) {\n            -ms-flex: 0 0 100%;\n            flex: 0 0 100%;\n            max-width: 100%;\n        }\n        \n        :host([order-xl-first]) {\n            -ms-flex-order: -1;\n            order: -1;\n        }\n        \n        :host([order-xl-last]) {\n            -ms-flex-order: 13;\n            order: 13;\n        }\n        \n        :host([order-xl-0]) {\n            -ms-flex-order: 0;\n            order: 0;\n        }\n        \n        :host([order-xl-1]) {\n            -ms-flex-order: 1;\n            order: 1;\n        }\n        \n        :host([order-xl-2]) {\n            -ms-flex-order: 2;\n            order: 2;\n        }\n        \n        :host([order-xl-3]) {\n            -ms-flex-order: 3;\n            order: 3;\n        }\n        \n        :host([order-xl-4]) {\n            -ms-flex-order: 4;\n            order: 4;\n        }\n        \n        :host([order-xl-5]) {\n            -ms-flex-order: 5;\n            order: 5;\n        }\n        \n        :host([order-xl-6]) {\n            -ms-flex-order: 6;\n            order: 6;\n        }\n        \n        :host([order-xl-7]) {\n            -ms-flex-order: 7;\n            order: 7;\n        }\n        \n        :host([order-xl-8]) {\n            -ms-flex-order: 8;\n            order: 8;\n        }\n        \n        :host([order-xl-9]) {\n            -ms-flex-order: 9;\n            order: 9;\n        }\n        \n        :host([order-xl-10]) {\n            -ms-flex-order: 10;\n            order: 10;\n        }\n        \n        :host([order-xl-11]) {\n            -ms-flex-order: 11;\n            order: 11;\n        }\n\n        :host([order-xl-12]) {\n            -ms-flex-order: 12;\n            order: 12;\n        }\n\n        :host([offset-xl-0]) {\n            margin-left: 0;\n        }\n\n        :host([offset-xl-1]) {\n            margin-left: 8.333333%;\n        }\n\n        :host([offset-xl-2]) {\n            margin-left: 16.666667%;\n        }\n\n        :host([offset-xl-3]) {\n            margin-left: 25%;\n        }\n\n        :host([offset-xl-4]) {\n            margin-left: 33.333333%;\n        }\n\n        :host([offset-xl-5]) {\n            margin-left: 41.666667%;\n        }\n\n        :host([offset-xl-6]) {\n            margin-left: 50%;\n        }\n\n        :host([offset-xl-7]) {\n            margin-left: 58.333333%;\n        }\n\n        :host([offset-xl-8]) {\n            margin-left: 66.666667%;\n        }\n\n        :host([offset-xl-9]) {\n            margin-left: 75%;\n        }\n\n        :host([offset-xl-10]) {\n            margin-left: 83.333333%;\n        }\n\n        :host([offset-xl-11]) {\n            margin-left: 91.666667%;\n        }\n    }\n"]);

  _templateObject$b = function _templateObject() {
    return data;
  };

  return data;
}
const BsColumnExtraLargeCss = css(_templateObject$b());

function _templateObject$c() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject$c = function _templateObject() {
    return data;
  };

  return data;
}
class BsColumn extends LitElement {
  static get styles() {
    return [BsContentRebootCss, BsColumnExtraSmallCss, BsColumnSmallCss, BsColumnMediumCss, BsColumnLargeCss, BsColumnExtraLargeCss];
  }

  render() {
    return html(_templateObject$c());
  }

}
window.customElements.define('bs-column', BsColumn);

function _templateObject$d() {
  const data = _taggedTemplateLiteral(["\n    \n    .bg-primary {\n        background-color: #007bff !important;\n    }\n\n    a.bg-primary:hover, \n    a.bg-primary:focus,\n        button.bg-primary:hover,\n        button.bg-primary:focus {\n        background-color: #0062cc !important;\n    }\n\n    .bg-secondary {\n        background-color: #6c757d !important;\n    }\n\n    a.bg-secondary:hover, \n    a.bg-secondary:focus,\n        button.bg-secondary:hover,\n        button.bg-secondary:focus {\n        background-color: #545b62 !important;\n    }\n\n    .bg-success {\n        background-color: #28a745 !important;\n    }\n\n    a.bg-success:hover, \n    a.bg-success:focus,\n        button.bg-success:hover,\n        button.bg-success:focus {\n        background-color: #1e7e34 !important;\n    }\n\n    .bg-info {\n        background-color: #17a2b8 !important;\n    }\n\n    a.bg-info:hover, \n    a.bg-info:focus,\n        button.bg-info:hover,\n        button.bg-info:focus {\n        background-color: #117a8b !important;\n    }\n\n    .bg-warning {\n        background-color: #ffc107 !important;\n    }\n\n    a.bg-warning:hover, \n    a.bg-warning:focus,\n        button.bg-warning:hover,\n        button.bg-warning:focus {\n        background-color: #d39e00 !important;\n    }\n\n    .bg-danger {\n        background-color: #dc3545 !important;\n    }\n\n    a.bg-danger:hover, \n    a.bg-danger:focus,\n        button.bg-danger:hover,\n        button.bg-danger:focus {\n        background-color: #bd2130 !important;\n    }\n\n    .bg-light {\n        background-color: #f8f9fa !important;\n    }\n\n    a.bg-light:hover, \n    a.bg-light:focus,\n        button.bg-light:hover,\n        button.bg-light:focus {\n        background-color: #dae0e5 !important;\n    }\n\n    .bg-dark {\n        background-color: #343a40 !important;\n    }\n\n    a.bg-dark:hover, \n    a.bg-dark:focus,\n        button.bg-dark:hover,\n        button.bg-dark:focus {\n        background-color: #1d2124 !important;\n    }\n\n    .bg-white {\n        background-color: #fff !important;\n    }\n\n    .bg-transparent {\n        background-color: transparent !important;\n    }\n"]);

  _templateObject$d = function _templateObject() {
    return data;
  };

  return data;
}
const BsBackgroundColorsCss = css(_templateObject$d());

function _templateObject$e() {
  const data = _taggedTemplateLiteral(["\n    \n    .border {\n        border: 1px solid #dee2e6 !important;\n    }\n\n    .border-top {\n        border-top: 1px solid #dee2e6 !important;\n    }\n\n    .border-right {\n        border-right: 1px solid #dee2e6 !important;\n    }\n\n    .border-bottom {\n        border-bottom: 1px solid #dee2e6 !important;\n    }\n\n    .border-left {\n        border-left: 1px solid #dee2e6 !important;\n    }\n\n    .border-0 {\n        border: 0 !important;\n    }\n\n    .border-top-0 {\n        border-top: 0 !important;\n    }\n\n    .border-right-0 {\n        border-right: 0 !important;\n    }\n\n    .border-bottom-0 {\n        border-bottom: 0 !important;\n    }\n\n    .border-left-0 {\n        border-left: 0 !important;\n    }\n\n    .border-primary {\n        border-color: #007bff !important;\n    }\n\n    .border-secondary {\n        border-color: #6c757d !important;\n    }\n\n    .border-success {\n        border-color: #28a745 !important;\n    }\n\n    .border-info {\n        border-color: #17a2b8 !important;\n    }\n\n    .border-warning {\n        border-color: #ffc107 !important;\n    }\n\n    .border-danger {\n        border-color: #dc3545 !important;\n    }\n\n    .border-light {\n        border-color: #f8f9fa !important;\n    }\n\n    .border-dark {\n        border-color: #343a40 !important;\n    }\n\n    .border-white {\n        border-color: #fff !important;\n    }\n\n    .rounded {\n        border-radius: 0.25rem !important;\n    }\n\n    .rounded-top {\n        border-top-left-radius: 0.25rem !important;\n        border-top-right-radius: 0.25rem !important;\n    }\n\n    .rounded-right {\n        border-top-right-radius: 0.25rem !important;\n        border-bottom-right-radius: 0.25rem !important;\n    }\n\n    .rounded-bottom {\n        border-bottom-right-radius: 0.25rem !important;\n        border-bottom-left-radius: 0.25rem !important;\n    }\n\n    .rounded-left {\n        border-top-left-radius: 0.25rem !important;\n        border-bottom-left-radius: 0.25rem !important;\n    }\n\n    .rounded-circle {\n        border-radius: 50% !important;\n    }\n\n    .rounded-0 {\n        border-radius: 0 !important;\n    }\n"]);

  _templateObject$e = function _templateObject() {
    return data;
  };

  return data;
}
const BsBordersCss = css(_templateObject$e());

function _templateObject$f() {
  const data = _taggedTemplateLiteral(["\n    \n    .clearfix::after {\n        display: block;\n        clear: both;\n        content: \"\";\n    }\n"]);

  _templateObject$f = function _templateObject() {
    return data;
  };

  return data;
}
const BsClearfixCss = css(_templateObject$f());

function _templateObject$g() {
  const data = _taggedTemplateLiteral(["\n    \n    .d-none {\n        display: none !important;\n    }\n\n    .d-inline {\n        display: inline !important;\n    }\n\n    .d-inline-block {\n        display: inline-block !important;\n    }\n\n    .d-block {\n        display: block !important;\n    }\n\n    .d-table {\n        display: table !important;\n    }\n\n    .d-table-row {\n        display: table-row !important;\n    }\n\n    .d-table-cell {\n        display: table-cell !important;\n    }\n\n    @media (min-width: 576px) {\n        \n        .d-sm-none {\n            display: none !important;\n        }\n        \n        .d-sm-inline {\n            display: inline !important;\n        }\n        \n        .d-sm-inline-block {\n            display: inline-block !important;\n        }\n        \n        .d-sm-block {\n            display: block !important;\n        }\n        \n        .d-sm-table {\n            display: table !important;\n        }\n        \n        .d-sm-table-row {\n            display: table-row !important;\n        }\n        \n        .d-sm-table-cell {\n            display: table-cell !important;\n        }\n    }\n\n    @media (min-width: 768px) {\n        \n        .d-md-none {\n            display: none !important;\n        }\n\n        .d-md-inline {\n            display: inline !important;\n        }\n        \n        .d-md-inline-block {\n            display: inline-block !important;\n        }\n\n        .d-md-block {\n            display: block !important;\n        }\n        \n        .d-md-table {\n            display: table !important;\n        }\n        \n        .d-md-table-row {\n            display: table-row !important;\n        }\n        \n        .d-md-table-cell {\n            display: table-cell !important;\n        }\n    }\n\n    @media (min-width: 992px) {\n        \n        .d-lg-none {\n            display: none !important;\n        }\n        \n        .d-lg-inline {\n            display: inline !important;\n        }\n        \n        .d-lg-inline-block {\n            display: inline-block !important;\n        }\n        \n        .d-lg-block {\n            display: block !important;\n        }\n        \n        .d-lg-table {\n            display: table !important;\n        }\n        \n        .d-lg-table-row {\n            display: table-row !important;\n        }\n        \n        .d-lg-table-cell {\n            display: table-cell !important;\n        }\n    }\n\n    @media (min-width: 1200px) {\n        \n        .d-xl-none {\n            display: none !important;\n        }\n        \n        .d-xl-inline {\n            display: inline !important;\n        }\n        \n        .d-xl-inline-block {\n            display: inline-block !important;\n        }\n        \n        .d-xl-block {\n            display: block !important;\n        }\n        \n        .d-xl-table {\n            display: table !important;\n        }\n        \n        .d-xl-table-row {\n            display: table-row !important;\n        }\n        \n        .d-xl-table-cell {\n            display: table-cell !important;\n        }\n    }\n\n    @media print {\n    \n        .d-print-none {\n            display: none !important;\n        }\n        \n        .d-print-inline {\n            display: inline !important;\n        }\n        \n        .d-print-inline-block {\n            display: inline-block !important;\n        }\n        \n        .d-print-block {\n            display: block !important;\n        }\n        \n        .d-print-table {\n            display: table !important;\n        }\n        \n        .d-print-table-row {\n            display: table-row !important;\n        }\n        \n        .d-print-table-cell {\n            display: table-cell !important;\n        }\n    }\n"]);

  _templateObject$g = function _templateObject() {
    return data;
  };

  return data;
}
const BsDisplayCss = css(_templateObject$g());

function _templateObject$h() {
  const data = _taggedTemplateLiteral(["\n    \n    .embed-responsive {\n         position: relative;\n         display: block;\n         width: 100%;\n         padding: 0;\n         overflow: hidden;\n       }\n\n       .embed-responsive::before {\n         display: block;\n         content: \"\";\n       }\n\n       .embed-responsive .embed-responsive-item,\n       .embed-responsive iframe,\n       .embed-responsive embed,\n       .embed-responsive object,\n       .embed-responsive video {\n         position: absolute;\n         top: 0;\n         bottom: 0;\n         left: 0;\n         width: 100%;\n         height: 100%;\n         border: 0;\n       }\n\n       .embed-responsive-21by9::before {\n         padding-top: 42.857143%;\n       }\n\n       .embed-responsive-16by9::before {\n         padding-top: 56.25%;\n       }\n\n       .embed-responsive-4by3::before {\n         padding-top: 75%;\n       }\n\n       .embed-responsive-1by1::before {\n         padding-top: 100%;\n       }\n"]);

  _templateObject$h = function _templateObject() {
    return data;
  };

  return data;
}
const BsEmbeddedCss = css(_templateObject$h());

function _templateObject$i() {
  const data = _taggedTemplateLiteral(["\n    \n    .float-left {\n        float: left !important;\n    }\n\n    .float-right {\n        float: right !important;\n    }\n\n    .float-none {\n        float: none !important;\n    }\n\n    @media (min-width: 576px) {\n        \n        .float-sm-left {\n            float: left !important;\n        }\n        \n        .float-sm-right {\n            float: right !important;\n        }\n\n        .float-sm-none {\n            float: none !important;\n        }\n    }\n\n    @media (min-width: 768px) {\n      \n        .float-md-left {\n            float: left !important;\n        }\n        \n        .float-md-right {\n            float: right !important;\n        }\n\n        .float-md-none {\n            float: none !important;\n        }\n    }\n\n    @media (min-width: 992px) {\n    \n        .float-lg-left {\n            float: left !important;\n        }\n\n        .float-lg-right {\n            float: right !important;\n        }\n        \n        .float-lg-none {\n            float: none !important;\n        }\n    }\n\n    @media (min-width: 1200px) {\n    \n        .float-xl-left {\n            float: left !important;\n        }\n\n        .float-xl-right {\n            float: right !important;\n        }\n\n        .float-xl-none {\n            float: none !important;\n        }\n    }\n"]);

  _templateObject$i = function _templateObject() {
    return data;
  };

  return data;
}
const BsFloatCss = css(_templateObject$i());

function _templateObject$j() {
  const data = _taggedTemplateLiteral(["\n    \n    .position-static {\n        position: static !important;\n    }\n\n    .position-relative {\n        position: relative !important;\n    }\n\n    .position-absolute {\n        position: absolute !important;\n    }\n\n    .position-fixed {\n        position: fixed !important;\n    }\n\n    .position-sticky {\n        position: -webkit-sticky !important;\n        position: sticky !important;\n    }\n\n    .fixed-top {\n        position: fixed;\n        top: 0;\n        right: 0;\n        left: 0;\n        z-index: 1030;\n    }\n\n    .fixed-bottom {\n        position: fixed;\n        right: 0;\n        bottom: 0;\n        left: 0;\n        z-index: 1030;\n    }\n\n    @supports ((position: -webkit-sticky) or (position: sticky)) {\n        .sticky-top {\n            position: -webkit-sticky;\n            position: sticky;\n            top: 0;\n            z-index: 1020;\n        }\n    }\n"]);

  _templateObject$j = function _templateObject() {
    return data;
  };

  return data;
}
const BsPositionCss = css(_templateObject$j());

function _templateObject$k() {
  const data = _taggedTemplateLiteral(["\n    \n    .sr-only {\n        position: absolute;\n        width: 1px;\n        height: 1px;\n        padding: 0;\n        overflow: hidden;\n        clip: rect(0, 0, 0, 0);\n        white-space: nowrap;\n        border: 0;\n    }\n\n    .sr-only-focusable:active, \n    .sr-only-focusable:focus {\n        position: static;\n        width: auto;\n        height: auto;\n        overflow: visible;\n        clip: auto;\n        white-space: normal;\n    }\n"]);

  _templateObject$k = function _templateObject() {
    return data;
  };

  return data;
}
const BsScreenreaderCss = css(_templateObject$k());

function _templateObject$l() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([w-25]), .w-25 {\n        width: 25% !important;\n    }\n\n    :host([w-50]), .w-50 {\n        width: 50% !important;\n    }\n\n    :host([w-75]), .w-75 {\n        width: 75% !important;\n    }\n\n    :host([w-100]), .w-100 {\n        width: 100% !important;\n    }\n\n    :host([w-auto]), .w-auto {\n        width: auto !important;\n    }\n\n    :host([h-25]), .h-25 {\n        height: 25% !important;\n    }\n\n    :host([h-50]), .h-50 {\n        height: 50% !important;\n    }\n\n    :host([h-75]), .h-75 {\n        height: 75% !important;\n    }\n\n    :host([h-100]), .h-100 {\n        height: 100% !important;\n    }\n\n    :host([h-auto]), .h-auto {\n        height: auto !important;\n    }\n\n    :host([mw-100]), .mw-100 {\n        max-width: 100% !important;\n    }\n\n    :host([mh-100]), .mh-100 {\n        max-height: 100% !important;\n    }\n"]);

  _templateObject$l = function _templateObject() {
    return data;
  };

  return data;
}
const BsSizingCss = css(_templateObject$l());

function _templateObject$m() {
  const data = _taggedTemplateLiteral(["\n    \n    .m-0 {\n        margin: 0 !important;\n    }\n\n    .mt-0, .my-0 {\n        margin-top: 0 !important;\n    }\n\n    .mr-0, .mx-0 {\n        margin-right: 0 !important;\n    }\n\n    .mb-0, .my-0 {\n        margin-bottom: 0 !important;\n    }\n\n    .ml-0, .mx-0 {\n        margin-left: 0 !important;\n    }\n\n    .m-1 {\n        margin: 0.25rem !important;\n    }\n\n    .mt-1, .my-1 {\n        margin-top: 0.25rem !important;\n    }\n\n    .mr-1, .mx-1 {\n        margin-right: 0.25rem !important;\n    }\n\n    .mb-1, .my-1 {\n        margin-bottom: 0.25rem !important;\n    }\n\n    .ml-1, .mx-1 {\n        margin-left: 0.25rem !important;\n    }\n\n    .m-2 {\n        margin: 0.5rem !important;\n    }\n\n    .mt-2, .my-2 {\n        margin-top: 0.5rem !important;\n    }\n\n    .mr-2, .mx-2 {\n        margin-right: 0.5rem !important;\n    }\n\n    .mb-2, .my-2 {\n        margin-bottom: 0.5rem !important;\n    }\n\n    .ml-2, .mx-2 {\n        margin-left: 0.5rem !important;\n    }\n\n    .m-3 {\n        margin: 1rem !important;\n    }\n\n    .mt-3, .my-3 {\n        margin-top: 1rem !important;\n    }\n\n    .mr-3, .mx-3 {\n        margin-right: 1rem !important;\n    }\n\n    .mb-3, .my-3 {\n        margin-bottom: 1rem !important;\n    }\n\n    .ml-3, .mx-3 {\n        margin-left: 1rem !important;\n    }\n\n    .m-4 {\n        margin: 1.5rem !important;\n    }\n\n    .mt-4, .my-4 {\n        margin-top: 1.5rem !important;\n    }\n\n    .mr-4, .mx-4 {\n        margin-right: 1.5rem !important;\n    }\n\n    .mb-4, .my-4 {\n        margin-bottom: 1.5rem !important;\n    }\n\n    .ml-4, .mx-4 {\n        margin-left: 1.5rem !important;\n    }\n\n    .m-5 {\n        margin: 3rem !important;\n    }\n\n    .mt-5, .my-5 {\n        margin-top: 3rem !important;\n    }\n\n    .mr-5, .mx-5 {\n        margin-right: 3rem !important;\n    }\n\n    .mb-5, .my-5 {\n        margin-bottom: 3rem !important;\n    }\n\n    .ml-5, .mx-5 {\n        margin-left: 3rem !important;\n    }\n\n    .p-0 {\n        padding: 0 !important;\n    }\n\n    .pt-0, .py-0 {\n        padding-top: 0 !important;\n    }\n\n    .pr-0, .px-0 {\n        padding-right: 0 !important;\n    }\n\n    .pb-0, .py-0 {\n        padding-bottom: 0 !important;\n    }\n\n    .pl-0, .px-0 {\n        padding-left: 0 !important;\n    }\n\n    .p-1 {\n        padding: 0.25rem !important;\n    }\n\n    .pt-1, .py-1 {\n        padding-top: 0.25rem !important;\n    }\n\n    .pr-1, .px-1 {\n        padding-right: 0.25rem !important;\n    }\n\n    .pb-1, .py-1 {\n        padding-bottom: 0.25rem !important;\n    }\n\n    .pl-1, .px-1 {\n        padding-left: 0.25rem !important;\n    }\n\n    .p-2 {\n     padding: 0.5rem !important;\n    }\n\n    .pt-2, .py-2 {\n        padding-top: 0.5rem !important;\n    }\n\n    .pr-2, .px-2 {\n        padding-right: 0.5rem !important;\n    }\n\n    .pb-2, .py-2 {\n        padding-bottom: 0.5rem !important;\n    }\n\n    .pl-2, .px-2 {\n        padding-left: 0.5rem !important;\n    }\n\n    .p-3 {\n        padding: 1rem !important;\n    }\n\n    .pt-3, .py-3 {\n        padding-top: 1rem !important;\n    }\n\n    .pr-3, .px-3 {\n        padding-right: 1rem !important;\n    }\n\n    .pb-3, .py-3 {\n        padding-bottom: 1rem !important;\n    }\n\n    .pl-3, .px-3 {\n        padding-left: 1rem !important;\n    }\n\n    .p-4 {\n        padding: 1.5rem !important;\n    }\n\n    .pt-4, .py-4 {\n        padding-top: 1.5rem !important;\n    }\n\n    .pr-4, .px-4 {\n        padding-right: 1.5rem !important;\n    }\n\n    .pb-4, .py-4 {\n        padding-bottom: 1.5rem !important;\n    }\n\n    .pl-4, .px-4 {\n        padding-left: 1.5rem !important;\n    }\n\n    .p-5 {\n        padding: 3rem !important;\n    }\n\n    .pt-5, .py-5 {\n        padding-top: 3rem !important;\n    }\n\n    .pr-5, .px-5 {\n        padding-right: 3rem !important;\n    }\n\n    .pb-5, .py-5 {\n        padding-bottom: 3rem !important;\n    }\n\n    .pl-5, .px-5 {\n        padding-left: 3rem !important;\n    }\n\n    .m-auto {\n        margin: auto !important;\n    }\n\n    .mt-auto, .my-auto {\n        margin-top: auto !important;\n    }\n\n    .mr-auto, .mx-auto {\n        margin-right: auto !important;\n    }\n\n    .mb-auto, .my-auto {\n        margin-bottom: auto !important;\n    }\n\n    .ml-auto, .mx-auto {\n        margin-left: auto !important;\n    }\n\n    @media (min-width: 576px) {\n     .m-sm-0 {\n       margin: 0 !important;\n     }\n     .mt-sm-0,\n     .my-sm-0 {\n       margin-top: 0 !important;\n     }\n     .mr-sm-0,\n     .mx-sm-0 {\n       margin-right: 0 !important;\n     }\n     .mb-sm-0,\n     .my-sm-0 {\n       margin-bottom: 0 !important;\n     }\n     .ml-sm-0,\n     .mx-sm-0 {\n       margin-left: 0 !important;\n     }\n     .m-sm-1 {\n       margin: 0.25rem !important;\n     }\n     .mt-sm-1,\n     .my-sm-1 {\n       margin-top: 0.25rem !important;\n     }\n     .mr-sm-1,\n     .mx-sm-1 {\n       margin-right: 0.25rem !important;\n     }\n     .mb-sm-1,\n     .my-sm-1 {\n       margin-bottom: 0.25rem !important;\n     }\n     .ml-sm-1,\n     .mx-sm-1 {\n       margin-left: 0.25rem !important;\n     }\n     .m-sm-2 {\n       margin: 0.5rem !important;\n     }\n     .mt-sm-2,\n     .my-sm-2 {\n       margin-top: 0.5rem !important;\n     }\n     .mr-sm-2,\n     .mx-sm-2 {\n       margin-right: 0.5rem !important;\n     }\n     .mb-sm-2,\n     .my-sm-2 {\n       margin-bottom: 0.5rem !important;\n     }\n     .ml-sm-2,\n     .mx-sm-2 {\n       margin-left: 0.5rem !important;\n     }\n     .m-sm-3 {\n       margin: 1rem !important;\n     }\n     .mt-sm-3,\n     .my-sm-3 {\n       margin-top: 1rem !important;\n     }\n     .mr-sm-3,\n     .mx-sm-3 {\n       margin-right: 1rem !important;\n     }\n     .mb-sm-3,\n     .my-sm-3 {\n       margin-bottom: 1rem !important;\n     }\n     .ml-sm-3,\n     .mx-sm-3 {\n       margin-left: 1rem !important;\n     }\n     .m-sm-4 {\n       margin: 1.5rem !important;\n     }\n     .mt-sm-4,\n     .my-sm-4 {\n       margin-top: 1.5rem !important;\n     }\n     .mr-sm-4,\n     .mx-sm-4 {\n       margin-right: 1.5rem !important;\n     }\n     .mb-sm-4,\n     .my-sm-4 {\n       margin-bottom: 1.5rem !important;\n     }\n     .ml-sm-4,\n     .mx-sm-4 {\n       margin-left: 1.5rem !important;\n     }\n     .m-sm-5 {\n       margin: 3rem !important;\n     }\n     .mt-sm-5,\n     .my-sm-5 {\n       margin-top: 3rem !important;\n     }\n     .mr-sm-5,\n     .mx-sm-5 {\n       margin-right: 3rem !important;\n     }\n     .mb-sm-5,\n     .my-sm-5 {\n       margin-bottom: 3rem !important;\n     }\n     .ml-sm-5,\n     .mx-sm-5 {\n       margin-left: 3rem !important;\n     }\n     .p-sm-0 {\n       padding: 0 !important;\n     }\n     .pt-sm-0,\n     .py-sm-0 {\n       padding-top: 0 !important;\n     }\n     .pr-sm-0,\n     .px-sm-0 {\n       padding-right: 0 !important;\n     }\n     .pb-sm-0,\n     .py-sm-0 {\n       padding-bottom: 0 !important;\n     }\n     .pl-sm-0,\n     .px-sm-0 {\n       padding-left: 0 !important;\n     }\n     .p-sm-1 {\n       padding: 0.25rem !important;\n     }\n     .pt-sm-1,\n     .py-sm-1 {\n       padding-top: 0.25rem !important;\n     }\n     .pr-sm-1,\n     .px-sm-1 {\n       padding-right: 0.25rem !important;\n     }\n     .pb-sm-1,\n     .py-sm-1 {\n       padding-bottom: 0.25rem !important;\n     }\n     .pl-sm-1,\n     .px-sm-1 {\n       padding-left: 0.25rem !important;\n     }\n     .p-sm-2 {\n       padding: 0.5rem !important;\n     }\n     .pt-sm-2,\n     .py-sm-2 {\n       padding-top: 0.5rem !important;\n     }\n     .pr-sm-2,\n     .px-sm-2 {\n       padding-right: 0.5rem !important;\n     }\n     .pb-sm-2,\n     .py-sm-2 {\n       padding-bottom: 0.5rem !important;\n     }\n     .pl-sm-2,\n     .px-sm-2 {\n       padding-left: 0.5rem !important;\n     }\n     .p-sm-3 {\n       padding: 1rem !important;\n     }\n     .pt-sm-3,\n     .py-sm-3 {\n       padding-top: 1rem !important;\n     }\n     .pr-sm-3,\n     .px-sm-3 {\n       padding-right: 1rem !important;\n     }\n     .pb-sm-3,\n     .py-sm-3 {\n       padding-bottom: 1rem !important;\n     }\n     .pl-sm-3,\n     .px-sm-3 {\n       padding-left: 1rem !important;\n     }\n     .p-sm-4 {\n       padding: 1.5rem !important;\n     }\n     .pt-sm-4,\n     .py-sm-4 {\n       padding-top: 1.5rem !important;\n     }\n     .pr-sm-4,\n     .px-sm-4 {\n       padding-right: 1.5rem !important;\n     }\n     .pb-sm-4,\n     .py-sm-4 {\n       padding-bottom: 1.5rem !important;\n     }\n     .pl-sm-4,\n     .px-sm-4 {\n       padding-left: 1.5rem !important;\n     }\n     .p-sm-5 {\n       padding: 3rem !important;\n     }\n     .pt-sm-5,\n     .py-sm-5 {\n       padding-top: 3rem !important;\n     }\n     .pr-sm-5,\n     .px-sm-5 {\n       padding-right: 3rem !important;\n     }\n     .pb-sm-5,\n     .py-sm-5 {\n       padding-bottom: 3rem !important;\n     }\n     .pl-sm-5,\n     .px-sm-5 {\n       padding-left: 3rem !important;\n     }\n     .m-sm-auto {\n       margin: auto !important;\n     }\n     .mt-sm-auto,\n     .my-sm-auto {\n       margin-top: auto !important;\n     }\n     .mr-sm-auto,\n     .mx-sm-auto {\n       margin-right: auto !important;\n     }\n     .mb-sm-auto,\n     .my-sm-auto {\n       margin-bottom: auto !important;\n     }\n     .ml-sm-auto,\n     .mx-sm-auto {\n       margin-left: auto !important;\n     }\n    }\n\n    @media (min-width: 768px) {\n     .m-md-0 {\n       margin: 0 !important;\n     }\n     .mt-md-0,\n     .my-md-0 {\n       margin-top: 0 !important;\n     }\n     .mr-md-0,\n     .mx-md-0 {\n       margin-right: 0 !important;\n     }\n     .mb-md-0,\n     .my-md-0 {\n       margin-bottom: 0 !important;\n     }\n     .ml-md-0,\n     .mx-md-0 {\n       margin-left: 0 !important;\n     }\n     .m-md-1 {\n       margin: 0.25rem !important;\n     }\n     .mt-md-1,\n     .my-md-1 {\n       margin-top: 0.25rem !important;\n     }\n     .mr-md-1,\n     .mx-md-1 {\n       margin-right: 0.25rem !important;\n     }\n     .mb-md-1,\n     .my-md-1 {\n       margin-bottom: 0.25rem !important;\n     }\n     .ml-md-1,\n     .mx-md-1 {\n       margin-left: 0.25rem !important;\n     }\n     .m-md-2 {\n       margin: 0.5rem !important;\n     }\n     .mt-md-2,\n     .my-md-2 {\n       margin-top: 0.5rem !important;\n     }\n     .mr-md-2,\n     .mx-md-2 {\n       margin-right: 0.5rem !important;\n     }\n     .mb-md-2,\n     .my-md-2 {\n       margin-bottom: 0.5rem !important;\n     }\n     .ml-md-2,\n     .mx-md-2 {\n       margin-left: 0.5rem !important;\n     }\n     .m-md-3 {\n       margin: 1rem !important;\n     }\n     .mt-md-3,\n     .my-md-3 {\n       margin-top: 1rem !important;\n     }\n     .mr-md-3,\n     .mx-md-3 {\n       margin-right: 1rem !important;\n     }\n     .mb-md-3,\n     .my-md-3 {\n       margin-bottom: 1rem !important;\n     }\n     .ml-md-3,\n     .mx-md-3 {\n       margin-left: 1rem !important;\n     }\n     .m-md-4 {\n       margin: 1.5rem !important;\n     }\n     .mt-md-4,\n     .my-md-4 {\n       margin-top: 1.5rem !important;\n     }\n     .mr-md-4,\n     .mx-md-4 {\n       margin-right: 1.5rem !important;\n     }\n     .mb-md-4,\n     .my-md-4 {\n       margin-bottom: 1.5rem !important;\n     }\n     .ml-md-4,\n     .mx-md-4 {\n       margin-left: 1.5rem !important;\n     }\n     .m-md-5 {\n       margin: 3rem !important;\n     }\n     .mt-md-5,\n     .my-md-5 {\n       margin-top: 3rem !important;\n     }\n     .mr-md-5,\n     .mx-md-5 {\n       margin-right: 3rem !important;\n     }\n     .mb-md-5,\n     .my-md-5 {\n       margin-bottom: 3rem !important;\n     }\n     .ml-md-5,\n     .mx-md-5 {\n       margin-left: 3rem !important;\n     }\n     .p-md-0 {\n       padding: 0 !important;\n     }\n     .pt-md-0,\n     .py-md-0 {\n       padding-top: 0 !important;\n     }\n     .pr-md-0,\n     .px-md-0 {\n       padding-right: 0 !important;\n     }\n     .pb-md-0,\n     .py-md-0 {\n       padding-bottom: 0 !important;\n     }\n     .pl-md-0,\n     .px-md-0 {\n       padding-left: 0 !important;\n     }\n     .p-md-1 {\n       padding: 0.25rem !important;\n     }\n     .pt-md-1,\n     .py-md-1 {\n       padding-top: 0.25rem !important;\n     }\n     .pr-md-1,\n     .px-md-1 {\n       padding-right: 0.25rem !important;\n     }\n     .pb-md-1,\n     .py-md-1 {\n       padding-bottom: 0.25rem !important;\n     }\n     .pl-md-1,\n     .px-md-1 {\n       padding-left: 0.25rem !important;\n     }\n     .p-md-2 {\n       padding: 0.5rem !important;\n     }\n     .pt-md-2,\n     .py-md-2 {\n       padding-top: 0.5rem !important;\n     }\n     .pr-md-2,\n     .px-md-2 {\n       padding-right: 0.5rem !important;\n     }\n     .pb-md-2,\n     .py-md-2 {\n       padding-bottom: 0.5rem !important;\n     }\n     .pl-md-2,\n     .px-md-2 {\n       padding-left: 0.5rem !important;\n     }\n     .p-md-3 {\n       padding: 1rem !important;\n     }\n     .pt-md-3,\n     .py-md-3 {\n       padding-top: 1rem !important;\n     }\n     .pr-md-3,\n     .px-md-3 {\n       padding-right: 1rem !important;\n     }\n     .pb-md-3,\n     .py-md-3 {\n       padding-bottom: 1rem !important;\n     }\n     .pl-md-3,\n     .px-md-3 {\n       padding-left: 1rem !important;\n     }\n     .p-md-4 {\n       padding: 1.5rem !important;\n     }\n     .pt-md-4,\n     .py-md-4 {\n       padding-top: 1.5rem !important;\n     }\n     .pr-md-4,\n     .px-md-4 {\n       padding-right: 1.5rem !important;\n     }\n     .pb-md-4,\n     .py-md-4 {\n       padding-bottom: 1.5rem !important;\n     }\n     .pl-md-4,\n     .px-md-4 {\n       padding-left: 1.5rem !important;\n     }\n     .p-md-5 {\n       padding: 3rem !important;\n     }\n     .pt-md-5,\n     .py-md-5 {\n       padding-top: 3rem !important;\n     }\n     .pr-md-5,\n     .px-md-5 {\n       padding-right: 3rem !important;\n     }\n     .pb-md-5,\n     .py-md-5 {\n       padding-bottom: 3rem !important;\n     }\n     .pl-md-5,\n     .px-md-5 {\n       padding-left: 3rem !important;\n     }\n     .m-md-auto {\n       margin: auto !important;\n     }\n     .mt-md-auto,\n     .my-md-auto {\n       margin-top: auto !important;\n     }\n     .mr-md-auto,\n     .mx-md-auto {\n       margin-right: auto !important;\n     }\n     .mb-md-auto,\n     .my-md-auto {\n       margin-bottom: auto !important;\n     }\n     .ml-md-auto,\n     .mx-md-auto {\n       margin-left: auto !important;\n     }\n    }\n\n    @media (min-width: 992px) {\n     .m-lg-0 {\n       margin: 0 !important;\n     }\n     .mt-lg-0,\n     .my-lg-0 {\n       margin-top: 0 !important;\n     }\n     .mr-lg-0,\n     .mx-lg-0 {\n       margin-right: 0 !important;\n     }\n     .mb-lg-0,\n     .my-lg-0 {\n       margin-bottom: 0 !important;\n     }\n     .ml-lg-0,\n     .mx-lg-0 {\n       margin-left: 0 !important;\n     }\n     .m-lg-1 {\n       margin: 0.25rem !important;\n     }\n     .mt-lg-1,\n     .my-lg-1 {\n       margin-top: 0.25rem !important;\n     }\n     .mr-lg-1,\n     .mx-lg-1 {\n       margin-right: 0.25rem !important;\n     }\n     .mb-lg-1,\n     .my-lg-1 {\n       margin-bottom: 0.25rem !important;\n     }\n     .ml-lg-1,\n     .mx-lg-1 {\n       margin-left: 0.25rem !important;\n     }\n     .m-lg-2 {\n       margin: 0.5rem !important;\n     }\n     .mt-lg-2,\n     .my-lg-2 {\n       margin-top: 0.5rem !important;\n     }\n     .mr-lg-2,\n     .mx-lg-2 {\n       margin-right: 0.5rem !important;\n     }\n     .mb-lg-2,\n     .my-lg-2 {\n       margin-bottom: 0.5rem !important;\n     }\n     .ml-lg-2,\n     .mx-lg-2 {\n       margin-left: 0.5rem !important;\n     }\n     .m-lg-3 {\n       margin: 1rem !important;\n     }\n     .mt-lg-3,\n     .my-lg-3 {\n       margin-top: 1rem !important;\n     }\n     .mr-lg-3,\n     .mx-lg-3 {\n       margin-right: 1rem !important;\n     }\n     .mb-lg-3,\n     .my-lg-3 {\n       margin-bottom: 1rem !important;\n     }\n     .ml-lg-3,\n     .mx-lg-3 {\n       margin-left: 1rem !important;\n     }\n     .m-lg-4 {\n       margin: 1.5rem !important;\n     }\n     .mt-lg-4,\n     .my-lg-4 {\n       margin-top: 1.5rem !important;\n     }\n     .mr-lg-4,\n     .mx-lg-4 {\n       margin-right: 1.5rem !important;\n     }\n     .mb-lg-4,\n     .my-lg-4 {\n       margin-bottom: 1.5rem !important;\n     }\n     .ml-lg-4,\n     .mx-lg-4 {\n       margin-left: 1.5rem !important;\n     }\n     .m-lg-5 {\n       margin: 3rem !important;\n     }\n     .mt-lg-5,\n     .my-lg-5 {\n       margin-top: 3rem !important;\n     }\n     .mr-lg-5,\n     .mx-lg-5 {\n       margin-right: 3rem !important;\n     }\n     .mb-lg-5,\n     .my-lg-5 {\n       margin-bottom: 3rem !important;\n     }\n     .ml-lg-5,\n     .mx-lg-5 {\n       margin-left: 3rem !important;\n     }\n     .p-lg-0 {\n       padding: 0 !important;\n     }\n     .pt-lg-0,\n     .py-lg-0 {\n       padding-top: 0 !important;\n     }\n     .pr-lg-0,\n     .px-lg-0 {\n       padding-right: 0 !important;\n     }\n     .pb-lg-0,\n     .py-lg-0 {\n       padding-bottom: 0 !important;\n     }\n     .pl-lg-0,\n     .px-lg-0 {\n       padding-left: 0 !important;\n     }\n     .p-lg-1 {\n       padding: 0.25rem !important;\n     }\n     .pt-lg-1,\n     .py-lg-1 {\n       padding-top: 0.25rem !important;\n     }\n     .pr-lg-1,\n     .px-lg-1 {\n       padding-right: 0.25rem !important;\n     }\n     .pb-lg-1,\n     .py-lg-1 {\n       padding-bottom: 0.25rem !important;\n     }\n     .pl-lg-1,\n     .px-lg-1 {\n       padding-left: 0.25rem !important;\n     }\n     .p-lg-2 {\n       padding: 0.5rem !important;\n     }\n     .pt-lg-2,\n     .py-lg-2 {\n       padding-top: 0.5rem !important;\n     }\n     .pr-lg-2,\n     .px-lg-2 {\n       padding-right: 0.5rem !important;\n     }\n     .pb-lg-2,\n     .py-lg-2 {\n       padding-bottom: 0.5rem !important;\n     }\n     .pl-lg-2,\n     .px-lg-2 {\n       padding-left: 0.5rem !important;\n     }\n     .p-lg-3 {\n       padding: 1rem !important;\n     }\n     .pt-lg-3,\n     .py-lg-3 {\n       padding-top: 1rem !important;\n     }\n     .pr-lg-3,\n     .px-lg-3 {\n       padding-right: 1rem !important;\n     }\n     .pb-lg-3,\n     .py-lg-3 {\n       padding-bottom: 1rem !important;\n     }\n     .pl-lg-3,\n     .px-lg-3 {\n       padding-left: 1rem !important;\n     }\n     .p-lg-4 {\n       padding: 1.5rem !important;\n     }\n     .pt-lg-4,\n     .py-lg-4 {\n       padding-top: 1.5rem !important;\n     }\n     .pr-lg-4,\n     .px-lg-4 {\n       padding-right: 1.5rem !important;\n     }\n     .pb-lg-4,\n     .py-lg-4 {\n       padding-bottom: 1.5rem !important;\n     }\n     .pl-lg-4,\n     .px-lg-4 {\n       padding-left: 1.5rem !important;\n     }\n     .p-lg-5 {\n       padding: 3rem !important;\n     }\n     .pt-lg-5,\n     .py-lg-5 {\n       padding-top: 3rem !important;\n     }\n     .pr-lg-5,\n     .px-lg-5 {\n       padding-right: 3rem !important;\n     }\n     .pb-lg-5,\n     .py-lg-5 {\n       padding-bottom: 3rem !important;\n     }\n     .pl-lg-5,\n     .px-lg-5 {\n       padding-left: 3rem !important;\n     }\n     .m-lg-auto {\n       margin: auto !important;\n     }\n     .mt-lg-auto,\n     .my-lg-auto {\n       margin-top: auto !important;\n     }\n     .mr-lg-auto,\n     .mx-lg-auto {\n       margin-right: auto !important;\n     }\n     .mb-lg-auto,\n     .my-lg-auto {\n       margin-bottom: auto !important;\n     }\n     .ml-lg-auto,\n     .mx-lg-auto {\n       margin-left: auto !important;\n     }\n    }\n\n    @media (min-width: 1200px) {\n     .m-xl-0 {\n       margin: 0 !important;\n     }\n     .mt-xl-0,\n     .my-xl-0 {\n       margin-top: 0 !important;\n     }\n     .mr-xl-0,\n     .mx-xl-0 {\n       margin-right: 0 !important;\n     }\n     .mb-xl-0,\n     .my-xl-0 {\n       margin-bottom: 0 !important;\n     }\n     .ml-xl-0,\n     .mx-xl-0 {\n       margin-left: 0 !important;\n     }\n     .m-xl-1 {\n       margin: 0.25rem !important;\n     }\n     .mt-xl-1,\n     .my-xl-1 {\n       margin-top: 0.25rem !important;\n     }\n     .mr-xl-1,\n     .mx-xl-1 {\n       margin-right: 0.25rem !important;\n     }\n     .mb-xl-1,\n     .my-xl-1 {\n       margin-bottom: 0.25rem !important;\n     }\n     .ml-xl-1,\n     .mx-xl-1 {\n       margin-left: 0.25rem !important;\n     }\n     .m-xl-2 {\n       margin: 0.5rem !important;\n     }\n     .mt-xl-2,\n     .my-xl-2 {\n       margin-top: 0.5rem !important;\n     }\n     .mr-xl-2,\n     .mx-xl-2 {\n       margin-right: 0.5rem !important;\n     }\n     .mb-xl-2,\n     .my-xl-2 {\n       margin-bottom: 0.5rem !important;\n     }\n     .ml-xl-2,\n     .mx-xl-2 {\n       margin-left: 0.5rem !important;\n     }\n     .m-xl-3 {\n       margin: 1rem !important;\n     }\n     .mt-xl-3,\n     .my-xl-3 {\n       margin-top: 1rem !important;\n     }\n     .mr-xl-3,\n     .mx-xl-3 {\n       margin-right: 1rem !important;\n     }\n     .mb-xl-3,\n     .my-xl-3 {\n       margin-bottom: 1rem !important;\n     }\n     .ml-xl-3,\n     .mx-xl-3 {\n       margin-left: 1rem !important;\n     }\n     .m-xl-4 {\n       margin: 1.5rem !important;\n     }\n     .mt-xl-4,\n     .my-xl-4 {\n       margin-top: 1.5rem !important;\n     }\n     .mr-xl-4,\n     .mx-xl-4 {\n       margin-right: 1.5rem !important;\n     }\n     .mb-xl-4,\n     .my-xl-4 {\n       margin-bottom: 1.5rem !important;\n     }\n     .ml-xl-4,\n     .mx-xl-4 {\n       margin-left: 1.5rem !important;\n     }\n     .m-xl-5 {\n       margin: 3rem !important;\n     }\n     .mt-xl-5,\n     .my-xl-5 {\n       margin-top: 3rem !important;\n     }\n     .mr-xl-5,\n     .mx-xl-5 {\n       margin-right: 3rem !important;\n     }\n     .mb-xl-5,\n     .my-xl-5 {\n       margin-bottom: 3rem !important;\n     }\n     .ml-xl-5,\n     .mx-xl-5 {\n       margin-left: 3rem !important;\n     }\n     .p-xl-0 {\n       padding: 0 !important;\n     }\n     .pt-xl-0,\n     .py-xl-0 {\n       padding-top: 0 !important;\n     }\n     .pr-xl-0,\n     .px-xl-0 {\n       padding-right: 0 !important;\n     }\n     .pb-xl-0,\n     .py-xl-0 {\n       padding-bottom: 0 !important;\n     }\n     .pl-xl-0,\n     .px-xl-0 {\n       padding-left: 0 !important;\n     }\n     .p-xl-1 {\n       padding: 0.25rem !important;\n     }\n     .pt-xl-1,\n     .py-xl-1 {\n       padding-top: 0.25rem !important;\n     }\n     .pr-xl-1,\n     .px-xl-1 {\n       padding-right: 0.25rem !important;\n     }\n     .pb-xl-1,\n     .py-xl-1 {\n       padding-bottom: 0.25rem !important;\n     }\n     .pl-xl-1,\n     .px-xl-1 {\n       padding-left: 0.25rem !important;\n     }\n     .p-xl-2 {\n       padding: 0.5rem !important;\n     }\n     .pt-xl-2,\n     .py-xl-2 {\n       padding-top: 0.5rem !important;\n     }\n     .pr-xl-2,\n     .px-xl-2 {\n       padding-right: 0.5rem !important;\n     }\n     .pb-xl-2,\n     .py-xl-2 {\n       padding-bottom: 0.5rem !important;\n     }\n     .pl-xl-2,\n     .px-xl-2 {\n       padding-left: 0.5rem !important;\n     }\n     .p-xl-3 {\n       padding: 1rem !important;\n     }\n     .pt-xl-3,\n     .py-xl-3 {\n       padding-top: 1rem !important;\n     }\n     .pr-xl-3,\n     .px-xl-3 {\n       padding-right: 1rem !important;\n     }\n     .pb-xl-3,\n     .py-xl-3 {\n       padding-bottom: 1rem !important;\n     }\n     .pl-xl-3,\n     .px-xl-3 {\n       padding-left: 1rem !important;\n     }\n     .p-xl-4 {\n       padding: 1.5rem !important;\n     }\n     .pt-xl-4,\n     .py-xl-4 {\n       padding-top: 1.5rem !important;\n     }\n     .pr-xl-4,\n     .px-xl-4 {\n       padding-right: 1.5rem !important;\n     }\n     .pb-xl-4,\n     .py-xl-4 {\n       padding-bottom: 1.5rem !important;\n     }\n     .pl-xl-4,\n     .px-xl-4 {\n       padding-left: 1.5rem !important;\n     }\n     .p-xl-5 {\n       padding: 3rem !important;\n     }\n     .pt-xl-5,\n     .py-xl-5 {\n       padding-top: 3rem !important;\n     }\n     .pr-xl-5,\n     .px-xl-5 {\n       padding-right: 3rem !important;\n     }\n     .pb-xl-5,\n     .py-xl-5 {\n       padding-bottom: 3rem !important;\n     }\n     .pl-xl-5,\n     .px-xl-5 {\n       padding-left: 3rem !important;\n     }\n     .m-xl-auto {\n       margin: auto !important;\n     }\n     .mt-xl-auto,\n     .my-xl-auto {\n       margin-top: auto !important;\n     }\n     .mr-xl-auto,\n     .mx-xl-auto {\n       margin-right: auto !important;\n     }\n     .mb-xl-auto,\n     .my-xl-auto {\n       margin-bottom: auto !important;\n     }\n     .ml-xl-auto,\n     .mx-xl-auto {\n       margin-left: auto !important;\n     }\n    }\n"]);

  _templateObject$m = function _templateObject() {
    return data;
  };

  return data;
}
const BsSpacingCss = css(_templateObject$m());

function _templateObject$n() {
  const data = _taggedTemplateLiteral(["\n    \n    .text-white {\n        color: #fff !important;\n    }\n\n    .text-primary {\n        color: #007bff !important;\n    }\n\n    a.text-primary:hover, a.text-primary:focus {\n        color: #0062cc !important;\n    }\n\n    .text-secondary {\n        color: #6c757d !important;\n    }\n\n    a.text-secondary:hover, a.text-secondary:focus {\n        color: #545b62 !important;\n    }\n\n    .text-success {\n        color: #28a745 !important;\n    }\n\n    a.text-success:hover, a.text-success:focus {\n        color: #1e7e34 !important;\n    }\n\n    .text-info {\n        color: #17a2b8 !important;\n    }\n\n    a.text-info:hover, a.text-info:focus {\n        color: #117a8b !important;\n    }\n\n    .text-warning {\n        color: #ffc107 !important;\n    }\n\n    a.text-warning:hover, a.text-warning:focus {\n        color: #d39e00 !important;\n    }\n\n    .text-danger {\n        color: #dc3545 !important;\n    }\n\n    a.text-danger:hover, a.text-danger:focus {\n        color: #bd2130 !important;\n    }\n\n    .text-light {\n        color: #f8f9fa !important;\n    }\n\n    a.text-light:hover, a.text-light:focus {\n        color: #dae0e5 !important;\n    }\n\n    .text-dark {\n        color: #343a40 !important;\n    }\n\n    a.text-dark:hover, a.text-dark:focus {\n        color: #1d2124 !important;\n    }\n\n    .text-body {\n        color: #212529 !important;\n    }\n\n    .text-muted {\n        color: #6c757d !important;\n    }\n\n    .text-black-50 {\n        color: rgba(0, 0, 0, 0.5) !important;\n    }\n\n    .text-white-50 {\n        color: rgba(255, 255, 255, 0.5) !important;\n    }\n\n    .text-hide {\n        font: 0/0 a;\n        color: transparent;\n        text-shadow: none;\n        background-color: transparent;\n        border: 0;\n    }\n"]);

  _templateObject$n = function _templateObject() {
    return data;
  };

  return data;
}
const BsTextColorCss = css(_templateObject$n());

function _templateObject$o() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([text-monospace]), .text-monospace {\n        font-family: SFMono-Regular, Menlo, Monaco, Consolas, \"Liberation Mono\", \"Courier New\", monospace;\n    }\n\n    :host([text-justify]), .text-justify {\n        text-align: justify !important;\n    }\n    \n    :host([text-nowrap]), .text-nowrap {\n        white-space: nowrap !important;\n    }\n\n    :host([text-truncate]), .text-truncate {\n        overflow: hidden;\n        text-overflow: ellipsis;\n        white-space: nowrap;\n    }\n\n    :host([text-left]), .text-left {\n        text-align: left !important;\n    }\n\n    :host([text-right]), .text-right {\n        text-align: right !important;\n    }\n\n    :host([text-center]), .text-center {\n        text-align: center !important;\n    }\n\n    @media (min-width: 576px) {\n        \n        :host([text-sm-left]), .text-sm-left {\n            text-align: left !important;\n        }\n\n        :host([text-sm-right]), .text-sm-right {\n            text-align: right !important;\n        }\n\n        :host([text-sm-center]), .text-sm-center {\n            text-align: center !important;\n        }\n    }\n\n    @media (min-width: 768px) {\n\n        :host([text-md-left]), .text-md-left {\n            text-align: left !important;\n        }\n\n        :host([text-md-right]), .text-md-right {\n            text-align: right !important;\n        }\n\n        :host([text-md-center]), .text-md-center {\n            text-align: center !important;\n        }\n    }\n\n    @media (min-width: 992px) {\n        \n        :host([text-lg-left]), .text-lg-left {\n            text-align: left !important;\n        }\n\n        :host([text-lg-right]), .text-lg-right {\n            text-align: right !important;\n        }\n\n        :host([text-lg-center]), .text-lg-center {\n            text-align: center !important;\n        }\n    }\n\n    @media (min-width: 1200px) {\n\n        :host([text-xl-left]), .text-xl-left {\n            text-align: left !important;\n        }\n\n        :host([text-xl-right]), .text-xl-right {\n            text-align: right !important;\n        }\n\n        :host([text-xl-center]), .text-xl-center {\n            text-align: center !important;\n        }\n    }\n\n    :host([text-lowercase]), .text-lowercase {\n        text-transform: lowercase !important;\n    }\n\n    :host([text-uppercase]), .text-uppercase {\n        text-transform: uppercase !important;\n    }\n\n    :host([text-capitalize]), .text-capitalize {\n        text-transform: capitalize !important;\n    }\n\n    :host([font-weight-light]), .font-weight-light {\n        font-weight: 300 !important;\n    }\n\n    :host([font-weight-normal]), .font-weight-normal {\n        font-weight: 400 !important;\n    }\n\n    :host([font-weight-bold]), .font-weight-bold {\n        font-weight: 700 !important;\n    }\n\n    :host([font-weight-bold]), .font-italic {\n        font-style: italic !important;\n    }\n"]);

  _templateObject$o = function _templateObject() {
    return data;
  };

  return data;
}
const BsTextCss = css(_templateObject$o());

function _templateObject$p() {
  const data = _taggedTemplateLiteral(["\n\n    .align-baseline {\n        vertical-align: baseline !important;\n    }\n\n    .align-top {\n        vertical-align: top !important;\n    }\n\n    .align-middle {\n        vertical-align: middle !important;\n    }\n\n    .align-bottom {\n        vertical-align: bottom !important;\n    }\n\n    .align-text-bottom {\n        vertical-align: text-bottom !important;\n    }\n\n    .align-text-top {\n        vertical-align: text-top !important;\n    }\n"]);

  _templateObject$p = function _templateObject() {
    return data;
  };

  return data;
}
const BsVerticalAlignCss = css(_templateObject$p());

function _templateObject$q() {
  const data = _taggedTemplateLiteral(["\n    \n    .visible {\n        visibility: visible !important;\n    }\n\n    .invisible {\n        visibility: hidden !important;\n    }\n"]);

  _templateObject$q = function _templateObject() {
    return data;
  };

  return data;
}
const BsVisibilityCss = css(_templateObject$q());

function _templateObject$r() {
  const data = _taggedTemplateLiteral(["\n    \n    .align-content-start {\n        -ms-flex-line-pack: start !important;\n        align-content: flex-start !important;\n    }\n\n    .align-content-end {\n        -ms-flex-line-pack: end !important;\n        align-content: flex-end !important;\n    }\n\n    .align-content-center {\n        -ms-flex-line-pack: center !important;\n        align-content: center !important;\n    }\n\n    .align-content-between {\n        -ms-flex-line-pack: justify !important;\n        align-content: space-between !important;\n    }\n\n    .align-content-around {\n        -ms-flex-line-pack: distribute !important;\n        align-content: space-around !important;\n    }\n\n    .align-content-stretch {\n        -ms-flex-line-pack: stretch !important;\n        align-content: stretch !important;\n    }\n    \n    @media (min-width: 576px) {\n        \n        .align-content-sm-start {\n            -ms-flex-line-pack: start !important;\n            align-content: flex-start !important;\n        }\n\n        .align-content-sm-end {\n            -ms-flex-line-pack: end !important;\n            align-content: flex-end !important;\n        }\n\n        .align-content-sm-center {\n            -ms-flex-line-pack: center !important;\n            align-content: center !important;\n        }\n\n        .align-content-sm-between {\n            -ms-flex-line-pack: justify !important;\n            align-content: space-between !important;\n        }\n\n        .align-content-sm-around {\n            -ms-flex-line-pack: distribute !important;\n            align-content: space-around !important;\n        }\n\n        .align-content-sm-stretch {\n            -ms-flex-line-pack: stretch !important;\n            align-content: stretch !important;\n        }\n    }\n    \n    @media (min-width: 768px) {\n        \n        .align-content-md-start {\n            -ms-flex-line-pack: start !important;\n            align-content: flex-start !important;\n        }\n\n        .align-content-md-end {\n            -ms-flex-line-pack: end !important;\n            align-content: flex-end !important;\n        }\n\n        .align-content-md-center {\n            -ms-flex-line-pack: center !important;\n            align-content: center !important;\n        }\n\n        .align-content-md-between {\n            -ms-flex-line-pack: justify !important;\n            align-content: space-between !important;\n        }\n\n        .align-content-md-around {\n            -ms-flex-line-pack: distribute !important;\n            align-content: space-around !important;\n        }\n\n        .align-content-md-stretch {\n            -ms-flex-line-pack: stretch !important;\n            align-content: stretch !important;\n        }\n    }\n\n    @media (min-width: 992px) {\n        \n        .align-content-lg-start {\n            -ms-flex-line-pack: start !important;\n            align-content: flex-start !important;\n        }\n\n        .align-content-lg-end {\n            -ms-flex-line-pack: end !important;\n            align-content: flex-end !important;\n        }\n\n        .align-content-lg-center {\n            -ms-flex-line-pack: center !important;\n            align-content: center !important;\n        }\n\n        .align-content-lg-between {\n            -ms-flex-line-pack: justify !important;\n            align-content: space-between !important;\n        }\n\n        .align-content-lg-around {\n            -ms-flex-line-pack: distribute !important;\n            align-content: space-around !important;\n        }\n\n        .align-content-lg-stretch {\n            -ms-flex-line-pack: stretch !important;\n            align-content: stretch !important;\n        }\n    }\n\n    @media (min-width: 1200px) {\n    \n        .align-content-xl-start {\n            -ms-flex-line-pack: start !important;\n            align-content: flex-start !important;\n        }\n\n        .align-content-xl-end {\n            -ms-flex-line-pack: end !important;\n            align-content: flex-end !important;\n        }\n\n        .align-content-xl-center {\n            -ms-flex-line-pack: center !important;\n            align-content: center !important;\n        }\n\n        .align-content-xl-between {\n            -ms-flex-line-pack: justify !important;\n            align-content: space-between !important;\n        }\n\n        .align-content-xl-around {\n            -ms-flex-line-pack: distribute !important;\n            align-content: space-around !important;\n        }\n\n        .align-content-xl-stretch {\n            -ms-flex-line-pack: stretch !important;\n            align-content: stretch !important;\n        }\n    }\n"]);

  _templateObject$r = function _templateObject() {
    return data;
  };

  return data;
}
const BsFlexAlignContentCss = css(_templateObject$r());

function _templateObject$s() {
  const data = _taggedTemplateLiteral(["\n    \n    .align-items-start {\n        -ms-flex-align: start !important;\n        align-items: flex-start !important;\n    }\n    \n    .align-items-end {\n        -ms-flex-align: end !important;\n        align-items: flex-end !important;\n    }\n    \n    .align-items-center {\n        -ms-flex-align: center !important;\n        align-items: center !important;\n    }\n\n    .align-items-baseline {\n        -ms-flex-align: baseline !important;\n        align-items: baseline !important;\n    }\n\n    .align-items-stretch {\n        -ms-flex-align: stretch !important;\n        align-items: stretch !important;\n    }\n\n    @media (min-width: 576px) {\n        \n        .align-items-sm-start {\n            -ms-flex-align: start !important;\n            align-items: flex-start !important;\n        }\n\n        .align-items-sm-end {\n            -ms-flex-align: end !important;\n            align-items: flex-end !important;\n        }\n\n        .align-items-sm-center {\n            -ms-flex-align: center !important;\n            align-items: center !important;\n        }\n\n        .align-items-sm-baseline {\n            -ms-flex-align: baseline !important;\n            align-items: baseline !important;\n        }\n\n        .align-items-sm-stretch {\n            -ms-flex-align: stretch !important;\n            align-items: stretch !important;\n        }\n    }\n\n    @media (min-width: 768px) {\n        \n        .align-items-md-start {\n            -ms-flex-align: start !important;\n            align-items: flex-start !important;\n        }\n\n        .align-items-md-end {\n            -ms-flex-align: end !important;\n            align-items: flex-end !important;\n        }\n\n        .align-items-md-center {\n            -ms-flex-align: center !important;\n            align-items: center !important;\n        }\n        \n        .align-items-md-baseline {\n            -ms-flex-align: baseline !important;\n            align-items: baseline !important;\n        }\n        \n        .align-items-md-stretch {\n            -ms-flex-align: stretch !important;\n            align-items: stretch !important;\n        }\n    }\n\n    @media (min-width: 992px) {\n        \n        .align-items-lg-start {\n            -ms-flex-align: start !important;\n            align-items: flex-start !important;\n        }\n        \n        .align-items-lg-end {\n            -ms-flex-align: end !important;\n            align-items: flex-end !important;\n        }\n\n        .align-items-lg-center {\n            align-items: center !important;\n        }\n\n        .align-items-lg-baseline {\n            -ms-flex-align: baseline !important;\n            align-items: baseline !important;\n        }\n        \n        .align-items-lg-stretch {\n            -ms-flex-align: stretch !important;\n            align-items: stretch !important;\n        }\n    }\n\n    @media (min-width: 1200px) {\n        \n        .align-items-xl-start {\n            -ms-flex-align: start !important;\n            align-items: flex-start !important;\n        }\n        \n        .align-items-xl-end {\n            -ms-flex-align: end !important;\n            align-items: flex-end !important;\n        }\n\n        .align-items-xl-center {\n            -ms-flex-align: center !important;\n            align-items: center !important;\n        }\n        \n        .align-items-xl-baseline {\n            -ms-flex-align: baseline !important;\n            align-items: baseline !important;\n        }\n        \n        .align-items-xl-stretch {\n            -ms-flex-align: stretch !important;\n            align-items: stretch !important;\n        }\n    }\n"]);

  _templateObject$s = function _templateObject() {
    return data;
  };

  return data;
}
const BsFlexAlignItemsCss = css(_templateObject$s());

function _templateObject$t() {
  const data = _taggedTemplateLiteral(["\n    \n    .align-self-auto {\n        -ms-flex-item-align: auto !important;\n        align-self: auto !important;\n    }\n\n    .align-self-start {\n        -ms-flex-item-align: start !important;\n        align-self: flex-start !important;\n    }\n\n    .align-self-end {\n        -ms-flex-item-align: end !important;\n        align-self: flex-end !important;\n    }\n\n    .align-self-center {\n        -ms-flex-item-align: center !important;\n        align-self: center !important;\n    }\n\n    .align-self-baseline {\n        -ms-flex-item-align: baseline !important;\n        align-self: baseline !important;\n    }\n\n    .align-self-stretch {\n        -ms-flex-item-align: stretch !important;\n        align-self: stretch !important;\n    }\n\n    @media (min-width: 576px) {\n        \n        .align-self-sm-auto {\n            -ms-flex-item-align: auto !important;\n            align-self: auto !important;\n        }\n\n        .align-self-sm-start {\n            -ms-flex-item-align: start !important;\n            align-self: flex-start !important;\n        }\n\n        .align-self-sm-end {\n            -ms-flex-item-align: end !important;\n            align-self: flex-end !important;\n        }\n\n        .align-self-sm-center {\n            -ms-flex-item-align: center !important;\n            align-self: center !important;\n        }\n\n        .align-self-sm-baseline {\n            -ms-flex-item-align: baseline !important;\n            align-self: baseline !important;\n        }\n\n        .align-self-sm-stretch {\n            -ms-flex-item-align: stretch !important;\n            align-self: stretch !important;\n        }\n    }\n\n    @media (min-width: 768px) {\n        \n        .align-self-md-auto {\n            -ms-flex-item-align: auto !important;\n            align-self: auto !important;\n        }\n\n        .align-self-md-start {\n            -ms-flex-item-align: start !important;\n            align-self: flex-start !important;\n        }\n\n        .align-self-md-end {\n            -ms-flex-item-align: end !important;\n            align-self: flex-end !important;\n        }\n\n        .align-self-md-center {\n            -ms-flex-item-align: center !important;\n            align-self: center !important;\n        }\n\n        .align-self-md-baseline {\n            -ms-flex-item-align: baseline !important;\n            align-self: baseline !important;\n        }\n\n        .align-self-md-stretch {\n            -ms-flex-item-align: stretch !important;\n            align-self: stretch !important;\n        }\n    }\n\n    @media (min-width: 992px) {\n        \n        .align-self-lg-auto {\n            -ms-flex-item-align: auto !important;\n            align-self: auto !important;\n        }\n\n        .align-self-lg-start {\n            -ms-flex-item-align: start !important;\n            align-self: flex-start !important;\n        }\n\n        .align-self-lg-end {\n            -ms-flex-item-align: end !important;\n            align-self: flex-end !important;\n        }\n\n        .align-self-lg-center {\n            -ms-flex-item-align: center !important;\n            align-self: center !important;\n        }\n\n        .align-self-lg-baseline {\n            -ms-flex-item-align: baseline !important;\n            align-self: baseline !important;\n        }\n\n        .align-self-lg-stretch {\n            -ms-flex-item-align: stretch !important;\n            align-self: stretch !important;\n        }\n    }\n\n    @media (min-width: 1200px) {\n        \n        .align-self-xl-auto {\n            -ms-flex-item-align: auto !important;\n            align-self: auto !important;\n        }\n\n        .align-self-xl-start {\n            -ms-flex-item-align: start !important;\n            align-self: flex-start !important;\n        }\n\n        .align-self-xl-end {\n            -ms-flex-item-align: end !important;\n            align-self: flex-end !important;\n        }\n\n        .align-self-xl-center {\n            -ms-flex-item-align: center !important;\n            align-self: center !important;\n        }\n\n        .align-self-xl-baseline {\n            -ms-flex-item-align: baseline !important;\n            align-self: baseline !important;\n        }\n\n        .align-self-xl-stretch {\n            -ms-flex-item-align: stretch !important;\n            align-self: stretch !important;\n        }\n    }\n"]);

  _templateObject$t = function _templateObject() {
    return data;
  };

  return data;
}
const BsFlexAlignSelfCss = css(_templateObject$t());

function _templateObject$u() {
  const data = _taggedTemplateLiteral(["\n    \n    .flex-row {\n        -ms-flex-direction: row !important;\n        flex-direction: row !important;\n    }\n\n    .flex-column {\n        -ms-flex-direction: column !important;\n        flex-direction: column !important;\n    }\n\n    .flex-row-reverse {\n        -ms-flex-direction: row-reverse !important;\n        flex-direction: row-reverse !important;\n    }\n\n    .flex-column-reverse {\n        -ms-flex-direction: column-reverse !important;\n        flex-direction: column-reverse !important;\n    }\n\n    @media (min-width: 576px) {\n    \n        .flex-sm-row {\n            -ms-flex-direction: row !important;\n            flex-direction: row !important;\n        }\n\n        .flex-sm-column {\n            -ms-flex-direction: column !important;\n            flex-direction: column !important;\n        }\n\n        .flex-sm-row-reverse {\n            -ms-flex-direction: row-reverse !important;\n            flex-direction: row-reverse !important;\n        }\n         \n        .flex-sm-column-reverse {\n            -ms-flex-direction: column-reverse !important;\n            flex-direction: column-reverse !important;\n        }\n    }\n\n    @media (min-width: 768px) {\n        \n        .flex-md-row {\n            -ms-flex-direction: row !important;\n            flex-direction: row !important;\n        }\n\n        .flex-md-column {\n            -ms-flex-direction: column !important;\n            flex-direction: column !important;\n        }\n\n        .flex-md-row-reverse {\n            -ms-flex-direction: row-reverse !important;\n            flex-direction: row-reverse !important;\n        }\n\n        .flex-md-column-reverse {\n            -ms-flex-direction: column-reverse !important;\n            flex-direction: column-reverse !important;\n        }\n    }\n\n    @media (min-width: 992px) {\n        \n        .flex-lg-row {\n            -ms-flex-direction: row !important;\n            flex-direction: row !important;\n        }\n\n        .flex-lg-column {\n            -ms-flex-direction: column !important;\n            flex-direction: column !important;\n        }\n\n        .flex-lg-row-reverse {\n            -ms-flex-direction: row-reverse !important;\n            flex-direction: row-reverse !important;\n        }\n\n        .flex-lg-column-reverse {\n            -ms-flex-direction: column-reverse !important;\n            flex-direction: column-reverse !important;\n        }\n    }\n\n    @media (min-width: 1200px) {\n        \n        .flex-xl-row {\n            -ms-flex-direction: row !important;\n            flex-direction: row !important;\n        }\n\n        .flex-xl-column {\n            -ms-flex-direction: column !important;\n            flex-direction: column !important;\n        }\n\n        .flex-xl-row-reverse {\n            -ms-flex-direction: row-reverse !important;\n            flex-direction: row-reverse !important;\n        }\n\n        .flex-xl-column-reverse {\n            -ms-flex-direction: column-reverse !important;\n            flex-direction: column-reverse !important;\n        }\n    }\n"]);

  _templateObject$u = function _templateObject() {
    return data;
  };

  return data;
}
const BsFlexDirectionCss = css(_templateObject$u());

function _templateObject$v() {
  const data = _taggedTemplateLiteral(["\n    \n    .d-flex {\n        display: -ms-flexbox !important;\n        display: flex !important;\n    }\n\n    .d-inline-flex {\n        display: -ms-inline-flexbox !important;\n        display: inline-flex !important;\n    }\n\n    @media (min-width: 576px) {\n\n        .d-sm-flex {\n            display: -ms-flexbox !important;\n            display: flex !important;\n        }\n\n        .d-sm-inline-flex {\n            display: -ms-inline-flexbox !important;\n            display: inline-flex !important;\n        }\n    }\n\n    @media (min-width: 768px) {\n\n        .d-md-flex {\n            display: -ms-flexbox !important;\n            display: flex !important;\n        }\n\n        .d-md-inline-flex {\n            display: -ms-inline-flexbox !important;\n            display: inline-flex !important;\n        }\n    }\n\n    @media (min-width: 992px) {\n\n        .d-lg-flex {\n            display: -ms-flexbox !important;\n            display: flex !important;\n        }\n\n        .d-lg-inline-flex {\n            display: -ms-inline-flexbox !important;\n            display: inline-flex !important;\n        }\n    }\n\n    @media (min-width: 1200px) {\n\n        .d-xl-flex {\n            display: -ms-flexbox !important;\n            display: flex !important;\n        }\n\n        .d-xl-inline-flex {\n            display: -ms-inline-flexbox !important;\n            display: inline-flex !important;\n        }\n    }\n\n    @media print {\n\n        .d-print-flex {\n            display: -ms-flexbox !important;\n            display: flex !important;\n        }\n\n        .d-print-inline-flex {\n            display: -ms-inline-flexbox !important;\n            display: inline-flex !important;\n        }\n    }\n"]);

  _templateObject$v = function _templateObject() {
    return data;
  };

  return data;
}
const BsFlexDisplayCss = css(_templateObject$v());

function _templateObject$w() {
  const data = _taggedTemplateLiteral(["\n\n    .justify-content-start {\n        -ms-flex-pack: start !important;\n        justify-content: flex-start !important;\n    }\n\n    .justify-content-end {\n        -ms-flex-pack: end !important;\n        justify-content: flex-end !important;\n    }\n\n    .justify-content-center {\n        -ms-flex-pack: center !important;\n        justify-content: center !important;\n    }\n\n    .justify-content-between {\n        -ms-flex-pack: justify !important;\n        justify-content: space-between !important;\n    }\n\n    .justify-content-around {\n        -ms-flex-pack: distribute !important;\n        justify-content: space-around !important;\n    }\n       \n    @media (min-width: 576px) {\n        \n        .justify-content-sm-start {\n            -ms-flex-pack: start !important;\n            justify-content: flex-start !important;\n        }\n\n        .justify-content-sm-end {\n            -ms-flex-pack: end !important;\n            justify-content: flex-end !important;\n        }\n\n        .justify-content-sm-center {\n            -ms-flex-pack: center !important;\n            justify-content: center !important;\n        }\n\n        .justify-content-sm-between {\n            -ms-flex-pack: justify !important;\n            justify-content: space-between !important;\n        }\n\n        .justify-content-sm-around {\n            -ms-flex-pack: distribute !important;\n            justify-content: space-around !important;\n        }\n    }\n\n    @media (min-width: 768px) {\n        \n        .justify-content-md-start {\n            -ms-flex-pack: start !important;\n            justify-content: flex-start !important;\n        }\n\n        .justify-content-md-end {\n            -ms-flex-pack: end !important;\n            justify-content: flex-end !important;\n        }\n\n        .justify-content-md-center {\n            -ms-flex-pack: center !important;\n            justify-content: center !important;\n        }\n\n        .justify-content-md-between {\n            -ms-flex-pack: justify !important;\n            justify-content: space-between !important;\n        }\n\n        .justify-content-md-around {\n            -ms-flex-pack: distribute !important;\n            justify-content: space-around !important;\n        }\n    }\n\n    @media (min-width: 992px) {\n        \n        .justify-content-lg-start {\n            -ms-flex-pack: start !important;\n            justify-content: flex-start !important;\n        }\n\n        .justify-content-lg-end {\n            -ms-flex-pack: end !important;\n            justify-content: flex-end !important;\n        }\n\n        .justify-content-lg-center {\n            -ms-flex-pack: center !important;\n            justify-content: center !important;\n        }\n\n        .justify-content-lg-between {\n            -ms-flex-pack: justify !important;\n            justify-content: space-between !important;\n        }\n\n        .justify-content-lg-around {\n            -ms-flex-pack: distribute !important;\n            justify-content: space-around !important;\n        }\n    }\n\n    @media (min-width: 1200px) {\n        \n        .justify-content-xl-start {\n            -ms-flex-pack: start !important;\n            justify-content: flex-start !important;\n        }\n\n        .justify-content-xl-end {\n            -ms-flex-pack: end !important;\n            justify-content: flex-end !important;\n        }\n\n        .justify-content-xl-center {\n            -ms-flex-pack: center !important;\n            justify-content: center !important;\n        }\n\n        .justify-content-xl-between {\n            -ms-flex-pack: justify !important;\n            justify-content: space-between !important;\n        }\n\n        .justify-content-xl-around {\n            -ms-flex-pack: distribute !important;\n            justify-content: space-around !important;\n        }\n    }\n"]);

  _templateObject$w = function _templateObject() {
    return data;
  };

  return data;
}
const BsFlexJustifyCss = css(_templateObject$w());

function _templateObject$x() {
  const data = _taggedTemplateLiteral(["\n    \n    .offset-1 {\n        margin-left: 8.333333%;\n    }\n\n    .offset-2 {\n        margin-left: 16.666667%;\n    }\n\n    .offset-3 {\n        margin-left: 25%;\n    }\n\n    .offset-4 {\n        margin-left: 33.333333%;\n    }\n\n    .offset-5 {\n        margin-left: 41.666667%;\n    }\n\n    .offset-6 {\n        margin-left: 50%;\n    }\n\n    .offset-7 {\n        margin-left: 58.333333%;\n    }\n\n    .offset-8 {\n        margin-left: 66.666667%;\n    }\n\n    .offset-9 {\n        margin-left: 75%;\n    }\n\n    .offset-10 {\n        margin-left: 83.333333%;\n    }\n\n    .offset-11 {\n        margin-left: 91.666667%;\n    }\n    \n    @media (min-width: 576px) {\n        \n        .offset-sm-0 {\n            margin-left: 0;\n        }\n\n        .offset-sm-1 {\n            margin-left: 8.333333%;\n        }\n\n        .offset-sm-2 {\n            margin-left: 16.666667%;\n        }\n\n        .offset-sm-3 {\n            margin-left: 25%;\n        }\n\n        .offset-sm-4 {\n            margin-left: 33.333333%;\n        }\n\n        .offset-sm-5 {\n            margin-left: 41.666667%;\n        }\n\n        .offset-sm-6 {\n            margin-left: 50%;\n        }\n\n        .offset-sm-7 {\n            margin-left: 58.333333%;\n        }\n\n        .offset-sm-8 {\n            margin-left: 66.666667%;\n        }\n\n        .offset-sm-9 {\n            margin-left: 75%;\n        }\n\n        .offset-sm-10 {\n            margin-left: 83.333333%;\n        }\n\n        .offset-sm-11 {\n            margin-left: 91.666667%;\n        }\n    }\n\n    @media (min-width: 768px) {\n        \n        .offset-md-0 {\n            margin-left: 0;\n        }\n\n        .offset-md-1 {\n            margin-left: 8.333333%;\n        }\n\n        .offset-md-2 {\n            margin-left: 16.666667%;\n        }\n\n        .offset-md-3 {\n            margin-left: 25%;\n        }\n\n        .offset-md-4 {\n            margin-left: 33.333333%;\n        }\n\n        .offset-md-5 {\n            margin-left: 41.666667%;\n        }\n\n        .offset-md-6 {\n            margin-left: 50%;\n        }\n\n        .offset-md-7 {\n            margin-left: 58.333333%;\n        }\n\n        .offset-md-8 {\n            margin-left: 66.666667%;\n        }\n\n        .offset-md-9 {\n            margin-left: 75%;\n        }\n\n        .offset-md-10 {\n            margin-left: 83.333333%;\n        }\n\n        .offset-md-11 {\n            margin-left: 91.666667%;\n        }\n    }\n    \n    @media (min-width: 992px) {\n        \n        .offset-lg-0 {\n            margin-left: 0;\n        }\n\n        .offset-lg-1 {\n            margin-left: 8.333333%;\n        }\n\n        .offset-lg-2 {\n            margin-left: 16.666667%;\n        }\n\n        .offset-lg-3 {\n            margin-left: 25%;\n        }\n\n        .offset-lg-4 {\n            margin-left: 33.333333%;\n        }\n\n        .offset-lg-5 {\n            margin-left: 41.666667%;\n        }\n\n        .offset-lg-6 {\n            margin-left: 50%;\n        }\n\n        .offset-lg-7 {\n            margin-left: 58.333333%;\n        }\n\n        .offset-lg-8 {\n            margin-left: 66.666667%;\n        }\n\n        .offset-lg-9 {\n            margin-left: 75%;\n        }\n\n        .offset-lg-10 {\n            margin-left: 83.333333%;\n        }\n\n        .offset-lg-11 {\n            margin-left: 91.666667%;\n        }\n    }\n    \n    @media (min-width: 1200px) {\n        \n        .offset-xl-0 {\n            margin-left: 0;\n        }\n\n        .offset-xl-1 {\n            margin-left: 8.333333%;\n        }\n\n        .offset-xl-2 {\n            margin-left: 16.666667%;\n        }\n\n        .offset-xl-3 {\n            margin-left: 25%;\n        }\n\n        .offset-xl-4 {\n            margin-left: 33.333333%;\n        }\n\n        .offset-xl-5 {\n            margin-left: 41.666667%;\n        }\n\n        .offset-xl-6 {\n            margin-left: 50%;\n        }\n\n        .offset-xl-7 {\n            margin-left: 58.333333%;\n        }\n\n        .offset-xl-8 {\n            margin-left: 66.666667%;\n        }\n\n        .offset-xl-9 {\n            margin-left: 75%;\n        }\n\n        .offset-xl-10 {\n            margin-left: 83.333333%;\n        }\n\n        .offset-xl-11 {\n            margin-left: 91.666667%;\n        }\n    }\n"]);

  _templateObject$x = function _templateObject() {
    return data;
  };

  return data;
}
const BsFlexOffsetCss = css(_templateObject$x());

function _templateObject$y() {
  const data = _taggedTemplateLiteral(["\n    \n    .order-first {\n        -webkit-box-ordinal-group: 0;\n        -ms-flex-order: -1;\n        order: -1;\n    }\n\n    .order-last {\n        -webkit-box-ordinal-group: 14;\n        -ms-flex-order: 13;\n        order: 13;\n    }\n\n    .order-0 {\n        -webkit-box-ordinal-group: 1;\n        -ms-flex-order: 0;\n        order: 0;\n    }\n\n    .order-1 {\n        -webkit-box-ordinal-group: 2;\n        -ms-flex-order: 1;\n        order: 1;\n    }\n\n    .order-2 {\n        -webkit-box-ordinal-group: 3;\n        -ms-flex-order: 2;\n        order: 2;\n    }\n\n    .order-3 {\n        -webkit-box-ordinal-group: 4;\n        -ms-flex-order: 3;\n        order: 3;\n    }\n\n    .order-4 {\n        -webkit-box-ordinal-group: 5;\n        -ms-flex-order: 4;\n        order: 4;\n    }\n\n    .order-5 {\n        -webkit-box-ordinal-group: 6;\n        -ms-flex-order: 5;\n        order: 5;\n    }\n\n    .order-6 {\n        -webkit-box-ordinal-group: 7;\n        -ms-flex-order: 6;\n        order: 6;\n    }\n\n    .order-7 {\n        -webkit-box-ordinal-group: 8;\n        -ms-flex-order: 7;\n        order: 7;\n    }\n\n    .order-8 {\n        -webkit-box-ordinal-group: 9;\n        -ms-flex-order: 8;\n        order: 8;\n    }\n\n    .order-9 {\n        -webkit-box-ordinal-group: 10;\n        -ms-flex-order: 9;\n        order: 9;\n    }\n\n    .order-10 {\n        -webkit-box-ordinal-group: 11;\n        -ms-flex-order: 10;\n        order: 10;\n    }\n\n    .order-11 {\n        -webkit-box-ordinal-group: 12;\n        -ms-flex-order: 11;\n        order: 11;\n    }\n\n    .order-12 {\n        -webkit-box-ordinal-group: 13;\n        -ms-flex-order: 12;\n        order: 12;\n    }\n\n    @media (min-width: 576px) {\n        \n        .order-sm-first {\n            -webkit-box-ordinal-group: 0;\n            -ms-flex-order: -1;\n            order: -1;\n        }\n\n        .order-sm-last {\n            -webkit-box-ordinal-group: 14;\n            -ms-flex-order: 13;\n            order: 13;\n        }\n\n        .order-sm-0 {\n            -webkit-box-ordinal-group: 1;\n            -ms-flex-order: 0;\n            order: 0;\n        }\n\n        .order-sm-1 {\n            -webkit-box-ordinal-group: 2;\n            -ms-flex-order: 1;\n            order: 1;\n        }\n\n        .order-sm-2 {\n            -webkit-box-ordinal-group: 3;\n            -ms-flex-order: 2;\n            order: 2;\n        }\n\n        .order-sm-3 {\n            -webkit-box-ordinal-group: 4;\n            -ms-flex-order: 3;\n            order: 3;\n        }\n\n        .order-sm-4 {\n            -webkit-box-ordinal-group: 5;\n            -ms-flex-order: 4;\n            order: 4;\n        }\n\n        .order-sm-5 {\n            -webkit-box-ordinal-group: 6;\n            -ms-flex-order: 5;\n            order: 5;\n        }\n\n        .order-sm-6 {\n            -webkit-box-ordinal-group: 7;\n            -ms-flex-order: 6;\n            order: 6;\n        }\n\n        .order-sm-7 {\n            -webkit-box-ordinal-group: 8;\n            -ms-flex-order: 7;\n            order: 7;\n        }\n\n        .order-sm-8 {\n            -webkit-box-ordinal-group: 9;\n            -ms-flex-order: 8;\n            order: 8;\n        }\n\n        .order-sm-9 {\n            -webkit-box-ordinal-group: 10;\n            -ms-flex-order: 9;\n            order: 9;\n        }\n\n        .order-sm-10 {\n            -webkit-box-ordinal-group: 11;\n            -ms-flex-order: 10;\n            order: 10;\n        }\n\n        .order-sm-11 {\n            -webkit-box-ordinal-group: 12;\n            -ms-flex-order: 11;\n            order: 11;\n        }\n\n        .order-sm-12 {\n            -webkit-box-ordinal-group: 13;\n            -ms-flex-order: 12;\n            order: 12;\n        }\n    }\n\n    @media (min-width: 768px) {\n        \n        .order-md-first {\n            -webkit-box-ordinal-group: 0;\n            -ms-flex-order: -1;\n            order: -1;\n        }\n\n        .order-md-last {\n            -webkit-box-ordinal-group: 14;\n            -ms-flex-order: 13;\n            order: 13;\n        }\n\n        .order-md-0 {\n            -webkit-box-ordinal-group: 1;\n            -ms-flex-order: 0;\n            order: 0;\n        }\n\n        .order-md-1 {\n            -webkit-box-ordinal-group: 2;\n            -ms-flex-order: 1;\n            order: 1;\n        }\n\n        .order-md-2 {\n            -webkit-box-ordinal-group: 3;\n            -ms-flex-order: 2;\n            order: 2;\n        }\n\n        .order-md-3 {\n            -webkit-box-ordinal-group: 4;\n            -ms-flex-order: 3;\n            order: 3;\n        }\n\n        .order-md-4 {\n            -webkit-box-ordinal-group: 5;\n            -ms-flex-order: 4;\n            order: 4;\n        }\n\n        .order-md-5 {\n            -webkit-box-ordinal-group: 6;\n            -ms-flex-order: 5;\n            order: 5;\n        }\n\n        .order-md-6 {\n            -webkit-box-ordinal-group: 7;\n            -ms-flex-order: 6;\n            order: 6;\n        }\n\n        .order-md-7 {\n            -webkit-box-ordinal-group: 8;\n            -ms-flex-order: 7;\n            order: 7;\n        }\n\n        .order-md-8 {\n            -webkit-box-ordinal-group: 9;\n            -ms-flex-order: 8;\n            order: 8;\n        }\n\n        .order-md-9 {\n            -webkit-box-ordinal-group: 10;\n            -ms-flex-order: 9;\n            order: 9;\n        }\n\n        .order-md-10 {\n            -webkit-box-ordinal-group: 11;\n            -ms-flex-order: 10;\n            order: 10;\n        }\n\n        .order-md-11 {\n            -webkit-box-ordinal-group: 12;\n            -ms-flex-order: 11;\n            order: 11;\n        }\n\n        .order-md-12 {\n            -webkit-box-ordinal-group: 13;\n            -ms-flex-order: 12;\n            order: 12;\n        }\n    }\n\n    @media (min-width: 992px) {\n        \n        .order-lg-first {\n            -webkit-box-ordinal-group: 0;\n            -ms-flex-order: -1;\n            order: -1;\n        }\n\n        .order-lg-last {\n            -webkit-box-ordinal-group: 14;\n            -ms-flex-order: 13;\n            order: 13;\n        }\n\n        .order-lg-0 {\n            -webkit-box-ordinal-group: 1;\n            -ms-flex-order: 0;\n            order: 0;\n        }\n\n        .order-lg-1 {\n            -webkit-box-ordinal-group: 2;\n            -ms-flex-order: 1;\n            order: 1;\n        }\n\n        .order-lg-2 {\n            -webkit-box-ordinal-group: 3;\n            -ms-flex-order: 2;\n            order: 2;\n        }\n\n        .order-lg-3 {\n            -webkit-box-ordinal-group: 4;\n            -ms-flex-order: 3;\n            order: 3;\n        }\n\n        .order-lg-4 {\n            -webkit-box-ordinal-group: 5;\n            -ms-flex-order: 4;\n            order: 4;\n        }\n\n        .order-lg-5 {\n            -webkit-box-ordinal-group: 6;\n            -ms-flex-order: 5;\n            order: 5;\n        }\n\n        .order-lg-6 {\n            -webkit-box-ordinal-group: 7;\n            -ms-flex-order: 6;\n            order: 6;\n        }\n\n        .order-lg-7 {\n            -webkit-box-ordinal-group: 8;\n            -ms-flex-order: 7;\n            order: 7;\n        }\n\n        .order-lg-8 {\n            -webkit-box-ordinal-group: 9;\n            -ms-flex-order: 8;\n            order: 8;\n        }\n\n        .order-lg-9 {\n            -webkit-box-ordinal-group: 10;\n            -ms-flex-order: 9;\n            order: 9;\n        }\n\n        .order-lg-10 {\n            -webkit-box-ordinal-group: 11;\n            -ms-flex-order: 10;\n            order: 10;\n        }\n\n        .order-lg-11 {\n            -webkit-box-ordinal-group: 12;\n            -ms-flex-order: 11;\n            order: 11;\n        }\n\n        .order-lg-12 {\n            -webkit-box-ordinal-group: 13;\n            -ms-flex-order: 12;\n            order: 12;\n        }\n    }\n    \n    @media (min-width: 1200px) {\n        \n        .order-xl-first {\n            -webkit-box-ordinal-group: 0;\n            -ms-flex-order: -1;\n            order: -1;\n        }\n\n        .order-xl-last {\n            -webkit-box-ordinal-group: 14;\n            -ms-flex-order: 13;\n            order: 13;\n        }\n\n        .order-xl-0 {\n            -webkit-box-ordinal-group: 1;\n            -ms-flex-order: 0;\n            order: 0;\n        }\n\n        .order-xl-1 {\n            -webkit-box-ordinal-group: 2;\n            -ms-flex-order: 1;\n            order: 1;\n        }\n\n        .order-xl-2 {\n            -webkit-box-ordinal-group: 3;\n            -ms-flex-order: 2;\n            order: 2;\n        }\n\n        .order-xl-3 {\n            -webkit-box-ordinal-group: 4;\n            -ms-flex-order: 3;\n            order: 3;\n        }\n\n        .order-xl-4 {\n            -webkit-box-ordinal-group: 5;\n            -ms-flex-order: 4;\n            order: 4;\n        }\n\n        .order-xl-5 {\n            -webkit-box-ordinal-group: 6;\n            -ms-flex-order: 5;\n            order: 5;\n        }\n\n        .order-xl-6 {\n            -webkit-box-ordinal-group: 7;\n            -ms-flex-order: 6;\n            order: 6;\n        }\n\n        .order-xl-7 {\n            -webkit-box-ordinal-group: 8;\n            -ms-flex-order: 7;\n            order: 7;\n        }\n\n        .order-xl-8 {\n            -webkit-box-ordinal-group: 9;\n            -ms-flex-order: 8;\n            order: 8;\n        }\n\n        .order-xl-9 {\n            -webkit-box-ordinal-group: 10;\n            -ms-flex-order: 9;\n            order: 9;\n        }\n\n        .order-xl-10 {\n            -webkit-box-ordinal-group: 11;\n            -ms-flex-order: 10;\n            order: 10;\n        }\n\n        .order-xl-11 {\n            -webkit-box-ordinal-group: 12;\n            -ms-flex-order: 11;\n            order: 11;\n        }\n\n        .order-xl-12 {\n            -webkit-box-ordinal-group: 13;\n            -ms-flex-order: 12;\n            order: 12;\n        }\n    }\n"]);

  _templateObject$y = function _templateObject() {
    return data;
  };

  return data;
}
const BsFlexOrderCss = css(_templateObject$y());

function _templateObject$z() {
  const data = _taggedTemplateLiteral(["\n    \n    .flex-wrap {\n        -ms-flex-wrap: wrap !important;\n        flex-wrap: wrap !important;\n    }\n\n    .flex-nowrap {\n        -ms-flex-wrap: nowrap !important;\n        flex-wrap: nowrap !important;\n    }\n\n    .flex-wrap-reverse {\n        -ms-flex-wrap: wrap-reverse !important;\n        flex-wrap: wrap-reverse !important;\n    }\n\n    .flex-fill {\n        -ms-flex: 1 1 auto !important;\n        flex: 1 1 auto !important;\n    }\n      \n    .flex-grow-0 {\n        -ms-flex-positive: 0 !important;\n        flex-grow: 0 !important;\n    }\n      \n    .flex-grow-1 {\n        -ms-flex-positive: 1 !important;\n        flex-grow: 1 !important;\n    }\n      \n    .flex-shrink-0 {\n        -ms-flex-negative: 0 !important;\n        flex-shrink: 0 !important;\n    }\n      \n    .flex-shrink-1 {\n        -ms-flex-negative: 1 !important;\n        flex-shrink: 1 !important;\n    }\n\n    @media (min-width: 576px) {\n        \n        .flex-sm-wrap {\n            -ms-flex-wrap: wrap !important;\n            flex-wrap: wrap !important;\n        }\n         \n        .flex-sm-nowrap {\n            -ms-flex-wrap: nowrap !important;\n            flex-wrap: nowrap !important;\n        }\n        \n        .flex-sm-wrap-reverse {\n            -ms-flex-wrap: wrap-reverse !important;\n            flex-wrap: wrap-reverse !important;\n        }\n\n        .flex-sm-fill {\n            -ms-flex: 1 1 auto !important;\n            flex: 1 1 auto !important;\n        }\n        \n        .flex-sm-grow-0 {\n            -ms-flex-positive: 0 !important;\n            flex-grow: 0 !important;\n        }\n        \n        .flex-sm-grow-1 {\n            -ms-flex-positive: 1 !important;\n            flex-grow: 1 !important;\n        }\n        \n        .flex-sm-shrink-0 {\n            -ms-flex-negative: 0 !important;\n            flex-shrink: 0 !important;\n        }\n        \n        .flex-sm-shrink-1 {\n            -ms-flex-negative: 1 !important;\n            flex-shrink: 1 !important;\n        }\n    }\n\n    @media (min-width: 768px) {\n\n        .flex-md-wrap {\n            -ms-flex-wrap: wrap !important;\n            flex-wrap: wrap !important;\n        }\n         \n        .flex-md-nowrap {\n            -ms-flex-wrap: nowrap !important;\n            flex-wrap: nowrap !important;\n        }\n        \n        .flex-md-wrap-reverse {\n            -ms-flex-wrap: wrap-reverse !important;\n            flex-wrap: wrap-reverse !important;\n        }\n\n        .flex-md-fill {\n            -ms-flex: 1 1 auto !important;\n            flex: 1 1 auto !important;\n        }\n        \n        .flex-md-grow-0 {\n            -ms-flex-positive: 0 !important;\n            flex-grow: 0 !important;\n        }\n        \n        .flex-md-grow-1 {\n            -ms-flex-positive: 1 !important;\n            flex-grow: 1 !important;\n        }\n        \n        .flex-md-shrink-0 {\n            -ms-flex-negative: 0 !important;\n            flex-shrink: 0 !important;\n        }\n        \n        .flex-md-shrink-1 {\n            -ms-flex-negative: 1 !important;\n            flex-shrink: 1 !important;\n        }\n    }\n\n    @media (min-width: 992px) {\n        \n        .flex-lg-wrap {\n            -ms-flex-wrap: wrap !important;\n            flex-wrap: wrap !important;\n        }\n        \n        .flex-lg-nowrap {\n            -ms-flex-wrap: nowrap !important;\n            flex-wrap: nowrap !important;\n        }\n        \n        .flex-lg-wrap-reverse {\n            -ms-flex-wrap: wrap-reverse !important;\n            flex-wrap: wrap-reverse !important;\n        }\n\n        .flex-lg-fill {\n            -ms-flex: 1 1 auto !important;\n            flex: 1 1 auto !important;\n        }\n        \n        .flex-lg-grow-0 {\n            -ms-flex-positive: 0 !important;\n            flex-grow: 0 !important;\n        }\n        \n        .flex-lg-grow-1 {\n            -ms-flex-positive: 1 !important;\n            flex-grow: 1 !important;\n        }\n        \n        .flex-lg-shrink-0 {\n            -ms-flex-negative: 0 !important;\n            flex-shrink: 0 !important;\n        }\n        \n        .flex-lg-shrink-1 {\n            -ms-flex-negative: 1 !important;\n            flex-shrink: 1 !important;\n        }\n    }\n\n    @media (min-width: 1200px) {\n\n        .flex-xl-wrap {\n            -ms-flex-wrap: wrap !important;\n            flex-wrap: wrap !important;\n        }\n        \n        .flex-xl-nowrap {\n            -ms-flex-wrap: nowrap !important;\n            flex-wrap: nowrap !important;\n        }\n        \n        .flex-xl-wrap-reverse {\n            -ms-flex-wrap: wrap-reverse !important;\n            flex-wrap: wrap-reverse !important;\n        }\n\n        .flex-xl-fill {\n            -ms-flex: 1 1 auto !important;\n            flex: 1 1 auto !important;\n        }\n        \n        .flex-xl-grow-0 {\n            -ms-flex-positive: 0 !important;\n            flex-grow: 0 !important;\n        }\n        \n        .flex-xl-grow-1 {\n            -ms-flex-positive: 1 !important;\n            flex-grow: 1 !important;\n        }\n        \n        .flex-xl-shrink-0 {\n            -ms-flex-negative: 0 !important;\n            flex-shrink: 0 !important;\n        }\n        \n        .flex-xl-shrink-1 {\n            -ms-flex-negative: 1 !important;\n            flex-shrink: 1 !important;\n        }\n    }\n"]);

  _templateObject$z = function _templateObject() {
    return data;
  };

  return data;
}
const BsFlexWrapCss = css(_templateObject$z());

function _templateObject2() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$A() {
  const data = _taggedTemplateLiteral(["\n                :host ::slotted(bs-card:first-of-type) {\n                    --bs-card-border-bottom: 0;\n                    --bs-card-border-bottom-right-radius: 0;\n                    --bs-card-border-bottom-left-radius: 0;\n                }\n                \n                :host ::slotted(bs-card:not(:first-of-type):not(:last-of-type)) {\n                    --bs-card-border-bottom: 0;\n                    --bs-card-border-top-right-radius: 0;\n                    --bs-card-border-top-left-radius: 0;\n                    --bs-card-border-bottom-right-radius: 0;\n                    --bs-card-border-bottom-left-radius: 0;\n                }\n                \n                :host ::slotted(bs-card:last-of-type) {\n                    --bs-card-border-top-left-radius: 0;\n                    --bs-card-border-top-right-radius: 0;\n                }\n            "]);

  _templateObject$A = function _templateObject() {
    return data;
  };

  return data;
}
class BsAccordion extends LitElement {
  static get properties() {
    return {
      multitab: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$A())];
  }

  render() {
    return html(_templateObject2());
  }

  constructor() {
    super();
    this.multitab = false;
  }

  firstUpdated() {
    this.addEventListener('bs-collapse-toggle', event => this._toggleCollapsable(event));
  }

  _toggleCollapsable(event) {
    const target = event.detail.target;

    if (!target) {
      return;
    }

    const collapsableElements = this._findAllCollapsableElements();

    if (this.multitab) {
      this._handleMultipleTabsOpen(collapsableElements, target);
    } else {
      this._handleSingleTabOpen(collapsableElements, target);
    }
  }

  _handleMultipleTabsOpen(collapsableElements, targetId) {
    for (let index = 0; index < collapsableElements.length; index++) {
      const collapsableElement = collapsableElements[index];

      if (this._isTargetCollapsableElement(collapsableElement, targetId)) {
        collapsableElement.toggle();
        return;
      }
    }
  }

  _handleSingleTabOpen(collapsableElements, target) {
    for (let index = 0; index < collapsableElements.length; index++) {
      const collapsableElement = collapsableElements[index];

      if (this._isTargetCollapsableElement(collapsableElement, target)) {
        collapsableElement.toggle();
      } else {
        collapsableElement.collapse();
      }
    }
  }

  _isTargetCollapsableElement(collapsableElement, target) {
    const collapsableElementId = collapsableElement.getAttribute('id');
    return collapsableElementId === target;
  }

  _findAllCollapsableElements() {
    const slotElement = this.shadowRoot.querySelector('slot');
    const slotNodes = slotElement.assignedNodes();
    const collapsableElements = [];

    for (let index = 0; index < slotNodes.length; index++) {
      const slotNode = slotNodes[index];

      const collapsableElement = this._findCollapsableElement(slotNode);

      if (collapsableElement) {
        collapsableElements.push(collapsableElement);
      }
    }

    return collapsableElements;
  }

  _findCollapsableElement(slotNode) {
    const slotChildren = slotNode.children;

    if (!slotChildren) {
      return;
    }

    for (let index = 0; index < slotChildren.length; index++) {
      const slotChild = slotChildren[index];

      if (this._isCollapsableElement(slotChild)) {
        return slotChild;
      }
    }
  }

  _isCollapsableElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-collapsable';
  }

}
window.customElements.define('bs-accordion', BsAccordion);

function _templateObject2$1() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$1 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$B() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                    height: auto;\n                    transition-property: var(--bs-collapsable-transition-property, height);\n                    transition-duration: var(--bs-collapsable-transition-duration, 0.35s);\n                    transition-timing-function: var(--bs-collapsable-transition-timing-function, ease);\n                }\n                \n                :host([transitioning]) {\n                    position: relative;\n                }\n                \n                @media screen and (prefers-reduced-motion: reduce) {\n                    :host {\n                        transition: none;\n                    }\n                }\n            "]);

  _templateObject$B = function _templateObject() {
    return data;
  };

  return data;
}
class BsCollapsable extends LitElement {
  static get properties() {
    return {
      expanded: {
        type: Boolean,
        reflect: true
      },
      collapsed: {
        type: Boolean,
        reflect: true
      },
      transitioning: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$B())];
  }

  render() {
    return html(_templateObject2$1());
  }

  constructor() {
    super();
    this.expanded = false;
    this.collapsed = false;
    this.transitioning = false;
  }

  firstUpdated() {
    this.addEventListener('transitionend', event => this._afterCollapsingTransition(event));

    if (this.collapsed) {
      this._collapseCollapsable();
    }
  }

  _afterCollapsingTransition() {
    if (this.expanded) {
      this.shadowRoot.host.style.overflow = 'inherit';
      this.shadowRoot.host.style.height = 'auto';
    }

    this.transitioning = false;
  }

  toggle() {
    this.transitioning = true;

    if (this.expanded) {
      this._collapseCollapsable();
    } else {
      this._expandCollapsable();
    }
  }

  expand() {
    this._expandCollapsable();
  }

  collapse() {
    this._collapseCollapsable();
  }

  isExpanded() {
    return this.expanded;
  }

  _expandCollapsable() {
    this.expanded = true;
    this.collapsed = false;
    this.shadowRoot.host.style.height = this._getSlottedElementsHeight() + 'px';
  }

  _collapseCollapsable() {
    this.collapsed = true;
    this.expanded = false;

    this._updateHeightBeforeCollapse();

    this.shadowRoot.host.style.overflow = 'hidden';
    this.shadowRoot.host.style.height = '0';
  }

  _updateHeightBeforeCollapse() {
    const existingHeight = this.shadowRoot.host.style.height;

    if (!existingHeight || existingHeight === 'auto') {
      this.shadowRoot.host.style.transition = 'none';
      this.shadowRoot.host.style.height = window.getComputedStyle(this.shadowRoot.host).height; //force browser to repaint after we change the height

      window.getComputedStyle(this.shadowRoot.host).height;
      this.shadowRoot.host.style.transitionProperty = this._getTransitionProperty();
      this.shadowRoot.host.style.transitionDuration = this._getTransitionDuration();
      this.shadowRoot.host.style.transitionTimingFunction = this._getTransitionTimingFunction();
    }
  }

  _getTransitionTimingFunction() {
    const transitionTimingFunction = getComputedStyle(this.shadowRoot.host).getPropertyValue('--bs-collapsable-transition-timing-function');

    if (!transitionTimingFunction) {
      return 'ease';
    }

    return transitionTimingFunction;
  }

  _getTransitionDuration() {
    const transitionDuration = getComputedStyle(this.shadowRoot.host).getPropertyValue('--bs-collapsable-transition-duration');

    if (!transitionDuration) {
      return '0.35s';
    }

    return transitionDuration;
  }

  _getTransitionProperty() {
    const transitionProperty = getComputedStyle(this.shadowRoot.host).getPropertyValue('--bs-collapsable-transition-property');

    if (!transitionProperty) {
      return 'height';
    }

    return transitionProperty;
  }

  _getSlottedElementsHeight() {
    const slotNode = this.shadowRoot.querySelector('slot');
    const slottedElements = slotNode.assignedNodes();
    let totalHeight = 0;

    for (let index = 0; index < slottedElements.length; index++) {
      const slotElement = slottedElements[index];

      if (slotElement.nodeType === Node.ELEMENT_NODE) {
        const slotElementHeight = slotElement.offsetHeight;
        const marginTopValue = window.getComputedStyle(slotElement).marginTop;
        const marginBottomValue = window.getComputedStyle(slotElement).marginBottom;
        const marginTop = new Number(marginTopValue.slice(0, marginTopValue.length - 2));
        const marginBottom = new Number(marginBottomValue.slice(0, marginBottomValue.length - 2));
        totalHeight += slotElementHeight + marginTop + marginBottom;
      }
    }

    return totalHeight;
  }

}
window.customElements.define('bs-collapsable', BsCollapsable);

const BsCollapseMixin = superClass => class extends superClass {
  firstUpdated() {
    this.addEventListener('bs-collapse-toggle', event => this._toggleCollapsable(event));
    this.addEventListener('bs-collapse-multi-toggle', event => this._multiToggleCollapsable(event));
  }

  _toggleCollapsable(event) {
    const target = event.detail.target;

    if (!target) {
      return;
    }

    const collapsableElement = this.shadowRoot.querySelector("bs-collapsable#".concat(target));

    if (collapsableElement) {
      collapsableElement.toggle();
    }
  }

  _multiToggleCollapsable(event) {
    const multiTarget = event.detail.multiTarget;

    if (!multiTarget) {
      return;
    }

    const collapsableElements = this.shadowRoot.querySelectorAll("bs-collapsable.".concat(multiTarget));

    for (let index = 0; index < collapsableElements.length; index++) {
      const collapsableElement = collapsableElements[index];

      if (collapsableElement) {
        collapsableElement.toggle();
      }
    }
  }

};

function _templateObject$C() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject$C = function _templateObject() {
    return data;
  };

  return data;
}
class BsCollapseMultiToggle extends LitElement {
  static get properties() {
    return {
      multiTarget: {
        type: String,
        reflect: true
      }
    };
  }

  render() {
    return html(_templateObject$C());
  }

  constructor() {
    super();
    this.multiTarget = '';
  }

  firstUpdated() {
    this.addEventListener('bs-button-click', event => this._handleMultiToggleCollapse(event));
  }

  _handleMultiToggleCollapse() {
    if (!this.multiTarget) {
      return;
    }

    const multiToggleCollapseEvent = new CustomEvent('bs-collapse-multi-toggle', {
      bubbles: true,
      composed: true,
      detail: {
        multiTarget: this.multiTarget
      }
    });
    this.dispatchEvent(multiToggleCollapseEvent);
  }

}
window.customElements.define('bs-collapse-multi-toggle', BsCollapseMultiToggle);

function _templateObject$D() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject$D = function _templateObject() {
    return data;
  };

  return data;
}
class BsCollapseToggle extends LitElement {
  static get properties() {
    return {
      target: {
        type: String,
        reflect: true
      }
    };
  }

  render() {
    return html(_templateObject$D());
  }

  constructor() {
    super();
    this.target = '';
  }

  firstUpdated() {
    this.addEventListener('bs-button-click', event => this._handleToggleCollapse(event));
  }

  _handleToggleCollapse() {
    if (!this.target) {
      return;
    }

    const toggleCollapseEvent = new CustomEvent('bs-collapse-toggle', {
      bubbles: true,
      composed: true,
      detail: {
        target: this.target
      }
    });
    this.dispatchEvent(toggleCollapseEvent);
  }

}
window.customElements.define('bs-collapse-toggle', BsCollapseToggle);

function _templateObject2$2() {
  const data = _taggedTemplateLiteral(["\n            <slot name=\"heading\"></slot>\n            <slot name=\"message\"></slot>\n            <slot name=\"dismiss\"></slot>\n        "]);

  _templateObject2$2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$E() {
  const data = _taggedTemplateLiteral(["\n                \n                :host {\n                    display: block;\n                    position: relative;\n                    padding: 0.75rem 1.25rem;\n                    margin-bottom: 1rem;\n                    border: 1px solid transparent;\n                    border-radius: 0.25rem;\n                }\n\n                :host([fade]) {\n                    opacity: 0;\n                    transition: opacity 0.15s linear;\n                }\n\n                :host([fade][show]) {\n                    opacity: 1;\n                }\n\n                :host([dismissable]) {\n                    padding-right: 4rem;\n                }\n\n                :host ::slotted([slot=heading]) {\n                    color: inherit;\n                }\n\n                :host ::slotted([slot=closeButton]) {\n                    position: absolute;\n                    top: 0;\n                    right: 0;\n                    padding: 0.75rem 1.25rem;\n                    color: inherit;\n                }\n\n                :host([primary]) {\n                    color: #004085;\n                    background-color: #cce5ff;\n                    border-color: #b8daff;\n                }\n\n                :host([secondary]) {\n                    color: #383d41;\n                    background-color: #e2e3e5;\n                    border-color: #d6d8db;\n                }\n\n                :host([success]) {\n                    color: #155724;\n                    background-color: #d4edda;\n                    border-color: #c3e6cb;\n                }\n\n                :host([info]) {\n                    color: #0c5460;\n                    background-color: #d1ecf1;\n                    border-color: #bee5eb;\n                }\n\n                :host([warning]) {\n                    color: #856404;\n                    background-color: #fff3cd;\n                    border-color: #ffeeba;\n                }\n\n                :host([danger]) {\n                    color: #721c24;\n                    background-color: #f8d7da;\n                    border-color: #f5c6cb;\n                }\n\n                :host([light]) {\n                    color: #818182;\n                    background-color: #fefefe;\n                    border-color: #fdfdfe;\n                }\n\n                :host([dark]) {\n                    color: #1b1e21;\n                    background-color: #d6d8d9;\n                    border-color: #c6c8ca;\n                }\n            "]);

  _templateObject$E = function _templateObject() {
    return data;
  };

  return data;
}
class BsAlert extends LitElement {
  static get properties() {
    return {
      show: {
        type: Boolean,
        reflect: true
      },
      fade: {
        type: Boolean,
        reflect: true
      },
      dismissable: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$E())];
  }

  render() {
    return html(_templateObject2$2());
  }

  constructor() {
    super();
    this.show = false;
    this.fade = false;
    this.dismissable = false;
  }

  firstUpdated() {
    const alertElement = this.shadowRoot.host;
    alertElement.addEventListener('transitionend', () => this._afterElementTransition());
    this.addEventListener('close-button-click', () => this._handleAlertDismiss());
  }

  _afterElementTransition() {
    this._fireClosedEvent();
  }

  _handleAlertDismiss() {
    this._fireCloseEvent();

    this.show = false;
  }

  _fireClosedEvent() {
    const alertClosedEvent = new CustomEvent('closed.bs.alert', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(alertClosedEvent);
  }

  _fireCloseEvent() {
    const alertCloseEvent = new CustomEvent('close.bs.alert', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(alertCloseEvent);
  }

}
window.customElements.define('bs-alert', BsAlert);

function _templateObject2$3() {
  const data = _taggedTemplateLiteral(["\n            <button type=\"button\" class=\"close\" aria-label=\"Close\">\n                <span aria-hidden=\"true\">&times;</span>\n            </button>\n            \n        "]);

  _templateObject2$3 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$F() {
  const data = _taggedTemplateLiteral(["\n            \n            .close {\n                border: 0;\n                float: right;\n                font-size: 1.5rem;\n                font-weight: 700;\n                line-height: 1;\n                color: #000;\n                text-shadow: 0 1px 0 #fff;\n                opacity: 0.5;\n                margin: var(--bs-close-btn-margin);\n                padding: var(--bs-close-btn-padding, 0);\n                background-color: transparent;\n                -webkit-appearance: none;\n            }\n\n            .close:not(:disabled):not(.disabled):hover, \n            .close:not(:disabled):not(.disabled):focus {\n                color: #000;\n                text-decoration: none;\n                opacity: 0.75;\n                cursor: pointer;\n            }\n        "]);

  _templateObject$F = function _templateObject() {
    return data;
  };

  return data;
}
class BsCloseButton extends LitElement {
  static get styles() {
    return css(_templateObject$F());
  }

  render() {
    return html(_templateObject2$3());
  }

  firstUpdated() {
    const buttonElement = this.shadowRoot.querySelector('button');
    buttonElement.addEventListener('click', () => this._handleClick());
  }

  _handleClick() {
    const alertCloseEvent = new CustomEvent('close-button-click', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(alertCloseEvent);
  }

}
window.customElements.define('bs-close-btn', BsCloseButton);

function _templateObject2$4() {
  const data = _taggedTemplateLiteral(["\n            <bs-close-btn class=\"dismiss-button\"></bs-close-btn>\n        "]);

  _templateObject2$4 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$G() {
  const data = _taggedTemplateLiteral(["\n            \n            .dismiss-button {\n                position: absolute;\n                top: 0;\n                right: 0;\n                padding: 0.75rem 1.25rem;\n                color: inherit;\n            }\n        "]);

  _templateObject$G = function _templateObject() {
    return data;
  };

  return data;
}
class BsAlertDismiss extends LitElement {
  static get styles() {
    return css(_templateObject$G());
  }

  render() {
    return html(_templateObject2$4());
  }

}
window.customElements.define('bs-alert-dismiss', BsAlertDismiss);

function _templateObject2$5() {
  const data = _taggedTemplateLiteral(["\n            <hr />\n        "]);

  _templateObject2$5 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$H() {
  const data = _taggedTemplateLiteral(["\n                :host([primary]) hr {\n                    border-top-color: #9fcdff;\n                }\n\n                :host([secondary]) hr {\n                    border-top-color: #c8cbcf;\n                }\n\n                :host([success]) hr {\n                    border-top-color: #b1dfbb;\n                }\n\n                :host([info]) hr {\n                    border-top-color: #abdde5;\n                }\n\n                :host([warning]) hr {\n                    border-top-color: #ffe8a1;\n                }\n\n                :host([danger]) hr {\n                    border-top-color: #f1b0b7;\n                }\n\n                :host([light]) hr {\n                    border-top-color: #ececf6;\n                }\n\n                :host([dark]) hr {\n                    border-top-color: #b9bbbe;\n                }\n            "]);

  _templateObject$H = function _templateObject() {
    return data;
  };

  return data;
}
class BsAlertHr extends LitElement {
  static get styles() {
    return [BsContentRebootCss, BsContentTypographyCss, css(_templateObject$H())];
  }

  render() {
    return html(_templateObject2$5());
  }

}
window.customElements.define('bs-alert-hr', BsAlertHr);

function _templateObject2$6() {
  const data = _taggedTemplateLiteral(["\n            <a href=\"", "\"><slot></slot></a>\n        "]);

  _templateObject2$6 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$I() {
  const data = _taggedTemplateLiteral(["\n                a {\n                    font-weight: 700;\n                }\n                \n                :host([primary]) a {\n                    color: #002752;\n                }\n\n                :host([secondary]) a {\n                    color: #202326;\n                }\n\n                :host([success]) a {\n                    color: #0b2e13;\n                }\n\n                :host([info]) a {\n                    color: #062c33;\n                }\n\n                :host([warning]) a {\n                    color: #533f03;\n                }\n\n                :host([danger]) a {\n                    color: #491217;\n                }\n\n                :host([light]) a {\n                    color: #686868;\n                }\n\n                :host([dark]) a {\n                    color: #040505;\n                }\n            "]);

  _templateObject$I = function _templateObject() {
    return data;
  };

  return data;
}
class BsAlertLink extends LitElement {
  static get properties() {
    return {
      href: String
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsContentTypographyCss, css(_templateObject$I())];
  }

  render() {
    return html(_templateObject2$6(), this.href);
  }

  constructor() {
    super();
    this.href = '#';
  }

}
window.customElements.define('bs-alert-link', BsAlertLink);

function _templateObject$J() {
  const data = _taggedTemplateLiteral(["\n                \n    .badge {\n        display: inline-block;\n        padding: 0.25em 0.4em;\n        font-size: 75%;\n        font-weight: 700;\n        line-height: 1;\n        text-align: center;\n        white-space: nowrap;\n        vertical-align: baseline;\n        border-radius: 0.25rem;\n    }\n\n    .badge:empty {\n        display: none;\n    }\n\n    :host-context(.btn) .badge {\n        position: relative;\n        top: -1px;\n    }\n\n    :host([pill]) .badge {\n        padding-right: 0.6em;\n        padding-left: 0.6em;\n        border-radius: 10rem;\n    }\n\n    :host([primary]) .badge {\n        color: #fff;\n        background-color: #007bff;\n    }\n\n    :host([secondary]) .badge {\n        color: #fff;\n        background-color: #6c757d;\n    }\n\n    :host([success]) .badge {\n        color: #fff;\n        background-color: #28a745;\n    }\n\n    :host([info]) .badge {\n        color: #fff;\n        background-color: #17a2b8;\n    }\n\n    :host([warning]) .badge {\n        color: #212529;\n        background-color: #ffc107;\n    }\n\n    :host([danger]) .badge {\n        color: #fff;\n        background-color: #dc3545;\n    }\n\n    :host([light]) .badge {\n        color: #212529;\n        background-color: #f8f9fa;\n    }\n\n    :host([dark]) .badge {\n        color: #fff;\n        background-color: #343a40;\n    }\n"]);

  _templateObject$J = function _templateObject() {
    return data;
  };

  return data;
}
const BsBadgeCss = css(_templateObject$J());

function _templateObject$K() {
  const data = _taggedTemplateLiteral(["\n            <span class=\"badge\">\n                <slot></slot>\n            </span>\n        "]);

  _templateObject$K = function _templateObject() {
    return data;
  };

  return data;
}
class BsBadge extends LitElement {
  static get styles() {
    return [BsContentRebootCss, BsBadgeCss];
  }

  render() {
    return html(_templateObject$K());
  }

}
window.customElements.define('bs-badge', BsBadge);

function _templateObject2$7() {
  const data = _taggedTemplateLiteral(["\n            <a href=\"", "\" class=\"badge\">\n                <slot></slot>\n            </a>\n        "]);

  _templateObject2$7 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$L() {
  const data = _taggedTemplateLiteral(["\n                \n                :host([primary]) a {\n                    text-decoration: none;\n                }\n                \n                :host([secondary]) a {\n                    text-decoration: none;\n                }\n                \n                :host([success]) a {\n                    text-decoration: none;\n                }\n        \n                :host([info]) a {\n                    text-decoration: none;\n                }\n                \n                :host([warning]) a {\n                    text-decoration: none;\n                }\n                \n                :host([danger]) a {\n                    text-decoration: none;\n                }\n\n                :host([light]) a {\n                    text-decoration: none;\n                }\n\n                :host([dark]) a {\n                    text-decoration: none;\n                }\n        \n                :host([primary]) a:hover,\n                :host([primary]) a:focus {\n                    color: #fff;\n                    text-decoration: none;\n                    background-color: #0062cc;\n                }\n        \n                :host([secondary]) a:hover,\n                :host([secondary]) a:focus {\n                    color: #fff;\n                    text-decoration: none;\n                    background-color: #545b62;\n                }\n        \n                :host([success]) a:hover,\n                :host([seccess]) a:focus {\n                    color: #fff;\n                    text-decoration: none;\n                    background-color: #1e7e34;\n                }\n        \n                :host([info]) a:hover,\n                :host([info]) a:focus {\n                    color: #fff;\n                    text-decoration: none;\n                    background-color: #117a8b;\n                }\n        \n                :host([warning]) a:hover,\n                :host([warning]) a:focus {\n                    color: #212529;\n                    text-decoration: none;\n                    background-color: #d39e00;\n                }\n        \n                :host([danger]) a:hover,\n                :host([danger]) a:focus {\n                    color: #fff;\n                    text-decoration: none;\n                    background-color: #bd2130;\n                }\n        \n                :host([light]) a:hover,\n                :host([light]) a:focus {\n                    color: #212529;\n                    text-decoration: none;\n                    background-color: #dae0e5;\n                }\n        \n                :host([dark][href]) a:hover,\n                :host([dark][href]) a:focus {\n                    color: #fff;\n                    text-decoration: none;\n                    background-color: #1d2124;\n                }\n            "]);

  _templateObject$L = function _templateObject() {
    return data;
  };

  return data;
}
class BsBadgeLink extends LitElement {
  static get properties() {
    return {
      href: String
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsBadgeCss, css(_templateObject$L())];
  }

  render() {
    return html(_templateObject2$7(), this.href);
  }

  constructor() {
    super();
    this.href = '#';
  }

}
window.customElements.define('bs-badge-link', BsBadgeLink);

function _templateObject4() {
  const data = _taggedTemplateLiteral(["<a href=\"", "\">", "</a>"]);

  _templateObject4 = function _templateObject4() {
    return data;
  };

  return data;
}

function _templateObject3() {
  const data = _taggedTemplateLiteral(["", ""]);

  _templateObject3 = function _templateObject3() {
    return data;
  };

  return data;
}

function _templateObject2$8() {
  const data = _taggedTemplateLiteral(["\n            ", "\n        "]);

  _templateObject2$8 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$M() {
  const data = _taggedTemplateLiteral(["\n                :host([active]) {\n                    color: #6c757d;\n                }\n            \n                :host {\n                    padding-left: var(--bs-breadcrumb-item-padding-left);\n                }\n            \n                :host::before {\n                    display: var(--bs-breadcrumb-item-display);\n                    padding-right: var(--bs-breadcrumb-item-padding-right);\n                    color: var(--bs-breadcrumb-item-color);\n                    text-decoration: var(--bs-breadcrumb-item-text-decoration);\n                    content: var(--bs-breadcrumb-item-divider);\n                }\n            "]);

  _templateObject$M = function _templateObject() {
    return data;
  };

  return data;
}
class BsBreadcrumbItem extends LitElement {
  static get properties() {
    return {
      title: String,
      href: String,
      active: Boolean
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$M())];
  }

  render() {
    return html(_templateObject2$8(), this._selectTemplateToLoad());
  }

  constructor() {
    super();
    this.href = '#';
    this.active = false;
    this.title = '';
  }

  _selectTemplateToLoad() {
    if (this.active) {
      return html(_templateObject3(), this.title);
    } else {
      return html(_templateObject4(), this.href, this.title);
    }
  }

}
window.customElements.define('bs-breadcrumb-item', BsBreadcrumbItem);

function _templateObject2$9() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$9 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$N() {
  const data = _taggedTemplateLiteral(["\n            :host {\n                display: flex;\n                flex-wrap: wrap;\n                padding: 0.75rem 1rem;\n                margin-bottom: 1rem;\n                list-style: none;\n                background-color: #e9ecef;\n                border-radius: 0.25rem;\n                --divider: var(--breadcrumb-divider, \"/\");\n            }\n        "]);

  _templateObject$N = function _templateObject() {
    return data;
  };

  return data;
}
class BsBreadcrumb extends LitElement {
  static get styles() {
    return css(_templateObject$N());
  }

  render() {
    return html(_templateObject2$9());
  }

  firstUpdated() {
    this._adjustAdjacentBreadcrumbItemCss();
  } // :slotted can only accept simple selectors and not combinators
  // since the adjucent sibling selector cannot be used, we apply css via javascript


  _adjustAdjacentBreadcrumbItemCss() {
    const breadcrumbItems = this._retrieveBreadcrumbItems();

    breadcrumbItems.forEach(breadcrumbItemElement => {
      const previousSibling = breadcrumbItemElement.previousElementSibling;

      if (previousSibling) {
        breadcrumbItemElement.style.setProperty('--bs-breadcrumb-item-padding-left', '0.5rem');
        breadcrumbItemElement.style.setProperty('--bs-breadcrumb-item-display', 'inline-block');
        breadcrumbItemElement.style.setProperty('--bs-breadcrumb-item-padding-right', '0.3rem');
        breadcrumbItemElement.style.setProperty('--bs-breadcrumb-item-color', '#6c757d');
        breadcrumbItemElement.style.setProperty('--bs-breadcrumb-item-text-decoration', 'none');
        breadcrumbItemElement.style.setProperty('--bs-breadcrumb-item-divider', 'var(--divider)');
      } else {
        breadcrumbItemElement.style.setProperty('--bs-breadcrumb-item-text-decoration', 'underline');
      }
    });
  }

  _retrieveBreadcrumbItems() {
    const breadcrumbItems = [];
    const slot = this.shadowRoot.querySelector('slot');
    const slottedNodes = slot.assignedNodes();
    slottedNodes.forEach(slotElement => {
      if (this._isBreadcrumbItemElement(slotElement)) {
        breadcrumbItems.push(slotElement);
      }
    });
    return breadcrumbItems;
  }

  _isBreadcrumbItemElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && (element.localName === 'bs-breadcrumb-item' || element instanceof BsBreadcrumbItem);
  }

}
window.customElements.define('bs-breadcrumb', BsBreadcrumb);

const BsButtonMixin = superClass => class extends superClass {
  static get properties() {
    return {
      action: String,
      toggle: {
        type: Boolean,
        reflect: true
      },
      active: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      },
      dropdownToggle: {
        type: Boolean,
        reflect: true,
        attribute: 'dropdown-toggle'
      }
    };
  }

  constructor() {
    super();
    this.active = false;
    this.toggle = false;
    this.action = 'button';
    this.disabled = false;
    this.dropdownToggle = false;
  }

  firstUpdated() {
    const btnElement = this._retrieveButtonElement();

    this._applyButtonActivateState(btnElement);

    this._applyButtonTypeIfApplicable();

    this.addEventListener('click', event => this._handleButtonClick(event));
    this.addEventListener('focusout', event => this._handleFocusOut(event));
  }

  updated(changedProperties) {
    super.updated();

    if (changedProperties.has('disabled')) {
      this._disabledChanged();
    }
  }

  _disabledChanged() {
    if (this.disabled) {
      const buttonElement = this._retrieveButtonElement();

      buttonElement.classList.add('disabled');
      buttonElement.setAttribute('disabled', '');
    }
  }

  _handleFocusOut(event) {
    event.preventDefault();

    if (this.disabled) {
      return;
    }

    if (this.active && !this.toggle) {
      this._updateToggleState();
    }

    const btnFocusOutEvent = new CustomEvent('bs-button-focusout', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(btnFocusOutEvent);
  }

  _handleButtonClick(event) {
    if (!this._isLinkButton()) {
      event.preventDefault();
    }

    if (this.disabled) {
      return;
    }

    this._updateButtonFocus();

    this._updateToggleState();

    const btnClickedEvent = new CustomEvent('bs-button-click', {
      bubbles: true,
      composed: true,
      detail: {
        action: this.action
      }
    });
    this.dispatchEvent(btnClickedEvent);
  }

  _updateToggleState() {
    const buttonElement = this._retrieveButtonElement(); // added the this.dropdownToggle to enable "active"
    // look and feel during the dropdown menu opened


    if (this.toggle || this.dropdownToggle) {
      if (this.active) {
        buttonElement.classList.remove('active');
        buttonElement.removeAttribute('active');
      } else {
        buttonElement.classList.add('active');
        buttonElement.setAttribute('active', '');
      }

      this.active = !this.active;
    }
  }

  _isLinkButton() {
    const linkButtonElement = this.shadowRoot.querySelector('a');

    if (linkButtonElement) {
      return true;
    }

    return false;
  }

  _retrieveButtonElement() {
    const buttonElement = this.shadowRoot.querySelector('button');
    const inputElement = this.shadowRoot.querySelector('input');
    const hrefElement = this.shadowRoot.querySelector('a');

    if (buttonElement) {
      return buttonElement;
    }

    if (inputElement) {
      return inputElement;
    }

    if (hrefElement) {
      return hrefElement;
    }
  }

  _updateButtonFocus() {
    const buttonElement = this.shadowRoot.querySelector('button');
    const inputElement = this.shadowRoot.querySelector('input');
    const hrefElement = this.shadowRoot.querySelector('a');

    if (buttonElement) {
      buttonElement.focus();
    }

    if (inputElement) {
      inputElement.focus();
    }

    if (hrefElement) {
      hrefElement.focus();
    }
  }

  _applyButtonActivateState(btnElement) {
    if (this.disabled && !this.active) {
      btnElement.classList.toggle('disabled');
    }

    if (!this.disabled && this.active) {
      btnElement.classList.toggle('active');
    }
  }

  _applyButtonTypeIfApplicable() {
    const buttonElement = this.shadowRoot.querySelector('button');
    const inputElement = this.shadowRoot.querySelector('input');

    if (buttonElement) {
      this._applyButtonType(buttonElement);
    }

    if (inputElement) {
      this._applyButtonType(inputElement);
    }
  }

  _applyButtonType(btnElement) {
    if (this.action === 'button') {
      btnElement.setAttribute('type', 'button');
    }

    if (this.action === 'reset') {
      btnElement.setAttribute('type', 'reset');
    }

    if (this.action === 'submit') {
      btnElement.setAttribute('type', 'submit');
    }
  }

};

function _templateObject$O() {
  const data = _taggedTemplateLiteral(["\n\n\n    :host {\n        display: inline-block;\n        width: var(--bs-button-width);\n        z-index: var(--bs-button-focus-z-index);\n    }\n\n    .btn {\n        display: var(--bs-button-display, inline-block);\n        font-weight: 400;\n        text-align: center;\n        white-space: nowrap;\n        vertical-align: middle;\n        -webkit-user-select: none;\n        -moz-user-select: none;\n        user-select: none;\n        height: var(--bs-button-height);\n        color: var(--bs-button-color);\n        border-width: var(--bs-button-border-width, 1px);\n        border-style: var(--bs-button-border-style, solid);\n        border-color: var(--bs-button-border-color, transparent);\n        padding-top: var(--bs-button-padding-top, 0.375rem);\n        padding-bottom: var(--bs-button-padding-bottom, 0.375rem);\n        padding-left: var(--bs-button-padding-left, 0.75rem);\n        padding-right: var(--bs-button-padding-right, 0.75rem);\n        font-size: var(--bs-button-font-size, 1rem);\n        line-height: var(--bs-button-line-height, 1.5);\n        width: var(--bs-button-width);\n        position: var(--bs-button-position);\n        flex: var(--bs-button-flex);\n        margin-top: var(--bs-button-margin-top);\n        margin-left: var(--bs-button-margin-left);\n        margin-bottom: var(--bs-button-margin-bottom);\n        background-color: var(--bs-button-background-color);\n        border-top-left-radius: var(--bs-button-border-top-left-radius, 0.25rem);\n        border-top-right-radius: var(--bs-button-border-top-right-radius, 0.25rem);\n        border-bottom-right-radius: var(--bs-button-border-bottom-right-radius, 0.25rem);\n        border-bottom-left-radius: var(--bs-button-border-bottom-left-radius, 0.25rem);\n        transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n    }\n    \n    .btn::after {\n        display: var(--bs-button-after-display);\n        width: var(--bs-button-after-width);\n        height: var(--bs-button-after-height);\n        margin-left: var(--bs-button-after-margin-left);\n        vertical-align: var(--bs-button-after-vertical-align);\n        content: var(--bs-button-after-content);\n        border-top: var(--bs-button-after-border-top);\n        border-right: var(--bs-button-after-border-right);\n        border-bottom: var(--bs-button-after-border-bottom);\n        border-left: var(--bs-button-after-border-left);\n    }\n    \n    .btn:empty::after {\n        margin-left: var(--bs-button-empty-after-margin-left);\n    }\n\n    .btn::before {\n        display: var(--bs-button-before-display);\n        width: var(--bs-button-before-width);\n        height: var(--bs-button-before-height);\n        margin-left: var(--bs-button-before-margin-left);\n        vertical-align: var(--bs-button-before-vertical-align);\n        content: var(--bs-button-before-content);\n        border-top: var(--bs-button-before-border-top);\n        border-right: var(--bs-button-before-border-right);\n        border-bottom: var(--bs-button-before-border-bottom);\n        border-left: var(--bs-button-before-border-left);\n    }\n    \n    @media screen and (prefers-reduced-motion: reduce) {\n        .btn {\n            transition: none;\n        }\n    }\n    \n    .btn:hover {\n        text-decoration: none;\n        color: var(--bs-button-color-hover);\n        box-shadow: var(--bs-button-box-shadow-hover);\n        z-index: var(--bs-button-hover-z-index);\n        border-color: var(--bs-button-border-color-hover);\n    }\n    \n    .btn:focus,\n    .btn.focus {\n        outline: 0;\n        text-decoration: none;\n        color: var(--bs-button-color-focus);\n        box-shadow: var(--bs-button-box-shadow-focus, 0 0 0 0.2rem rgba(0, 123, 255, 0.25));\n        z-index: var(--bs-button-focus-z-index);\n        border-color: var(--bs-button-border-color-focus);\n    }\n\n    :host([disabled]) .btn {\n        opacity: 0.65;\n        pointer-events: none;\n    }\n    \n    :host(:not(:disabled):not(.disabled)) .btn {\n        cursor: pointer;\n        z-index: var(--bs-button-active-z-index);\n    }\n"]);

  _templateObject$O = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonsCommonCss = css(_templateObject$O());

function _templateObject$P() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([primary]) .btn {\n        color: #fff;\n        background-color: #007bff;\n        border-color: #007bff;\n    }\n\n    :host([primary]) .btn:hover {\n        color: #fff;\n        background-color: #0069d9;\n        border-color: #0062cc;\n    }\n\n    :host([primary]) .btn:focus, \n    :host([primary]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.5);\n    }\n\n    :host([primary]) .btn.disabled,\n    :host([primary]) .btn:disabled {\n        color: #fff;\n        background-color: #007bff;\n        border-color: #007bff;\n    }\n\n    :host([primary]) .btn:not(:disabled):not(.disabled):active, \n    :host([primary]) .btn:not(:disabled):not(.disabled).active,\n    :host([primary][dropdown-toggle][dropdown-show]) .btn {\n        color: #fff;\n        background-color: #0062cc;\n        border-color: #005cbf;\n    }\n\n    :host([primary]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([primary]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([primary][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.5);\n    }\n"]);

  _templateObject$P = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonPrimaryCss = css(_templateObject$P());

function _templateObject$Q() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([secondary]) .btn {\n        color: #fff;\n        background-color: #6c757d;\n        border-color: #6c757d;\n    }\n\n    :host([secondary]) .btn:hover {\n        color: #fff;\n        background-color: #5a6268;\n        border-color: #545b62;\n    }\n\n    :host([secondary]) .btn:focus, \n    :host([secondary]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(108, 117, 125, 0.5);\n    }\n\n    :host([secondary]) .btn.disabled, \n    :host([secondary]) .btn:disabled {\n        color: #fff;\n        background-color: #6c757d;\n        border-color: #6c757d;\n    }\n    \n    :host([secondary]) .btn:not(:disabled):not(.disabled):active, \n    :host([secondary]) .btn:not(:disabled):not(.disabled).active,\n    :host([secondary][dropdown-toggle][dropdown-show]) .btn {\n        color: #fff;\n        background-color: #545b62;\n        border-color: #4e555b;\n    }\n    \n    :host([secondary]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([secondary]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([secondary][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(108, 117, 125, 0.5);\n    }\n"]);

  _templateObject$Q = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonSecondaryCss = css(_templateObject$Q());

function _templateObject$R() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([success]) .btn {\n        color: #fff;\n        background-color: #28a745;\n        border-color: #28a745;\n    }\n\n    :host([success]) .btn:hover {\n        color: #fff;\n        background-color: #218838;\n        border-color: #1e7e34;\n    }\n\n    :host([success]) .btn:focus, \n    :host([success]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.5);\n    }\n\n    :host([success]) .btn.disabled, \n    :host([success]) .btn:disabled {\n        color: #fff;\n        background-color: #28a745;\n        border-color: #28a745;\n    }\n\n    :host([success]) .btn:not(:disabled):not(.disabled):active, \n    :host([success]) .btn:not(:disabled):not(.disabled).active,\n    :host([success][dropdown-toggle][dropdown-show]) .btn {\n        color: #fff;\n        background-color: #1e7e34;\n        border-color: #1c7430;\n    }\n\n    :host([success]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([success]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([success][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.5);\n    }\n"]);

  _templateObject$R = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonSuccessCss = css(_templateObject$R());

function _templateObject$S() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([info]) .btn {\n        color: #fff;\n        background-color: #17a2b8;\n        border-color: #17a2b8;\n    }\n\n    :host([info]) .btn:hover {\n        color: #fff;\n        background-color: #138496;\n        border-color: #117a8b;\n    }\n\n    :host([info]) .btn:focus, \n    :host([info]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(23, 162, 184, 0.5);\n    }\n\n    :host([info]) .btn.disabled, \n    :host([info]) .btn:disabled {\n        color: #fff;\n        background-color: #17a2b8;\n        border-color: #17a2b8;\n    }\n\n    :host([info]) .btn:not(:disabled):not(.disabled):active, \n    :host([info]) .btn:not(:disabled):not(.disabled).active,\n    :host([info][dropdown-toggle][dropdown-show]) .btn {\n        color: #fff;\n        background-color: #117a8b;\n        border-color: #10707f;\n    }\n\n    :host([info]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([info]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([info][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(23, 162, 184, 0.5);\n    }\n"]);

  _templateObject$S = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonInfoCss = css(_templateObject$S());

function _templateObject$T() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([warning]) .btn {\n        color: #212529;\n        background-color: #ffc107;\n        border-color: #ffc107;\n    }\n\n    :host([warning]) .btn:hover {\n        color: #212529;\n        background-color: #e0a800;\n        border-color: #d39e00;\n    }\n\n    :host([warning]) .btn:focus, \n    :host([warning]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(255, 193, 7, 0.5);\n    }\n\n    :host([warning]) .btn.disabled, \n    :host([warning]) .btn:disabled {\n        color: #212529;\n        background-color: #ffc107;\n        border-color: #ffc107;\n    }\n\n    :host([warning]) .btn:not(:disabled):not(.disabled):active, \n    :host([warning]) .btn:not(:disabled):not(.disabled).active,\n    :host([warning][dropdown-toggle][dropdown-show]) .btn {\n        color: #212529;\n        background-color: #d39e00;\n        border-color: #c69500;\n    }\n\n    :host([warning]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([warning]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([warning][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(255, 193, 7, 0.5);\n    }\n"]);

  _templateObject$T = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonWarningCss = css(_templateObject$T());

function _templateObject$U() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([danger]) .btn {\n        color: #fff;\n        background-color: #dc3545;\n        border-color: #dc3545;\n    }\n\n    :host([danger]) .btn:hover {\n        color: #fff;\n        background-color: #c82333;\n        border-color: #bd2130;\n    }\n\n    :host([danger]) .btn:focus, .btn-danger.focus {\n        box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.5);\n    }\n\n    :host([danger]) .btn.disabled, \n    :host([danger]) .btn:disabled {\n        color: #fff;\n        background-color: #dc3545;\n        border-color: #dc3545;\n    }\n\n    :host([danger]) .btn:not(:disabled):not(.disabled):active, \n    :host([danger]) .btn:not(:disabled):not(.disabled).active,\n    :host([danger][dropdown-toggle][dropdown-show]) .btn {\n        color: #fff;\n        background-color: #bd2130;\n        border-color: #b21f2d;\n    }\n\n    :host([danger]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([danger]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([danger][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.5);\n    }\n"]);

  _templateObject$U = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonDangerCss = css(_templateObject$U());

function _templateObject$V() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([light]) .btn {\n        color: #212529;\n        background-color: #f8f9fa;\n        border-color: #f8f9fa;\n    }\n\n    :host([light]) .btn:hover {\n        color: #212529;\n        background-color: #e2e6ea;\n        border-color: #dae0e5;\n    }\n\n    :host([light]) .btn:focus, \n    :host([light]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(248, 249, 250, 0.5);\n    }\n\n    :host([light]) .btn.disabled, \n    :host([light]) .btn:disabled {\n        color: #212529;\n        background-color: #f8f9fa;\n        border-color: #f8f9fa;\n    }\n\n    :host([light]) .btn:not(:disabled):not(.disabled):active, \n    :host([light]) .btn:not(:disabled):not(.disabled).active,\n    :host([light][dropdown-toggle][dropdown-show]) .btn {\n        color: #212529;\n        background-color: #dae0e5;\n        border-color: #d3d9df;\n    }\n\n    :host([light]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([light]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([light][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(248, 249, 250, 0.5);\n    }\n"]);

  _templateObject$V = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonLightCss = css(_templateObject$V());

function _templateObject$W() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([dark]) .btn {\n        color: #fff;\n        background-color: #343a40;\n        border-color: #343a40;\n    }\n\n    :host([dark]) .btn:hover {\n        color: #fff;\n        background-color: #23272b;\n        border-color: #1d2124;\n    }\n\n    :host([dark]) .btn:focus, \n    :host([dark]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(52, 58, 64, 0.5);\n    }\n\n    :host([dark]) .btn.disabled, \n    :host([dark]) .btn:disabled {\n        color: #fff;\n        background-color: #343a40;\n        border-color: #343a40;\n    }\n\n    :host([dark]) .btn:not(:disabled):not(.disabled):active, \n    :host([dark]) .btn:not(:disabled):not(.disabled).active,\n    :host([dark][dropdown-toggle][dropdown-show]) .btn {\n        color: #fff;\n        background-color: #1d2124;\n        border-color: #171a1d;\n    }\n\n    :host([dark]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([dark]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([dark][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(52, 58, 64, 0.5);\n    }\n"]);

  _templateObject$W = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonDarkCss = css(_templateObject$W());

function _templateObject$X() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([outline-primary]) .btn {\n        color: #007bff;\n        background-color: transparent;\n        background-image: none;\n        border-color: #007bff;\n    }\n\n    :host([outline-primary]) .btn:hover {\n        color: #fff;\n        background-color: #007bff;\n        border-color: #007bff;\n    }\n\n    :host([outline-primary]) .btn:focus, \n    :host([outline-primary]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.5);\n    }\n\n    :host([outline-primary]) .btn.disabled, \n    :host([outline-primary]) .btn:disabled {\n        color: #007bff;\n        background-color: transparent;\n    }\n\n    :host([outline-primary]) .btn:not(:disabled):not(.disabled):active, \n    :host([outline-primary]) .btn:not(:disabled):not(.disabled).active,\n    :host([outline-primary][dropdown-toggle][dropdown-show]) .btn {\n        color: #fff;\n        background-color: #007bff;\n        border-color: #007bff;\n    }\n\n    :host([outline-primary]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([outline-primary]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([outline-primary][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.5);\n    }\n"]);

  _templateObject$X = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonPrimaryOutlineCss = css(_templateObject$X());

function _templateObject$Y() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([outline-secondary]) .btn {\n        color: #6c757d;\n        background-color: transparent;\n        background-image: none;\n        border-color: #6c757d;\n    }\n\n    :host([outline-secondary]) .btn:hover {\n        color: #fff;\n        background-color: #6c757d;\n        border-color: #6c757d;\n    }\n\n    :host([outline-secondary]) .btn:focus, \n    :host([outline-secondary]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(108, 117, 125, 0.5);\n    }\n\n    :host([outline-secondary]) .btn.disabled, \n    :host([outline-secondary]) .btn:disabled {\n        color: #6c757d;\n        background-color: transparent;\n    }\n\n    :host([outline-secondary]) .btn:not(:disabled):not(.disabled):active, \n    :host([outline-secondary]) .btn:not(:disabled):not(.disabled).active,\n    :host([outline-secondary][dropdown-toggle][dropdown-show]) .btn {\n        color: #fff;\n        background-color: #6c757d;\n        border-color: #6c757d;\n    }\n\n    :host([outline-secondary]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([outline-secondary]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([outline-secondary][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(108, 117, 125, 0.5);\n    }\n"]);

  _templateObject$Y = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonSecondaryOutlineCss = css(_templateObject$Y());

function _templateObject$Z() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([outline-success]) .btn {\n        color: #28a745;\n        background-color: transparent;\n        background-image: none;\n        border-color: #28a745;\n    }\n\n    :host([outline-success]) .btn:hover {\n        color: #fff;\n        background-color: #28a745;\n        border-color: #28a745;\n    }\n\n    :host([outline-success]) .btn:focus, \n    :host([outline-success]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.5);\n    }\n\n    :host([outline-success]) .btn.disabled, \n    :host([outline-success]) .btn:disabled {\n        color: #28a745;\n        background-color: transparent;\n    }\n\n    :host([outline-success]) .btn:not(:disabled):not(.disabled):active, \n    :host([outline-success]) .btn:not(:disabled):not(.disabled).active,\n    :host([outline-success][dropdown-toggle][dropdown-show]) .btn {\n        color: #fff;\n        background-color: #28a745;\n        border-color: #28a745;\n    }\n\n    :host([outline-success]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([outline-success]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([outline-success][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.5);\n    }\n"]);

  _templateObject$Z = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonSuccessOutlineCss = css(_templateObject$Z());

function _templateObject$_() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([outline-info]) .btn {\n        color: #17a2b8;\n        background-color: transparent;\n        background-image: none;\n        border-color: #17a2b8;\n    }\n\n    :host([outline-info]) .btn:hover {\n        color: #fff;\n        background-color: #17a2b8;\n        border-color: #17a2b8;\n    }\n\n    :host([outline-info]) .btn:focus, \n    :host([outline-info]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(23, 162, 184, 0.5);\n    }\n\n    :host([outline-info]) .btn.disabled, \n    :host([outline-info]) .btn:disabled {\n        color: #17a2b8;\n        background-color: transparent;\n    }\n\n    :host([outline-info]) .btn:not(:disabled):not(.disabled):active, \n    :host([outline-info]) .btn:not(:disabled):not(.disabled).active,\n    :host([outline-info][dropdown-toggle][dropdown-show]) .btn {\n        color: #fff;\n        background-color: #17a2b8;\n        border-color: #17a2b8;\n    }\n\n    :host([outline-info]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([outline-info]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([outline-info][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(23, 162, 184, 0.5);\n    }\n"]);

  _templateObject$_ = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonInfoOutlineCss = css(_templateObject$_());

function _templateObject$$() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([outline-warning]) .btn {\n        color: #ffc107;\n        background-color: transparent;\n        background-image: none;\n        border-color: #ffc107;\n    }\n\n    :host([outline-warning]) .btn:hover {\n        color: #212529;\n        background-color: #ffc107;\n        border-color: #ffc107;\n    }\n\n    :host([outline-warning]) .btn:focus, \n    :host([outline-warning]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(255, 193, 7, 0.5);\n    }\n\n    :host([outline-warning]) .btn.disabled, \n    :host([outline-warning]) .btn:disabled {\n        color: #ffc107;\n        background-color: transparent;\n    }\n\n    :host([outline-warning]) .btn:not(:disabled):not(.disabled):active, \n    :host([outline-warning]) .btn:not(:disabled):not(.disabled).active,\n    :host([outline-warning][dropdown-toggle][dropdown-show]) .btn {\n        color: #212529;\n        background-color: #ffc107;\n        border-color: #ffc107;\n    }\n\n    :host([outline-warning]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([outline-warning]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([outline-warning][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(255, 193, 7, 0.5);\n    }\n"]);

  _templateObject$$ = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonWarningOutlineCss = css(_templateObject$$());

function _templateObject$10() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([outline-danger]) .btn {\n        color: #dc3545;\n        background-color: transparent;\n        background-image: none;\n        border-color: #dc3545;\n    }\n\n    :host([outline-danger]) .btn:hover {\n        color: #fff;\n        background-color: #dc3545;\n        border-color: #dc3545;\n    }\n\n    :host([outline-danger]) .btn:focus, \n    :host([outline-danger]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.5);\n    }\n\n    :host([outline-danger]) .btn.disabled, \n    :host([outline-danger]) .btn:disabled {\n        color: #dc3545;\n        background-color: transparent;\n    }\n\n    :host([outline-danger]) .btn:not(:disabled):not(.disabled):active, \n    :host([outline-danger]) .btn:not(:disabled):not(.disabled).active,\n    :host([outline-danger][dropdown-toggle][dropdown-show]) .btn {\n        color: #fff;\n        background-color: #dc3545;\n        border-color: #dc3545;\n    }\n\n    :host([outline-danger]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([outline-danger]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([outline-danger][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.5);\n    }\n"]);

  _templateObject$10 = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonDangerOutlineCss = css(_templateObject$10());

function _templateObject$11() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([outline-light]) .btn {\n        color: #f8f9fa;\n        background-color: transparent;\n        background-image: none;\n        border-color: #f8f9fa;\n    }\n\n    :host([outline-light]) .btn:hover {\n        color: #212529;\n        background-color: #f8f9fa;\n        border-color: #f8f9fa;\n    }\n\n    :host([outline-light]) .btn:focus, \n    :host([outline-light]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(248, 249, 250, 0.5);\n    }\n\n    :host([outline-light]) .btn.disabled, \n    :host([outline-light]) .btn:disabled {\n        color: #f8f9fa;\n        background-color: transparent;\n    }\n\n    :host([outline-light]) .btn:not(:disabled):not(.disabled):active, \n    :host([outline-light]) .btn:not(:disabled):not(.disabled).active,\n    :host([outline-light][dropdown-toggle][dropdown-show]) .btn {\n        color: #212529;\n        background-color: #f8f9fa;\n        border-color: #f8f9fa;\n    }\n\n    :host([outline-light]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([outline-light]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([outline-light][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(248, 249, 250, 0.5);\n    }\n"]);

  _templateObject$11 = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonLightOutlineCss = css(_templateObject$11());

function _templateObject$12() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([outline-dark]) .btn {\n        color: #343a40;\n        background-color: transparent;\n        background-image: none;\n        border-color: #343a40;\n    }\n\n    :host([outline-dark]) .btn:hover {\n        color: #fff;\n        background-color: #343a40;\n        border-color: #343a40;\n    }\n\n    :host([outline-dark]) .btn:focus, \n    :host([outline-dark]) .btn.focus {\n        box-shadow: 0 0 0 0.2rem rgba(52, 58, 64, 0.5);\n    }\n\n    :host([outline-dark]) .btn.disabled, \n    :host([outline-dark]) .btn:disabled {\n        color: #343a40;\n        background-color: transparent;\n    }\n\n    :host([outline-dark]) .btn:not(:disabled):not(.disabled):active, \n    :host([outline-dark]) .btn:not(:disabled):not(.disabled).active,\n    :host([outline-dark][dropdown-toggle][dropdown-show]) .btn {\n        color: #fff;\n        background-color: #343a40;\n        border-color: #343a40;\n    }\n\n    :host([outline-dark]) .btn:not(:disabled):not(.disabled):active:focus, \n    :host([outline-dark]) .btn:not(:disabled):not(.disabled).active:focus,\n    :host([outline-dark][dropdown-toggle][dropdown-show]) .btn:focus {\n        box-shadow: 0 0 0 0.2rem rgba(52, 58, 64, 0.5);\n    }\n"]);

  _templateObject$12 = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonDarkOutlineCss = css(_templateObject$12());

function _templateObject$13() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([link]) .btn {\n        font-weight: 400;\n        color: #007bff;\n        background-color: transparent;\n    }\n\n    :host([link]) .btn:hover {\n        color: #0056b3;\n        text-decoration: underline;\n        background-color: transparent;\n        border-color: transparent;\n    }\n\n    :host([link]) .btn:focus, \n    :host([link]) .btn.focus {\n        text-decoration: underline;\n        border-color: transparent;\n        box-shadow: none;\n    }\n\n    :host([link]) .btn:disabled, \n    :host([link]) .btn.disabled {\n        color: #6c757d;\n        pointer-events: none;\n    }\n"]);

  _templateObject$13 = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonLinkCss = css(_templateObject$13());

function _templateObject$14() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([block]) {\n        display: block;\n    }\n    \n    :host([block]) .btn {\n        width: 100%;\n    }\n\n    :host([block]:not(:first-child)) .btn {\n        margin-top: 0.5rem;\n    }\n"]);

  _templateObject$14 = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonBlockCss = css(_templateObject$14());

function _templateObject$15() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([large]) .btn {\n        padding: 0.5rem 1rem;\n        padding-top: var(--bs-button-large-top-padding, 0.5rem);\n        padding-bottom: var(--bs-button-large-bottom-padding, 0.5rem);\n        padding-left: var(--bs-button-large-left-padding, 1rem);\n        padding-right: var(--bs-button-large-right-padding, 1rem);\n        font-size: 1.25rem;\n        line-height: 1.5;\n        border-top-left-radius: var(--bs-button-border-top-left-radius,  0.3rem);\n        border-top-right-radius: var(--bs-button-border-top-right-radius, 0.3rem);\n        border-bottom-right-radius: var(--bs-button-border-bottom-right-radius,  0.3rem);\n        border-bottom-left-radius: var(--bs-button-border-bottom-left-radius,  0.3rem);\n    }\n"]);

  _templateObject$15 = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonLargeCss = css(_templateObject$15());

function _templateObject$16() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([small]) .btn {\n        padding-top: var(--bs-button-small-top-padding, 0.25rem);\n        padding-bottom: var(--bs-button-small-bottom-padding, 0.25rem);\n        padding-left: var(--bs-button-small-left-padding, 0.5rem);\n        padding-right: var(--bs-button-small-right-padding, 0.5rem);\n        font-size: 0.875rem;\n        line-height: 1.5;\n        border-top-left-radius: var(--bs-button-border-top-left-radius, 0.2rem);\n        border-top-right-radius: var(--bs-button-border-top-right-radius, 0.2rem);\n        border-bottom-right-radius: var(--bs-button-border-bottom-right-radius, 0.2rem);\n        border-bottom-left-radius: var(--bs-button-border-bottom-left-radius, 0.2rem);\n    }\n"]);

  _templateObject$16 = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonSmallCss = css(_templateObject$16());

function _templateObject$17() {
  const data = _taggedTemplateLiteral(["\n            <button class=\"btn\">\n                <slot></slot>\n            </button>\n        "]);

  _templateObject$17 = function _templateObject() {
    return data;
  };

  return data;
}
class BsButton extends BsButtonMixin(LitElement) {
  static get styles() {
    return [BsContentRebootCss, BsContentTypographyCss, BsButtonsCommonCss, BsButtonPrimaryCss, BsButtonSecondaryCss, BsButtonSuccessCss, BsButtonInfoCss, BsButtonWarningCss, BsButtonDangerCss, BsButtonLightCss, BsButtonDarkCss, BsButtonPrimaryOutlineCss, BsButtonSecondaryOutlineCss, BsButtonSuccessOutlineCss, BsButtonInfoOutlineCss, BsButtonWarningOutlineCss, BsButtonDangerOutlineCss, BsButtonLightOutlineCss, BsButtonDarkOutlineCss, BsButtonLinkCss, BsButtonBlockCss, BsButtonLargeCss, BsButtonSmallCss];
  }

  render() {
    return html(_templateObject$17());
  }

}
window.customElements.define('bs-button', BsButton);

function _templateObject$18() {
  const data = _taggedTemplateLiteral(["\n            <a href=\"", "\" target=\"", "\" rel=\"noreferrer\" class=\"btn\">\n                <slot></slot>\n            </a>\n        "]);

  _templateObject$18 = function _templateObject() {
    return data;
  };

  return data;
}
class BsLinkButton extends BsButtonMixin(LitElement) {
  static get properties() {
    return {
      href: String,
      target: String
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsContentTypographyCss, BsButtonsCommonCss, BsButtonPrimaryCss, BsButtonSecondaryCss, BsButtonSuccessCss, BsButtonInfoCss, BsButtonWarningCss, BsButtonDangerCss, BsButtonLightCss, BsButtonDarkCss, BsButtonPrimaryOutlineCss, BsButtonSecondaryOutlineCss, BsButtonSuccessOutlineCss, BsButtonInfoOutlineCss, BsButtonWarningOutlineCss, BsButtonDangerOutlineCss, BsButtonLightOutlineCss, BsButtonDarkOutlineCss, BsButtonLinkCss, BsButtonBlockCss, BsButtonLargeCss, BsButtonSmallCss];
  }

  render() {
    return html(_templateObject$18(), ifDefined(this.href), ifDefined(this.target));
  }

  constructor() {
    super();
    this.href = undefined;
    this.target = undefined;
  }

}
window.customElements.define('bs-link-button', BsLinkButton);

function _templateObject$19() {
  const data = _taggedTemplateLiteral(["\n\n    :host([horizontal]) ::slotted(bs-button:not(:last-child):not(bs-dropdown)),\n    :host([horizontal]) ::slotted(bs-link-button:not(:last-child):not(bs-dropdown)),\n    :host([horizontal]) ::slotted(bs-input-button:not(:last-child):not(bs-dropdown)) {\n        --bs-button-border-top-right-radius: 0;\n        --bs-button-border-bottom-right-radius: 0;\n    }\n\n    :host([horizontal]) ::slotted(bs-button:not(:first-child)),\n    :host([horizontal]) ::slotted(bs-link-button:not(:first-child)),\n    :host([horizontal]) ::slotted(bs-input-button:not(:first-child)),\n    :host([horizontal]) ::slotted(bs-button-group:not(:first-child)) {\n        --bs-button-border-top-left-radius: 0;\n        --bs-button-border-bottom-left-radius: 0;\n    }\n"]);

  _templateObject$19 = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonGroupHorizontalCss = css(_templateObject$19());

function _templateObject$1a() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([vertical]) {\n        flex-direction: column;\n        align-items: flex-start;\n        justify-content: center;\n    }\n\n    :host([vertical]) ::slotted(bs-button),\n    :host([vertical]) ::slotted(bs-link-button),\n    :host([vertical]) ::slotted(bs-input-button),\n    :host([vertical]) ::slotted(bs-dropdown) {\n        --bs-button-width: 100%;\n    }\n\n    :host([vertical]) ::slotted(bs-button:not(:last-child):not(bs-dropdown)),\n    :host([vertical]) ::slotted(bs-link-button:not(:last-child):not(bs-dropdown)),\n    :host([vertical]) ::slotted(bs-input-button:not(:last-child):not(bs-dropdown)),\n    :host([vertical]) ::slotted(bs-button-group:not(:last-child)) {\n        --bs-button-border-bottom-left-radius: 0;\n        --bs-button-border-bottom-right-radius: 0;\n    }\n    \n    :host([vertical]) ::slotted(bs-button:not(:first-child)),\n    :host([vertical]) ::slotted(bs-link-button:not(:first-child)),\n    :host([vertical]) ::slotted(bs-input-button:not(:first-child)),\n    :host([vertical]) ::slotted(bs-button-group:not(:first-child)) {\n        --bs-button-border-top-left-radius: 0;\n        --bs-button-border-top-right-radius: 0;\n    }\n"]);

  _templateObject$1a = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonGroupVerticalCss = css(_templateObject$1a());

function _templateObject$1b() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([large]) ::slotted(bs-button),\n    :host([large]) ::slotted(bs-link-button),\n    :host([large]) ::slotted(bs-input-button),\n    :host([large]) ::slotted(bs-dropdown) {\n        --bs-button-padding-top: 0.5rem;\n        --bs-button-padding-bottom: 0.5rem;\n        --bs-button-padding-left: 1rem;\n        --bs-button-padding-right: 1rem;\n        --bs-button-font-size: 1.25rem;\n        --bs-button-line-height: 1.5;\n        --bs-button-border-top-left-radius: 0.3rem;\n        --bs-button-border-bottom-left-radius: 0.3rem;\n        --bs-button-border-top-right-radius: 0.3rem;\n        --bs-button-border-bottom-right-radius: 0.3rem;\n    }\n"]);

  _templateObject$1b = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonGroupLargeCss = css(_templateObject$1b());

function _templateObject$1c() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([small]) ::slotted(bs-button),\n    :host([small]) ::slotted(bs-link-button),\n    :host([small]) ::slotted(bs-input-button),\n    :host([small]) ::slotted(bs-dropdown) {\n        --bs-button-padding-top: 0.25rem;\n        --bs-button-padding-bottom: 0.25rem;\n        --bs-button-padding-left: 0.5rem;\n        --bs-button-padding-right: 0.5rem;\n        --bs-button-font-size: 0.875rem;\n        --bs-button-line-height: 1.5;\n        --bs-button-border-top-left-radius: 0.2rem;\n        --bs-button-border-bottom-left-radius: 0.2rem;\n        --bs-button-border-top-right-radius: 0.2rem;\n        --bs-button-border-bottom-right-radius: 0.2rem;\n    }\n"]);

  _templateObject$1c = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonGroupSmallCss = css(_templateObject$1c());

function _templateObject$1d() {
  const data = _taggedTemplateLiteral(["\n    \n    :host {\n        position: relative;\n        display: inline-flex;\n        vertical-align: middle;\n    }\n\n    :host ::slotted(bs-button),\n    :host ::slotted(bs-link-button),\n    :host ::slotted(bs-input-button),\n    :host ::slotted(bs-dropdown) {\n        --bs-button-position: relative;\n        --bs-button-flex: 0 1 auto;\n        --bs-button-hover-z-index: 1;\n        --bs-button-focus-z-index: 1;\n        --bs-button-active-z-index: 1;\n    }\n\n    :host ::slotted(bs-button:first-child),\n    :host ::slotted(bs-link-button:first-child),\n    :host ::slotted(bs-input-button:first-child) {\n        --bs-button-margin-left: 0;\n    }\n"]);

  _templateObject$1d = function _templateObject() {
    return data;
  };

  return data;
}
const BsButtonGroupCss = css(_templateObject$1d());

function _templateObject$1e() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject$1e = function _templateObject() {
    return data;
  };

  return data;
}
class BsButtonGroup extends LitElement {
  static get properties() {
    return {
      small: {
        type: Boolean,
        reflect: true
      },
      large: {
        type: Boolean,
        reflect: true
      },
      vertical: {
        type: Boolean,
        reflect: true
      },
      horizontal: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsButtonGroupHorizontalCss, BsButtonGroupVerticalCss, BsButtonGroupLargeCss, BsButtonGroupSmallCss, BsButtonGroupCss];
  }

  render() {
    return html(_templateObject$1e());
  }

  constructor() {
    super();
    this.small = false;
    this.large = false;
    this.vertical = false;
    this.horizontal = false;
  }

  firstUpdated() {
    this._adjustMarginOnMultipleSlottedElements();
  } // :slotted can only accept simple selectors and not combinators
  // since the adjucent sibling selector cannot be used, we apply css via javascript


  _adjustMarginOnMultipleSlottedElements() {
    const slotNode = this.shadowRoot.querySelector('slot');
    const slottedNodes = slotNode.assignedNodes();
    slottedNodes.forEach(slotElement => {
      this._applyCssForButtonElement(slotElement);

      this._applyCssForButtonGroupElement(slotElement);
    });
  }

  _applyCssForButtonElement(slotElement) {
    if (this._isButtonElement(slotElement)) {
      if (this._isButtonElement(slotElement.previousElementSibling)) {
        if (this.vertical) {
          slotElement.style.setProperty('--bs-button-margin-top', '-1px');
          slotElement.style.setProperty('--bs-button-margin-left', '0');
        } else {
          slotElement.style.setProperty('--bs-button-margin-left', '-1px');
        }
      }

      if (this._isButtonGroupElement(slotElement.previousElementSibling)) {
        if (this.vertical) {
          slotElement.style.setProperty('--bs-button-margin-top', '-1px');
          slotElement.style.setProperty('--bs-button-margin-left', '0');
        } else {
          slotElement.style.setProperty('--bs-button-margin-left', '-1px');
        }
      }
    }
  }

  _applyCssForButtonGroupElement(slotElement) {
    if (this._isButtonGroupElement(slotElement)) {
      if (this._isButtonElement(slotElement.previousElementSibling)) {
        if (this.vertical) {
          slotElement.style.setProperty('--bs-button-margin-top', '-1px');
          slotElement.style.setProperty('--bs-button-margin-left', '0');
        } else {
          slotElement.style.setProperty('--bs-button-margin-left', '-1px');
        }
      }

      if (this._isButtonGroupElement(slotElement.previousElementSibling)) {
        if (this.vertical) {
          slotElement.style.setProperty('--bs-button-margin-top', '-1px');
          slotElement.style.setProperty('--bs-button-margin-left', '0');
        } else {
          slotElement.style.setProperty('--bs-button-margin-left', '-1px');
        }
      }
    }
  }

  _isButtonElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && (element.localName === 'bs-button' || element.localName === 'bs-input-button' || element.localName === 'bs-link-button');
    }
  }

  _isButtonGroupElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-button-group';
    }
  }

}
window.customElements.define('bs-button-group', BsButtonGroup);

function configureFlushListGroupBorders(assignedNodes) {
  const slotElements = extractOnlyElements(assignedNodes);

  for (let index = 0; index < slotElements.length; ++index) {
    const slotElement = slotElements[index];

    if (isFlushListGroupElement(slotElement)) {
      handleTopBorder(slotElement);
      handleBottomBorder(slotElement);
    }
  }
}

function handleTopBorder(slotElement) {
  const previousElement = slotElement.previousElementSibling;

  if (previousElement) {
    if (isCardHeaderElement(previousElement)) {
      removeListGroupTopBorder(slotElement);
    } else {
      addListGroupTopBorder(slotElement);
    }
  } else {
    removeListGroupTopBorder(slotElement);
  }
}

function handleBottomBorder(slotElement) {
  const nextElement = slotElement.nextElementSibling;

  if (nextElement) {
    addListGroupBottomBorder(slotElement);
  } else {
    addListGroupBottomBorderRadius(slotElement);
  }
}

function removeListGroupTopBorder(element) {
  element.style.setProperty('--flush-list-group-item-top-border', '0');
  element.style.setProperty('--flush-list-group-item-top-left-radius', '0.25rem');
  element.style.setProperty('--flush-list-group-item-top-right-radius', '0.25rem');
}

function addListGroupTopBorder(element) {
  element.style.setProperty('--flush-list-group-item-top-border', '1px solid rgba(0, 0, 0, 0.125)');
}

function addListGroupBottomBorder(element) {
  element.style.setProperty('--flush-list-group-item-bottom-border', '1px solid rgba(0, 0, 0, 0.125)');
}

function addListGroupBottomBorderRadius(element) {
  element.style.setProperty('--flush-list-group-item-bottom-left-radius', '0.25rem');
  element.style.setProperty('--flush-list-group-item-bottom-right-radius', '0.25rem');
}

function extractOnlyElements(slotNodes) {
  const elementNodes = [];

  for (let index = 0; index < slotNodes.length; ++index) {
    let slotItem = slotNodes[index];

    if (isElementButNotSlot(slotItem)) {
      elementNodes.push(slotItem);
    }
  }

  return elementNodes;
}

function isFlushListGroupElement(el) {
  return el.nodeType === Node.ELEMENT_NODE && (el.localName === 'bs-list-group-flush' || el.localName === 'bs-list-group-action-flush');
}

function isElementButNotSlot(el) {
  return el.nodeType === Node.ELEMENT_NODE && el.localName !== 'slot';
}

function isCardHeaderElement(el) {
  return el.nodeType === Node.ELEMENT_NODE && el.localName === 'bs-card-header';
}

function _templateObject2$a() {
  const data = _taggedTemplateLiteral(["\n            <slot name=\"top-image\"></slot>\n            <slot name=\"card-header\"></slot>\n            <slot id=\"content\"></slot>\n            <slot name=\"card-footer\"></slot>\n            <slot name=\"bottom-image\"></slot>\n        "]);

  _templateObject2$a = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1f() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    position: relative;\n                    display: flex;\n                    flex-direction: column;\n                    min-width: 0;\n                    word-wrap: break-word;\n                    background-color: #fff;\n                    background-clip: border-box;\n                    border: 1px solid rgba(0, 0, 0, 0.125);\n                    border-bottom: var(--bs-card-border-bottom, 1px solid rgba(0, 0, 0, 0.125));\n                    border-top-left-radius: var(--bs-card-border-top-left-radius, 0.25rem);\n                    border-top-right-radius: var(--bs-card-border-top-right-radius, 0.25rem);\n                    border-bottom-left-radius: var(--bs-card-border-bottom-left-radius, 0.25rem);\n                    border-bottom-right-radius: var(--bs-card-border-bottom-right-radius, 0.25rem);\n                    margin-left: var(--bs-card-margin-left);\n                    border-left: var(--bs-card-border-left, 1px solid rgba(0, 0, 0, 0.125));\n                }\n\n                hr {\n                    margin-right: 0;\n                    margin-left: 0;\n                }\n\n                :host ::slotted(bs-list-group-flush) {\n                    --flush-list-group-item-top-left-radius: 0;\n                    --flush-list-group-item-top-right-radius: 0;\n                    --flush-list-group-item-bottom-right-radius: 0;\n                    --flush-list-group-item-bottom-left-radius: 0;\n                    --flush-list-group-item-top-border: 1px solid rgba(0, 0, 0, 0.125);\n                    --flush-list-group-item-bottom-border: 1px solid rgba(0, 0, 0, 0.125);\n                }\n\n                :host ::slotted(bs-list-group-action-flush) {\n                    --flush-list-group-item-top-left-radius: 0;\n                    --flush-list-group-item-top-right-radius: 0;\n                    --flush-list-group-item-bottom-right-radius: 0;\n                    --flush-list-group-item-bottom-left-radius: 0;\n                    --flush-list-group-item-top-border: 1px solid rgba(0, 0, 0, 0.125);\n                    --flush-list-group-item-bottom-border: 1px solid rgba(0, 0, 0, 0.125);\n                }\n            "]);

  _templateObject$1f = function _templateObject() {
    return data;
  };

  return data;
}
class BsCard extends LitElement {
  static get styles() {
    return [BsContentRebootCss, BsSizingCss, BsTextCss, css(_templateObject$1f())];
  }

  render() {
    return html(_templateObject2$a());
  }

  firstUpdated() {
    const contentSlotElement = this.shadowRoot.querySelector('slot#content');
    const slotNodes = contentSlotElement.assignedNodes();
    configureFlushListGroupBorders(slotNodes);
  }

}
window.customElements.define('bs-card', BsCard);

function _templateObject2$b() {
  const data = _taggedTemplateLiteral(["\n            <slot name=\"card-title\"></slot>\n            <slot name=\"card-subtitle\"></slot>\n            <slot name=\"card-text\"></slot>\n            <slot id=\"plainSlot\"></slot>\n            <slot name=\"card-links\"></slot>\n        "]);

  _templateObject2$b = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1g() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    flex: 1 1 auto;\n                    padding: 1.25rem;\n                    display: block;\n                }\n        \n                :host > ::slotted([name=\"card-text\"]:last-child) {\n                    margin-bottom: 0;\n                }\n            "]);

  _templateObject$1g = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardBody extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1g())];
  }

  render() {
    return html(_templateObject2$b());
  }

  firstUpdated() {
    this._ifLastChildIsCardTextRemoveBottomMargin();
  }

  _ifLastChildIsCardTextRemoveBottomMargin() {
    const slotElement = this.shadowRoot.querySelector('slot#plainSlot');

    const slotElementNodes = this._getSlotElementNodes(slotElement);

    const cardLinksSlotELement = this.shadowRoot.querySelector('slot[name="card-links"]');

    const cardLinksElementNodes = this._getSlotElementNodes(cardLinksSlotELement); // if nothing was added to the slot node and to the card links node,
    // then find the last element of the card-text and change the margin-bottom


    if (slotElementNodes.length === 0 && cardLinksElementNodes.length === 0) {
      const cardTextElement = this._findCardTextElement();

      if (cardTextElement) {
        const cardTextChildren = cardTextElement.children;
        const lastElementIndex = cardTextChildren.length - 1;
        const lastNode = cardTextChildren[lastElementIndex];
        lastNode.style.marginBottom = '0';
      }
    }
  }

  _getSlotElementNodes(slotElement) {
    const slotNodes = slotElement.assignedNodes();
    const nodeElements = [];

    for (let index = 0; index < slotNodes.length; index++) {
      const element = slotNodes[index];

      if (element.nodeType === Node.ELEMENT_NODE) {
        nodeElements.push(element);
      }
    }

    return nodeElements;
  }

  _findCardTextElement() {
    const cardTextSlotElement = this.shadowRoot.querySelector('slot[name="card-text"]');
    const cardTextAssignedNodes = cardTextSlotElement.assignedNodes();

    for (let index = 0; index < cardTextAssignedNodes.length; index++) {
      const slotItem = cardTextAssignedNodes[index];

      if (this._isCardTextElement(slotItem)) {
        return slotItem;
      }
    }
  }

  _isCardTextElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-card-text';
  }

}
window.customElements.define('bs-card-body', BsCardBody);

function _templateObject2$c() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$c = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1h() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                }\n                \n                :host ::slotted(bs-card) {\n                    margin-bottom: 0.75rem;\n                }\n                \n                @media (min-width: 576px) {\n                    \n                    :host {\n                        -webkit-column-count: var(--card-column-count, 3);\n                        -moz-column-count: var(--card-column-count, 3);\n                        column-count: var(--card-column-count, 3);\n                        -webkit-column-gap: var(--card-column-gap, 1.25rem);\n                        -moz-column-gap: var(--card-column-gap, 1.25rem);\n                        column-gap: var(--card-column-gap, 1.25rem);\n                        orphans: 1;\n                        widows: 1;\n                    }\n                    \n                    :host ::slotted(bs-card) {\n                        display: inline-block;\n                        width: 100%;\n                    }\n                }\n            "]);

  _templateObject$1h = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardColumns extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1h())];
  }

  render() {
    return html(_templateObject2$c());
  }

}
window.customElements.define('bs-card-columns', BsCardColumns);

function _templateObject2$d() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$d = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1i() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: flex;\n                    flex-direction: column;\n                }\n\n                :host ::slotted(bs-card) {\n                    margin-bottom: 15px;\n                }\n\n                @media (min-width: 576px) {\n                    \n                    :host {\n                        flex-flow: row wrap;\n                        margin-right: -15px;\n                        margin-left: -15px;\n                    }\n                    \n                    :host ::slotted(bs-card) {\n                        display: flex;\n                        flex: 1 0 0%;\n                        flex-direction: column;\n                        margin-right: 15px;\n                        margin-bottom: 0;\n                        margin-left: 15px;\n                    }\n                }\n            "]);

  _templateObject$1i = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardDeck extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1i())];
  }

  render() {
    return html(_templateObject2$d());
  }

}
window.customElements.define('bs-card-deck', BsCardDeck);

function _templateObject2$e() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$e = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1j() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    padding: 0.75rem 1.25rem;\n                    background-color: rgba(0, 0, 0, 0.03);\n                    border-top: 1px solid rgba(0, 0, 0, 0.125);\n                    border-bottom-left-radius: var(--card-footer-bottom-left-border-radius);\n                    border-bottom-right-radius: var(--card-footer-bottom-right-border-radius);\n                }\n\n                :host ::slotted(*:last-child) {\n                    border-radius: 0 0 calc(0.25rem - 1px) calc(0.25rem - 1px);\n                }\n            "]);

  _templateObject$1j = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardFooter extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1j())];
  }

  render() {
    return html(_templateObject2$e());
  }

}
window.customElements.define('bs-card-footer', BsCardFooter);

function _templateObject2$f() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$f = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1k() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: flex;\n                    flex-direction: column;\n                }\n\n                :host ::slotted(bs-card) {\n                    margin-bottom: 15px;\n                }\n                \n                @media (min-width: 576px) {\n                    \n                    :host {\n                        flex-flow: row wrap;\n                    }\n                    \n                    :host ::slotted(bs-card) {\n                        flex: 1 0 0%;\n                        margin-bottom: 0;\n                    }\n                    \n                    :host ::slotted(bs-card:first-child) {\n                        border-top-right-radius: 0px;\n                        border-bottom-right-radius: 0px;\n                        --card-header-top-right-border-radius: 0px;\n                        --card-img-top-right-border-radius: 0px;\n                        --card-footer-bottom-right-border-radius: 0px;\n                        --card-img-bottom-right-border-radius: 0px;\n                    }\n                    \n                    :host ::slotted(bs-card:last-child) {\n                        border-top-left-radius: 0px;\n                        border-bottom-left-radius: 0px;\n                        --bs-card-margin-left: 0px;\n                        --bs-card-border-left: 0px;\n                        --card-header-top-left-border-radius: 0px;\n                        --card-footer-bottom-left-border-radius: 0px;\n                        --card-img-top-left-border-radius: 0px;\n                        --card-img-bottom-left-border-radius: 0px;\n                    }\n                    \n                    :host ::slotted(bs-card:only-child) {\n                        border-radius: 0.25rem;\n                        --card-header-top-left-border-radius: 0.25rem;\n                        --card-header-top-right-border-radius: 0.25rem;\n                        --card-footer-bottom-left-border-radius: 0.25rem;\n                        --card-footer-bottom-right-border-radius: 0.25rem;\n                        --card-img-top-left-border-radius: 0.25rem;\n                        --card-img-top-right-border-radius: 0.25rem;\n                        --card-img-bottom-left-border-radius: 0.25rem;\n                        --card-img-bottom-right-border-radius: 0.25rem;\n                    }\n                    \n                    :host ::slotted(bs-card:not(:first-child):not(:last-child):not(:only-child)) {\n                        border-radius: 0;\n                        --bs-card-margin-left: 0px;\n                        --bs-card-border-left: 0px;\n                        --card-footer-bottom-left-border-radius: 0px;\n                        --card-footer-bottom-right-border-radius: 0px;\n                        --card-header-top-left-border-radius: 0px;\n                        --card-header-top-right-border-radius: 0px;\n                        --card-img-top-right-border-radius: 0px;\n                        --card-img-top-left-border-radius: 0px;\n                        --card-img-bottom-right-border-radius: 0px;\n                        --card-img-bottom-left-border-radius: 0px;\n                    }\n                }\n            "]);

  _templateObject$1k = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardGroup extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1k())];
  }

  render() {
    return html(_templateObject2$f());
  }

}
window.customElements.define('bs-card-group', BsCardGroup);

function _templateObject2$g() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$g = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1l() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    padding: 0.75rem 1.25rem;\n                    margin-bottom: 0;\n                    background-color: rgba(0, 0, 0, 0.03);\n                    border-bottom: 1px solid rgba(0, 0, 0, 0.125);\n                    border-top-left-radius: var(--card-header-top-left-border-radius);\n                    border-top-right-radius: var(--card-header-top-right-border-radius);\n                }\n                \n                :host:first-child {\n                    border-radius: calc(0.25rem - 1px) calc(0.25rem - 1px) 0 0;\n                }\n                \n                :host ::slotted(*) + .list-group .list-group-item:first-child {\n                    border-top: 0;\n                }\n        \n                :host ::slotted(bs-nav[tabs]) {\n                    --bs-nav-margin-right: -0.625rem;\n                    --bs-nav-margin-bottom: -0.75rem;\n                    --bs-nav-margin-left: -0.625rem;\n                    --bs-nav-border-bottom: 0;\n                    --nav-link-active-background-color: #fff;\n                }\n        \n                :host ::slotted(bs-nav[pills]) {\n                    --bs-nav-margin-right: -0.625rem;\n                    --bs-nav-margin-left: -0.625rem;\n                }\n            "]);

  _templateObject$1l = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardHeader extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1l())];
  }

  render() {
    return html(_templateObject2$g());
  }

}
window.customElements.define('bs-card-header', BsCardHeader);

function _templateObject2$h() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$h = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1m() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                    width: 100%;\n                }\n        \n                :host ::slotted(img), :host ::slotted(svg) {\n                    width: var(--bs-img-width, 100%);\n                    height: var(--bs-img-height);\n                    display: block;\n                }\n        \n                :host([position=\"top\"]) ::slotted(img),\n                :host([position=\"top\"]) ::slotted(svg) {\n                    border-top-left-radius: var(--card-img-top-left-border-radius, calc(0.25rem - 1px));\n                    border-top-right-radius: var(--card-img-top-right-border-radius, calc(0.25rem - 1px));\n                }\n                \n                :host([position=\"bottom\"]) ::slotted(img),\n                :host([position=\"bottom\"]) ::slotted(svg), {\n                    border-bottom-left-radius: var(--card-img-bottom-left-border-radius, calc(0.25rem - 1px));\n                    border-bottom-right-radius: var(--card-img-bottom-right-border-radius, calc(0.25rem - 1px));\n                }\n        \n                :host([position=\"overlay\"]) :slotted(img),\n                :host([position=\"overlay\"]) :slotted(svg) {\n                    border-radius: calc(0.25rem - 1px);\n                }\n        \n                :host(:not([position=\"top\"]):not([position=\"bottom\"]):not([position=\"overlay\"])) :slotted(img),\n                :host(:not([position=\"top\"]):not([position=\"bottom\"]):not([position=\"overlay\"])) :slotted(svg) {\n                    border-radius: calc(0.25rem - 1px);\n                }\n            "]);

  _templateObject$1m = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardImg extends LitElement {
  static get properties() {
    return {
      position: String
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1m())];
  }

  render() {
    return html(_templateObject2$h());
  }

}
window.customElements.define('bs-card-img', BsCardImg);

function _templateObject2$i() {
  const data = _taggedTemplateLiteral(["\n            <a href=\"", "\">", "</a>\n        "]);

  _templateObject2$i = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1n() {
  const data = _taggedTemplateLiteral(["\n                a {\n                    margin-left: var(--card-link-left-margin, 1.25rem);\n                }\n\n                a:hover {\n                    color: #0056b3;\n                    text-decoration: none;\n                }\n            "]);

  _templateObject$1n = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardLink extends LitElement {
  static get properties() {
    return {
      label: String,
      target: String
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1n())];
  }

  render() {
    return html(_templateObject2$i(), this.target, this.label);
  }

  constructor() {
    super();
    this.label = '';
    this.target = '#';
  }

}
window.customElements.define('bs-card-link', BsCardLink);

function configureCardLinks(assignedNodes) {
  const slotElements = extractOnlyElements$1(assignedNodes);

  for (let index = 0; index < slotElements.length; ++index) {
    const slotElement = slotElements[index];

    if (isCardLinkElement(slotElement)) {
      const previousElement = slotElement.previousElementSibling;

      if (previousElement) {
        if (isCardLinkElement(previousElement)) {
          addLeftMarginToCardLink(slotElement);
        } else {
          removeLeftMarginToCardLink(slotElement);
        }
      } else {
        removeLeftMarginToCardLink(slotElement);
      }
    }
  }
}

function removeLeftMarginToCardLink(element) {
  element.style.setProperty('--card-link-left-margin', '0');
}

function addLeftMarginToCardLink(element) {
  element.style.setProperty('--card-link-left-margin', '1.25rem');
}

function extractOnlyElements$1(slotNodes) {
  const elementNodes = [];

  for (let index = 0; index < slotNodes.length; ++index) {
    let slotItem = slotNodes[index];

    if (isElementButNotSlot$1(slotItem)) {
      elementNodes.push(slotItem);
    }
  }

  return elementNodes;
}

function isCardLinkElement(el) {
  return el.nodeType === Node.ELEMENT_NODE && el.localName === 'bs-card-link';
}

function isElementButNotSlot$1(el) {
  return el.nodeType === Node.ELEMENT_NODE && el.localName !== 'slot';
}

function _templateObject2$j() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$j = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1o() {
  const data = _taggedTemplateLiteral(["\n                :host ::slotted(*):hover {\n                    color: red;\n                    text-decoration: underline;\n                }\n            "]);

  _templateObject$1o = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardLinks extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1o())];
  }

  render() {
    return html(_templateObject2$j());
  }

  firstUpdated() {
    const slotElement = this.shadowRoot.querySelector('slot');
    const slotNodes = slotElement.assignedNodes();
    configureCardLinks(slotNodes);
  }

}
window.customElements.define('bs-card-links', BsCardLinks);

function _templateObject2$k() {
  const data = _taggedTemplateLiteral(["\n            <slot name=\"card-title\"></slot>\n            <slot name=\"card-subtitle\"></slot>\n            <slot name=\"card-text\"></slot>\n            <slot id=\"plainSlot\"></slot>\n            <slot name=\"card-links\"></slot>\n        "]);

  _templateObject2$k = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1p() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    position: absolute;\n                    top: 0;\n                    right: 0;\n                    bottom: 0;\n                    left: 0;\n                    padding: 1.25rem;\n                }\n            "]);

  _templateObject$1p = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardOverlay extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1p())];
  }

  render() {
    return html(_templateObject2$k());
  }

}
window.customElements.define('bs-card-overlay', BsCardOverlay);

function _templateObject2$l() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$l = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1q() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    margin-top: -0.375rem;\n                    margin-bottom: 0;\n                }\n            "]);

  _templateObject$1q = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardSubtitle extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1q())];
  }

  render() {
    return html(_templateObject2$l());
  }

}
window.customElements.define('bs-card-subtitle', BsCardSubtitle);

function _templateObject2$m() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$m = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1r() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                }\n        \n                :host > ::slotted(*:last-child) {\n                    margin-bottom: 0;\n                }\n            "]);

  _templateObject$1r = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardText extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1r())];
  }

  render() {
    return html(_templateObject2$m());
  }

}
window.customElements.define('bs-card-text', BsCardText);

function _templateObject2$n() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$n = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1s() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    margin-bottom: 0.75rem;\n                }\n            "]);

  _templateObject$1s = function _templateObject() {
    return data;
  };

  return data;
}
class BsCardTitle extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1s())];
  }

  render() {
    return html(_templateObject2$n());
  }

}
window.customElements.define('bs-card-title', BsCardTitle);

function _templateObject2$o() {
  const data = _taggedTemplateLiteral(["\n            <slot name=\"indicators\"></slot>\n            <div class=\"carousel-inner\">\n                <slot id=\"items\"></slot>\n                <slot name=\"control-prev\"></slot>\n                <slot name=\"control-next\"></slot>\n            </div>\n        "]);

  _templateObject2$o = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1t() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                    position: relative;\n                }\n                \n                :host(:hover),\n                :host(:focus) {\n                    color: #fff;\n                    text-decoration: none;\n                    outline: 0;\n                }\n                \n                .carousel-inner {\n                    position: relative;\n                    width: 100%;\n                    overflow: hidden;\n                }\n            "]);

  _templateObject$1t = function _templateObject() {
    return data;
  };

  return data;
}
const Direction = {
  NEXT: 'next',
  PREV: 'prev',
  LEFT: 'left',
  RIGHT: 'right'
};
class BsCarousel extends LitElement {
  static get properties() {
    return {
      interval: {
        type: Number,
        reflect: true
      },
      keyboard: {
        type: Boolean,
        reflect: true
      },
      pause: {
        type: Boolean,
        reflect: true
      },
      ride: {
        type: String,
        reflect: true
      },
      wrap: {
        type: Boolean,
        reflect: true
      },
      slide: {
        type: Boolean,
        reflect: true
      },
      fade: {
        type: Boolean,
        reflect: true
      },
      _isSliding: Boolean,
      _isPaused: Boolean,
      _intervalId: Number,
      _touchTimeoutId: Number
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1t())];
  }

  render() {
    return html(_templateObject2$o());
  }

  constructor() {
    super();
    this.interval = 5000;
    this.keyboard = true;
    this.pause = 'hover';
    this.ride = 'carousel';
    this.wrap = true;
    this.slide = 'next';
    this.fade = false;
    this._isSliding = false;
    this._isPaused = false;
  }

  firstUpdated() {
    this.addEventListener('bs-carousel-control-prev-click', () => this._prev());
    this.addEventListener('bs-carousel-control-next-click', () => this._next());
    this.addEventListener('bs-carousel-indicator-click', event => this._handleIndicatorClick(event));

    if (this.fade) {
      this._setCarouselItemsToFade();
    }

    if (this.keyboard) {
      this.setAttribute('tabIndex', '1');
      this.addEventListener('keydown', event => this._handleArrowKeys(event));
    }

    if (this.pause === 'hover') {
      this.addEventListener('mouseenter', event => this._handlePauseOnMouseEnter(event));
      this.addEventListener('mouseleave', event => this._handleResumeOnMouseLeave(event));

      if ('ontouchstart' in document.documentElement) {
        this.addEventListener('touchend', event => this._handlePauseOnTouch(event));
      }
    }

    if (this.interval) {
      this._cycle();
    }
  }

  _handlePauseOnMouseEnter(event) {
    this._pause(event);
  }

  _handleResumeOnMouseLeave(event) {
    this._cycle(event);
  }

  _handlePauseOnTouch(event) {
    this._pause(event);

    if (this._touchTimeoutId) {
      clearTimeout(this._touchTimeoutId);
    }

    const TOUCHEVENT_COMPAT_WAIT = 500;

    const resumeFunction = this._resumeFunction.bind(this);

    const resumeTimeout = this.interval + TOUCHEVENT_COMPAT_WAIT;
    this._touchTimeoutId = setTimeout(resumeFunction, resumeTimeout);
  }

  _resumeFunction(event) {
    return this._cycle(event);
  }

  _handleArrowKeys(event) {
    const targetTagName = event.target.tagName;

    if (targetTagName === 'INPUT' || targetTagName === 'TEXTAREA') {
      return;
    }

    const ARROW_LEFT_KEYCODE = 37;
    const ARROW_RIGHT_KEYCODE = 39;

    switch (event.which) {
      case ARROW_LEFT_KEYCODE:
        event.preventDefault();

        this._prev();

        break;

      case ARROW_RIGHT_KEYCODE:
        event.preventDefault();

        this._next();

        break;

      default:
        break;
    }
  }

  _handleIndicatorClick(event) {
    const slideIndex = event.detail.index;

    if (slideIndex >= 0) {
      this._to(slideIndex);
    }
  }

  _prev() {
    if (!this._isSliding) {
      this._slide(Direction.PREV);
    }
  }

  _next() {
    if (!this._isSliding) {
      this._slide(Direction.NEXT);
    }
  }

  _nextWhenVisible() {
    const documentIsHidden = document.hidden;
    const hostVisible = window.getComputedStyle(this.shadowRoot.host, ':visible');
    const hostVisibility = window.getComputedStyle(this.shadowRoot.host).getPropertyValue('visibility'); // Don't call next if: 
    // - the page isn't visible 
    // - the carousel isn't visible
    // - the parent node isn't visible

    if (!documentIsHidden && hostVisible && hostVisibility !== 'hidden') {
      this._next();
    }
  }

  _pause(event) {
    if (!event) {
      this._isPaused = true;
    }

    const carouselItemHaveNextOrPrev = this._carouselItemsHaveNextOrPrev();

    if (carouselItemHaveNextOrPrev) {
      this._isSliding = false;

      this._cycle(true);
    }

    clearInterval(this._intervalId);
    this._intervalId = null;
  }

  _cycle(event) {
    if (!event) {
      this._isPaused = false;
    }

    if (this._intervalId) {
      clearInterval(this._intervalId);
      this._intervalId = null;
    }

    if (this.interval && !this._isPaused) {
      const nextFunction = this._cycleFunction.bind(this);

      this._intervalId = setInterval(nextFunction, this.interval);
    }
  }

  _cycleFunction() {
    if (document.visibilityState) {
      return this._nextWhenVisible();
    } else {
      return this._next();
    }
  }

  _to(index) {
    const carouselItems = this._retrieveCarouselItems();

    const activeElement = this._extractActiveCarouseItem(carouselItems);

    const activeElementIndex = this._getCarouselItemIndex(carouselItems, activeElement);

    if (activeElementIndex > carouselItems.length - 1 || activeElementIndex < 0) {
      return;
    }

    if (this._isSliding) {
      activeElement.addEventListener('bs-carousel-slide', () => this._to(index), {
        once: true
      });
      return;
    }

    if (activeElementIndex === index) {
      this.pause();
      this.cycle();
      return;
    }

    const direction = index > activeElementIndex ? Direction.NEXT : Direction.PREV;
    const targetElement = carouselItems[index];

    this._slide(direction, targetElement);
  }

  _slide(direction, targetElement) {
    const carouselItems = this._retrieveCarouselItems();

    const activeElement = this._extractActiveCarouseItem(carouselItems);

    const activeElementIndex = this._getCarouselItemIndex(carouselItems, activeElement);

    let nextElement;
    let nextElementIndex;

    if (targetElement) {
      nextElement = targetElement;
      nextElementIndex = this._getCarouselItemIndex(carouselItems, targetElement);
    } else {
      nextElement = this._getNextItemByDirection(direction, activeElement, carouselItems);
      nextElementIndex = this._getCarouselItemIndex(carouselItems, nextElement);
    }

    const isCycling = Boolean(this._intervalId);
    let directionalClassName;
    let orderClassName;
    let eventDirectionName;

    if (direction === Direction.NEXT) {
      directionalClassName = 'left';
      orderClassName = 'next';
      eventDirectionName = Direction.LEFT;
    } else {
      directionalClassName = 'right';
      orderClassName = 'prev';
      eventDirectionName = Direction.RIGHT;
    }

    if (nextElement && nextElement.hasAttribute('active')) {
      this._isSliding = false;
      return;
    }

    const slideEventResult = this._triggerSlideEvent(activeElementIndex, nextElement, nextElementIndex, eventDirectionName);

    if (!slideEventResult) {
      return;
    }

    if (!activeElement || !nextElement) {
      return;
    }

    this._isSliding = true;

    if (isCycling) {
      this._pause();
    }

    this._setActiveIndicatorElement(nextElementIndex);

    const slideTransitionCompleteEvent = new CustomEvent('bs-carousel-slide-before-transition', {
      bubbles: true,
      composed: true,
      detail: {
        relatedTarget: nextElement,
        direction: eventDirectionName,
        from: activeElementIndex,
        to: nextElementIndex
      }
    });

    if (this.slide) {
      nextElement.setAttribute(orderClassName, '');
      nextElement.offsetHeight;
      activeElement.setAttribute(directionalClassName, '');
      nextElement.setAttribute(directionalClassName, '');
      activeElement.addEventListener('transitionend', () => {
        nextElement.removeAttribute(directionalClassName);
        nextElement.removeAttribute(orderClassName);
        nextElement.setAttribute('active', '');
        activeElement.removeAttribute('active');
        activeElement.removeAttribute(orderClassName);
        activeElement.removeAttribute(directionalClassName);
        this._isSliding = false;
        this.dispatchEvent(slideTransitionCompleteEvent);
      }, {
        once: true
      });
    } else {
      activeElement.removeAttribute('active');
      nextElement.setAttribute('active', '');
      this._isSliding = false;
      this.dispatchEvent(slideTransitionCompleteEvent);
    }

    if (isCycling) {
      this._cycle();
    }
  }

  _getTransitionDurationFromElement(element) {
    if (!element) {
      return 0;
    }

    let transitionDuration = window.getComputedStyle(element).getPropertyValue('transition-duration');
    const floatTransitionDuration = parseFloat(transitionDuration);

    if (!floatTransitionDuration) {
      return 0;
    }

    transitionDuration = transitionDuration.split(',')[0];
    return parseFloat(transitionDuration) * 1000;
  }

  _triggerSlideEvent(activeElementIndex, nextElement, nextElementIndex, eventDirectionName) {
    const slideEvent = new CustomEvent('bs-carousel-slide', {
      bubbles: true,
      composed: true,
      detail: {
        relatedTarget: nextElement,
        direction: eventDirectionName,
        from: activeElementIndex,
        to: nextElementIndex
      }
    });
    return this.dispatchEvent(slideEvent);
  }

  _setActiveIndicatorElement(nextElementIndex) {
    const indicatorsSlot = this.shadowRoot.querySelector('slot[name="indicators"]');

    if (indicatorsSlot) {
      const indicatorsSlotNodes = indicatorsSlot.assignedNodes();

      const carouselIndicatorsElement = this._extractOnlyCarouselIndicators(indicatorsSlotNodes);

      if (carouselIndicatorsElement) {
        carouselIndicatorsElement.updateActiveIndicatorElement(nextElementIndex);
      }
    }
  }

  _getNextItemByDirection(direction, activeItem, carouselItems) {
    const isNextDirection = direction === Direction.NEXT;
    const isPrevDirection = direction === Direction.PREV;

    const activeItemIndex = this._getCarouselItemIndex(carouselItems, activeItem);

    const lastItemIndex = carouselItems.length - 1;
    const isGoingToWrap = isPrevDirection && activeItemIndex === 0 || isNextDirection && activeItemIndex === lastItemIndex;

    if (isGoingToWrap && !this.wrap) {
      return activeItem;
    }

    const delta = direction === Direction.PREV ? -1 : 1;
    const itemIndex = (activeItemIndex + delta) % carouselItems.length;

    if (itemIndex === -1) {
      return carouselItems[carouselItems.length - 1];
    }

    return carouselItems[itemIndex];
  }

  _retrieveCarouselItems() {
    const slotNode = this.shadowRoot.querySelector('slot#items');
    const slotNodes = slotNode.assignedNodes();

    const carouselItems = this._extractOnlyCarouselItems(slotNodes);

    return carouselItems;
  }

  _setCarouselItemsToFade() {
    const carouselItems = this._retrieveCarouselItems();

    for (let index = 0; index < carouselItems.length; index++) {
      const carouselItem = carouselItems[index];

      if (this._isCarouselItemElement(carouselItem)) {
        carouselItem.setAttribute('fade', '');
      }
    }
  }

  _carouselItemsHaveNextOrPrev() {
    const carouselItems = this._retrieveCarouselItems();

    for (let index = 0; index < carouselItems.length; index++) {
      const carouselItem = carouselItems[index];

      if (this._isCarouselItemElement(carouselItem)) {
        if (carouselItem.hasAttribute(Direction.NEXT) || carouselItem.hasAttribute(Direction.PREV)) {
          return true;
        }
      }
    }

    return false;
  }

  _getCarouselItemIndex(carouselItems, carouselItem) {
    return carouselItems.indexOf(carouselItem);
  }

  _extractActiveCarouseItem(carouselItems) {
    for (let index = 0; index < carouselItems.length; index++) {
      const carouselItem = carouselItems[index];

      if (this._isCarouselItemActive(carouselItem)) {
        return carouselItem;
      }
    }
  }

  _extractOnlyCarouselIndicators(slotNodes) {
    for (let index = 0; index < slotNodes.length; index++) {
      const slotItem = slotNodes[index];

      if (this._isCarouselIndicatorsElement(slotItem)) {
        return slotItem;
      }
    }
  }

  _extractOnlyCarouselItems(slotNodes) {
    const elementNodes = [];

    for (let index = 0; index < slotNodes.length; index++) {
      const slotItem = slotNodes[index];

      if (this._isCarouselItemElement(slotItem)) {
        elementNodes.push(slotItem);
      }
    }

    return elementNodes;
  }

  _isCarouselItemActive(carouselItem) {
    return carouselItem.hasAttribute('active');
  }

  _isCarouselItemElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-carousel-item';
  }

  _isCarouselIndicatorsElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-carousel-indicators';
  }

}
window.customElements.define('bs-carousel', BsCarousel);

function _templateObject2$p() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$p = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1u() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    position: absolute;\n                    right: 15%;\n                    bottom: 20px;\n                    left: 15%;\n                    z-index: 10;\n                    padding-top: 20px;\n                    padding-bottom: 20px;\n                    color: #fff;\n                    text-align: center;\n                }\n            "]);

  _templateObject$1u = function _templateObject() {
    return data;
  };

  return data;
}
class BsCarouselCaption extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1u())];
  }

  render() {
    return html(_templateObject2$p());
  }

}
window.customElements.define('bs-carousel-caption', BsCarouselCaption);

function _templateObject2$q() {
  const data = _taggedTemplateLiteral(["\n            <a class=\"carousel-control-next\">\n                <span class=\"icon\"></span>\n            </a>\n        "]);

  _templateObject2$q = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1v() {
  const data = _taggedTemplateLiteral(["\n                .carousel-control-next {\n                    position: absolute;\n                    top: 0;\n                    bottom: 0;\n                    z-index: 1;\n                    display: flex;\n                    align-items: center;\n                    justify-content: center;\n                    width: 15%;\n                    color: #fff;\n                    text-align: center;\n                    opacity: 0.5;\n                    cursor: pointer;\n                    right: 0;\n                }\n        \n                .carousel-control-next:hover,\n                .carousel-control-next:focus {\n                    color: #fff;\n                    text-decoration: none;\n                    outline: 0;\n                    opacity: 0.9;\n                }\n                \n                .icon {\n                    display: inline-block;\n                    width: 20px;\n                    height: 20px;\n                    background: no-repeat 50%/100% 100%;\n                    background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 fill=%27%23fff%27 viewBox=%270 0 8 8%27%3E%3Cpath d=%27M2.75 0l-1.5 1.5 2.5 2.5-2.5 2.5 1.5 1.5 4-4-4-4z%27/%3E%3C/svg%3E\");\n                }\n            "]);

  _templateObject$1v = function _templateObject() {
    return data;
  };

  return data;
}
class BsCarouselControlNext extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1v())];
  }

  render() {
    return html(_templateObject2$q());
  }

  firstUpdated() {
    const nextLink = this.shadowRoot.querySelector('a.carousel-control-next');
    nextLink.addEventListener('click', event => this._handleClickEvent(event));
  }

  _handleClickEvent(event) {
    event.preventDefault();
    const nextControlClickEvent = new CustomEvent('bs-carousel-control-next-click', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(nextControlClickEvent);
  }

}
window.customElements.define('bs-carousel-control-next', BsCarouselControlNext);

function _templateObject2$r() {
  const data = _taggedTemplateLiteral(["\n            <a class=\"carousel-control-prev\">\n                <span class=\"icon\"></span>\n            </a>\n        "]);

  _templateObject2$r = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1w() {
  const data = _taggedTemplateLiteral(["\n                .carousel-control-prev {\n                    position: absolute;\n                    top: 0;\n                    bottom: 0;\n                    z-index: 1;\n                    display: flex;\n                    align-items: center;\n                    justify-content: center;\n                    width: 15%;\n                    color: #fff;\n                    text-align: center;\n                    opacity: 0.5;\n                    cursor: pointer;\n                    left: 0;\n                }\n            \n                .carousel-control-prev:hover, \n                .carousel-control-prev:focus {\n                    color: #fff;\n                    text-decoration: none;\n                    outline: 0;\n                    opacity: 0.9;\n                }\n        \n                .icon {\n                    display: inline-block;\n                    width: 20px;\n                    height: 20px;\n                    background: no-repeat 50%/100% 100%;\n                    background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg xmlns=%27http://www.w3.org/2000/svg%27 fill=%27%23fff%27 viewBox=%270 0 8 8%27%3E%3Cpath d=%27M5.25 0l-4 4 4 4 1.5-1.5-2.5-2.5 2.5-2.5-1.5-1.5z%27/%3E%3C/svg%3E\");\n                }\n            "]);

  _templateObject$1w = function _templateObject() {
    return data;
  };

  return data;
}
class BsCarouselControlPrev extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1w())];
  }

  render() {
    return html(_templateObject2$r());
  }

  firstUpdated() {
    const prevLink = this.shadowRoot.querySelector('a.carousel-control-prev');
    prevLink.addEventListener('click', event => this._handleClickEvent(event));
  }

  _handleClickEvent(event) {
    event.preventDefault();
    const prevControlClickEvent = new CustomEvent('bs-carousel-control-prev-click', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(prevControlClickEvent);
  }

}
window.customElements.define('bs-carousel-control-prev', BsCarouselControlPrev);

function _templateObject$1x() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    position: relative;\n                    flex: 0 1 auto;\n                    width: 30px;\n                    height: 3px;\n                    margin-right: 3px;\n                    margin-left: 3px;\n                    text-indent: -999px;\n                    cursor: pointer;\n                    background-color: rgba(255, 255, 255, 0.5);\n                }\n                \n                :host([active]) {\n                    background-color: #fff;\n                }\n        \n                :host::before {\n                    position: absolute;\n                    top: -10px;\n                    left: 0;\n                    display: inline-block;\n                    width: 100%;\n                    height: 10px;\n                    content: \"\";\n                }\n        \n                :host::after {\n                    position: absolute;\n                    bottom: -10px;\n                    left: 0;\n                    display: inline-block;\n                    width: 100%;\n                    height: 10px;\n                    content: \"\";\n                }\n            "]);

  _templateObject$1x = function _templateObject() {
    return data;
  };

  return data;
}
class BsCarouselIndicator extends LitElement {
  static get properties() {
    return {
      index: Number,
      active: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1x())];
  }

  constructor() {
    super();
    this.index = 0;
    this.active = false;
  }

  firstUpdated() {
    this.addEventListener('click', event => this._handleClickEvent(event));
  }

  _handleClickEvent(event) {
    event.preventDefault();
    const indicatorClickEvent = new CustomEvent('bs-carousel-indicator-click', {
      bubbles: true,
      composed: true,
      detail: {
        index: this.index
      }
    });
    this.dispatchEvent(indicatorClickEvent);
  }

}
window.customElements.define('bs-carousel-indicator', BsCarouselIndicator);

function _templateObject2$s() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$s = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1y() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    position: absolute;\n                    right: 0;\n                    bottom: 10px;\n                    left: 0;\n                    z-index: 15;\n                    display: flex;\n                    justify-content: center;\n                    padding-left: 0;\n                    margin-right: 15%;\n                    margin-left: 15%;\n                    margin-bottom: 1rem;\n                }\n            "]);

  _templateObject$1y = function _templateObject() {
    return data;
  };

  return data;
}
class BsCarouselIndicators extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1y())];
  }

  render() {
    return html(_templateObject2$s());
  }

  updateActiveIndicatorElement(nextElementIndex) {
    const slotNode = this.shadowRoot.querySelector('slot');
    const slotNodes = slotNode.assignedNodes();

    const indicatorItems = this._extractOnlyIndicatorItems(slotNodes);

    const activeIndicator = this._extractActiveIndicatorItem(indicatorItems);

    if (activeIndicator) {
      activeIndicator.removeAttribute('active');
    }

    const nextIndicator = indicatorItems[nextElementIndex];

    if (nextIndicator) {
      nextIndicator.setAttribute('active', '');
    }
  }

  _extractActiveIndicatorItem(indicatorItems) {
    for (let index = 0; index < indicatorItems.length; index++) {
      const indicatorItem = indicatorItems[index];

      if (this._isIndicatorItemActive(indicatorItem)) {
        return indicatorItem;
      }
    }
  }

  _isIndicatorItemActive(indicatorItem) {
    return indicatorItem.hasAttribute('active');
  }

  _extractOnlyIndicatorItems(slotNodes) {
    const elementNodes = [];

    for (let index = 0; index < slotNodes.length; index++) {
      const slotItem = slotNodes[index];

      if (this._isCarouselIndicatorElement(slotItem)) {
        elementNodes.push(slotItem);
      }
    }

    return elementNodes;
  }

  _isCarouselIndicatorElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-carousel-indicator';
  }

}
window.customElements.define('bs-carousel-indicators', BsCarouselIndicators);

function _templateObject2$t() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n            <slot name=\"caption\"></slot>\n        "]);

  _templateObject2$t = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1z() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    position: relative;\n                    display: none;\n                    align-items: center;\n                    width: 100%;\n                    -webkit-backface-visibility: hidden;\n                    backface-visibility: hidden;\n                    -webkit-perspective: 1000px;\n                    perspective: 1000px;\n                }\n                \n                :host([active]),\n                :host([next]),\n                :host([prev]) {\n                    display: block;\n                    transition: -webkit-transform 0.6s ease;\n                    transition: transform 0.6s ease;\n                    transition: transform 0.6s ease, -webkit-transform 0.6s ease;\n                }\n        \n                @media screen and (prefers-reduced-motion: reduce) {\n                    :host([active]),\n                    :host([next]),\n                    :host([prev]) {\n                        transition: none;\n                    }\n                }\n        \n                :host([active]),\n                :host([next]),\n                :host([prev]) {\n                    display: block;\n                }\n        \n                :host([next]),\n                :host([prev]) {\n                    position: absolute;\n                    top: 0;\n                }\n        \n                :host([next][left]),\n                :host([prev][right]) {\n                    -webkit-transform: translateX(0);\n                    transform: translateX(0);\n                }\n                \n                @supports ((-webkit-transform-style: preserve-3d) or (transform-style: preserve-3d)) {\n                    :host([next][left]),\n                    :host([prev][right]) {\n                        -webkit-transform: translate3d(0, 0, 0);\n                        transform: translate3d(0, 0, 0);\n                    }\n                }\n        \n                :host([next]),\n                :host([active][right]) {\n                    -webkit-transform: translateX(100%);\n                    transform: translateX(100%);\n                }\n        \n                @supports ((-webkit-transform-style: preserve-3d) or (transform-style: preserve-3d)) {\n                    :host([next]),\n                    :host([active][right]) {\n                        -webkit-transform: translate3d(100%, 0, 0);\n                        transform: translate3d(100%, 0, 0);\n                    }\n                }\n        \n                :host([prev]),\n                :host([active][left]) {\n                    -webkit-transform: translateX(-100%);\n                    transform: translateX(-100%);\n                }\n        \n                @supports ((-webkit-transform-style: preserve-3d) or (transform-style: preserve-3d)) {\n                    :host([prev]),\n                    :host([active][left]) {\n                        -webkit-transform: translate3d(-100%, 0, 0);\n                        transform: translate3d(-100%, 0, 0);\n                    }\n                }\n        \n                :host([fade]) {\n                    opacity: 0;\n                    transition-duration: .6s;\n                    transition-property: opacity;\n                }\n        \n                :host([fade][active]),\n                :host([fade][next][left]),\n                :host([fade][next][right]) {\n                    opacity: 1;\n                }\n        \n                :host([fade][left]),\n                :host([fade][active][right]) {\n                    opacity: 0;\n                }\n                \n                :host([fade][next]),\n                :host([fade][prev]),\n                :host([fade][active]),\n                :host([fade][active][left]),\n                :host([fade][active][prev]) {\n                    -webkit-transform: translateX(0);\n                    transform: translateX(0);\n                }\n        \n                @supports ((-webkit-transform-style: preserve-3d) or (transform-style: preserve-3d)) {\n                    :host([fade][next]),\n                    :host([fade][prev]),\n                    :host([fade][active]),\n                    :host([fade][active][left]),\n                    :host([fade][active][prev]) {\n                        -webkit-transform: translate3d(0, 0, 0);\n                        transform: translate3d(0, 0, 0);\n                    }\n                }\n            "]);

  _templateObject$1z = function _templateObject() {
    return data;
  };

  return data;
}
class BsCarouselItem extends LitElement {
  static get properties() {
    return {
      next: {
        type: Boolean,
        reflect: true
      },
      prev: {
        type: Boolean,
        reflect: true
      },
      fade: {
        type: Boolean,
        reflect: true
      },
      active: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1z())];
  }

  render() {
    return html(_templateObject2$t());
  }

  constructor() {
    super();
    this.next = false;
    this.prev = false;
    this.fade = false;
    this.active = false;
  }

}
window.customElements.define('bs-carousel-item', BsCarouselItem);

function _templateObject$1A() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([split]) ::slotted(bs-button:not(:last-child)),\n    :host([split]) ::slotted(bs-link-button:not(:last-child)),\n    :host([split]) ::slotted(bs-input-button:not(:last-child)) {\n        --bs-button-border-top-right-radius: 0;\n        --bs-button-border-bottom-right-radius: 0;\n    }\n\n    :host([split]) ::slotted(bs-button:not(:first-child)),\n    :host([split]) ::slotted(bs-link-button:not(:first-child)),\n    :host([split]) ::slotted(bs-input-button:not(:first-child)) {\n        --bs-button-border-top-left-radius: 0;\n        --bs-button-border-bottom-left-radius: 0;\n    }\n    \n    :host([split]) ::slotted(bs-button[dropdown-toggle]),\n    :host([split]) ::slotted(bs-link-button[dropdown-toggle]),\n    :host([split]) ::slotted(bs-input-button[dropdown-toggle]) {\n        --bs-button-border-top-right-radius: var(--dropdown-toggle-border-top-right, 0.25rem);\n        --bs-button-border-bottom-right-radius: var(--dropdown-toggle-border-bottom-right, 0.25rem);\n        --bs-button-padding-left: 0.5625rem;\n        --bs-button-padding-right: 0.5625rem;\n        --bs-button-after-margin-left: 0;\n        --bs-button-margin-left: var(--dropdown-toggle-margin-left);\n    }\n    \n    /* applies to drop-left split dropdown */\n    :host([split]) ::slotted(bs-button[dropdown-toggle]:first-child),\n    :host([split]) ::slotted(bs-link-button[dropdown-toggle]:first-child),\n    :host([split]) ::slotted(bs-input-button[dropdown-toggle]:first-child) {\n        --bs-button-border-top-right-radius: 0;\n        --bs-button-border-bottom-right-radius: 0;\n        --bs-button-padding-left: 0.5625rem;\n        --bs-button-padding-right: 0.5625rem;\n        --bs-button-after-margin-left: 0;\n    }\n"]);

  _templateObject$1A = function _templateObject() {
    return data;
  };

  return data;
}
const BsDropdownSplitCss = css(_templateObject$1A());

function _templateObject$1B() {
  const data = _taggedTemplateLiteral(["\n    \n    :host ::slotted(bs-button[dropdown-toggle]),\n    :host ::slotted(bs-link-button[dropdown-toggle]),\n    :host ::slotted(bs-input-button[dropdown-toggle]) {\n        --bs-button-after-display: inline-block;\n        --bs-button-after-width: 0;\n        --bs-button-after-height: 0;\n        --bs-button-after-margin-left: 0.255em;\n        --bs-button-after-vertical-align: 0.255em;\n        --bs-button-after-content: \"\";\n        --bs-button-after-border-top: 0.3em solid;\n        --bs-button-after-border-right: 0.3em solid transparent;\n        --bs-button-after-border-bottom: 0;\n        --bs-button-after-border-left: 0.3em solid transparent;\n        --bs-button-empty-after-margin-left: 0;\n    }\n    \n    :host ::slotted(bs-button[dropdown-toggle][dropup]),\n    :host ::slotted(bs-link-button[dropdown-toggle][dropup]),\n    :host ::slotted(bs-input-button[dropdown-toggle][dropup]) {\n        --bs-button-after-display: inline-block;\n        --bs-button-after-width: 0;\n        --bs-button-after-height: 0;\n        --bs-button-after-margin-left: 0.255em;\n        --bs-button-after-vertical-align: 0.255em;\n        --bs-button-after-content: \"\";\n        --bs-button-after-border-top: 0;\n        --bs-button-after-border-right: 0.3em solid transparent;\n        --bs-button-after-border-bottom: 0.3em solid;\n        --bs-button-after-border-left: 0.3em solid transparent;\n        --bs-button-empty-after-margin-left: 0;\n    }\n\n    :host ::slotted(bs-button[dropdown-toggle][dropright]),\n    :host ::slotted(bs-link-button[dropdown-toggle][dropright]),\n    :host ::slotted(bs-input-button[dropdown-toggle][dropright]) {\n        --bs-button-after-display: inline-block;\n        --bs-button-after-width: 0;\n        --bs-button-after-height: 0;\n        --bs-button-after-margin-left: 0.255em;\n        --bs-button-after-vertical-align: 0;\n        --bs-button-after-content: \"\";\n        --bs-button-after-border-top: 0.3em solid transparent;\n        --bs-button-after-border-right: 0;\n        --bs-button-after-border-bottom: 0.3em solid transparent;\n        --bs-button-after-border-left: 0.3em solid;\n        --bs-button-empty-after-margin-left: 0;\n    }\n\n    :host ::slotted(bs-button[dropdown-toggle][dropleft])\n    :host ::slotted(bs-link-button[dropdown-toggle][dropleft]),\n    :host ::slotted(bs-input-button[dropdown-toggle][dropleft]) {\n        --bs-button-after-display: none;\n        --bs-button-after-width: 0;\n        --bs-button-after-height: 0;\n        --bs-button-after-margin-left: 0.255em;\n        --bs-button-after-vertical-align: 0.255em;\n        --bs-button-after-content: \"\";\n        --bs-button-empty-after-margin-left: 0;\n        --bs-button-before-display: inline-block;\n        --bs-button-before-width: 0;\n        --bs-button-before-height: 0;\n        --bs-button-before-margin-right: 0.255em;\n        --bs-button-before-vertical-align: 0;\n        --bs-button-before-content: \"\";\n        --bs-button-before-border-top: 0.3em solid transparent;\n        --bs-button-before-border-right: 0.3em solid;\n        --bs-button-before-border-bottom: 0.3em solid transparent;\n    }\n"]);

  _templateObject$1B = function _templateObject() {
    return data;
  };

  return data;
}
const BsDropdownToggleCss = css(_templateObject$1B());

function _templateObject$1C() {
  const data = _taggedTemplateLiteral(["\n    \n    :host ::slotted(bs-button[dropdown-nav-link]),\n    :host ::slotted(bs-link-button[dropdown-nav-link]),\n    :host ::slotted(bs-input-button[dropdown-nav-link]) {\n        \n        --bs-button-display: block;\n        --bs-button-border: 1px solid transparent;\n        --bs-button-border-top-left-radius: 0.25rem;\n        --bs-button-border-top-right-radius: 0.25rem;\n        --bs-button-padding-bottom: var(--dropdown-nav-link-padding-bottom);\n        --bs-button-padding-left: var(--dropdown-nav-link-padding-left);\n        --bs-button-padding-right: var(--dropdown-nav-link-padding-right);\n        --bs-button-border-bottom-right-radius: var(--nav-link-active-border-bottom-right-radius, 0);\n        --bs-button-border-bottom-left-radius: var(--nav-link-active-border-bottom-left-radius, 0);\n        --bs-button-color: var(--dropdown-nav-link-color, #007bff);\n        \n        --bs-button-background-color: var(--dropdown-nav-link-background-color);\n        --bs-button-color-hover: var(--dropdown-nav-link-hover-color);\n        --bs-button-color-focus: var(--dropdown-nav-link-hover-color);\n        --bs-button-box-shadow-hover: none;\n        --bs-button-box-shadow-focus: none;\n        \n        --bs-button-border-color-hover: var(--dropdown-nav-link-hover-border-color, #e9ecef #e9ecef #dee2e6);\n        --bs-button-border-color-focus: var(--dropdown-nav-link-hover-border-color, #e9ecef #e9ecef #dee2e6);\n    }\n\n    :host ::slotted(bs-button[dropdown-nav-link][active]),\n    :host ::slotted(bs-link-button[dropdown-nav-link][active]),\n    :host ::slotted(bs-input-button[dropdown-nav-link][active]) {\n        \n        --bs-button-color: var(--dropdown-nav-link-active-color);\n        --bs-button-color-hover: var(--dropdown-nav-link-active-hover-color);\n        --bs-button-color-focus: var(--dropdown-nav-link-active-focus-color);\n        --bs-button-background-color: var(--dropdown-nav-link-active-background-color);\n    }\n"]);

  _templateObject$1C = function _templateObject() {
    return data;
  };

  return data;
}
const BsDropdownNavCss = css(_templateObject$1C());

function _templateObject2$u() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$u = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1D() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    position: relative;\n                    display: var(--dropdown-display, flex);\n                }\n            "]);

  _templateObject$1D = function _templateObject() {
    return data;
  };

  return data;
}
class BsDropdown extends LitElement {
  static get properties() {
    return {
      _popper: Popper,
      offset: String,
      split: Boolean
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsDropdownNavCss, BsDropdownToggleCss, BsDropdownSplitCss, css(_templateObject$1D())];
  }

  render() {
    return html(_templateObject2$u());
  }

  constructor() {
    super();
    this._popper = null;
    this.offset = '';
    this.split = false;
  }

  firstUpdated() {
    const slotElement = this.shadowRoot.querySelector('slot');
    const slotNodes = slotElement.assignedNodes();

    const dropdownMenuElement = this._findDropdownMenuElement(slotNodes);

    this.addEventListener('bs-button-click', () => this._handleBtnClicked(dropdownMenuElement));
    this.addEventListener('bs-button-focusout', () => this._handleBtnFocusOut(dropdownMenuElement)); // if the dropdown is part of a navbar, don't add popper.js

    if (!this._isParentElementNavItem()) {
      const dropdownButtonElement = this._findDropdownButtonElement(slotNodes);

      this._configurePopper(dropdownButtonElement, dropdownMenuElement);
    }
  }

  _configurePopper(dropdownButtonElement, dropdownMenuElement) {
    const dropdDownMenuPlacement = dropdownMenuElement.getAttribute('x-placement');

    const referenceElement = this._findReferenceElement(dropdownButtonElement);

    const config = this._createPopperConfig(dropdDownMenuPlacement);

    this._popper = new Popper(referenceElement, dropdownMenuElement, config);
  }

  _createPopperConfig(dropdDownMenuPlacement) {
    if (this.offset) {
      return {
        placement: dropdDownMenuPlacement,
        modifiers: {
          flip: {
            enabled: true
          },
          offset: {
            enabled: true,
            offset: this.offset
          },
          keepTogether: {
            enabled: true
          }
        }
      };
    }

    return {
      placement: dropdDownMenuPlacement,
      modifiers: {
        flip: {
          enabled: true
        },
        keepTogether: {
          enabled: true
        }
      }
    };
  }

  _handleBtnClicked(dropdownMenuElement) {
    dropdownMenuElement.toggleMenu();
    this.active = !this.active;
  }

  _handleBtnFocusOut(dropdownMenuElement) {
    dropdownMenuElement.closeMenu();
    this.active = false;
  }

  _findReferenceElement(dropdownButtonElement) {
    if (this.split) {
      return dropdownButtonElement;
    }

    return this.shadowRoot.host;
  }

  _findDropdownButtonElement(slotNodes) {
    for (let index = 0; index < slotNodes.length; index++) {
      const slotItem = slotNodes[index];

      if (this._isDropdownButtonElement(slotItem) && this._isDropdownButtonToggle(slotItem)) {
        return slotItem;
      }
    }
  }

  _findDropdownMenuElement(slotNodes) {
    for (let index = 0; index < slotNodes.length; index++) {
      const slotItem = slotNodes[index];

      if (this._isDropdownMenuElement(slotItem)) {
        return slotItem;
      }
    }
  }

  _isDropdownButtonToggle(element) {
    return element.hasAttribute('dropdown-toggle');
  }

  _isDropdownMenuElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-dropdown-menu';
  }

  _isDropdownButtonElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && (element.localName === 'bs-button' || element.localName === 'bs-link-button' || element.localName === 'bs-input-button');
  }

  _isParentElementNavItem() {
    const parentElement = this.parentElement;
    return parentElement.nodeType === Node.ELEMENT_NODE && parentElement.localName === 'bs-nav-item';
  }

}
window.customElements.define('bs-dropdown', BsDropdown);

function _templateObject2$v() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$v = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1E() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                    height: 0;\n                    margin: 0.5rem 0;\n                    overflow: hidden;\n                    border-top: 1px solid #e9ecef;\n                }\n            "]);

  _templateObject$1E = function _templateObject() {
    return data;
  };

  return data;
}
class BsDropdownDivider extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1E())];
  }

  render() {
    return html(_templateObject2$v());
  }

}
window.customElements.define('bs-dropdown-divider', BsDropdownDivider);

function _templateObject2$w() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$w = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1F() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                    padding: 0.5rem 1.5rem;\n                    margin-bottom: 0;\n                    font-size: 0.875rem;\n                    color: #6c757d;\n                    white-space: nowrap;\n                }\n            "]);

  _templateObject$1F = function _templateObject() {
    return data;
  };

  return data;
}
class BsDropdownHeader extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1F())];
  }

  render() {
    return html(_templateObject2$w());
  }

}
window.customElements.define('bs-dropdown-header', BsDropdownHeader);

const BsDropdownItemMixin = superClass => class extends superClass {
  static get properties() {
    return {
      title: String,
      index: Number,
      active: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      }
    };
  }

  constructor() {
    super();
    this.active = false;
    this.disabled = false;
  }

  firstUpdated() {
    const buttonElement = this._retrieveButtonElement();

    this._applyButtonActivateState(buttonElement);

    buttonElement.addEventListener('click', event => this._handleButtonClick(event));
  }

  _retrieveButtonElement() {
    const linkElement = this.shadowRoot.querySelector('a.dropdown-item');
    const buttonElement = this.shadowRoot.querySelector('button.dropdown-item');

    if (linkElement) {
      return linkElement;
    }

    if (buttonElement) {
      return buttonElement;
    }
  }

  _applyButtonActivateState(btnElement) {
    if (this.disabled && !this.active) {
      btnElement.classList.toggle('disabled');
    }

    if (!this.disabled && this.active) {
      btnElement.classList.toggle('active');
    }
  }

  _handleButtonClick(event) {
    event.preventDefault();

    if (!this.disabled) {
      const btnClickedEvent = new CustomEvent('bs-dropdown-item-click', {
        bubbles: true,
        composed: true,
        detail: {
          index: this.index
        }
      });
      this.dispatchEvent(btnClickedEvent);
    }
  }

};

function _templateObject$1G() {
  const data = _taggedTemplateLiteral(["\n\n    :host {\n        display: block;\n    }\n\n    .dropdown-item {\n        display: block;\n        width: 100%;\n        padding: 0.25rem 1.5rem;\n        clear: both;\n        font-weight: 400;\n        color: #212529;\n        text-align: inherit;\n        white-space: nowrap;\n        background-color: transparent;\n        border: 0;\n    }\n\n    .dropdown-item:hover, \n    .dropdown-item:focus {\n        color: #16181b;\n        text-decoration: none;\n        background-color: #f8f9fa;\n    }\n\n    :host([active]) .dropdown-item,\n    :host:active .dropdown-item {\n        color: #fff;\n        text-decoration: none;\n        background-color: #007bff;\n    }\n\n    :host([disabled]) .dropdown-item, \n    :host:disabled .dropdown-item {\n        color: #6c757d;\n        background-color: transparent;\n    }\n"]);

  _templateObject$1G = function _templateObject() {
    return data;
  };

  return data;
}
const BsDropdownItemCss = css(_templateObject$1G());

function _templateObject$1H() {
  const data = _taggedTemplateLiteral(["\n            <button class=\"dropdown-item\" type=\"button\">", "</button>\n        "]);

  _templateObject$1H = function _templateObject() {
    return data;
  };

  return data;
}
class BsDropdownItemButton extends BsDropdownItemMixin(LitElement) {
  static get styles() {
    return [BsContentRebootCss, BsDropdownItemCss];
  }

  render() {
    return html(_templateObject$1H(), this.title);
  }

}
window.customElements.define('bs-dropdown-item-button', BsDropdownItemButton);

function _templateObject$1I() {
  const data = _taggedTemplateLiteral(["\n\n            <!-- TODO: replace the title property with a slot -->\n            \n            <a href=\"", "\" class=\"dropdown-item\">", "</a>\n        "]);

  _templateObject$1I = function _templateObject() {
    return data;
  };

  return data;
}
class BsDropdownItemLink extends BsDropdownItemMixin(LitElement) {
  static get properties() {
    return {
      index: Number,
      title: String,
      target: String
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsDropdownItemCss];
  }

  render() {
    return html(_templateObject$1I(), this.target, this.title);
  }

  constructor() {
    super();
    this.index = 0;
    this.title = '';
    this.target = '#';
  }

}
window.customElements.define('bs-dropdown-item-link', BsDropdownItemLink);

function _templateObject2$x() {
  const data = _taggedTemplateLiteral(["\n            <span class=\"dropdown-item-text\">\n                <slot></slot>\n            </span>\n        "]);

  _templateObject2$x = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1J() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                }\n                \n                .dropdown-item-text {\n                    display: block;\n                    padding: 0.25rem 1.5rem;\n                    color: #212529;\n                }\n            "]);

  _templateObject$1J = function _templateObject() {
    return data;
  };

  return data;
}
class BsDropdownItemText extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1J())];
  }

  render() {
    return html(_templateObject2$x());
  }

}
window.customElements.define('bs-dropdown-item-text', BsDropdownItemText);

function _templateObject2$y() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$y = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1K() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    position: var(--dropdown-menu-position, absolute);\n                    left: 0;\n                    z-index: 1000;\n                    display: var(--dropdown-menu-display, block);\n                    visibility: hidden !important;\n                    float: var(--dropdown-menu-float, left);\n                    min-width: 10rem;\n                    padding: 0.5rem 0;\n                    margin-left: 0;\n                    margin-right: 0;\n                    font-size: 1rem;\n                    color: #212529;\n                    text-align: left;\n                    list-style: none;\n                    background-color: #fff;\n                    background-clip: padding-box;\n                    border: 1px solid rgba(0, 0, 0, 0.15);\n                    border-top-left-radius: var(--dropdown-menu-border-top-left-radius, 0.25rem);\n                    border-top-right-radius: var(--dropdown-menu-border-top-right-radius, 0.25rem);\n                    border-bottom-right-radius: var(--dropdown-menu-border-bottom-right-radius, 0.25rem);\n                    border-bottom-left-radius: var(--dropdown-menu-border-bottom-left-radius, 0.25rem);\n                }\n        \n                :host([static]) {\n                    position: static;\n                }\n        \n                :host([down]) {\n                    top: 100%;\n                    margin-top: var(--dropdown-menu-down-margin-top, 0.125rem);\n                    margin-bottom: 0;\n                }\n                \n                :host([up]) {\n                    top: auto;\n                    bottom: 100%;\n                    margin-top: var(--dropdown-menu-up-margin-top, 0);\n                    margin-bottom: 0.125rem;\n                }\n        \n                :host([right]) {\n                    top: 0;\n                    right: auto;\n                    left: 100%;\n                    margin-top: var(--dropdown-menu-right-margin-top, 0);\n                    margin-left: 0.125rem;\n                }\n                \n                :host([left]) {\n                    top: 0;\n                    right: 100%;\n                    left: auto;\n                    margin-top: var(--dropdown-menu-left-margin-top, 0);\n                    margin-right: 0.125rem;\n                }\n                \n                :host([align-right]) {\n                    right: 0;\n                    left: auto;\n                }\n                \n                :host([show]) {\n                    visibility: visible !important;\n                }\n                \n                :host([x-placement^=\"top\"]), \n                :host([x-placement^=\"right\"]), \n                :host([x-placement^=\"bottom\"]), \n                :host([x-placement^=\"left\"]) {\n                    right: auto;\n                    bottom: auto;\n                }\n            "]);

  _templateObject$1K = function _templateObject() {
    return data;
  };

  return data;
}
class BsDropdownMenu extends LitElement {
  static get properties() {
    return {
      show: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1K())];
  }

  render() {
    return html(_templateObject2$y());
  }

  constructor() {
    super();
    this.show = false;
  }

  toggleMenu() {
    this.show = !this.show;

    this._changeDisplayValueInCollapsedNavbar();
  }

  openMenu() {
    this.show = true;
  }

  closeMenu() {
    this.show = false;
  }

  _changeDisplayValueInCollapsedNavbar() {
    const compStyles = window.getComputedStyle(this.shadowRoot.host);
    const displayValue = compStyles.getPropertyValue('display');

    if (this.show && displayValue === 'none') {
      this.shadowRoot.host.style.display = 'block';
    }

    if (!this.show && displayValue === 'block') {
      this.shadowRoot.host.style.display = 'none';
    }
  }

}
window.customElements.define('bs-dropdown-menu', BsDropdownMenu);

function _templateObject2$z() {
  const data = _taggedTemplateLiteral(["\n            <form\n                name=", "\n                action=", "\n                method=", "\n                enctype=", "\n                accept-charset=", "\n                ?novalidate=", "\n                ?autocomplete=", ">\n                <slot></slot>\n            <form>\n        "]);

  _templateObject2$z = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1L() {
  const data = _taggedTemplateLiteral(["\n                :host(:not([inline])) {\n                    display: block;\n                }\n                \n                :host([inline]) {\n                    display: flex;\n                    flex-flow: row wrap;\n                    align-items: center;\n                }\n                \n                :host([inline]) form {\n                    display: flex;\n                    flex-flow: row wrap;\n                    align-items: center;\n                }\n        \n                @media (min-width: 576px) {\n                    :host([inline]) {\n                        --bs-form-control-display: inline-block;\n                        --bs-form-control-width: auto;\n                        --bs-form-control-vertical-align: middle;\n                        --bs-input-group-width: auto;\n                    }\n                }\n            "]);

  _templateObject$1L = function _templateObject() {
    return data;
  };

  return data;
}
class BsForm extends LitElement {
  static get properties() {
    return {
      name: String,
      action: String,
      ajax: Boolean,
      method: {
        type: String,
        reflect: true
      },
      enctype: {
        type: String,
        reflect: true
      },
      inline: {
        type: Boolean,
        reflect: true
      },
      novalidate: {
        type: Boolean,
        reflect: true
      },
      autocomplete: {
        type: Boolean,
        reflect: true
      },
      acceptCharset: {
        type: String,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1L())];
  }

  render() {
    return html(_templateObject2$z(), ifDefined(this.name), ifDefined(this.action), this.method, this.enctype, this.acceptCharset, this.novalidate, this.autocomplete);
  }

  constructor() {
    super();
    this.inline = false;
    this.novalidate = false;
    this.autocomplete = false;
    this.ajax = false;
    this.method = "get";
    this.enctype = "application/x-www-form-urlencoded";
    this.acceptCharset = "UTF-8";
  }

  firstUpdated() {
    this._setFormGroupsToInline();

    this.addEventListener('bs-button-click', event => this._handleButton(event));
  }

  _handleButton(event) {
    const action = event.detail.action;
    const formElement = this.shadowRoot.querySelector('form');

    if (action === 'submit') {
      this._handleSubmit(formElement);
    }

    if (action === 'reset') {
      formElement.reset();
    }
  }

  _handleSubmit(formElement) {
    const formInputValidation = this._validateFormInputs();

    if (!formInputValidation) {
      return;
    }

    if (this.ajax) {
      const formData = new FormData(formElement);

      this._populateFormDataFromInputControls(formData);

      this._executeAjaxFormSubmission(formData);

      return;
    }

    const formData = new FormData(formElement);

    this._populateFormDataFromInputControls(formData); // formElement.submit();

  }

  _executeAjaxFormSubmission(formData) {
    const request = new XMLHttpRequest(); // the fired event should contain the XMLHttpRequest object
    // so that users can post on their own

    const eventPrevented = this._firePreSubmitEvent(request);

    if (eventPrevented) {
      return;
    }

    request.open('POST', this.action);
    request.send(formData);
  }

  _firePreSubmitEvent(request) {
    const presubmitEvent = new CustomEvent('bs-form-presubmit', {
      bubbles: true,
      composed: true,
      cancelable: true,
      detail: {
        request: request
      }
    });
    this.dispatchEvent(presubmitEvent);
    const presubmitEventPrevented = presubmitEvent.defaultPrevented;
    return presubmitEventPrevented;
  }

  _validateFormInputs() {
    if (this.novalidate) {
      return true;
    } // TODO also find and include all native elements 


    const customFormInputValidationStates = [];

    const formInputElements = this._retrieveFormInputElements(true);

    for (let index = 0; index < formInputElements.length; index++) {
      const formInputElement = formInputElements[index];
      const formInputValid = formInputElement.validate();
      customFormInputValidationStates.push(formInputValid);
    } // has any of the custom form input elements failed validation


    const atLeastOneInputFailedValidation = customFormInputValidationStates.includes(false);
    return !atLeastOneInputFailedValidation;
  }

  _populateFormDataFromInputControls(formData) {
    const formInputElements = this._retrieveFormInputElements(false);

    for (let index = 0; index < formInputElements.length; index++) {
      const formInputElement = formInputElements[index];

      this._extractInputData(formData, formInputElement);
    }
  }

  _extractInputData(formData, formInput) {
    if (this._isInputDisabled(formInput)) {
      return;
    }

    const name = formInput.getInputName();
    const value = formInput.getInputValue();

    if (name && value) {
      formData.append(name, value);
    }
  }

  _setFormGroupsToInline() {
    if (!this.inline) {
      return;
    }

    const slotElement = this.shadowRoot.querySelector('slot');
    const slotNodes = slotElement.assignedNodes();

    const formGroupElements = this._retrieveFormGroupElements(slotNodes);

    for (let index = 0; index < formGroupElements.length; index++) {
      const formGroupElement = formGroupElements[index];

      if (formGroupElement) {
        formGroupElement.setAttribute('inline', '');
      }
    }
  }

  _retrieveFormGroupElements(slotNodes) {
    const formGroupElements = [];

    for (let index = 0; index < slotNodes.length; ++index) {
      const slotNode = slotNodes[index];

      if (this._isFormGroupElement(slotNode)) {
        formGroupElements.push(slotNode);
      }
    }

    return formGroupElements;
  }

  _retrieveFormInputElements(validatableOnlyElements) {
    const formInputElements = [];
    const slotElement = this.shadowRoot.querySelector('slot');
    const slotNodes = slotElement.assignedNodes();

    for (let index = 0; index < slotNodes.length; index++) {
      const slotNode = slotNodes[index];

      if (this._isFormGroupElement(slotNode) || this._isFormCheckGroupElement(slotNode)) {
        if (this._isGroupDisabled(slotNode)) {
          continue;
        }

        const groupChildren = slotNode.children;

        for (let index = 0; index < groupChildren.length; index++) {
          const formGroupChild = groupChildren[index];

          if (this._isFormInputElement(formGroupChild) || this._isFormCheckboxInput(formGroupChild)) {
            if (validatableOnlyElements) {
              if (formGroupChild.isValidatable()) {
                formInputElements.push(formGroupChild);
              }
            } else {
              formInputElements.push(formGroupChild);
            }
          }
        }
      }
    }

    return formInputElements;
  }

  _isGroupDisabled(formGroupElement) {
    return formGroupElement.isDisabled();
  }

  _isInputDisabled(formInputElement) {
    return formInputElement.isDisabled();
  }

  _isElementSubmittable(element) {
    return element.nodeType === Node.ELEMENT_NODE && !element.disabled && !element.name;
  }

  _isFormFileInput(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-file-input';
  }

  _isFormTextAreaElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-textarea';
  }

  _isFormInputElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-input';
  }

  _isFormCheckboxInput(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-checkbox-input';
  }

  _isFormRadioInput(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-radio-input';
  }

  _isFormGroupElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-group';
  }

  _isFormCheckGroupElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-check-group';
  }

}
window.customElements.define('bs-form', BsForm);

function _templateObject2$A() {
  const data = _taggedTemplateLiteral(["\n            <slot name=\"check\"></slot>\n            <slot name=\"label\"></slot>\n            <slot name=\"feedback\"></slot>\n            <slot></slot>\n        "]);

  _templateObject2$A = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1M() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    position: relative;\n                    display: block;\n                    padding-left: 1.25rem;\n                }\n                \n                :host([inline]) {\n                    display: -ms-inline-flexbox;\n                    display: inline-flex;\n                    align-items: center;\n                    padding-left: 0;\n                    margin-right: 0.75rem;\n                }\n            "]);

  _templateObject$1M = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormCheckGroup extends LitElement {
  static get properties() {
    return {
      inline: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1M())];
  }

  render() {
    return html(_templateObject2$A());
  }

  constructor() {
    super();
    this.disabled = false;
    this.inline = false;
  }

  firstUpdated() {
    this.addEventListener('bs-form-check-label-click', () => this._handleLabelClick());
    this.addEventListener('bs-form-input-validation', event => this._handleInputValidationEvent(event));
  }

  updated(changedProperties) {
    if (changedProperties.has('disabled')) {
      this._disabledChanged();
    }

    if (changedProperties.has('inline')) {
      this._inlineChanged();
    }
  }

  isDisabled() {
    return this.disabled;
  }

  _handleInputValidationEvent(event) {
    const validityState = event.detail.validityState;

    const inputFeedbackElement = this._retrieveFeedbackElement();

    const labelElement = this._retrieveLabelElement();

    if (inputFeedbackElement) {
      inputFeedbackElement.showValidationFeedback(validityState);
    }

    if (validityState.valid) {
      labelElement.setAttribute('valid', '');
      labelElement.removeAttribute('invalid');
    } else {
      labelElement.setAttribute('invalid', '');
      labelElement.removeAttribute('valid');
    }
  }

  _handleLabelClick() {
    const inputElement = this._retrieveInputElement();

    if (inputElement) {
      inputElement.toggle();
    }
  }

  _inlineChanged() {
    if (this.inline) {
      this._setElementsToInline();
    }
  }

  _disabledChanged() {
    if (this.disabled) {
      this._setElementsToDisabled();
    }
  } // TODO this is not optiomal. instead of
  // setting attributes we should instead use css properties


  _setElementsToDisabled() {
    const inputElement = this._retrieveInputElement();

    const labelElement = this._retrieveLabelElement();

    if (inputElement) {
      inputElement.setAttribute('disabled', '');
    }

    if (labelElement) {
      labelElement.setAttribute('disabled', '');
    }
  }

  _setElementsToInline() {
    const inputElement = this._retrieveInputElement();

    const labelElement = this._retrieveLabelElement();

    if (inputElement) {
      inputElement.setAttribute('inline', '');
    }

    if (labelElement) {
      labelElement.setAttribute('inline', '');
    }
  }

  _retrieveInputElement() {
    const checkSlotElement = this.shadowRoot.querySelector('slot[name="check"]');
    const checkSlotNodes = checkSlotElement.assignedNodes();

    const inputElement = this._findFormCheckInputElement(checkSlotNodes);

    return inputElement;
  }

  _retrieveLabelElement() {
    const labelSlotElement = this.shadowRoot.querySelector('slot[name="label"]');
    const labelSlotNodes = labelSlotElement.assignedNodes();

    const labelElement = this._findLabelElement(labelSlotNodes);

    return labelElement;
  }

  _retrieveFeedbackElement() {
    const feedbackSlotElement = this.shadowRoot.querySelector('slot[name="feedback"]');
    const feedbackSlotNodes = feedbackSlotElement.assignedNodes();

    const feedbackElement = this._findInputFeedbackElement(feedbackSlotNodes);

    return feedbackElement;
  }

  _findFormCheckInputElement(slotNodes) {
    for (let index = 0; index < slotNodes.length; index++) {
      const slotItem = slotNodes[index];

      if (this._isFormCheckboxInputElement(slotItem) || this._isFormRadioInputElement(slotItem)) {
        return slotItem;
      }
    }
  }

  _findLabelElement(slotNodes) {
    for (let index = 0; index < slotNodes.length; index++) {
      const slotItem = slotNodes[index];

      if (this._isLabelElement(slotItem)) {
        return slotItem;
      }
    }
  }

  _findInputFeedbackElement(slotNodes) {
    for (let index = 0; index < slotNodes.length; index++) {
      const slotItem = slotNodes[index];

      if (this._isInputFeedbackElement(slotItem)) {
        return slotItem;
      }
    }
  }

  _isInputFeedbackElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-input-feedback';
  }

  _isFormCheckboxInputElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-checkbox-input';
  }

  _isFormRadioInputElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-radio-input';
  }

  _isLabelElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-check-label';
  }

}
window.customElements.define('bs-form-check-group', BsFormCheckGroup);

function _templateObject2$B() {
  const data = _taggedTemplateLiteral(["\n            <label><slot></slot></label>\n        "]);

  _templateObject2$B = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1N() {
  const data = _taggedTemplateLiteral(["\n                label {\n                    margin-bottom: 0;\n                }\n        \n                :host([disabled]) label {\n                    color: #6c757d;\n                }\n                \n                :host([valid]) label {\n                    color: #28a745;\n                }\n                \n                :host([invalid]) label {\n                    color: #dc3545;\n                }\n            "]);

  _templateObject$1N = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormCheckLabel extends LitElement {
  static get styles() {
    return [BsContentRebootCss, BsContentTypographyCss, css(_templateObject$1N())];
  }

  render() {
    return html(_templateObject2$B());
  }

  firstUpdated() {
    const labelElement = this.shadowRoot.querySelector('label');
    labelElement.addEventListener('click', event => this._handleEvent(event));
  }

  _handleEvent(event) {
    event.preventDefault();
    const disabledAttribute = this.hasAttribute('disabled');

    if (disabledAttribute) {
      return;
    }

    const labelClickedEvent = new CustomEvent('bs-form-check-label-click', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(labelClickedEvent);
  }

}
window.customElements.define('bs-form-check-label', BsFormCheckLabel);

const BsFormInputMixin = superClass => class extends superClass {
  static get properties() {
    return {
      name: String,
      value: String,
      placeholder: String,
      type: String,
      readonly: {
        type: Boolean,
        reflect: true
      },
      inline: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      },
      required: {
        type: Boolean,
        reflect: true
      },
      valid: {
        type: Boolean,
        reflect: true
      },
      invalid: {
        type: Boolean,
        reflect: true
      },
      skipValidation: {
        type: Boolean,
        reflect: true
      },
      browserValidation: {
        type: Boolean,
        reflect: true
      },
      browserMissingValueMsg: {
        type: String,
        attribute: 'browser-missing-value-msg'
      },
      browserMismatchValueMsg: {
        type: String,
        attribute: 'browser-mismatch-value-msg'
      },
      browserPatternValueMag: {
        type: String,
        attribute: 'browser-pattern-value-msg'
      },
      browserTooLongValueMsg: {
        type: String,
        attribute: 'browser-too-long-value-msg'
      },
      browserTooShortValueMsg: {
        type: String,
        attribute: 'browser-too-short-value-msg'
      },
      browserRangeUnderflowMsg: {
        type: String,
        attribute: 'browser-range-underflow-msg'
      },
      browserRangeOverflowMsg: {
        type: String,
        attribute: 'browser-range-overflow-msg'
      },
      browserStepMismatchMsg: {
        type: String,
        attribute: 'browser-step-mismatch-msg'
      },
      browserBadInputValueMsg: {
        type: String,
        attribute: 'browser-bad-input-value-msg'
      }
    };
  }

  constructor() {
    super();
    this.name = '';
    this.value = '';
    this.type = 'text';
    this.readonly = false;
    this.inline = false;
    this.disabled = false;
    this.required = false;
    this.valid = false;
    this.invalid = false;
    this.skipValidation = false;
    this.browserValidation = false;
    this.browserMissingValueMsg = '';
    this.browserMismatchValueMsg = '';
    this.browserPatternValueMag = '';
    this.browserTooLongValueMsg = '';
    this.browserTooShortValueMsg = '';
    this.browserRangeUnderflowMsg = '';
    this.browserRangeOverflowMsg = '';
    this.browserStepMismatchMsg = '';
    this.browserBadInputValueMsg = '';
  }

  firstUpdated() {
    const inputElement = this.shadowRoot.querySelector('input');
    inputElement.addEventListener('keyup', () => this._handleKeyUp());
  }

  _handleKeyUp() {
    // if element has been called to be validated before
    // both valid and invalid start out as false
    if (this.valid || this.invalid) {
      this.validate();
    }
  }

  isDisabled() {
    return this.disabled;
  }

  setFocus() {
    const inputElement = this.shadowRoot.querySelector('input');
    inputElement.focus();
  }

  getInputName() {
    return this.name;
  }

  isValidatable() {
    return !this.skipValidation;
  }

  validate() {
    if (this.skipValidation) {
      return;
    }

    const inputElement = this.shadowRoot.querySelector('input');
    const validityState = inputElement.validity;

    if (this.browserValidation) {
      this._executeBrowserValidation(inputElement, validityState);

      return;
    }

    this._executeCustomValidation(validityState);

    return validityState.valid;
  }

  _executeCustomValidation(validityState) {
    if (validityState.valid) {
      this.valid = true;
      this.invalid = false;
    } else {
      this.valid = false;
      this.invalid = true;
    }

    const formInputValidationEvent = new CustomEvent('bs-form-input-validation', {
      bubbles: true,
      composed: true,
      detail: {
        validityState: validityState
      }
    });
    this.dispatchEvent(formInputValidationEvent);
  }

  _executeBrowserValidation(inputElement, validityState) {
    // has user specified custom message
    const customValidationMessage = this._getCustomValidationMessage(validityState);

    if (customValidationMessage) {
      inputElement.setCustomValidity(customValidationMessage);
    }

    inputElement.reportValidity();
  }

  _getCustomValidationMessage(validityState) {
    if (validityState.valueMissing) {
      return this.browserMissingValueMsg;
    }

    if (validityState.typeMismatch) {
      return this.browserMismatchValueMsg;
    }

    if (validityState.patternMismatch) {
      return this.browserPatternValueMsg;
    }

    if (validityState.tooLong) {
      return this.browserTooLongValueMsg;
    }

    if (validityState.tooShort) {
      return this.browserTooShortValueMsg;
    }

    if (validityState.rangeUnderflow) {
      return this.browserRangeUnderflowMsg;
    }

    if (validityState.rangeOverflow) {
      return this.browserRangeOverflowMsg;
    }

    if (validityState.stepMismatch) {
      return this.browserStepMismatchMsg;
    }

    if (validityState.badInput) {
      return this.browserBadInputValueMsg;
    }
  }

};

function _templateObject2$C() {
  const data = _taggedTemplateLiteral(["\n            <input \n                type=\"checkbox\"\n                name=", "\n                ?checked=", "\n                ?required=", "\n                ?disabled=", " />\n        "]);

  _templateObject2$C = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1O() {
  const data = _taggedTemplateLiteral(["\n                input {\n                    position: var(--bs-form-checkbox-input-position, absolute);\n                    margin-top: var(--bs-form-checkbox-input-margin-top, 0.3rem);\n                    margin-left: var(--bs-form-checkbox-input-margin-left, -1.25rem);\n                }\n                \n                :host([inline]) {\n                    display: inline-flex;\n                }\n                \n                :host([inline]) input {\n                    position: static;\n                    margin-top: 0;\n                    margin-right: 0.3125rem;\n                    margin-left: 0;\n                }\n                \n                @media (min-width: 576px) {\n        \n                    :host([inline]) input {\n                        position: relative;\n                        margin-top: 0;\n                        margin-right: 0.25rem;\n                        margin-left: 0;\n                    }\n                }\n            "]);

  _templateObject$1O = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormCheckboxInput extends BsFormInputMixin(LitElement) {
  static get properties() {
    return {
      static: {
        type: Boolean,
        reflect: true
      },
      checked: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsPositionCss, css(_templateObject$1O())];
  }

  render() {
    return html(_templateObject2$C(), this.name, this.checked, this.required, this.disabled);
  }

  constructor() {
    super();
    this.static = false;
    this.checked = false;
  }

  firstUpdated() {
    this._applyStaticCss();
  }

  _applyStaticCss() {
    if (this.static) {
      const checkboxElement = this.shadowRoot.querySelector('input');
      checkboxElement.classList.add('position-static');
    }
  }

  check() {
    const checkboxElement = this.shadowRoot.querySelector('input');
    checkboxElement.checked = true;
  }

  uncheck() {
    const checkboxElement = this.shadowRoot.querySelector('input');
    checkboxElement.checked = false;
  }

  toggle() {
    const checkboxElement = this.shadowRoot.querySelector('input');
    checkboxElement.checked = !checkboxElement.checked;
  }

  getInputValue() {
    const checkboxElement = this.shadowRoot.querySelector('input');
    return checkboxElement.checked;
  }

}
window.customElements.define('bs-form-checkbox-input', BsFormCheckboxInput);

function _templateObject$1P() {
  const data = _taggedTemplateLiteral(["\n            <fieldset>\n                <slot></slot>\n            </fieldset>\n        "]);

  _templateObject$1P = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormFieldset extends LitElement {
  static get properties() {
    return {
      disabled: {
        type: Boolean,
        value: false
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss];
  }

  render() {
    return html(_templateObject$1P());
  }

  constructor() {
    super();
    this.disabled = false;
  }

  firstUpdated() {
    this._disableElements();
  }

  _disableElements() {
    if (!this.disabled) {
      return;
    }

    const slotElement = this.shadowRoot.querySelector('slot');
    const slotNodes = slotElement.assignedNodes();

    this._disableFormGroups(slotNodes);

    this._disableFormCheckGroups(slotNodes);

    this._disableButtons(slotNodes);
  }

  _disableButtons(slotNodes) {
    const buttonElements = this._retrieveButtonElements(slotNodes);

    for (let index = 0; index < buttonElements.length; index++) {
      const buttonItem = buttonElements[index];
      buttonItem.setAttribute('disabled', '');
    }
  }

  _disableFormCheckGroups(slotNodes) {
    const formCheckGroupElements = this._retrieveFormCheckGroupElements(slotNodes);

    for (let index = 0; index < formCheckGroupElements.length; index++) {
      const formGroupItem = formCheckGroupElements[index];
      formGroupItem.setAttribute('disabled', '');
    }
  }

  _disableFormGroups(slotNodes) {
    const formGroupElements = this._retrieveFormGroupElements(slotNodes);

    for (let index = 0; index < formGroupElements.length; index++) {
      const formGroupItem = formGroupElements[index];
      formGroupItem.setAttribute('disabled', '');
    }
  }

  _retrieveFormGroupElements(slotNodes) {
    const formGroupNodes = [];

    for (let index = 0; index < slotNodes.length; index++) {
      const slotElement = slotNodes[index];

      if (this._isFormGroupElement(slotElement)) {
        formGroupNodes.push(slotElement);
      }
    }

    return formGroupNodes;
  }

  _retrieveFormCheckGroupElements(slotNodes) {
    const formCheckGroupNodes = [];

    for (let index = 0; index < slotNodes.length; index++) {
      const slotElement = slotNodes[index];

      if (this._isFormCheckGroupElement(slotElement)) {
        formCheckGroupNodes.push(slotElement);
      }
    }

    return formCheckGroupNodes;
  }

  _retrieveButtonElements(slotNodes) {
    const buttonNodes = [];

    for (let index = 0; index < slotNodes.length; index++) {
      const slotElement = slotNodes[index];

      if (this._isButtonElement(slotElement)) {
        buttonNodes.push(slotElement);
      }
    }

    return buttonNodes;
  }

  _isButtonElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && (element.localName === 'bs-button' || element.localName === 'bs-input-button' || element.localName === 'bs-link-button');
  }

  _isFormGroupElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-group';
  }

  _isFormCheckGroupElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-check-group';
  }

}
window.customElements.define('bs-form-fieldset', BsFormFieldset);

function _templateObject2$D() {
  const data = _taggedTemplateLiteral(["\n            <input \n                type=\"file\"\n                class=\"form-control-file\"\n                .placeholder=", " />\n        "]);

  _templateObject2$D = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1Q() {
  const data = _taggedTemplateLiteral(["\n                .form-control-file {\n                    display: block;\n                    width: 100%;\n                }\n            "]);

  _templateObject$1Q = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormFileInput extends LitElement {
  static get properties() {
    return {
      placeholder: {
        type: String,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1Q())];
  }

  render() {
    return html(_templateObject2$D(), this.placeholder);
  }

  constructor() {
    super();
    this.placeholder = '';
  }

  setFocus() {
    const inputElement = this.shadowRoot.querySelector('input');
    inputElement.focus();
  }

}
window.customElements.define('bs-form-file-input', BsFormFileInput);

function _templateObject2$E() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$E = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1R() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: flex;\n                    flex-wrap: wrap;\n                    margin-right: -15px;\n                    margin-left: -15px;\n                }\n\n                :host([no-gutters]) {\n                    margin-right: 0;\n                    margin-left: 0;\n                }\n\n                :host([no-gutters]) ::slotted(*) {\n                    padding-right: 0;\n                    padding-left: 0;\n                }\n            "]);

  _templateObject$1R = function _templateObject() {
    return data;
  };

  return data;
}
class BsRow extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1R())];
  }

  render() {
    return html(_templateObject2$E());
  }

}
window.customElements.define('bs-row', BsRow);

function _templateObject2$F() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$F = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1S() {
  const data = _taggedTemplateLiteral(["\n                \n                :host {\n                    width: 100%;\n                    display: block;\n                    padding-right: 15px;\n                    padding-left: 15px;\n                    margin-right: auto;\n                    margin-left: auto;\n                }\n        \n                @media (min-width: 576px) {\n                    :host:not([fluid]) {\n                        max-width: 540px;\n                    }\n                }\n\n                @media (min-width: 768px) {\n                    :host:not([fluid]) {\n                        max-width: 720px;\n                    }\n                }\n\n                @media (min-width: 992px) {\n                    :host:not([fluid]) {\n                        max-width: 960px;\n                    }\n                }\n\n                @media (min-width: 1200px) {\n                    :host:not([fluid]) {\n                        max-width: 1140px;\n                    }\n                }\n        \n                :host([fluid]) {\n                    width: 100%;\n                    display: block;\n                    padding-right: 15px;\n                    padding-left: 15px;\n                    margin-right: auto;\n                    margin-left: auto;\n                }\n            "]);

  _templateObject$1S = function _templateObject() {
    return data;
  };

  return data;
}
class BsContainer extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1S())];
  }

  render() {
    return html(_templateObject2$F());
  }

}
window.customElements.define('bs-container', BsContainer);

function _templateObject2$G() {
  const data = _taggedTemplateLiteral(["\n            <slot name=\"label\"></slot>\n            <slot name=\"control\"></slot>\n            <slot name=\"feedback\"></slot>\n            <slot name=\"helptext\"></slot>\n        "]);

  _templateObject2$G = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1T() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                    margin-bottom: 1rem;\n                }\n        \n                :host([row]) {\n                    display: -ms-flexbox;\n                    display: flex;\n                    -ms-flex-wrap: wrap;\n                    flex-wrap: wrap;\n                    margin-right: -15px;\n                    margin-left: -15px;\n                }\n        \n                @media (min-width: 576px) {\n                    \n                    :host([inline]) {\n                        display: -ms-flexbox;\n                        display: flex;\n                        -ms-flex: 0 0 auto;\n                        flex: 0 0 auto;\n                        -ms-flex-flow: row wrap;\n                        flex-flow: row wrap;\n                        -ms-flex-align: center;\n                        align-items: center;\n                        margin-bottom: 0;\n                    }\n                }\n            "]);

  _templateObject$1T = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormGroup extends LitElement {
  static get properties() {
    return {
      inline: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsColumnExtraSmallCss, BsColumnSmallCss, BsColumnMediumCss, BsColumnLargeCss, BsColumnExtraLargeCss, css(_templateObject$1T())];
  }

  render() {
    return html(_templateObject2$G());
  }

  constructor() {
    super();
    this.inline = false;
    this.disabled = false;
  }

  firstUpdated() {
    this.addEventListener('bs-form-label-click', () => this._handleLabelClickEvent());
    this.addEventListener('bs-form-input-validation', event => this._handleInputValidationEvent(event));
  }

  updated(changedProperties) {
    super.updated();

    if (changedProperties.has('disabled')) {
      this._disabledChanged();
    }

    if (changedProperties.has('inline')) {
      this._inlineChanged();
    }
  }

  isDisabled() {
    return this.disabled;
  }

  _handleInputValidationEvent(event) {
    const validityState = event.detail.validityState;

    const inputFeedbackElement = this._retrieveFeedbackElement();

    if (inputFeedbackElement) {
      inputFeedbackElement.showValidationFeedback(validityState);
    }
  }

  _handleLabelClickEvent() {
    const inputElement = this._retrieveInputElement();

    if (inputElement) {
      inputElement.setFocus();
    }
  }

  _inlineChanged() {
    if (this.inline) {
      this._setElementsToInline();
    }
  }

  _disabledChanged() {
    if (this.disabled) {
      this._setElementsToDisabled();
    }
  }

  _setElementsToDisabled() {
    const inputElement = this._retrieveInputElement();

    const labelElement = this._retrieveLabelElement();

    if (inputElement) {
      inputElement.setAttribute('disabled', '');
    }

    if (labelElement) {
      labelElement.setAttribute('disabled', '');
    }
  }

  _setElementsToInline() {
    const inputElement = this._retrieveInputElement();

    const labelElement = this._retrieveLabelElement();

    if (inputElement) {
      inputElement.setAttribute('inline', '');
    }

    if (labelElement) {
      labelElement.setAttribute('inline', '');
    }
  }

  _retrieveInputElement() {
    const controlSlotElement = this.shadowRoot.querySelector('slot[name="control"]');
    const controlSlotNodes = controlSlotElement.assignedNodes();

    const inputElement = this._findInputElement(controlSlotNodes);

    return inputElement;
  }

  _retrieveLabelElement() {
    const labelSlotElement = this.shadowRoot.querySelector('slot[name="label"]');
    const labelSlotNodes = labelSlotElement.assignedNodes();

    const labelElement = this._findLabelElement(labelSlotNodes);

    return labelElement;
  }

  _retrieveFeedbackElement() {
    const feedbackSlotElement = this.shadowRoot.querySelector('slot[name="feedback"]');
    const feedbackSlotNodes = feedbackSlotElement.assignedNodes();

    const feedbackElement = this._findInputFeedbackElement(feedbackSlotNodes);

    return feedbackElement;
  }

  _findInputFeedbackElement(slotNodes) {
    for (let index = 0; index < slotNodes.length; index++) {
      const slotItem = slotNodes[index];

      if (this._isInputFeedbackElement(slotItem)) {
        return slotItem;
      }
    }
  }

  _findInputElement(slotNodes) {
    for (let index = 0; index < slotNodes.length; index++) {
      const slotItem = slotNodes[index];

      if (this._isInputElement(slotItem) || this._isPlainTextInputElement(slotItem) || this._isSelectInputElement(slotItem) || this._isTextAreaElement(slotItem)) {
        return slotItem;
      }
    }
  }

  _findLabelElement(slotNodes) {
    for (let index = 0; index < slotNodes.length; index++) {
      const slotItem = slotNodes[index];

      if (this._isLabelElement(slotItem)) {
        return slotItem;
      }
    }
  }

  _isInputFeedbackElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-input-feedback';
  }

  _isInputElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-input';
  }

  _isSelectInputElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-select';
  }

  _isTextAreaElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-textarea';
  }

  _isPlainTextInputElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-input-plaintext';
  }

  _isLabelElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-label';
  }

}
window.customElements.define('bs-form-group', BsFormGroup);

function _templateObject2$H() {
  const data = _taggedTemplateLiteral(["\n            <small class=\"form-text text-muted\">\n                <slot></slot>\n            </small>\n        "]);

  _templateObject2$H = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1U() {
  const data = _taggedTemplateLiteral(["\n                .form-text {\n                    display: block;\n                    margin-top: 0.25rem;\n                }\n            "]);

  _templateObject$1U = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormHelpText extends LitElement {
  static get styles() {
    return [BsContentRebootCss, BsTextColorCss, css(_templateObject$1U())];
  }

  render() {
    return html(_templateObject2$H());
  }

}
window.customElements.define('bs-form-help-text', BsFormHelpText);

function _templateObject$1V() {
  const data = _taggedTemplateLiteral(["\n    \n    :host {\n        display: block;\n        width: var(--bs-form-control-width, 100%);\n    }\n    \n    .form-control {\n        display: var(--bs-form-control-display, block);\n        position: var(--bs-form-control-position);\n        width: var(--bs-form-control-width, 100%);\n        vertical-align: var(--bs-form-control-vertical-align);\n        height: var(--bs-form-control-height, calc(2.25rem + 2px));\n        padding: var(--bs-form-control-padding, 0.375rem 0.75rem);\n        font-size: var(--bs-form-control-font-size, 1rem);\n        line-height: var(--bs-form-control-line-height, 1.5);\n        color: #495057;\n        background-color: #fff;\n        background-clip: padding-box;\n        border: 1px solid #ced4da;\n        margin-left: var(--bs-form-control-margin-left);\n        border-top-left-radius: var(--bs-form-control-border-top-left-radius, 0.25rem);\n        border-top-right-radius: var(--bs-form-control-border-top-right-radius, 0.25rem);\n        border-bottom-right-radius: var(--bs-form-control-border-bottom-right-radius, 0.25rem);\n        border-bottom-left-radius: var(--bs-form-control-border-bottom-left-radius, 0.25rem);\n        transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n    }\n\n    @media screen and (prefers-reduced-motion: reduce) {\n      \n        .form-control {\n            transition: none;\n        }\n    }\n\n    .form-control::-ms-expand {\n        background-color: transparent;\n        border: 0;\n    }\n    \n    .form-control:focus {\n        color: #495057;\n        background-color: #fff;\n        border-color: #80bdff;\n        outline: 0;\n        box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);\n        z-index: var(--bs-form-control-z-index);\n    }\n    \n    .form-control::-webkit-input-placeholder {\n        color: #6c757d;\n        opacity: 1;\n    }\n\n    .form-control::-moz-placeholder {\n        color: #6c757d;\n        opacity: 1;\n    }\n\n    .form-control:-ms-input-placeholder {\n        color: #6c757d;\n        opacity: 1;\n    }\n\n    .form-control::-ms-input-placeholder {\n        color: #6c757d;\n        opacity: 1;\n    }\n\n    .form-control::placeholder {\n        color: #6c757d;\n        opacity: 1;\n    }\n\n    .form-control:disabled, \n    .form-control[readonly] {\n        background-color: #e9ecef;\n        opacity: 1;\n    }\n\n    :host([valid]) .form-control {\n        border-color: #28a745;\n    }\n    \n    :host([valid]) .form-control:focus {\n        border-color: #28a745;\n        box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.25);\n    }\n\n    :host([invalid]) .form-control {\n        border-color: #dc3545;\n    }\n\n    :host([invalid]) .form-control:focus {\n        border-color: #dc3545;\n        box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.25);\n    }\n    \n    /* Below styles are necessary because of: */\n    /* https://developer.mozilla.org/en-US/docs/Web/CSS/:-moz-ui-invalid */\n    \n    .form-control:-moz-submit-invalid {\n        box-shadow: none;\n    }\n\n    .form-control:-moz-ui-invalid {\n        box-shadow:none;\n    }\n"]);

  _templateObject$1V = function _templateObject() {
    return data;
  };

  return data;
}
const BsFormControlCss = css(_templateObject$1V());

function _templateObject$1W() {
  const data = _taggedTemplateLiteral(["\n\n    :host([sm]) .form-control {\n        height: calc(1.8125rem + 2px);\n        padding: 0.25rem 0.5rem;\n        font-size: 0.875rem;\n        line-height: 1.5;\n        border-radius: 0.2rem;\n    }\n    \n    :host([lg]) .form-control {\n        height: calc(2.875rem + 2px);\n        padding: 0.5rem 1rem;\n        font-size: 1.25rem;\n        line-height: 1.5;\n        border-radius: 0.3rem;\n    }\n"]);

  _templateObject$1W = function _templateObject() {
    return data;
  };

  return data;
}
const BsFormControlSizeCss = css(_templateObject$1W());

function _templateObject$1X() {
  const data = _taggedTemplateLiteral(["\n            <input \n                class=\"form-control\"\n                type=", "\n                ?readonly=", "\n                name=", "\n                .value=", "\n                ?required=", "\n                placeholder=", "\n                ?disabled=", " />\n        "]);

  _templateObject$1X = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormInput extends BsFormInputMixin(LitElement) {
  static get styles() {
    return [BsContentRebootCss, BsFormControlCss, BsFormControlSizeCss];
  }

  render() {
    return html(_templateObject$1X(), this.type, this.readonly, this.name, this.value, this.required, ifDefined(this.placeholder), this.disabled);
  }

  getInputValue() {
    const inputElement = this.shadowRoot.querySelector('input');
    return inputElement.value;
  }

}
window.customElements.define('bs-form-input', BsFormInput);

function _templateObject2$I() {
  const data = _taggedTemplateLiteral(["\n            ", "\n        "]);

  _templateObject2$I = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1Y() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: none;\n                }\n                \n                :host([valid]) {\n                    display: block;\n                    width: 100%;\n                    margin-top: .25rem;\n                    font-size: 80%;\n                    color: #28a745;\n                }\n                \n                :host([invalid]) {\n                    display: block;\n                    width: 100%;\n                    margin-top: .25rem;\n                    font-size: 80%;\n                    color: #dc3545;\n                }\n            "]);

  _templateObject$1Y = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormInputFeedback extends LitElement {
  static get properties() {
    return {
      validValueMsg: {
        type: String,
        attribute: 'valid-value-msg'
      },
      missingValueMsg: {
        type: String,
        attribute: 'missing-value-msg'
      },
      mismatchValueMsg: {
        type: String,
        attribute: 'mismatch-value-msg'
      },
      patternValueMsg: {
        type: String,
        attribute: 'pattern-value-msg'
      },
      tooLongValueMsg: {
        type: String,
        attribute: 'too-long-value-msg'
      },
      tooShortValueMsg: {
        type: String,
        attribute: 'too-short-value-msg'
      },
      rangeUnderflowMsg: {
        type: String,
        attribute: 'range-underflow-msg'
      },
      rangeOverflowMsg: {
        type: String,
        attribute: 'range-overflow-msg'
      },
      stepMismatchMsg: {
        type: String,
        attribute: 'step-mismatch-msg'
      },
      badInputValueMsg: {
        type: String,
        attribute: 'bad-input-value-msg'
      },
      feedbackMsg: {
        type: String,
        reflect: true
      },
      valid: {
        type: Boolean,
        reflect: true
      },
      invalid: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$1Y())];
  }

  render() {
    return html(_templateObject2$I(), this.feedbackMsg);
  }

  constructor() {
    super();
    this.feedbackMsg = '';
    this.validValueMsg = '';
    this.missingValueMsg = '';
    this.mismatchValueMsg = '';
    this.patternValueMsg = '';
    this.tooLongValueMsg = '';
    this.tooShortValueMsg = '';
    this.rangeUnderflowMsg = '';
    this.rangeOverflowMsg = '';
    this.stepMismatchMsg = '';
    this.badInputValueMsg = '';
    this.valid = false;
    this.invalid = false;
  }

  showValidationFeedback(validityState) {
    if (validityState.valid) {
      this.valid = true;
      this.invalid = false;

      if (this.validValueMsg) {
        this.feedbackMsg = this.validValueMsg;
      } else {
        this.feedbackMsg = '';
      }
    } else {
      this.valid = false;
      this.invalid = true;

      const validationMsg = this._getCustomValidationMessage(validityState);

      if (validationMsg) {
        this.feedbackMsg = validationMsg;
      }
    }
  }

  _getCustomValidationMessage(validityState) {
    if (validityState.valueMissing) {
      return this.missingValueMsg;
    }

    if (validityState.typeMismatch) {
      return this.mismatchValueMsg;
    }

    if (validityState.patternMismatch) {
      return this.patternValueMsg;
    }

    if (validityState.tooLong) {
      return this.tooLongValueMsg;
    }

    if (validityState.tooShort) {
      return this.tooShortValueMsg;
    }

    if (validityState.rangeUnderflow) {
      return this.rangeUnderflowMsg;
    }

    if (validityState.rangeOverflow) {
      return this.rangeOverflowMsg;
    }

    if (validityState.stepMismatch) {
      return this.stepMismatchMsg;
    }

    if (validityState.badInput) {
      return this.badInputValueMsg;
    }
  }

}
window.customElements.define('bs-form-input-feedback', BsFormInputFeedback);

function _templateObject2$J() {
  const data = _taggedTemplateLiteral(["\n            <input \n                type=", "\n                ?readonly=", "\n                .value=", "\n                placeholder=", " />\n        "]);

  _templateObject2$J = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1Z() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                }\n                \n                input {\n                    display: block;\n                    width: 100%;\n                    padding-top: 0.375rem;\n                    padding-bottom: 0.375rem;\n                    margin-bottom: 0;\n                    line-height: 1.5;\n                    color: #212529;\n                    background-color: transparent;\n                    border: solid transparent;\n                    border-width: 1px 0;\n                }\n\n                :host([sm]) input,\n                :host([lg]) input {\n                    padding-right: 0;\n                    padding-left: 0;\n                }\n        \n                @media (min-width: 576px) {\n                    \n                    :host([inline]) input {\n                        display: inline-block;\n                    }\n                }\n            "]);

  _templateObject$1Z = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormInputPlaintext extends LitElement {
  static get properties() {
    return {
      placeholder: String,
      value: String,
      type: String,
      readonly: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsFormControlSizeCss, css(_templateObject$1Z())];
  }

  render() {
    return html(_templateObject2$J(), this.type, this.readonly, this.value, ifDefined(this.placeholder));
  }

  constructor() {
    super();
    this.value = '';
    this.type = 'text';
    this.readonly = false;
  }

}
window.customElements.define('bs-form-input-plaintext', BsFormInputPlaintext);

function _templateObject2$K() {
  const data = _taggedTemplateLiteral(["\n            <label><slot></slot></label>\n        "]);

  _templateObject2$K = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$1_() {
  const data = _taggedTemplateLiteral(["\n                :host([column]) {\n                    padding-top: calc(0.375rem + 1px);\n                    padding-bottom: calc(0.375rem + 1px);\n                    margin-bottom: 0;\n                    font-size: inherit;\n                    line-height: 1.5;\n                }\n\n                :host([column-lg]) {\n                    padding-top: calc(0.5rem + 1px);\n                    padding-bottom: calc(0.5rem + 1px);\n                    font-size: 1.25rem;\n                    line-height: 1.5;\n                }\n\n                :host([column-sm]) {\n                    padding-top: calc(0.25rem + 1px);\n                    padding-bottom: calc(0.25rem + 1px);\n                    font-size: 0.875rem;\n                    line-height: 1.5;\n                }\n        \n                @media (min-width: 576px) {\n                    \n                    :host([inline]) {\n                        display: -ms-flexbox;\n                        display: flex;\n                        -ms-flex-align: center;\n                        align-items: center;\n                        -ms-flex-pack: center;\n                        justify-content: center;\n                        margin-bottom: 0;\n                    }\n                }\n            "]);

  _templateObject$1_ = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormLabel extends LitElement {
  static get styles() {
    return [BsContentRebootCss, BsContentTypographyCss, BsColumnExtraSmallCss, BsColumnSmallCss, BsColumnMediumCss, BsColumnLargeCss, BsColumnExtraLargeCss, css(_templateObject$1_())];
  }

  render() {
    return html(_templateObject2$K());
  }

  firstUpdated() {
    const labelElement = this.shadowRoot.querySelector('label');
    labelElement.addEventListener('click', event => this._handleEvent(event));
  }

  _handleEvent(event) {
    event.preventDefault();
    const disabledAttribute = this.hasAttribute('disabled');

    if (disabledAttribute) {
      return;
    }

    const labelClickedEvent = new CustomEvent('bs-form-label-click', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(labelClickedEvent);
  }

}
window.customElements.define('bs-form-label', BsFormLabel);

function _templateObject$1$() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject$1$ = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormRadioGroup extends LitElement {
  static get properties() {
    return {
      name: String
    };
  }

  render() {
    return html(_templateObject$1$());
  }

  firstUpdated() {
    this._updateInputsWithGroupName();

    this.addEventListener('bs-form-radio-click', event => this._handleRadioClick(event));
  }

  _updateInputsWithGroupName() {
    if (!this.name) {
      return;
    }

    const slotNode = this.shadowRoot.querySelector('slot');
    const slotNodes = slotNode.assignedNodes();

    const formCheckGroupElements = this._retrieveFormCheckGroups(slotNodes);

    for (let index = 0; index < formCheckGroupElements.length; index++) {
      const formGroupElement = formCheckGroupElements[index];

      const formRadioInputElement = this._retrieveFormRadioInput(formGroupElement);

      formRadioInputElement.setAttribute('name', this.name);
    }
  }

  _handleRadioClick(event) {
    const name = event.detail.name;
    const value = event.detail.value;
    const slotNode = this.shadowRoot.querySelector('slot');
    const slotNodes = slotNode.assignedNodes();

    const formCheckGroupElements = this._retrieveFormCheckGroups(slotNodes);

    for (let index = 0; index < formCheckGroupElements.length; index++) {
      const formGroupElement = formCheckGroupElements[index];

      const formRadioInputElement = this._retrieveFormRadioInput(formGroupElement);

      formRadioInputElement.radioGroupItemSelected(name, value);
    }
  }

  _retrieveFormRadioInput(formCheckGroup) {
    const formCheckGroupChildren = formCheckGroup.children;

    for (let index = 0; index < formCheckGroupChildren.length; index++) {
      const childrenItem = formCheckGroupChildren[index];

      if (this._isFormRadioInputElement(childrenItem)) {
        return childrenItem;
      }
    }
  }

  _retrieveFormCheckGroups(slotNodes) {
    const elementNodes = [];

    for (let index = 0; index < slotNodes.length; index++) {
      const slotItem = slotNodes[index];

      if (this._isFormCheckGroupElement(slotItem)) {
        elementNodes.push(slotItem);
      }
    }

    return elementNodes;
  }

  _isFormRadioInputElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-radio-input';
  }

  _isFormCheckGroupElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-check-group';
  }

}
window.customElements.define('bs-form-radio-group', BsFormRadioGroup);

function _templateObject2$L() {
  const data = _taggedTemplateLiteral(["\n            <input \n                type=\"radio\"\n                .value=", "\n                name=", "\n                ?checked=", "\n                ?disabled=", " />\n        "]);

  _templateObject2$L = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$20() {
  const data = _taggedTemplateLiteral(["\n                input {\n                    position: var(--bs-form-radio-input-position, absolute);\n                    margin-top: var(--bs-form-radio-input-margin-top, 0.3rem);\n                    margin-left: var(--bs-form-radio-input-margin-left, -1.25rem);\n                }\n            \n                :host([inline]) {\n                    display: inline-flex;\n                }\n                \n                :host([inline]) input {\n                    position: static;\n                    margin-top: 0;\n                    margin-right: 0.3125rem;\n                    margin-left: 0;\n                }\n        \n                @media (min-width: 576px) {\n        \n                    :host([inline]) input {\n                        position: relative;\n                        margin-top: 0;\n                        margin-right: 0.25rem;\n                        margin-left: 0;\n                    }\n                }\n            "]);

  _templateObject$20 = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormRadioInput extends LitElement {
  static get properties() {
    return {
      name: String,
      value: String,
      static: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      },
      checked: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsPositionCss, css(_templateObject$20())];
  }

  render() {
    return html(_templateObject2$L(), this.value, this.name, this.checked, this.disabled);
  }

  constructor() {
    super();
    this.name = '';
    this.value = '';
    this.static = false;
    this.disabled = false;
    this.checked = false;
  }

  firstUpdated() {
    const inputElement = this.shadowRoot.querySelector('input');
    inputElement.addEventListener('click', event => this._handleClick(event));

    this._applyStaticCss();
  }

  _handleClick() {
    const radioInputClickEvent = new CustomEvent('bs-form-radio-click', {
      bubbles: true,
      composed: true,
      detail: {
        name: this.name,
        value: this.value
      }
    });
    this.dispatchEvent(radioInputClickEvent);
  }

  radioGroupItemSelected(name, value) {
    if (name === this.name && value === this.value) {
      this.check();
    } else {
      this.uncheck();
    }
  }

  _applyStaticCss() {
    if (this.static) {
      const checkboxElement = this.shadowRoot.querySelector('input');
      checkboxElement.classList.add('position-static');
    }
  }

  check() {
    const radioInputElement = this.shadowRoot.querySelector('input');
    radioInputElement.checked = true;
    this.checked = true;
  }

  uncheck() {
    const radioInputElement = this.shadowRoot.querySelector('input');
    radioInputElement.checked = false;
    this.checked = false;
  }

  toggle() {
    const radioInputElement = this.shadowRoot.querySelector('input');
    radioInputElement.checked = !radioInputElement.checked;

    this._handleClick();
  }

}
window.customElements.define('bs-form-radio-input', BsFormRadioInput);

function _templateObject2$M() {
  const data = _taggedTemplateLiteral(["\n            <input type=\"range\" class=\"form-control-range\" />\n        "]);

  _templateObject2$M = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$21() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                }\n                \n                .form-control-range {\n                    display: block;\n                    width: 100%;\n                }\n            "]);

  _templateObject$21 = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormRange extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$21())];
  }

  render() {
    return html(_templateObject2$M());
  }

}
window.customElements.define('bs-form-range', BsFormRange);

function _templateObject2$N() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$N = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$22() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: flex;\n                    flex-wrap: wrap;\n                    margin-right: -5px;\n                    margin-left: -5px;\n                }\n                \n                ::slotted(bs-column) {\n                    padding-right: 5px !important;\n                    padding-left: 5px !important;\n                }\n                \n                /* \n                 * the below assumes that the bs-form-group \n                 * has column attributes like md-6\n                 */\n                \n                ::slotted(bs-form-group) {\n                    padding-right: 5px !important;\n                    padding-left: 5px !important;\n                }\n            "]);

  _templateObject$22 = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormRow extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$22())];
  }

  render() {
    return html(_templateObject2$N());
  }

}
window.customElements.define('bs-form-row', BsFormRow);

function _templateObject2$O() {
  const data = _taggedTemplateLiteral(["\n            <select \n                class=\"form-control\"\n                ?multiple=", "\n                ?disabled=", ">\n            </select>\n        "]);

  _templateObject2$O = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$23() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                }\n                \n                select.form-control:focus::-ms-value {\n                    color: #495057;\n                    background-color: #fff;\n                }\n\n                select.form-control[size], \n                select.form-control[multiple] {\n                    height: auto;\n                }\n            "]);

  _templateObject$23 = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormSelect extends LitElement {
  static get properties() {
    return {
      arrayData: Array,
      jsonData: JSON,
      jsonId: {
        type: String,
        attribute: 'json-id'
      },
      jsonText: {
        type: String,
        attribute: 'json-text'
      },
      selected: Object,
      caption: String,
      multiple: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      },
      valid: {
        type: Boolean,
        reflect: true
      },
      invalid: {
        type: Boolean,
        reflect: true
      },
      _currentSelected: Object
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsFormControlCss, BsFormControlSizeCss, css(_templateObject$23())];
  }

  render() {
    return html(_templateObject2$O(), this.multiple, this.disabled);
  }

  constructor() {
    super();
    this.arrayData = [];
    this.jsonId = '';
    this.jsonText = '';
    this.caption = '';
    this.multiple = false;
    this.disabled = false;
    this.valid = false;
    this.invalid = false;
  }

  firstUpdated() {
    const selectElement = this.shadowRoot.querySelector('select');

    this._generateOptions(selectElement);

    selectElement.addEventListener('change', event => this._handleSelection(event));
  }

  setFocus() {
    const selectElement = this.shadowRoot.querySelector('select');
    selectElement.focus();
  }

  validate() {
    const selectElement = this.shadowRoot.querySelector('select');
    return selectElement.checkValidity();
  }

  getValidity() {
    const selectElement = this.shadowRoot.querySelector('select');
    return selectElement.validity;
  }

  getValue() {
    return this._currentSelected;
  }

  _handleSelection(event) {
    this._currentSelected = event.target.value;
  }

  _generateOptions(selectElement) {
    if (this.caption) {
      const captionOptionItem = this._createCaptionOptionItem();

      selectElement.add(captionOptionItem);
    }

    if (this.arrayData && this.arrayData.length) {
      this._createOptionItemsFromArray(selectElement);

      return;
    }

    if (this.jsonData && this.jsonData.length && this.jsonId && this.jsonText) {
      this._createOptionItemsFromJsonData(selectElement);

      return;
    }
  }

  _createCaptionOptionItem() {
    let captionSelected = false;

    if (!this.selected) {
      captionSelected = true;
    }

    const captionOptionItem = new Option(this.caption, '', captionSelected, captionSelected);
    captionOptionItem.setAttribute('disabled', '');
    return captionOptionItem;
  }

  _createOptionItemsFromArray(selectElement) {
    for (let index = 0; index < this.arrayData.length; index++) {
      const item = this.arrayData[index];
      const selectedItem = item.toString() === this.selected;
      const optionItem = new Option(item, item, selectedItem, selectedItem);
      selectElement.add(optionItem);
    }
  }

  _createOptionItemsFromJsonData(selectElement) {
    for (let index = 0; index < this.jsonData.length; index++) {
      const item = this.jsonData[index];
      const id = item[this.jsonId];
      const value = item[this.jsonText];
      const selectedItem = value.toString() === this.selected;
      const optionItem = new Option(value, id, selectedItem, selectedItem);
      selectElement.add(optionItem);
    }
  }

}
window.customElements.define('bs-form-select', BsFormSelect);

function _templateObject2$P() {
  const data = _taggedTemplateLiteral(["\n            \n            <textarea \n                class=\"form-control\"\n                tabIndex=", "\n                ?wrap=", "\n                rows=", "\n                cols=", "\n                minlength=", "\n                maxlength=", "\n                ?required=", "\n                ?disabled=", "\n                .value=", "\n                placeholder=", ">\n            </textarea>\n        "]);

  _templateObject2$P = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$24() {
  const data = _taggedTemplateLiteral(["\n                textarea.form-control {\n                    height: auto;\n                }\n            "]);

  _templateObject$24 = function _templateObject() {
    return data;
  };

  return data;
}
class BsFormTextarea extends LitElement {
  static get properties() {
    return {
      rows: Number,
      cols: Number,
      maxlength: Number,
      minlength: Number,
      tabIndex: Number,
      placeholder: String,
      wrap: {
        type: Boolean,
        reflect: true
      },
      required: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      },
      valid: {
        type: Boolean,
        reflect: true
      },
      invalid: {
        type: Boolean,
        reflect: true
      },
      value: {
        type: String,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsFormControlCss, css(_templateObject$24())];
  }

  render() {
    return html(_templateObject2$P(), ifDefined(this.tabIndex), this.wrap, ifDefined(this.rows), ifDefined(this.cols), ifDefined(this.minlength), ifDefined(this.maxlength), this.required, this.disabled, this.value, ifDefined(this.placeholder));
  }

  constructor() {
    super();
    this.value = '';
    this.wrap = false;
    this.required = false;
    this.disabled = false;
    this.valid = false;
    this.invalid = false;
  }

  setFocus() {
    const textareaElement = this.shadowRoot.querySelector('textarea');
    textareaElement.focus();
  }

  validate() {
    const textareaElement = this.shadowRoot.querySelector('textarea');
    return textareaElement.checkValidity();
  }

  getValidity() {
    const textareaElement = this.shadowRoot.querySelector('textarea');
    return textareaElement.validity;
  }

}
window.customElements.define('bs-form-textarea', BsFormTextarea);

function _templateObject$25() {
  const data = _taggedTemplateLiteral(["\n    \n    :host {\n        position: relative;\n        display: flex;\n        flex-wrap: wrap;\n        align-items: stretch;\n        width: var(--bs-input-group-width, 100%);\n    }\n\n    :host ::slotted(bs-form-input),\n    :host ::slotted(bs-form-select),\n    :host ::slotted(bs-form-textarea),\n    :host ::slotted(bs-custom-select),\n    :host ::slotted(bs-custom-file) {\n        flex: 1 1 auto;\n        width: 1%;\n        margin-bottom: 0;\n        \n        --bs-form-control-position: relative;\n        --bs-form-control-z-index: 3;\n        --bs-custom-select-position: relative;\n        --bs-custom-select-z-index: 3;\n        --bs-custom-file-position: relative;\n        --bs-custom-file-z-index: 3;\n    }\n    \n    /* \n        remember to add this inside the bs-custom-file component \n       \n        .input-group > .custom-file .custom-file-input:focus ~ .custom-file-label \n    */\n    \n    /* \n        remember to add this inside the bs-custom-file component\n        \n        .input-group > .custom-file .custom-file-input:focus {\n            z-index: 4;\n        } \n    */\n    \n    :host ::slotted(bs-form-input:not(:last-child)),\n    :host ::slotted(bs-form-select:not(:last-child)),\n    :host ::slotted(bs-form-textarea:not(:last-child)),\n    :host ::slotted(bs-custom-select:not(:last-child)) {\n        --bs-form-control-border-top-right-radius: 0;\n        --bs-form-control-border-bottom-right-radius: 0;\n    }\n    \n    :host ::slotted(bs-form-input:not(:first-child)),\n    :host ::slotted(bs-form-select:not(:first-child)),\n    :host ::slotted(bs-form-textarea:not(:first-child)),\n    :host ::slotted(bs-custom-select:not(:first-child)) {\n        --bs-form-control-border-top-left-radius: 0;\n        --bs-form-control-border-bottom-left-radius: 0;\n    }\n    \n    :host ::slotted(bs-custom-file) {\n        display: flex;\n        align-items: center;\n    }\n    \n    /*\n        remember to add this inside the bs-custom-file component\n\n        .input-group > .custom-file:not(:last-child) .custom-file-label,\n        .input-group > .custom-file:not(:last-child) .custom-file-label::after {\n            border-top-right-radius: 0;\n            border-bottom-right-radius: 0;\n        }\n        \n        .input-group > .custom-file:not(:first-child) .custom-file-label {\n            border-top-left-radius: 0;\n            border-bottom-left-radius: 0;\n          }\n    */\n"]);

  _templateObject$25 = function _templateObject() {
    return data;
  };

  return data;
}
const BsInputGroupCss = css(_templateObject$25());

function _templateObject$26() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([small]) ::slotted(bs-form-input),\n    :host([small]) ::slotted(bs-form-select),\n    :host([small]) ::slotted(bs-form-textarea),\n    :host([small]) ::slotted(bs-input-group-append),\n    :host([small]) ::slotted(bs-input-group-prepend) {\n        \n        --bs-button-height: calc(2.875rem + 2px);\n        --bs-button-padding-top: 0.5rem;\n        --bs-button-padding-bottom: 0.5rem;\n        --bs-button-padding-left: 1rem;\n        --bs-button-padding-right: 1rem;\n        --bs-button-font-size: 1.25rem;\n        --bs-button-line-height: 1.5;\n        --bs-button-border-top-left-radius: 0.3rem;\n        --bs-button-border-top-right-radius: 0.3rem;\n        --bs-button-border-bottom-left-radius: 0.3rem;\n        --bs-button-border-bottom-right-radius: 0.3rem;\n\n        --bs-form-control-height: calc(2.875rem + 2px);\n        --bs-form-control-padding: 0.5rem 1rem;\n        --bs-form-control-font-size: 1.25rem;\n        --bs-form-control-line-height: 1.5;\n        --bs-form-control-border-top-left-radius: 0.3rem;\n        --bs-form-control-border-top-right-radius: 0.3rem;\n        --bs-form-control-border-bottom-left-radius: 0.3rem;\n        --bs-form-control-border-bottom-right-radius: 0.3rem;\n\n        --bs-input-group-text-height: calc(2.875rem + 2px);\n        --bs-input-group-text-padding: 0.5rem 1rem;\n        --bs-input-group-text-font-size: 1.25rem;\n        --bs-input-group-text-line-height: 1.5;\n        --bs-input-group-text-border-top-left-radius: 0.3rem;\n        --bs-input-group-text-border-top-right-radius: 0.3rem;\n        --bs-input-group-text-border-bottom-left-radius: 0.3rem;\n        --bs-input-group-text-border-bottom-right-radius: 0.3rem;\n    }\n"]);

  _templateObject$26 = function _templateObject() {
    return data;
  };

  return data;
}
const BsInputGroupLargeCss = css(_templateObject$26());

function _templateObject$27() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([small]) ::slotted(bs-form-input),\n    :host([small]) ::slotted(bs-form-select),\n    :host([small]) ::slotted(bs-form-textarea),\n    :host([small]) ::slotted(bs-input-group-append),\n    :host([small]) ::slotted(bs-input-group-prepend) {\n        --bs-button-height: calc(1.8125rem + 2px);\n        --bs-button-padding-top: 0.25rem;\n        --bs-button-padding-bottom: 0.25rem;\n        --bs-button-padding-left: 0.5rem;\n        --bs-button-padding-right: 0.5rem;\n        --bs-button-font-size: 0.875rem;\n        --bs-button-line-height: 1.5;\n        --bs-button-border-top-left-radius: 0.2rem;\n        --bs-button-border-top-right-radius: 0.2rem;\n        --bs-button-border-bottom-left-radius: 0.2rem;\n        --bs-button-border-bottom-right-radius: 0.2rem;\n\n        --bs-form-control-height: calc(1.8125rem + 2px);\n        --bs-form-control-padding: 0.25rem 0.5rem;\n        --bs-form-control-font-size: 0.875rem;\n        --bs-form-control-line-height: 1.5;\n        --bs-form-control-border-top-left-radius: 0.2rem;\n        --bs-form-control-border-top-right-radius: 0.2rem;\n        --bs-form-control-border-bottom-left-radius: 0.2rem;\n        --bs-form-control-border-bottom-right-radius: 0.2rem;\n\n        --bs-input-group-text-height: calc(1.8125rem + 2px);\n        --bs-input-group-text-padding: 0.25rem 0.5rem;\n        --bs-input-group-text-font-size: 0.875rem;\n        --bs-input-group-text-line-height: 1.5;\n        --bs-input-group-text-border-top-left-radius: 0.2rem;\n        --bs-input-group-text-border-top-right-radius: 0.2rem;\n        --bs-input-group-text-border-bottom-left-radius: 0.2rem;\n        --bs-input-group-text-border-bottom-right-radius: 0.2rem;\n    }\n"]);

  _templateObject$27 = function _templateObject() {
    return data;
  };

  return data;
}
const BsInputGroupSmallCss = css(_templateObject$27());

function _templateObject$28() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject$28 = function _templateObject() {
    return data;
  };

  return data;
}
class BsInputGroup extends LitElement {
  static get properties() {
    return {
      large: {
        type: Boolean,
        reflect: true
      },
      small: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsInputGroupCss, BsInputGroupLargeCss, BsInputGroupSmallCss];
  }

  render() {
    return html(_templateObject$28());
  }

  constructor() {
    super();
    this.large = false;
    this.small = false;
  }

  firstUpdated() {
    this._adjustMarginOnMultipleFormControlElements();
  } // :slotted can only accept simple selectors and not combinators
  // since the adjucent sibling selector cannot be used, we apply css via javascript


  _adjustMarginOnMultipleFormControlElements() {
    const slotNode = this.shadowRoot.querySelector('slot');
    const slottedNodes = slotNode.assignedNodes();
    slottedNodes.forEach(slotElement => {
      this._applyCssForFormInputElement(slotElement);

      this._applyCssForFormSelectElement(slotElement);

      this._applyCssForFormTextAreaElement(slotElement);

      this._applyCssForCustomSelectElement(slotElement);

      this._applyCssForCustomFileElement(slotElement);
    });
  }

  _applyCssForFormTextAreaElement(slotElement) {
    if (this._isFormTextAreaElement(slotElement)) {
      if (this._isFormTextAreaElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-form-control-margin-left', '-1px');
      }

      if (this._isCustomSelectElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-form-control-margin-left', '-1px');
      }

      if (this._isCustomFileElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-form-control-margin-left', '-1px');
      }
    }
  }

  _applyCssForFormSelectElement(slotElement) {
    if (this._isFormSelectElement(slotElement)) {
      if (this._isFormSelectElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-form-control-margin-left', '-1px');
      }

      if (this._isCustomSelectElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-form-control-margin-left', '-1px');
      }

      if (this._isCustomFileElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-form-control-margin-left', '-1px');
      }
    }
  }

  _applyCssForFormInputElement(slotElement) {
    if (this._isFormInputElement(slotElement)) {
      if (this._isFormInputElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-form-control-margin-left', '-1px');
      }

      if (this._isCustomSelectElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-form-control-margin-left', '-1px');
      }

      if (this._isCustomFileElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-form-control-margin-left', '-1px');
      }
    }
  }

  _applyCssForCustomSelectElement(slotElement) {
    if (this._isCustomSelectElement(slotElement)) {
      if (this._isCustomSelectElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-custom-select-margin-left', '-1px');
      }

      if (this._isCustomFileElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-custom-select-margin-left', '-1px');
      }

      if (this._isFormInputElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-custom-select-margin-left', '-1px');
      }

      if (this._isFormSelectElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-custom-select-margin-left', '-1px');
      }

      if (this._isFormTextAreaElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-custom-select-margin-left', '-1px');
      }
    }
  }

  _applyCssForCustomFileElement(slotElement) {
    if (this._isCustomFileElement(slotElement)) {
      if (this._isCustomFileElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-custom-file-margin-left', '-1px');
      }

      if (this._isCustomSelectElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-custom-file-margin-left', '-1px');
      }

      if (this._isFormInputElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-custom-file-margin-left', '-1px');
      }

      if (this._isFormSelectElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-custom-file-margin-left', '-1px');
      }

      if (this._isFormTextAreaElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-custom-file-margin-left', '-1px');
      }
    }
  }

  _isFormSelectElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-select';
    }
  }

  _isFormInputElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-input';
    }
  }

  _isFormTextAreaElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-form-textarea';
    }
  }

  _isCustomFileElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-custom-file';
    }
  }

  _isCustomSelectElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-custom-select';
    }
  }

}
window.customElements.define('bs-input-group', BsInputGroup);

function _templateObject2$Q() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$Q = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$29() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: flex;\n                    margin-left: -1px;\n                }\n                \n                :host ::slotted(bs-button),\n                :host ::slotted(bs-link-button),\n                :host ::slotted(bs-input-button),\n                :host ::slotted(bs-dropdown),\n                :host ::slotted(bs-input-group-text) {\n                    --bs-button-border-top-left-radius: 0;\n                    --bs-button-border-bottom-left-radius: 0;\n                    --bs-input-group-text-border-top-left-radius: 0;\n                    --bs-input-group-text-border-bottom-left-radius: 0;\n                    --bs-button-position: relative;\n                    --bs-button-focus-z-index: 2;\n                }\n        \n                :host(:not(:last-child)) ::slotted(bs-button),\n                :host(:not(:last-child)) ::slotted(bs-link-button),\n                :host(:not(:last-child)) ::slotted(bs-input-button),\n                :host(:not(:last-child)) ::slotted(bs-dropdown),\n                :host(:not(:last-child)) ::slotted(bs-input-group-text) {\n                    --bs-button-border-top-right-radius: 0;\n                    --bs-button-border-bottom-right-radius: 0;\n                    --bs-input-group-text-border-top-right-radius: 0;\n                    --bs-input-group-text-border-bottom-right-radius: 0;\n                }\n        \n                :host(:last-child) ::slotted(bs-button:not(:last-child)),\n                :host(:last-child) ::slotted(bs-link-button:not(:last-child)),\n                :host(:last-child) ::slotted(bs-input-button:not(:last-child)),\n                :host(:last-child) ::slotted(bs-dropdown:not(:last-child)),\n                :host(:last-child) ::slotted(bs-input-group-text:not(:last-child)) {\n                    --bs-button-border-top-right-radius: 0;\n                    --bs-button-border-bottom-right-radius: 0;\n                    --bs-input-group-text-border-top-right-radius: 0;\n                    --bs-input-group-text-border-bottom-right-radius: 0;\n                }\n            "]);

  _templateObject$29 = function _templateObject() {
    return data;
  };

  return data;
}
class BsInputGroupAppend extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$29())];
  }

  render() {
    return html(_templateObject2$Q());
  }

  firstUpdated() {
    this._adjustMarginOnMultipleAddonsElements();
  }

  _adjustMarginOnMultipleAddonsElements() {
    const slotNode = this.shadowRoot.querySelector('slot');
    const slottedNodes = slotNode.assignedNodes();
    slottedNodes.forEach(slotElement => {
      this._applyCssForInputGroupTextElement(slotElement);

      this._applyCssForButtonElement(slotElement);

      this._applyCssForDropdownSplitElement(slotElement);
    });
  }

  _applyCssForInputGroupTextElement(slotElement) {
    if (this._isInputGroupTextElement(slotElement)) {
      if (this._isInputGroupTextElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-input-group-text-margin-left', '-1px');
      }

      if (this._isButtonElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-input-group-text-margin-left', '-1px');
      }
    }
  }

  _applyCssForButtonElement(slotElement) {
    if (this._isButtonElement(slotElement)) {
      if (this._isButtonElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-button-margin-left', '-1px');
      }

      if (this._isInputGroupTextElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-button-margin-left', '-1px');
      }
    }
  }

  _applyCssForDropdownSplitElement(slotElement) {
    if (this._isDropdownElement(slotElement)) {
      slotElement.style.setProperty('--dropdown-toggle-margin-left', '-1px');
    }
  }

  _isInputGroupTextElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-input-group-text';
    }
  }

  _isDropdownElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-dropdown';
    }
  }

  _isButtonElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && (element.localName === 'bs-button' || element.localName === 'bs-link-button' || element.localName === 'bs-input-button');
    }
  }

}
window.customElements.define('bs-input-group-append', BsInputGroupAppend);

function _templateObject2$R() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$R = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2a() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: flex;\n                    margin-right: -1px;\n                }\n                \n                :host ::slotted(bs-button),\n                :host ::slotted(bs-link-button),\n                :host ::slotted(bs-input-button),\n                :host ::slotted(bs-dropdown),\n                :host ::slotted(bs-input-group-text) {\n                    --bs-button-border-top-right-radius: 0;\n                    --bs-button-border-bottom-right-radius: 0;\n                    --bs-input-group-text-border-top-right-radius: 0;\n                    --bs-input-group-text-border-bottom-right-radius: 0;\n                    --bs-button-position: relative;\n                    --bs-button-focus-z-index: 2;\n                }\n                \n                :host(:not(:first-child)) ::slotted(bs-button:not(:first-child)),\n                :host(:not(:first-child)) ::slotted(bs-link-button:not(:first-child)),\n                :host(:not(:first-child)) ::slotted(bs-input-button:not(:first-child)),\n                :host(:not(:first-child)) ::slotted(bs-dropdown:not(:first-child)),\n                :host(:not(:first-child)) ::slotted(bs-input-group-text:not(:first-child)) {\n                    --bs-button-border-top-left-radius: 0;\n                    --bs-button-border-bottom-left-radius: 0;\n                    --bs-input-group-text-border-top-left-radius: 0;\n                    --bs-input-group-text-border-bottom-left-radius: 0;\n                }\n                \n                :host(:first-child) ::slotted(bs-button:not(:first-child)),\n                :host(:first-child) ::slotted(bs-link-button:not(:first-child)),\n                :host(:first-child) ::slotted(bs-input-button:not(:first-child)),\n                :host(:first-child) ::slotted(bs-dropdown:not(:first-child)),\n                :host(:first-child) ::slotted(bs-input-group-text:not(:first-child)) {\n                    --bs-button-border-top-left-radius: 0;\n                    --bs-button-border-bottom-left-radius: 0;\n                    --bs-input-group-text-border-top-left-radius: 0;\n                    --bs-input-group-text-border-bottom-left-radius: 0;\n                }\n            "]);

  _templateObject$2a = function _templateObject() {
    return data;
  };

  return data;
}
class BsInputGroupPrepend extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2a())];
  }

  render() {
    return html(_templateObject2$R());
  }

  firstUpdated() {
    this._adjustMarginOnMultipleAddonsElements();
  }

  _adjustMarginOnMultipleAddonsElements() {
    const slotNode = this.shadowRoot.querySelector('slot');
    const slottedNodes = slotNode.assignedNodes();
    slottedNodes.forEach(slotElement => {
      this._applyCssForInputGroupTextElement(slotElement);

      this._applyCssForButtonElement(slotElement);

      this._applyCssForDropdownSplitElement(slotElement);
    });
  }

  _applyCssForInputGroupTextElement(slotElement) {
    if (this._isInputGroupTextElement(slotElement)) {
      if (this._isInputGroupTextElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-input-group-text-margin-left', '-1px');
      }

      if (this._isButtonElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-input-group-text-margin-left', '-1px');
      }
    }
  }

  _applyCssForButtonElement(slotElement) {
    if (this._isButtonElement(slotElement)) {
      if (this._isButtonElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-button-margin-left', '-1px');
      }

      if (this._isInputGroupTextElement(slotElement.previousElementSibling)) {
        slotElement.style.setProperty('--bs-button-margin-left', '-1px');
      }
    }
  }

  _applyCssForDropdownSplitElement(slotElement) {
    if (this._isDropdownElement(slotElement)) {
      slotElement.style.setProperty('--dropdown-toggle-margin-left', '-1px');
      slotElement.style.setProperty('--dropdown-toggle-border-top-right', '0');
      slotElement.style.setProperty('--dropdown-toggle-border-bottom-right', '0');
    }
  }

  _isInputGroupTextElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-input-group-text';
    }
  }

  _isDropdownElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-dropdown';
    }
  }

  _isButtonElement(element) {
    if (element) {
      return element.nodeType === Node.ELEMENT_NODE && (element.localName === 'bs-button' || element.localName === 'bs-link-button' || element.localName === 'bs-input-button');
    }
  }

}
window.customElements.define('bs-input-group-prepend', BsInputGroupPrepend);

function _templateObject2$S() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$S = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2b() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: flex;\n                    align-items: center;\n                    padding: var(--bs-input-group-text-padding, 0.375rem 0.75rem);\n                    margin-bottom: 0;\n                    margin-left: var(--bs-input-group-text-margin-left);\n                    font-size: var(--bs-input-group-text-font-size, 1rem);\n                    font-weight: 400;\n                    line-height: var(--bs-input-group-text-line-height, 1.5);\n                    color: #495057;\n                    text-align: center;\n                    white-space: nowrap;\n                    background-color: #e9ecef;\n                    border: 1px solid #ced4da;\n                    height: var(--bs-input-group-text-height);\n                    border-top-left-radius: var(--bs-input-group-text-border-top-left-radius, 0.25rem);\n                    border-top-right-radius: var(--bs-input-group-text-border-top-right-radius, 0.25rem);\n                    border-bottom-right-radius: var(--bs-input-group-text-border-bottom-right-radius, 0.25rem);\n                    border-bottom-left-radius: var(--bs-input-group-text-border-bottom-left-radius, 0.25rem);\n                }\n                \n                :host ::slotted(bs-form-radio-input),\n                :host ::slotted(bs-form-checkbox-input) {\n                    --bs-form-checkbox-input-position: static;\n                    --bs-form-checkbox-input-margin-top: 0;\n                    --bs-form-checkbox-input-margin-left: 0;\n                    --bs-form-radio-input-position: static;\n                    --bs-form-radio-input-margin-top: 0;\n                    --bs-form-radio-input-margin-left: 0;\n                }\n            "]);

  _templateObject$2b = function _templateObject() {
    return data;
  };

  return data;
}
class BsInputGroupText extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2b())];
  }

  render() {
    return html(_templateObject2$S());
  }

}
window.customElements.define('bs-input-group-text', BsInputGroupText);

function _templateObject2$T() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$T = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2c() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                    padding: 2rem 1rem;\n                    margin-bottom: 2rem;\n                    background-color: #e9ecef;\n                    border-radius: 0.3rem;\n                }\n\n                @media (min-width: 576px) {\n                    :host {\n                        padding: 4rem 2rem;\n                    }\n                }\n\n                :host([fluid]) {\n                    padding-right: 0;\n                    padding-left: 0;\n                    border-radius: 0;\n                }\n            "]);

  _templateObject$2c = function _templateObject() {
    return data;
  };

  return data;
}
class BsJumbotron extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2c())];
  }

  render() {
    return html(_templateObject2$T());
  }

}
window.customElements.define('bs-jumbotron', BsJumbotron);

function _templateObject$2d() {
  const data = _taggedTemplateLiteral(["\n    \n    .list-group {\n        display: flex;\n        flex-direction: column;\n        padding-left: 0;\n        margin-bottom: 0;\n        max-width: var(--list-group-max-width, 400px);\n    }\n"]);

  _templateObject$2d = function _templateObject() {
    return data;
  };

  return data;
}
const BsListGroupCommonCss = css(_templateObject$2d());

function _templateObject2$U() {
  const data = _taggedTemplateLiteral(["\n            <ul class=\"list-group\">\n                <slot></slot>\n            </ul>\n        "]);

  _templateObject2$U = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2e() {
  const data = _taggedTemplateLiteral(["\n                ul ::slotted(*:first-child) {\n                    --list-group-item-border-radius-top-left: 0.25rem;\n                    --list-group-item-border-radius-top-right: 0.25rem;\n                }\n                \n                ul ::slotted(*:last-child) {\n                    margin-bottom: 0;\n                    --list-group-item-border-radius-bottom-left: 0.25rem;\n                    --list-group-item-border-radius-bottom-right: 0.25rem;\n                }\n            "]);

  _templateObject$2e = function _templateObject() {
    return data;
  };

  return data;
}
class BsListGroup extends LitElement {
  static get styles() {
    return [BsContentRebootCss, BsListGroupCommonCss, css(_templateObject$2e())];
  }

  render() {
    return html(_templateObject2$U());
  }

}
window.customElements.define('bs-list-group', BsListGroup);

function _templateObject2$V() {
  const data = _taggedTemplateLiteral(["\n            <div class=\"list-group\">\n                <slot></slot>\n            </div>\n        "]);

  _templateObject2$V = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2f() {
  const data = _taggedTemplateLiteral(["\n                div ::slotted(*:first-child) {\n                    --list-group-item-border-radius-top-left: 0.25rem;\n                    --list-group-item-border-radius-top-right: 0.25rem;\n                }\n                \n                div ::slotted(*:last-child) {\n                    margin-bottom: 0;\n                    --list-group-item-border-radius-bottom-left: 0.25rem;\n                    --list-group-item-border-radius-bottom-right: 0.25rem;\n                }\n            "]);

  _templateObject$2f = function _templateObject() {
    return data;
  };

  return data;
}
class BsListGroupAction extends LitElement {
  static get properties() {
    return {
      selectedItem: {
        type: Number,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsListGroupCommonCss, css(_templateObject$2f())];
  }

  render() {
    return html(_templateObject2$V());
  }

  constructor() {
    super();
    this.selectedItem = 0;
  }

  firstUpdated() {
    this._addGroupActionItemsIndex();

    this.addEventListener('list-group-item-selected', event => this._handleListGroupItemSelected(event));
  }

  updated(changedProperties) {
    if (changedProperties.has('selecteditem')) {
      this._updateSelectedItem();
    }
  }

  _handleListGroupItemSelected(event) {
    this.selectedItem = event.detail.index;
  }

  _addGroupActionItemsIndex() {
    const groupItems = this._retrieveGroupItems();

    for (let index = 0; index < groupItems.length; ++index) {
      const groupItem = groupItems[index];
      groupItem.setAttribute('index', index);
    }
  }

  _updateSelectedItem() {
    const groupItems = this._retrieveGroupItems();

    for (let index = 0; index < groupItems.length; ++index) {
      const groupItem = groupItems[index];

      if (index === this.selectedItem) {
        groupItem.setAttribute('active', '');
      } else {
        groupItem.removeAttribute('active');
      }
    }
  }

  _retrieveGroupItems() {
    const slotNodes = this.shadowRoot.querySelector('slot').assignedNodes();

    const groupActionItemNodes = this._retrieveGroupItemNodes(slotNodes);

    return groupActionItemNodes;
  }

  _retrieveGroupItemNodes(nodes) {
    const groupActionItemNodes = [];

    for (let index = 0; index < nodes.length; ++index) {
      const el = nodes[index];

      if (this._isGroupActionItem(el)) {
        groupActionItemNodes.push(el);
      }
    }

    return groupActionItemNodes;
  }

  _isGroupActionItem(el) {
    return el.nodeType === Node.ELEMENT_NODE && (el.localName === 'bs-list-group-item-action-link' || el.localName === 'bs-list-group-item-action-button');
  }

}
window.customElements.define('bs-list-group-action', BsListGroupAction);

function _templateObject2$W() {
  const data = _taggedTemplateLiteral(["\n            <div class=\"list-group\">\n                <slot></slot>\n            </div>\n        "]);

  _templateObject2$W = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2g() {
  const data = _taggedTemplateLiteral(["\n                div ::slotted(*) {\n                    --list-group-item-border-right: 0px;\n                    --list-group-item-border-left: 0px;\n                    --list-group-item-border-radius-bottom-right: 0;\n                    --list-group-item-border-radius-bottom-left: 0;\n                    --list-group-item-border-radius-top-left: 0;\n                    --list-group-item-border-radius-top-right: 0;\n                }\n                \n                div ::slotted(*:first-child) {\n                    --list-group-item-border-top: var(--flush-list-group-item-top-border, 0);\n                    --list-group-item-border-radius-top-left: var(--flush-list-group-item-top-left-radius, 0);\n                    --list-group-item-border-radius-top-right: var(--flush-list-group-item-top-right-radius, 0);\n                }\n                \n                div ::slotted(*:last-child) {\n                    --list-group-item-border-bottom: var(--flush-list-group-item-bottom-border, 0);\n                    --list-group-item-border-radius-bottom-left: var(--flush-list-group-item-bottom-left-radius , 0);\n                    --list-group-item-border-radius-bottom-right: var(--flush-list-group-item-bottom-right-radius , 0);\n                }\n            "]);

  _templateObject$2g = function _templateObject() {
    return data;
  };

  return data;
}
class BsListGroupActionFlush extends LitElement {
  static get properties() {
    return {
      selectedItem: {
        type: Number,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsListGroupCommonCss, css(_templateObject$2g())];
  }

  render() {
    return html(_templateObject2$W());
  }

  constructor() {
    super();
    this.selectedItem = 0;
  }

  firstUpdated() {
    this._addGroupActionItemsIndex();

    this.addEventListener('list-group-item-selected', event => this._handleListGroupItemSelected(event));
  }

  updated(changedProperties) {
    if (changedProperties.has('selecteditem')) {
      this._updateSelectedItem();
    }
  }

  _handleListGroupItemSelected(event) {
    this.selectedItem = event.detail.index;
  }

  _addGroupActionItemsIndex() {
    const groupItems = this._retrieveGroupItems();

    for (let index = 0; index < groupItems.length; ++index) {
      const groupItem = groupItems[index];
      groupItem.setAttribute('index', index);
    }
  }

  _updateSelectedItem() {
    const groupItems = this._retrieveGroupItems();

    for (let index = 0; index < groupItems.length; ++index) {
      const groupItem = groupItems[index];

      if (index === this.selectedItem) {
        groupItem.setAttribute('active', '');
      } else {
        groupItem.removeAttribute('active');
      }
    }
  }

  _retrieveGroupItems() {
    const slotNodes = this.shadowRoot.querySelector('slot').assignedNodes();

    const groupActionItemNodes = this._retrieveGroupItemNodes(slotNodes);

    return groupActionItemNodes;
  }

  _retrieveGroupItemNodes(nodes) {
    const groupActionItemNodes = [];

    for (let index = 0; index < nodes.length; ++index) {
      const el = nodes[index];

      if (this._isGroupActionItem(el)) {
        groupActionItemNodes.push(el);
      }
    }

    return groupActionItemNodes;
  }

  _isGroupActionItem(el) {
    return el.nodeType === Node.ELEMENT_NODE && (el.localName === 'bs-list-group-item-action-link' || el.localName === 'bs-list-group-item-action-button');
  }

}
window.customElements.define('bs-list-group-action-flush', BsListGroupActionFlush);

function _templateObject$2h() {
  const data = _taggedTemplateLiteral(["\n                \n    .list-group-item {\n        position: relative;\n        display: block;\n        padding: 0.75rem 1.25rem;\n        margin-bottom: -1px;\n        background-color: #fff;\n\n        border-bottom-right-radius: var(--list-group-item-border-radius-bottom-right);\n        border-bottom-left-radius: var(--list-group-item-border-radius-bottom-left);\n        border-top-left-radius: var(--list-group-item-border-radius-top-left);\n        border-top-right-radius: var(--list-group-item-border-radius-top-right);\n\n        border-top: var(--list-group-item-border-top, 1px solid rgba(0, 0, 0, 0.125));\n        border-bottom: var(--list-group-item-border-bottom, 1px solid rgba(0, 0, 0, 0.125));\n        border-right: var(--list-group-item-border-right, 1px solid rgba(0, 0, 0, 0.125));\n        border-left: var(--list-group-item-border-left, 1px solid rgba(0, 0, 0, 0.125));\n    }\n\n    .list-group-item:hover, \n    .list-group-item:focus {\n        z-index: 1;\n        text-decoration: none;\n    }\n\n    :host([disabled]) .list-group-item, \n    :host([disabled]) .list-group-item:disabled {\n        color: #6c757d;\n        background-color: #fff;\n    }\n\n    :host([active]) .list-group-item {\n        z-index: 2;\n        color: #fff;\n        background-color: #007bff;\n        border-color: #007bff;\n    }\n\n    :host([primary]) .list-group-item {\n        color: #004085;\n        background-color: #b8daff;\n    }\n\n    :host([secondary]) .list-group-item {\n        color: #383d41;\n        background-color: #d6d8db;\n    }\n\n    :host([success]) .list-group-item {\n        color: #155724;\n        background-color: #c3e6cb;\n    }\n\n    :host([info]) .list-group-item {\n        color: #0c5460;\n        background-color: #bee5eb;\n    }\n\n    :host([warning]) .list-group-item {\n        color: #856404;\n        background-color: #ffeeba;\n    }\n\n    :host([danger]) .list-group-item {\n        color: #721c24;\n        background-color: #f5c6cb;\n    }\n\n    :host([light]) .list-group-item {\n        color: #818182;\n        background-color: #fdfdfe;\n    }\n\n    :host([dark]) .list-group-item {\n        color: #1b1e21;\n        background-color: #c6c8ca;\n    }\n"]);

  _templateObject$2h = function _templateObject() {
    return data;
  };

  return data;
}
const BsListGroupItemCommonCss = css(_templateObject$2h());

function _templateObject$2i() {
  const data = _taggedTemplateLiteral(["\n            <li class=\"list-group-item d-flex\">\n                <slot></slot>\n            </li>\n        "]);

  _templateObject$2i = function _templateObject() {
    return data;
  };

  return data;
}
class BsListGroupBadgeItem extends LitElement {
  static get properties() {
    return {
      align: String,
      justify: String
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsListGroupItemCommonCss, BsFlexJustifyCss, BsFlexDisplayCss, BsFlexAlignItemsCss];
  }

  render() {
    return html(_templateObject$2i());
  }

  constructor() {
    super();
    this.justify = 'between';
    this.align = 'center';
  }

  firstUpdated() {
    const groupItemElement = this.shadowRoot.querySelector('li');

    this._handleAlignItems(groupItemElement);

    this._handleJustification(groupItemElement);
  }

  _handleAlignItems(groupItemElement) {
    if (this.align === 'start') {
      groupItemElement.classList.add('align-items-start');
    }

    if (this.align === 'end') {
      groupItemElement.classList.add('align-items-end');
    }

    if (this.align === 'center') {
      groupItemElement.classList.add('align-items-center');
    }

    if (this.align === 'baseline') {
      groupItemElement.classList.add('align-items-baseline');
    }

    if (this.align === 'stretch') {
      groupItemElement.classList.add('align-items-stretch');
    }
  }

  _handleJustification(groupItemElement) {
    if (this.justify === 'start') {
      groupItemElement.classList.add('justify-content-start');
    }

    if (this.justify === 'end') {
      groupItemElement.classList.add('justify-content-end');
    }

    if (this.justify === 'center') {
      groupItemElement.classList.add('justify-content-center');
    }

    if (this.justify === 'between') {
      groupItemElement.classList.add('justify-content-between');
    }

    if (this.justify === 'around') {
      groupItemElement.classList.add('justify-content-around');
    }
  }

}
window.customElements.define('bs-list-group-badge-item', BsListGroupBadgeItem);

function _templateObject2$X() {
  const data = _taggedTemplateLiteral(["\n            <ul class=\"list-group\">\n                <slot></slot>\n            </ul>\n        "]);

  _templateObject2$X = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2j() {
  const data = _taggedTemplateLiteral(["\n                ul ::slotted(*) {\n                    --list-group-item-border-right: 0px;\n                    --list-group-item-border-left: 0px;\n                    --list-group-item-border-radius-bottom-right: 0;\n                    --list-group-item-border-radius-bottom-left: 0;\n                    --list-group-item-border-radius-top-left: 0;\n                    --list-group-item-border-radius-top-right: 0;\n                }\n                \n                ul ::slotted(*:first-child) {\n                    --list-group-item-border-top: var(--flush-list-group-item-top-border, 0);\n                    --list-group-item-border-radius-top-left: var(--flush-list-group-item-top-left-radius, 0);\n                    --list-group-item-border-radius-top-right: var(--flush-list-group-item-top-right-radius, 0);\n                }\n                \n                ul ::slotted(*:last-child) {\n                    --list-group-item-border-bottom: var(--flush-list-group-item-bottom-border, 0);\n                    --list-group-item-border-radius-bottom-left: var(--flush-list-group-item-bottom-left-radius, 0);\n                    --list-group-item-border-radius-bottom-right: var(--flush-list-group-item-bottom-right-radius, 0);\n                }\n            "]);

  _templateObject$2j = function _templateObject() {
    return data;
  };

  return data;
}
class BsListGroupFlush extends LitElement {
  static get styles() {
    return [BsContentRebootCss, BsListGroupCommonCss, css(_templateObject$2j())];
  }

  render() {
    return html(_templateObject2$X());
  }

}
window.customElements.define('bs-list-group-flush', BsListGroupFlush);

function _templateObject$2k() {
  const data = _taggedTemplateLiteral(["\n            <li class=\"list-group-item\">\n                <slot></slot>\n            </li>\n        "]);

  _templateObject$2k = function _templateObject() {
    return data;
  };

  return data;
}
class BsListGroupItem extends LitElement {
  static get styles() {
    return [BsContentRebootCss, BsListGroupItemCommonCss];
  }

  render() {
    return html(_templateObject$2k());
  }

}
window.customElements.define('bs-list-group-item', BsListGroupItem);

function _templateObject$2l() {
  const data = _taggedTemplateLiteral(["\n\n    .list-group-item-action {\n        width: 100%;\n        color: #495057;\n        text-align: inherit;\n    }\n\n    .list-group-item-action:hover, \n    .list-group-item-action:focus {\n        color: #495057;\n        text-decoration: none;\n        background-color: #f8f9fa;\n    }\n\n    :host([active]) .list-group-item-action {\n        color: #212529;\n        background-color: #e9ecef;\n    }\n\n    :host([primary]) .list-group-item-action:hover, \n    :host([primary]) .list-group-item-action:focus {\n        color: #004085;\n        background-color: #9fcdff;\n    }\n\n    :host([primary][active]) .list-group-item-action {\n        color: #fff;\n        background-color: #004085;\n        border-color: #004085;\n    }\n\n    :host([secondary]) .list-group-item-action:hover, \n    :host([secondary]) .list-group-item-action:focus {\n        color: #383d41;\n        background-color: #c8cbcf;\n    }\n\n    :host([secondary][active]) .list-group-item-action {\n        color: #fff;\n        background-color: #383d41;\n        border-color: #383d41;\n    }\n\n    :host([success]) .list-group-item-action:hover, \n    :host([success]) .list-group-item-action:focus {\n        color: #155724;\n        background-color: #b1dfbb;\n    }\n\n    :host([success][active]) .list-group-item-action {\n        color: #fff;\n        background-color: #155724;\n        border-color: #155724;\n    }\n\n    :host([info]) .list-group-item-action:hover, \n    :host([info]) .list-group-item-action:focus {\n        color: #0c5460;\n        background-color: #abdde5;\n    }\n\n    :host([info][active]) .list-group-item-action {\n        color: #fff;\n        background-color: #0c5460;\n        border-color: #0c5460;\n    }\n\n    :host([warning]) .list-group-item-action:hover, \n    :host([warning]) .list-group-item-action:focus {\n        color: #856404;\n        background-color: #ffe8a1;\n    }\n\n    :host([warning][active]) .list-group-item-action {\n        color: #fff;\n        background-color: #856404;\n        border-color: #856404;\n    }\n\n    :host([danger]) .list-group-item-action:hover, \n    :host([danger]) .list-group-item-action:focus {\n        color: #721c24;\n        background-color: #f1b0b7;\n    }\n\n    :host([danger][active]) .list-group-item-action {\n        color: #fff;\n        background-color: #721c24;\n        border-color: #721c24;\n    }\n\n    :host([light]) .list-group-item-action:hover, \n    :host([light]) .list-group-item-action:focus {\n        color: #818182;\n        background-color: #ececf6;\n    }\n\n    :host([light][active]) .list-group-item-action {\n        color: #fff;\n        background-color: #818182;\n        border-color: #818182;\n    }\n\n    :host([dark]) .list-group-item-action:hover, \n    :host([dark]) .list-group-item-action:focus {\n        color: #1b1e21;\n        background-color: #b9bbbe;\n    }\n\n    :host([dark][active]) .list-group-item-action {\n        color: #fff;\n        background-color: #1b1e21;\n        border-color: #1b1e21;\n    }\n"]);

  _templateObject$2l = function _templateObject() {
    return data;
  };

  return data;
}
const BsListGroupItemActionCommonCss = css(_templateObject$2l());

function _templateObject$2m() {
  const data = _taggedTemplateLiteral(["\n            <button class=\"list-group-item list-group-item-action\">\n                <slot></slot>\n            </button>\n        "]);

  _templateObject$2m = function _templateObject() {
    return data;
  };

  return data;
}
class BsListGroupItemActionButton extends LitElement {
  static get properties() {
    return {
      index: Number,
      button: {
        type: Boolean,
        reflect: true
      },
      reset: {
        type: Boolean,
        reflect: true
      },
      submit: {
        type: Boolean,
        reflect: true
      },
      active: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsContentTypographyCss, BsListGroupItemActionCommonCss, BsListGroupItemCommonCss];
  }

  render() {
    return html(_templateObject$2m());
  }

  constructor() {
    super();
    this.index = 0;
    this.button = true;
    this.reset = false;
    this.submit = false;
    this.active = false;
    this.disabled = false;
  }

  firstUpdated() {
    const buttonElement = this.shadowRoot.querySelector('button');
    buttonElement.addEventListener('click', event => this._handleClickEvent(event));

    this._setActiveState(buttonElement);

    this._setButtonType(buttonElement);
  }

  _setActiveState(buttonElement) {
    if (this.disabled && !this.active) {
      buttonElement.setAttribute('disabled', '');
    }

    if (!this.disabled && this.active) {
      buttonElement.classList.toggle('active');
    }
  }

  _setButtonType(buttonElement) {
    if (this.button) {
      buttonElement.setAttribute('type', 'button');
    }

    if (this.reset) {
      buttonElement.setAttribute('type', 'reset');
    }

    if (this.submit) {
      buttonElement.setAttribute('type', 'submit');
    }
  }

  _handleClickEvent(event) {
    if (this.disabled) {
      event.preventDefault();
    }

    const listGroupItemSelectedEvent = new CustomEvent('list-group-item-selected', {
      bubbles: true,
      composed: true,
      detail: {
        index: this.index
      }
    });
    this.dispatchEvent(listGroupItemSelectedEvent);
  }

}
window.customElements.define('bs-list-group-item-action-button', BsListGroupItemActionButton);

function _templateObject$2n() {
  const data = _taggedTemplateLiteral(["\n            <a href=\"[", "\" class=\"list-group-item list-group-item-action\">\n                <slot></slot>\n            </a>\n        "]);

  _templateObject$2n = function _templateObject() {
    return data;
  };

  return data;
}
class BsListGroupItemActionLink extends LitElement {
  static get properties() {
    return {
      index: Number,
      target: String,
      active: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsContentTypographyCss, BsListGroupItemActionCommonCss, BsListGroupItemCommonCss];
  }

  render() {
    return html(_templateObject$2n(), this.target);
  }

  constructor() {
    super();
    this.index = -1;
    this.active = false;
    this.target = '#';
    this.disabled = false;
  }

  firstUpdated() {
    const listGroupItemAction = this.shadowRoot.querySelector('a.list-group-item-action');
    listGroupItemAction.addEventListener('click', event => this._handleClickEvent(event));
  }

  _handleClickEvent(event) {
    if (this.disabled) {
      event.preventDefault();
      return;
    }

    if (this.target === '#') {
      event.preventDefault();
    }

    const listGroupItemSelectedEvent = new CustomEvent('list-group-item-selected', {
      bubbles: true,
      composed: true,
      detail: {
        index: this.index
      }
    });
    this.dispatchEvent(listGroupItemSelectedEvent);
  }

}
window.customElements.define('bs-list-group-item-action-link', BsListGroupItemActionLink);

function _templateObject2$Y() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$Y = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2o() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: flex;\n                    align-items: flex-start;\n                }\n            "]);

  _templateObject$2o = function _templateObject() {
    return data;
  };

  return data;
}
class BsMedia extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2o())];
  }

  render() {
    return html(_templateObject2$Y());
  }

}
window.customElements.define('bs-media', BsMedia);

function _templateObject2$Z() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$Z = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2p() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    flex: 1;\n                }\n            "]);

  _templateObject$2p = function _templateObject() {
    return data;
  };

  return data;
}
class BsMediaBody extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2p())];
  }

  render() {
    return html(_templateObject2$Z());
  }

}
window.customElements.define('bs-media-body', BsMediaBody);

function _templateObject2$_() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$_ = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2q() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    margin-top: 0;\n                    margin-bottom: 1rem;\n                }\n            "]);

  _templateObject$2q = function _templateObject() {
    return data;
  };

  return data;
}
class BsMediaGroup extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2q())];
  }

  render() {
    return html(_templateObject2$_());
  }

}
window.customElements.define('bs-media-group', BsMediaGroup);

function _templateObject2$$() {
  const data = _taggedTemplateLiteral(["\n            <div class=\"modal-backdrop\"></div>\n            <div class=\"modal\">\n                <div class=\"modal-dialog\" role=\"document\">\n                    <div class=\"modal-content\">\n                        <slot name=\"header\"></slot>\n                        <slot name=\"body\"></slot>\n                        <slot name=\"footer\"></slot>\n                    </div>\n                </div>\n            </div>\n        "]);

  _templateObject2$$ = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2r() {
  const data = _taggedTemplateLiteral(["\n                .modal {\n                    position: var(--bs-modal-position, fixed);\n                    top: var(--bs-modal-top, 0);\n                    right: var(--bs-modal-right, 0);\n                    bottom: var(--bs-modal-bottom, 0);\n                    left: var(--bs-modal-left, 0);\n                    z-index: var(--bs-modal-z-index, 1050);\n                    display: var(--bs-modal-display, none);\n                    overflow: hidden;\n                    outline: 0;\n                    opacity: var(--bs-modal-opacity, 0);\n                    transition: opacity 0.15s linear;\n                }\n                \n                :host([opened]) .modal {\n                    overflow-x: hidden;\n                    overflow-y: auto;\n                }\n        \n                .modal-dialog {\n                    position: relative;\n                    width: auto;\n                    left: var(--bs-modal-dialog-left);\n                    margin-top: 0.5rem;\n                    margin-bottom: 0.5rem;\n                    margin-right: 0.5rem;\n                    margin-left: 0.5rem;\n                    pointer-events: none;\n                    transition: -webkit-transform 0.3s ease-out;\n                    transition: transform 0.3s ease-out;\n                    transition: transform 0.3s ease-out, -webkit-transform 0.3s ease-out;\n                    -webkit-transform: translate(0, -25%);\n                    transform: translate(0, -25%);\n                }\n        \n                :host([opened]) .modal-dialog {\n                    -webkit-transform: translate(0, 0);\n                    transform: translate(0, 0);\n                }\n                \n                @media screen and (prefers-reduced-motion: reduce) {\n                    .modal-dialog {\n                        transition: none;\n                    }\n                }\n                \n                :host([centered]) .modal-dialog {\n                    display: -ms-flexbox;\n                    display: flex;\n                    -ms-flex-align: center;\n                    align-items: center;\n                    min-height: calc(100% - (0.5rem * 2));\n                }\n                \n                :host([centered]) .modal-dialog::before {\n                    display: block;\n                    height: calc(100vh - (0.5rem * 2));\n                    content: \"\";\n                }\n                \n                .modal-content {\n                    position: relative;\n                    display: -ms-flexbox;\n                    display: flex;\n                    -ms-flex-direction: column;\n                    flex-direction: column;\n                    width: 100%;\n                    pointer-events: auto;\n                    background-color: #fff;\n                    background-clip: padding-box;\n                    border: 1px solid rgba(0, 0, 0, 0.2);\n                    border-radius: 0.3rem;\n                    outline: 0;\n                }\n                \n                .modal-backdrop {\n                    opacity: 0;\n                }\n                \n                .modal-backdrop.show {\n                    position: fixed;\n                    top: 0;\n                    right: 0;\n                    bottom: 0;\n                    left: 0;\n                    z-index: 1040;\n                    background-color: #000;\n                    transition: opacity 0.15s linear;\n                }\n                \n                .modal-scrollbar-measure {\n                    position: absolute;\n                    top: -9999px;\n                    width: 50px;\n                    height: 50px;\n                    overflow: scroll;\n                }\n                \n                @media (min-width: 576px) {\n                    \n                    .modal-dialog {\n                        max-width: 500px;\n                        margin: 1.75rem auto;\n                    }\n                    \n                    :host([centered]) .modal-dialog {\n                        min-height: calc(100% - (1.75rem * 2));\n                    }\n                    \n                    :host([centered]) .modal-dialog::before {\n                        height: calc(100vh - (1.75rem * 2));\n                    }\n                    \n                    :host([small]) .modal-dialog {\n                        max-width: 300px;\n                    }\n                }\n        \n                @media (min-width: 992px) {\n                        \n                    :host([large]) .modal-dialog {\n                        max-width: 800px;\n                    }\n                }\n            "]);

  _templateObject$2r = function _templateObject() {
    return data;
  };

  return data;
}
class BsModal extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2r())];
  }

  render() {
    return html(_templateObject2$$());
  }

  static get properties() {
    return {
      large: Boolean,
      small: {
        type: Boolean,
        reflect: true
      },
      centered: {
        type: Boolean,
        reflect: true
      },
      _openTransition: Boolean,
      _closeTransition: Boolean,
      opened: {
        type: Boolean,
        reflect: true
      },
      dismissable: {
        type: Boolean,
        reflect: true
      },
      backdrop: {
        type: Boolean,
        reflect: true
      },
      animated: {
        type: Boolean,
        reflect: true
      }
    };
  }

  constructor() {
    super();
    this.opened = false;
    this.centered = false;
    this.dismissable = false;
    this.backdrop = false;
    this.animated = false;
    this.large = false;
    this.small = false;
    this._openTransition = false;
    this._closeTransition = false;
  }

  firstUpdated() {
    if (!this.animated) {
      this._removeTransitions();
    }

    this.addEventListener('bs-modal-dismiss', () => this._handleDismissEvent());
    const modalElement = this.shadowRoot.querySelector('.modal');
    modalElement.addEventListener('click', () => this._handleModalClick());
    const modalContentElement = this.shadowRoot.querySelector('.modal-content');
    modalContentElement.addEventListener('click', event => this._handleModalContentClick(event));
    const modalBackdrop = this.shadowRoot.querySelector('.modal-backdrop');
    modalBackdrop.addEventListener('transitionend', () => this._handleModalBackdropTransitionEnd());
    const modalDialogElement = this.shadowRoot.querySelector('.modal-dialog');
    modalDialogElement.addEventListener('transitionend', () => this._handleModalDialogTransitionEnd());
  }

  _handleDismissEvent() {
    if (this.dismissable) {
      this.close();
    }
  }

  _handleModalClick() {
    if (this.opened) {
      this.close();
    }
  }

  _handleModalContentClick(event) {
    event.stopPropagation();
    event.preventDefault();
  }

  _handleBackdropClickEvent() {
    if (this.opened) {
      this.close();
    }
  }

  _removeTransitions() {
    const modalElement = this.shadowRoot.querySelector('.modal');
    const modalDialogElement = this.shadowRoot.querySelector('.modal-dialog');
    const modalBackdropElement = this.shadowRoot.querySelector('.modal-backdrop');
    modalElement.style.transition = 'none';
    modalDialogElement.style.transition = 'none';
    modalBackdropElement.style.transition = 'none';
  }

  toggle() {
    if (this.opened) {
      this.close();
    } else {
      this.open();
    }
  }

  open() {
    this._sendModalOpenEvent();

    this._openTransition = true;

    if (this.animated) {
      this._openWithAnimation();
    } else {
      this._openWithNoAnimation();
    }
  }

  close() {
    this._sendModalCloseEvent();

    this.opened = false;

    if (this.animated) {
      this._closeWithAnimation();
    } else {
      this._closeWithNoAnimation();
    }
  }

  _closeWithAnimation() {
    this._hideModal();
  }

  _closeWithNoAnimation() {
    this._closeTransition = true;

    if (this.backdrop) {
      this._hideBackdrop();

      this._dismissBackdrop();
    }

    this._dismissModal();

    this._closeTransition = false;

    this._sendModalClosedEvent();
  }

  _openWithAnimation() {
    if (this.backdrop) {
      this._showBackdrop();
    } else {
      this._showModal();

      this.opened = true;
    }
  }

  _openWithNoAnimation() {
    if (this.backdrop) {
      this._showBackdrop();
    }

    this._showModal();

    this.opened = true;
    this._openTransition = false;

    this._sendModalOpenedEvent();
  }

  _handleModalDialogTransitionEnd() {
    if (this._openTransition) {
      this._sendModalOpenedEvent();

      this._openTransition = false;
    } else {
      this._closeTransition = true;

      if (this.backdrop) {
        this._hideBackdrop();
      } else {
        this._dismissModal();

        this._closeTransition = false;

        this._sendModalClosedEvent();
      }
    }
  }

  _handleModalBackdropTransitionEnd() {
    if (this._openTransition) {
      this._showModal();

      this.opened = true;
    }

    if (this._closeTransition) {
      this._dismissModal();

      this._dismissBackdrop();

      this._closeTransition = false;
    }
  }

  _showModal() {
    const modalElement = this.shadowRoot.querySelector('.modal');
    modalElement.style.setProperty('--bs-modal-display', 'block');
    window.getComputedStyle(modalElement).display;
    modalElement.style.opacity = '1';
  }

  _hideModal() {
    const modalElement = this.shadowRoot.querySelector('.modal');
    modalElement.style.opacity = '0';
  }

  _dismissModal() {
    const modalElement = this.shadowRoot.querySelector('.modal');
    modalElement.style.setProperty('--bs-modal-display', 'none');
  }

  _showBackdrop() {
    const modalBackdropElement = this.shadowRoot.querySelector('.modal-backdrop');
    modalBackdropElement.classList.add('show');
    modalBackdropElement.style.opacity = '0.5';
  }

  _hideBackdrop() {
    const modalBackdropElement = this.shadowRoot.querySelector('.modal-backdrop');
    modalBackdropElement.style.opacity = '0';
  }

  _dismissBackdrop() {
    const modalBackdropElement = this.shadowRoot.querySelector('.modal-backdrop');
    modalBackdropElement.classList.remove('show');
  }

  _sendModalOpenEvent() {
    const modalOpenEvent = new CustomEvent('bs.modal.open', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(modalOpenEvent);
  }

  _sendModalOpenedEvent() {
    const modalOpenedEvent = new CustomEvent('bs.modal.opened', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(modalOpenedEvent);
  }

  _sendModalCloseEvent() {
    const modalCloseEvent = new CustomEvent('bs.modal.close', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(modalCloseEvent);
  }

  _sendModalClosedEvent() {
    const modalClosedEvent = new CustomEvent('bs.modal.closed', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(modalClosedEvent);
  }

}
window.customElements.define('bs-modal', BsModal);

function _templateObject2$10() {
  const data = _taggedTemplateLiteral(["\n            <div class=\"modal-body\">\n                <slot></slot>\n            </div>\n        "]);

  _templateObject2$10 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2s() {
  const data = _taggedTemplateLiteral(["\n                .modal-body {\n                    position: relative;\n                    flex: 1 1 auto;\n                    padding: 1rem;\n                }\n            "]);

  _templateObject$2s = function _templateObject() {
    return data;
  };

  return data;
}
class BsModalBody extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2s())];
  }

  render() {
    return html(_templateObject2$10());
  }

}
window.customElements.define('bs-modal-body', BsModalBody);

function _templateObject2$11() {
  const data = _taggedTemplateLiteral(["\n            <div class=\"modal-footer\">\n                <slot></slot>\n            </div>\n        "]);

  _templateObject2$11 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2t() {
  const data = _taggedTemplateLiteral(["\n                .modal-footer {\n                    display: flex;\n                    align-items: center;\n                    justify-content: flex-end;\n                    padding: 1rem;\n                    border-top: 1px solid #e9ecef;\n                }\n\n                :host ::slotted(:not(:first-child)) {\n                    margin-left: .25rem;\n                }\n\n                :host ::slotted(:not(:last-child)) {\n                    margin-right: .25rem;\n                }\n            "]);

  _templateObject$2t = function _templateObject() {
    return data;
  };

  return data;
}
class BsModalFooter extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2t())];
  }

  render() {
    return html(_templateObject2$11());
  }

}
window.customElements.define('bs-modal-footer', BsModalFooter);

function _templateObject2$12() {
  const data = _taggedTemplateLiteral(["\n            <div class=\"modal-header\">\n                <div class=\"modal-title\">\n                    <slot></slot>\n                </div>\n                <bs-close-btn><bs-close-btn>\n            </div>\n        "]);

  _templateObject2$12 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2u() {
  const data = _taggedTemplateLiteral(["\n                .modal-header {\n                    display: flex;\n                    align-items: flex-start;\n                    justify-content: space-between;\n                    padding: 1rem;\n                    border-bottom: 1px solid #e9ecef;\n                    border-top-left-radius: 0.3rem;\n                    border-top-right-radius: 0.3rem;\n                }\n                \n                bs-close-btn {\n                    --bs-close-btn-padding: 1rem;\n                    --bs-close-btn-margin: -1rem -1rem -1rem auto;\n                }\n                \n                .modal-title {\n                    margin-bottom: 0;\n                    line-height: 1.5;\n                }\n            "]);

  _templateObject$2u = function _templateObject() {
    return data;
  };

  return data;
}
class BsModalHeader extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2u())];
  }

  render() {
    return html(_templateObject2$12());
  }

  firstUpdated() {
    this.addEventListener('close-button-click', () => this._handleCloseEvent());
  }

  _handleCloseEvent() {
    const modalDismissEvent = new CustomEvent('bs-modal-dismiss', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(modalDismissEvent);
  }

}
window.customElements.define('bs-modal-header', BsModalHeader);

function _templateObject$2v() {
  const data = _taggedTemplateLiteral(["\n    \n    @media (max-width: 991.98px) {\n        \n        :host([expand-lg]) ::slotted(bs-container) {\n            padding-right: 0;\n            padding-left: 0;\n        }\n    }\n\n    :host([expand-lg]) {\n        --nav-link-padding-left: 0;\n        --nav-link-padding-right: 0;\n        --nav-link-active-hover-color: rgba(0,0,0, 0.9);\n        \n        --dropdown-nav-link-padding-top: 0.5rem;\n        --dropdown-nav-link-padding-bottom: 0.5rem;\n        --dropdown-nav-link-padding-left: 0;\n        --dropdown-nav-link-padding-right: 0;\n        \n        --dropdown-display: block;\n        --dropdown-menu-position: static;\n        --dropdown-menu-float: none;\n        --dropdown-menu-display: none;\n    }\n\n    @media (min-width: 992px) {\n        \n        :host([expand-lg]) {\n            flex-flow: row nowrap;\n            justify-content: flex-start;\n            \n            --navbar-nav-flex-direction: row;\n            --nav-link-padding-left: 0.5rem;\n            --nav-link-padding-right: 0.5rem;\n            --nav-link-active-hover-color: rgba(0,0,0, 0.9);\n            \n            --dropdown-nav-link-padding-left: 0.5rem;\n            --dropdown-nav-link-padding-right: 0.5rem;\n\n            --navbar-collapse-flex-basis: auto;\n            --navbar-collapse-ms-flex-preferred-size: auto;\n            --navbar-collapse-display: flex !important;\n\n            --dropdown-display: flex;\n            --dropdown-menu-position: absolute;\n            --dropdown-menu-float: left;\n            --dropdown-menu-display: block;\n        }\n        \n        :host([expand-lg]) ::slotted(bs-container) {\n            flex-wrap: nowrap;\n        }\n        \n        :host([expand-lg]) ::slotted(bs-navbar-toggler) {\n            display: none;\n        }\n    }\n"]);

  _templateObject$2v = function _templateObject() {
    return data;
  };

  return data;
}
const BsNavbarExpandLargeCss = css(_templateObject$2v());

function _templateObject$2w() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([navbar-light]) {\n        \n        --navbar-brand-color: rgba(0, 0, 0, 0.9);\n        --navbar-brand-link-hover-color: rgba(0, 0, 0, 0.9);\n        --navbar-brand-link-focus-color: rgba(0, 0, 0, 0.9);\n        \n        --nav-link-active-color: rgba(0,0,0, 0.9);\n        --nav-link-color: rgba(0,0,0, 0.5);\n        --nav-link-disabled-color: rgba(0, 0, 0, 0.3);\n        --nav-link-hover-color: rgba(0, 0, 0, 0.7);\n\n        --dropdown-nav-link-color: rgba(0,0,0, 0.5);\n        --dropdown-nav-link-hover-border-color: transparent;\n        --dropdown-nav-link-hover-color: rgba(0, 0, 0, 0.7);\n        \n        --navbar-toggler-color: rgba(0, 0, 0, 0.5);\n        --navbar-toggler-border-color: rgba(0, 0, 0, 0.1);\n\n        --navbar-toggler-icon-background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg viewBox=%270 0 30 30%27 xmlns=%27http://www.w3.org/2000/svg%27%3E%3Cpath stroke=%27rgba%280,0,0,0.5%29%27 stroke-width=%272%27 stroke-linecap=%27round%27 stroke-miterlimit=%2710%27 d=%27M4 7h22M4 15h22M4 23h22%27/%3E%3C/svg%3E\");\n        \n        --navbar-text-color: rgba(0, 0, 0, 0.5);\n        --navbar-text-link-color: rgba(0, 0, 0, 0.9);\n        --navbar-text-link-hover-color: rgba(0, 0, 0, 0.9);\n        --navbar-text-link-focus-color: rgba(0, 0, 0, 0.9);\n    }\n"]);

  _templateObject$2w = function _templateObject() {
    return data;
  };

  return data;
}
const BsNavbarLightColorCss = css(_templateObject$2w());

function _templateObject$2x() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([navbar-dark]) {\n        \n        --navbar-brand-color: #fff;\n        --navbar-brand-link-hover-color: #fff;\n        --navbar-brand-link-focus-color: #fff;\n        \n        --nav-link-color: rgba(255, 255, 255, 0.5);\n        --nav-link-active-color: #fff;\n        --nav-link-disabled-color: rgba(255, 255, 255, 0.25);\n        --nav-link-hover-color: rgba(255, 255, 255, 0.75);\n        --nav-link-focus-color: rgba(255, 255, 255, 0.75);\n\n        --dropdown-nav-link-color: rgba(0,0,0, 0.5);\n        --dropdown-nav-link-hover-border-color: transparent;\n        --dropdown-nav-link-hover-color: rgba(0, 0, 0, 0.7);\n        \n        --navbar-toggler-color: rgba(255, 255, 255, 0.5);\n        --navbar-toggler-border-color: rgba(255, 255, 255, 0.1);\n\n        --navbar-toggler-icon-background-image: url(\"data:image/svg+xml;charset=utf8,%3Csvg viewBox=%270 0 30 30%27 xmlns=%27http://www.w3.org/2000/svg%27%3E%3Cpath stroke=%27rgba%28255, 255, 255, 0.5%29%27 stroke-width=%272%27 stroke-linecap=%27round%27 stroke-miterlimit=%2710%27 d=%27M4 7h22M4 15h22M4 23h22%27/%3E%3C/svg%3E\");\n        \n        --navbar-text-color: rgba(255, 255, 255, 0.5);\n        --navbar-text-link-color: #fff;\n        --navbar-text-link-hover-color: color: #fff;\n        --navbar-text-link-focus-color: color: #fff;\n    }\n"]);

  _templateObject$2x = function _templateObject() {
    return data;
  };

  return data;
}
const BsNavbarDarkColorCss = css(_templateObject$2x());

function _templateObject2$13() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$13 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2y() {
  const data = _taggedTemplateLiteral(["\n                \n                :host {\n                    position: relative;\n                    display: flex;\n                    flex-wrap: wrap;\n                    align-items: center;\n                    justify-content: space-between;\n                    padding: 0.5rem 1rem;\n                }\n                \n                :host ::slotted(bs-container) {\n                    display: flex;\n                    flex-wrap: wrap;\n                    align-items: center;\n                    justify-content: space-between;\n                }\n            "]);

  _templateObject$2y = function _templateObject() {
    return data;
  };

  return data;
}
class BsNavbar extends LitElement {
  static get styles() {
    return [BsContentRebootCss, BsNavbarExpandLargeCss, BsNavbarLightColorCss, BsNavbarDarkColorCss, css(_templateObject$2y())];
  }

  render() {
    return html(_templateObject2$13());
  }

  firstUpdated() {
    this.addEventListener('bs-navbar-toggler-click', () => this._handleToggleEvent());
  }

  _handleToggleEvent() {
    const navbarCollapseElement = this._findCollapsableElement();

    if (navbarCollapseElement) {
      navbarCollapseElement.toggle();
    }
  }

  _retrieveSlotAssignedNodes() {
    const slotElement = this.shadowRoot.querySelector('slot');
    const assignedNodes = slotElement.assignedNodes();
    return assignedNodes;
  }

  _findCollapsableElement() {
    const assignedNodes = this._retrieveSlotAssignedNodes();

    for (let index = 0; index < assignedNodes.length; index++) {
      const slotItem = assignedNodes[index];

      if (this._isNavbarCollapse(slotItem)) {
        return slotItem;
      }
    }
  }

  _isNavbarCollapse(element) {
    return element.nodeType === Node.ELEMENT_NODE && element.localName === 'bs-navbar-collapse';
  }

}
window.customElements.define('bs-navbar', BsNavbar);

function _templateObject2$14() {
  const data = _taggedTemplateLiteral(["\n            <span class=\"mb-0 h1\">\n                <slot></slot>\n            </span>\n        "]);

  _templateObject2$14 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2z() {
  const data = _taggedTemplateLiteral(["\n                :host span {\n                    display: inline-block;\n                    padding-top: 0.3125rem;\n                    padding-bottom: 0.3125rem;\n                    margin-right: 1rem;\n                    font-size: 1.25rem;\n                    line-height: inherit;\n                    white-space: nowrap;\n                }\n        \n                span {\n                    color: var(--navbar-brand-color);\n                }\n            "]);

  _templateObject$2z = function _templateObject() {
    return data;
  };

  return data;
}
class BsNavbarBrand extends LitElement {
  static get styles() {
    return [BsContentRebootCss, BsContentTypographyCss, BsSpacingCss, css(_templateObject$2z())];
  }

  render() {
    return html(_templateObject2$14());
  }

}
window.customElements.define('bs-navbar-brand', BsNavbarBrand);

function _templateObject2$15() {
  const data = _taggedTemplateLiteral(["\n            <a href=\"", "\">\n                <slot></slot>\n            </a>\n        "]);

  _templateObject2$15 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2A() {
  const data = _taggedTemplateLiteral(["\n                \n                :host {\n                    display: inline-block;\n                    padding-top: 0.3125rem;\n                    padding-bottom: 0.3125rem;\n                    margin-right: 1rem;\n                    font-size: 1.25rem;\n                    line-height: inherit;\n                    white-space: nowrap;\n                }\n        \n                a {\n                    color: var(--navbar-brand-color);\n                }\n                \n                a:hover {\n                    color: var(--navbar-brand-link-hover-color);\n                    text-decoration: none;\n                }\n        \n                a:focus {\n                    color: var(--navbar-brand-link-focus-color);\n                    text-decoration: none;\n                }\n            "]);

  _templateObject$2A = function _templateObject() {
    return data;
  };

  return data;
}
class BsNavbarBrandLink extends LitElement {
  static get properties() {
    return {
      target: String
    };
  }

  static get styles() {
    return [BsContentRebootCss, BsContentTypographyCss, BsSpacingCss, css(_templateObject$2A())];
  }

  render() {
    return html(_templateObject2$15(), this.target);
  }

  constructor() {
    super();
    this.target = '#';
  }

}
window.customElements.define('bs-navbar-brand-link', BsNavbarBrandLink);

function _templateObject2$16() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$16 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2B() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: var(--navbar-collapse-display);\n                    -ms-flex-preferred-size: var(--navbar-collapse-ms-flex-preferred-size, 100%);\n                    flex-basis: var(--navbar-collapse-flex-basis, 100%);\n                    -ms-flex-positive: 1;\n                    flex-grow: 1;\n                    -ms-flex-align: center;\n                    align-items: center;\n                    height: auto;\n                    transition: height 0.35s ease;\n                }\n                \n                :host([transitioning]) {\n                    position: relative;\n                }\n                \n                @media screen and (prefers-reduced-motion: reduce) {\n                    :host {\n                        transition: none;\n                    }\n                }\n            "]);

  _templateObject$2B = function _templateObject() {
    return data;
  };

  return data;
}
class BsNavbarCollapse extends LitElement {
  static get properties() {
    return {
      expanded: {
        type: Boolean,
        reflect: true
      },
      collapsed: {
        type: Boolean,
        reflect: true
      },
      transitioning: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2B())];
  }

  render() {
    return html(_templateObject2$16());
  }

  constructor() {
    super();
    this.expanded = true;
    this.collapsed = false;
    this.transitioning = false;
  }

  firstUpdated() {
    installMediaQueryWatcher('(min-width: 992px)', matches => this._minLargeDeviceLayoutChanged(matches));
    this.addEventListener('transitionend', event => this._afterCollapsingTransition(event));
  }

  _afterCollapsingTransition() {
    if (this.expanded) {
      this.shadowRoot.host.style.overflow = 'inherit';
      this.shadowRoot.host.style.height = 'auto';
    }

    this.transitioning = false;
  }

  _minLargeDeviceLayoutChanged(matches) {
    if (matches) {
      this.expanded = true;
      this.collapsed = false;
      this.transitioning = false;
      this.shadowRoot.host.style.overflow = 'inherit';
      this.shadowRoot.host.style.height = 'auto';
    }
  }

  toggle() {
    this.transitioning = true;

    if (this.expanded) {
      this._collapse();
    } else {
      this._expand();
    }
  }

  _expand() {
    this.expanded = true;
    this.collapsed = false;
    this.shadowRoot.host.style.height = this._getSlottedElementsHeight() + 'px';
  }

  _collapse() {
    this.collapsed = true;
    this.expanded = false;

    this._updateHeightBeforeCollapse();

    this.shadowRoot.host.style.overflow = 'hidden';
    this.shadowRoot.host.style.height = '0';
  }

  _updateHeightBeforeCollapse() {
    const existingHeight = this.shadowRoot.host.style.height;

    if (!existingHeight || existingHeight === 'auto') {
      this.shadowRoot.host.style.transition = 'none';
      this.shadowRoot.host.style.height = window.getComputedStyle(this.shadowRoot.host).height; //force browser to repaint after we change the height

      window.getComputedStyle(this.shadowRoot.host).height;
      this.shadowRoot.host.style.transition = 'height 0.35s ease';
    }
  }

  _getSlottedElementsHeight() {
    const slotNode = this.shadowRoot.querySelector('slot');
    const slottedElements = slotNode.assignedNodes();
    let totalHeight = 0;

    for (let index = 0; index < slottedElements.length; index++) {
      const slotElement = slottedElements[index];

      if (slotElement.nodeType === Node.ELEMENT_NODE) {
        const slotElementHeight = slotElement.offsetHeight;
        const marginTopValue = window.getComputedStyle(slotElement).marginTop;
        const marginBottomValue = window.getComputedStyle(slotElement).marginBottom;
        const marginTop = new Number(marginTopValue.slice(0, marginTopValue.length - 2));
        const marginBottom = new Number(marginBottomValue.slice(0, marginBottomValue.length - 2));
        totalHeight += slotElementHeight + marginTop + marginBottom;
      }
    }

    return totalHeight;
  }

}
window.customElements.define('bs-navbar-collapse', BsNavbarCollapse);

function _templateObject2$17() {
  const data = _taggedTemplateLiteral(["\n            <a href=\"", "\">\n                <slot></slot>\n            </a>\n        "]);

  _templateObject2$17 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2C() {
  const data = _taggedTemplateLiteral(["\n                \n                :host {\n                    display: inline-block;\n                    padding-top: 0.5rem;\n                    padding-bottom: 0.5rem;\n                }\n                \n                a {\n                    color: var(--navbar-text-link-color, rgba(0, 0, 0, 0.9));\n                }\n        \n                a:hover {\n                    color: var(--navbar-text-link-hover-color, rgba(0, 0, 0, 0.9));\n                }\n                \n                a:focus {\n                    color: var(--navbar-text-link-focus-color, rgba(0, 0, 0, 0.9));\n                }\n            "]);

  _templateObject$2C = function _templateObject() {
    return data;
  };

  return data;
}
class BsNavbarLink extends LitElement {
  static get properties() {
    return {
      target: String
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2C())];
  }

  render() {
    return html(_templateObject2$17(), this.target);
  }

  constructor() {
    super();
    this.target = '#';
  }

}
window.customElements.define('bs-navbar-link', BsNavbarLink);

function _templateObject2$18() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$18 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2D() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: flex;\n                    flex-direction: var(--navbar-nav-flex-direction, column);\n                    padding-left: 0;\n                    margin-bottom: 0;\n                    list-style: none;\n                }\n                \n                :host ::slotted(bs-dropdown) {\n                    position: static;\n                    float: none;\n                }\n            "]);

  _templateObject$2D = function _templateObject() {
    return data;
  };

  return data;
}
class BsNavbarNav extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2D())];
  }

  render() {
    return html(_templateObject2$18());
  }

}
window.customElements.define('bs-navbar-nav', BsNavbarNav);

function _templateObject2$19() {
  const data = _taggedTemplateLiteral(["\n            <span><slot></slot></span>\n        "]);

  _templateObject2$19 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2E() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: inline-block;\n                    padding-top: 0.5rem;\n                    padding-bottom: 0.5rem;\n                }\n                \n                span {\n                    color: var(--navbar-text-color, rgba(0, 0, 0, 0.5));\n                }\n            "]);

  _templateObject$2E = function _templateObject() {
    return data;
  };

  return data;
}
class BsNavbarText extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2E())];
  }

  render() {
    return html(_templateObject2$19());
  }

}
window.customElements.define('bs-navbar-text', BsNavbarText);

function _templateObject2$1a() {
  const data = _taggedTemplateLiteral(["\n            <button>\n                <slot></slot>\n            </button>\n        "]);

  _templateObject2$1a = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2F() {
  const data = _taggedTemplateLiteral(["\n                \n                button {\n                    padding: var(--navbar-toggler-padding, 0.25rem 0.75rem);\n                    font-size: var(--navbar-toggler-font-size, 1.25rem);\n                    line-height: 1;\n                    border: var(--navbar-toggler-border, 1px solid transparent);\n                    border-top-left-radius: 0.25rem;\n                    border-top-right-radius: 0.25rem;\n                    border-bottom-right-radius: 0.25rem;\n                    border-bottom-left-radius: 0.25rem;\n                    background-color: transparent;\n                    color: var(--navbar-toggler-color);\n                    border-color: var(--navbar-toggler-border-color);\n                }\n                \n                button:focus {\n                    text-decoration: none;\n                    outline: var(--navbar-toggler-outline-focus);\n                }\n                \n                button:hover {\n                    text-decoration: none;\n                }\n\n                button:not(:disabled):not(.disabled)  {\n                    cursor: pointer;\n                }\n            "]);

  _templateObject$2F = function _templateObject() {
    return data;
  };

  return data;
}
class BsNavbarToggler extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2F())];
  }

  render() {
    return html(_templateObject2$1a());
  }

  firstUpdated() {
    const toggleButton = this.shadowRoot.querySelector('button');
    toggleButton.addEventListener('click', event => this._handleToggleButtonClickEvent(event));
  }

  _handleToggleButtonClickEvent(event) {
    event.stopPropagation();
    event.preventDefault();
    const btnClickedEvent = new CustomEvent('bs-navbar-toggler-click', {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(btnClickedEvent);
  }

}
window.customElements.define('bs-navbar-toggler', BsNavbarToggler);

function _templateObject$2G() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: inline-block;\n                    width: 1.5em;\n                    height: 1.5em;\n                    vertical-align: middle;\n                    content: \"\";\n                    background: no-repeat center center;\n                    background-size: 100% 100%;\n                    background-image: var(--navbar-toggler-icon-background-image);\n                    font-size: 1.25rem;\n                    line-height: 1;\n                    color: rgba(0,0,0,0.5);\n                }\n            "]);

  _templateObject$2G = function _templateObject() {
    return data;
  };

  return data;
}
class BsNavbarTogglerIcon extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2G())];
  }

}
window.customElements.define('bs-navbar-toggler-icon', BsNavbarTogglerIcon);

function _templateObject$2H() {
  const data = _taggedTemplateLiteral(["\n    \n    @media (max-width: 767.98px) {\n        \n        :host([expand-md]) ::slotted(bs-container) {\n            padding-right: 0;\n            padding-left: 0;\n        }\n    }\n\n    :host([expand-md]) {\n        --nav-link-padding-left: 0;\n        --nav-link-padding-right: 0;\n        --nav-link-active-hover-color: rgba(0,0,0, 0.9);\n        \n        --dropdown-nav-link-padding-top: 0.5rem;\n        --dropdown-nav-link-padding-bottom: 0.5rem;\n        --dropdown-nav-link-padding-left: 0;\n        --dropdown-nav-link-padding-right: 0;\n        \n        --dropdown-display: block;\n        --dropdown-menu-position: static;\n        --dropdown-menu-float: none;\n        --dropdown-menu-display: none;\n    }\n\n    @media (min-width: 768px) {\n\n        :host([expand-md]) {\n            flex-flow: row nowrap;\n            justify-content: flex-start;\n\n            --navbar-nav-flex-direction: row;\n            --nav-link-padding-left: 0.5rem;\n            --nav-link-padding-right: 0.5rem;\n            --nav-link-active-hover-color: rgba(0,0,0, 0.9);\n            \n            --dropdown-nav-link-padding-left: 0.5rem;\n            --dropdown-nav-link-padding-right: 0.5rem;\n            \n            --navbar-collapse-flex-basis: auto;\n            --navbar-collapse-ms-flex-preferred-size: auto;\n            --navbar-collapse-display: flex !important;\n\n            --dropdown-display: flex;\n            --dropdown-menu-position: absolute;\n            --dropdown-menu-float: left;\n            --dropdown-menu-display: block;\n        }\n\n        :host([expand-md]) ::slotted(bs-container) {\n            flex-wrap: nowrap;\n        }\n        \n        :host([expand-md]) ::slotted(bs-navbar-toggler) {\n            display: none;\n        }\n    }\n"]);

  _templateObject$2H = function _templateObject() {
    return data;
  };

  return data;
}
const BsNavbarExpandMediumCss = css(_templateObject$2H());

function _templateObject$2I() {
  const data = _taggedTemplateLiteral(["\n    \n    @media (max-width: 575.98px) {\n        \n        :host([expand-sm]) ::slotted(bs-container) {\n            padding-right: 0;\n            padding-left: 0;\n        }\n    }\n\n    :host([expand-sm]) {\n        --nav-link-padding-left: 0;\n        --nav-link-padding-right: 0;\n        --nav-link-active-hover-color: rgba(0,0,0, 0.9);\n        \n        --dropdown-nav-link-padding-top: 0.5rem;\n        --dropdown-nav-link-padding-bottom: 0.5rem;\n        --dropdown-nav-link-padding-left: 0;\n        --dropdown-nav-link-padding-right: 0;\n        \n        --dropdown-display: block;\n        --dropdown-menu-position: static;\n        --dropdown-menu-float: none;\n        --dropdown-menu-display: none;\n    }\n\n    @media (min-width: 576px) {\n    \n        :host([expand-sm]) {\n            flex-flow: row nowrap;\n            justify-content: flex-start;\n            \n            --navbar-nav-flex-direction: row;\n            --nav-link-padding-left: 0.5rem;\n            --nav-link-padding-right: 0.5rem;\n            --nav-link-active-hover-color: rgba(0,0,0, 0.9);\n            \n            --navbar-collapse-flex-basis: auto;\n            --navbar-collapse-ms-flex-preferred-size: auto;\n            --navbar-collapse-display: flex !important;\n            \n            --dropdown-display: flex;\n            --dropdown-menu-position: absolute;\n            --dropdown-menu-float: left;\n            --dropdown-menu-display: block;\n        }\n        \n        :host([expand-sm]) ::slotted(bs-container) {\n            flex-wrap: nowrap;\n        }\n        \n        :host([expand-lg]) ::slotted(bs-navbar-toggler) {\n            display: none;\n        }\n    }\n"]);

  _templateObject$2I = function _templateObject() {
    return data;
  };

  return data;
}
const BsNavbarExpandSmallCss = css(_templateObject$2I());

function _templateObject$2J() {
  const data = _taggedTemplateLiteral(["\n    \n    :host([expand-xs]) ::slotted(bs-container) {\n        padding-right: 0;\n        padding-left: 0;\n    }\n    \n    :host([expand-xs]) {\n        --nav-link-padding-left: 0;\n        --nav-link-padding-right: 0;\n        --nav-link-active-hover-color: rgba(0,0,0, 0.9);\n        \n        --dropdown-nav-link-padding-top: 0.5rem;\n        --dropdown-nav-link-padding-bottom: 0.5rem;\n        --dropdown-nav-link-padding-left: 0;\n        --dropdown-nav-link-padding-right: 0;\n        \n        --dropdown-display: block;\n        --dropdown-menu-position: static;\n        --dropdown-menu-float: none;\n        --dropdown-menu-display: none;\n\n        -ms-flex-flow: row nowrap;\n        flex-flow: row nowrap;\n        -ms-flex-pack: start;\n        justify-content: flex-start;\n        \n        --navbar-nav-flex-direction: row;\n        --nav-link-padding-left: 0.5rem;\n        --nav-link-padding-right: 0.5rem;\n        \n        --dropdown-nav-link-padding-left: 0.5rem;\n        --dropdown-nav-link-padding-right: 0.5rem;\n\n        --navbar-collapse-flex-basis: auto;\n        --navbar-collapse-ms-flex-preferred-size: auto;\n        --navbar-collapse-display: flex !important;\n        \n        --dropdown-display: flex;\n        --dropdown-menu-position: absolute;\n        --dropdown-menu-float: left;\n        --dropdown-menu-display: block;\n    }\n    \n    :host([expand-xs]) ::slotted(bs-container) {\n        -ms-flex-wrap: nowrap;\n        flex-wrap: nowrap;\n    }\n    \n    :host([expand-xs]) ::slotted(bs-navbar-toggler) {\n        display: none;\n    }\n"]);

  _templateObject$2J = function _templateObject() {
    return data;
  };

  return data;
}
const BsNavbarExpandExtraSmallCss = css(_templateObject$2J());

function _templateObject2$1b() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$1b = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2K() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: -ms-flexbox;\n                    display: flex;\n                    -ms-flex-wrap: wrap;\n                    flex-wrap: wrap;\n                    padding-left: 0;\n                    margin-bottom: 0;\n                    list-style: none;\n                }\n\n                :host([fill]) ::slotted(bs-nav-item) {\n                    -ms-flex: 1 1 auto;\n                    flex: 1 1 auto;\n                    text-align: center;\n                }\n\n                :host([justified]) ::slotted(bs-nav-item) {\n                    -ms-flex-preferred-size: 0;\n                    flex-basis: 0;\n                    -ms-flex-positive: 1;\n                    flex-grow: 1;\n                    text-align: center;\n                }\n        \n                :host([tabs]) {\n                    \n                    margin-right: var(--bs-nav-margin-right);\n                    margin-bottom: var(--bs-nav-margin-bottom);\n                    margin-left: var(--bs-nav-margin-left);\n                    border-bottom: var(--bs-nav-border-bottom, 1px solid #dee2e6);\n                    \n                    --nav-item-margin-bottom: -1px;\n                    --nav-link-background-color: #fff;\n                    --nav-link-border: 1px solid transparent;\n                    --nav-link-active-color: #495057;\n                    --nav-link-active-border-top-left-radius: 0.25rem;\n                    --nav-link-active-border-top-right-radius: 0.25rem;\n                    --nav-link-active-border-color: #dee2e6 #dee2e6 #fff;\n                    \n                    --dropdown-nav-link-hover-color: #495057;\n                    --dropdown-nav-link-padding-bottom: 0.6rem;\n                    --dropdown-nav-link-active-color: #495057;\n                    --dropdown-nav-link-active-hover-color: #495057;\n                    --dropdown-nav-link-active-focus-color: #495057;\n\n                    --dropdown-menu-down-margin-top: -1px;\n                    --dropdown-menu-border-top-left-radius: 0;\n                    --dropdown-menu-border-top-right-radius: 0;\n                }\n                \n                :host([pills]) {\n                    \n                    margin-right: var(--bs-nav-margin-right);\n                    margin-left: var(--bs-nav-margin-left);\n                    \n                    --nav-link-active-color: #fff;\n                    --nav-link-active-hover-color: #fff;\n                    --nav-link-active-background-color: #007bff;\n                    --nav-link-border-radius: 0.25rem;\n                    --nav-link-active-border-bottom-left-radius: 0.25rem;\n                    --nav-link-active-border-bottom-right-radius: 0.25rem;\n                    --nav-link-active-border-top-left-radius: 0.25rem;\n                    --nav-link-active-border-top-right-radius: 0.25rem;\n                    \n                    --dropdown-nav-link-padding-top: 0.5rem;\n                    --dropdown-nav-link-padding-bottom: 0.5rem;\n                    --dropdown-nav-link-padding-left: 1rem;\n                    --dropdown-nav-link-padding-right: 1rem;\n                    --dropdown-nav-link-hover-color: #0056b3;\n                    --dropdown-nav-link-active-color: #fff;\n                    --dropdown-nav-link-active-hover-color: #fff;\n                    --dropdown-nav-link-active-focus-color: #fff;\n                    --dropdown-nav-link-active-background-color: #007bff;\n                    --dropdown-nav-link-hover-border-color: transparent;\n\n                    --dropdown-menu-border-top-left-radius: 0.25rem;\n                    --dropdown-menu-border-top-right-radius: 0.25rem;\n                }\n            "]);

  _templateObject$2K = function _templateObject() {
    return data;
  };

  return data;
}
class BsNav extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2K())];
  }

  render() {
    return html(_templateObject2$1b());
  }

}
window.customElements.define('bs-nav', BsNav);

function _templateObject2$1c() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$1c = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2L() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    margin-bottom: var(--nav-item-margin-bottom);\n                }\n                \n                :host([show]) {\n                    --dropdown-nav-link-color: #fff;\n                    --dropdown-nav-link-hover-color: #fff;\n                    --dropdown-nav-link-background-color: #007bff;\n                }\n            "]);

  _templateObject$2L = function _templateObject() {
    return data;
  };

  return data;
}
class BsNavItem extends LitElement {
  static get properties() {
    return {
      show: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2L())];
  }

  render() {
    return html(_templateObject2$1c());
  }

  constructor() {
    super();
    this.show = false;
  }

  firstUpdated() {
    this.addEventListener('bs-button-click', () => this._handleDropdownToggleClick());
    this.addEventListener('bs-button-focusout', () => this._handleDropdownToggleFocusOut());
  }

  _handleDropdownToggleClick() {
    const navParentElement = this.parentElement;

    if (navParentElement.hasAttribute('pills')) {
      this.show = !this.show;
    }
  }

  _handleDropdownToggleFocusOut() {
    const navParentElement = this.parentElement;

    if (navParentElement.hasAttribute('pills')) {
      if (this.show) {
        this.show = !this.show;
      }
    }
  }

}
window.customElements.define('bs-nav-item', BsNavItem);

function _templateObject2$1d() {
  const data = _taggedTemplateLiteral(["\n            <a href=\"", "\" target=\"", "\">\n                <slot></slot>\n            </a>\n        "]);

  _templateObject2$1d = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2M() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: block;\n                    padding-top: 0.5rem;\n                    padding-bottom: 0.5rem;\n                    padding-right: var(--nav-link-padding-right, 1rem);\n                    padding-left: var(--nav-link-padding-left, 1rem);\n                    border: var(--nav-link-border);\n                    border-radius: var(--nav-link-border-radius);\n                }\n                \n                :host(:hover),\n                :host(:focus) {\n                    border-color: #e9ecef #e9ecef #dee2e6;\n                    border-top-left-radius: 0.25rem;\n                    border-top-right-radius: 0.25rem;\n                }\n                \n                a {\n                    color: var(--nav-link-color, #007bff);\n                }\n                \n                :host(:hover) a {\n                    color: var(--nav-link-hover-color, #0056b3);\n                    text-decoration: none;\n                }\n                \n                :host(:focus) a {\n                    color: var(--nav-link-focus-color);\n                    text-decoration: none;\n                }\n\n                :host([disabled]) a {\n                    color: var(--nav-link-disabled-color, #6c757d);\n                }\n                \n                :host([disabled]) {\n                    background-color: transparent;\n                    border-color: transparent;\n                }\n                \n                :host([active]) a {\n                    color: var(--nav-link-active-color, #007bff);\n                }\n                \n                :host([active]) a:hover {\n                    text-decoration: none;\n                    color: var(--nav-link-active-hover-color, #0056b3);\n                }\n                \n                :host([active]) {\n                    background-color: var(--nav-link-active-background-color);\n                    border-color: var(--nav-link-active-border-color);\n                    border-bottom-left-radius: var(--nav-link-active-border-bottom-left-radius);\n                    border-bottom-right-radius: var(--nav-link-active-border-bottom-right-radius);\n                    border-top-left-radius: var(--nav-link-active-border-top-left-radius);\n                    border-top-right-radius: var(--nav-link-active-border-top-right-radius);\n                }\n            "]);

  _templateObject$2M = function _templateObject() {
    return data;
  };

  return data;
}
class BsNavLink extends LitElement {
  static get properties() {
    return {
      index: Number,
      href: String,
      target: String,
      active: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2M())];
  }

  render() {
    return html(_templateObject2$1d(), this.href, this.target);
  }

  constructor() {
    super();
    this.index = -1;
    this.href = '';
    this.target = '_blank';
    this.active = false;
    this.disabled = false;
  }

  firstUpdated() {
    const navLink = this.shadowRoot.querySelector('a');
    navLink.addEventListener('click', event => this._handleClickEvent(event));
  }

  _handleClickEvent(event) {
    if (this.disabled) {
      event.preventDefault();
      return;
    }

    if (this.target === '#') {
      event.preventDefault();
    }

    const navLinkClickEvent = new CustomEvent('nav-link', {
      bubbles: true,
      composed: true,
      detail: {
        index: this.index
      }
    });
    this.dispatchEvent(navLinkClickEvent);
  }

}
window.customElements.define('bs-nav-link', BsNavLink);

function _templateObject2$1e() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$1e = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2N() {
  const data = _taggedTemplateLiteral(["\n               :host(:first-child) ::slotted(bs-page-link) {\n                    margin-left: 0;\n                    border-top-left-radius: 0.25rem;\n                    border-bottom-left-radius: 0.25rem;\n                }\n\n                :host(:last-child) ::slotted(bs-page-link) {\n                    border-top-right-radius: 0.25rem;\n                    border-bottom-right-radius: 0.25rem;\n                }\n\n                :host([active]) ::slotted(bs-page-link) {\n                    z-index: 1;\n                    --bs-page-link-color: #fff;\n                    background-color: #007bff;\n                    border-color: #007bff;\n                }\n\n                :host([disabled]) ::slotted(bs-page-link) {\n                    --bs-page-link-color: #6c757d;\n                    pointer-events: none;\n                    cursor: auto;\n                    background-color: #fff;\n                    border-color: #dee2e6;\n                } \n            "]);

  _templateObject$2N = function _templateObject() {
    return data;
  };

  return data;
}
class BsPageItem extends LitElement {
  static get properties() {
    return {
      active: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2N())];
  }

  render() {
    return html(_templateObject2$1e());
  }

  constructor() {
    super();
    this.active = false;
    this.disabled = false;
  }

}
window.customElements.define('bs-page-item', BsPageItem);

function _templateObject2$1f() {
  const data = _taggedTemplateLiteral(["\n            <a href=\"", "\"><slot></slot></a>\n        "]);

  _templateObject2$1f = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2O() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    position: relative;\n                    display: block;\n                    padding: var(--bs-page-link-padding, 0.5rem 0.75rem);\n                    margin-left: -1px;\n                    line-height: var(--bs-page-link-line-height, 1.25);\n                    background-color: #fff;\n                    border: 1px solid #dee2e6;\n                    font-size: var(--bs-page-link-font-size);\n                    border-top-left-radius: var(--bs-page-link-radius-top-left);\n                    border-bottom-left-radius: var(--bs-page-link-radius-bottom-left);\n                    border-top-right-radius: var(--bs-page-link-radius-top-right);\n                    border-bottom-right-radius: var(--bs-page-link-radius-bottom-right);\n                }\n        \n                :host a {\n                    color: var(--bs-page-link-color, #007bff);\n                }\n        \n                :host(:hover) {\n                    z-index: 2;\n                    color: #0056b3;\n                    background-color: #e9ecef;\n                    border-color: #dee2e6;\n                }\n                \n                :host(:hover) a {\n                    text-decoration: none;\n                }\n                \n                :host(:focus) {\n                    z-index: 2;\n                    outline: 0;\n                    box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);\n                }\n                \n                :host(:not([disabled])) {\n                    cursor: pointer;\n                }\n            "]);

  _templateObject$2O = function _templateObject() {
    return data;
  };

  return data;
}
class BsPageLink extends LitElement {
  static get properties() {
    return {
      target: {
        type: String,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2O())];
  }

  render() {
    return html(_templateObject2$1f(), this.target);
  }

  constructor() {
    super();
    this.target = '#';
    this.disabled = false;
  }

}
window.customElements.define('bs-page-link', BsPageLink);

function _templateObject2$1g() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$1g = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2P() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: flex;\n                    padding-left: 0;\n                    list-style: none;\n                    border-radius: 0.25rem;\n                }\n        \n                :host([large]) {\n                    --bs-page-link-padding: 0.75rem 1.5rem;\n                    --bs-page-link-font-size: 1.25rem;\n                    --bs-page-link-line-height: 1.5;\n                }\n\n                :host([large]) ::slotted(bs-page-item:first-child) {\n                    --bs-page-link-radius-top-left: 0.3rem;\n                    --bs-page-link-radius-bottom-left: 0.3rem;\n                }\n\n                :host([large]) ::slotted(bs-page-item:last-child) {\n                    --bs-page-link-radius-top-right: 0.3rem;\n                    --bs-page-link-radius-bottom-right: 0.3rem;\n                }\n        \n                :host([small]) {\n                    --bs-page-link-padding: 0.25rem 0.5rem;\n                    --bs-page-link-font-size: 0.875rem;\n                    --bs-page-link-line-height: 1.5;\n                }\n\n                :host([small]) ::slotted(bs-page-item:first-child) {\n                    --bs-page-link-radius-top-left: 0.2rem;\n                    --bs-page-link-radius-bottom-left: 0.2rem;\n                }\n\n                :host([small]) ::slotted(bs-page-item:last-child) {\n                   --bs-page-link-radius-top-right: 0.2rem;\n                   --bs-page-link-radius-bottom-right: 0.2rem;\n                }\n            "]);

  _templateObject$2P = function _templateObject() {
    return data;
  };

  return data;
}
class BsPagination extends LitElement {
  static get properties() {
    return {
      small: {
        type: Boolean,
        reflect: true
      },
      large: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2P())];
  }

  render() {
    return html(_templateObject2$1g());
  }

  constructor() {
    super();
    this.small = false;
    this.large = false;
  }

}
window.customElements.define('bs-pagination', BsPagination);

function _templateObject2$1h() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$1h = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2Q() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: flex;\n                    height: 1rem;\n                    overflow: hidden;\n                    font-size: 0.75rem;\n                    background-color: #e9ecef;\n                    border-radius: 0.25rem;\n                }\n            "]);

  _templateObject$2Q = function _templateObject() {
    return data;
  };

  return data;
}
class BsProgress extends LitElement {
  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2Q())];
  }

  render() {
    return html(_templateObject2$1h());
  }

}
window.customElements.define('bs-progress', BsProgress);

function _templateObject2$1i() {
  const data = _taggedTemplateLiteral(["\n            <slot></slot>\n        "]);

  _templateObject2$1i = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2R() {
  const data = _taggedTemplateLiteral(["\n                :host {\n                    display: flex;\n                    flex-direction: column;\n                    justify-content: center;\n                    color: #fff;\n                    text-align: center;\n                    white-space: nowrap;\n                    background-color: #007bff;\n                    transition: width 0.6s ease;\n                }\n                \n                @media screen and (prefers-reduced-motion: reduce) {\n                    :host {\n                        transition: none;\n                    }\n                }\n        \n                :host([striped]) {\n                    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);\n                    background-size: 1rem 1rem;\n                }\n                \n                :host([animated]) {\n                    -webkit-animation: progress-bar-stripes 1s linear infinite;\n                    animation: progress-bar-stripes 1s linear infinite;\n                }\n                \n                @-webkit-keyframes progress-bar-stripes {\n                    from {\n                        background-position: 1rem 0;\n                    }\n                    to {\n                        background-position: 0 0;\n                    }\n                }\n\n                @keyframes progress-bar-stripes {\n                    from {\n                        background-position: 1rem 0;\n                    }\n                    to {\n                        background-position: 0 0;\n                    }\n                }\n            "]);

  _templateObject$2R = function _templateObject() {
    return data;
  };

  return data;
}
class BsProgressBar extends LitElement {
  static get properties() {
    return {
      striped: {
        type: Boolean,
        reflect: true
      },
      animated: {
        type: Boolean,
        reflect: true
      },
      completed: {
        type: Number,
        reflect: true,
        attribute: 'completed'
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2R())];
  }

  render() {
    return html(_templateObject2$1i());
  }

  constructor() {
    super();
    this.striped = false;
    this.animated = false;
    this.completed = 0;
  }

  updated(changedProperties) {
    super.updated();

    if (changedProperties.has('completed')) {
      this._percentCompletedChanged();
    }
  }

  _percentCompletedChanged() {
    if (this.completed) {
      this.shadowRoot.host.style.width = "".concat(this.completed, "%");
    }
  }

}
window.customElements.define('bs-progress-bar', BsProgressBar);

function _templateObject$2S() {
  const data = _taggedTemplateLiteral(["\n            <div class=\"tab-content\">\n                <slot></slot>\n            </div>\n        "]);

  _templateObject$2S = function _templateObject() {
    return data;
  };

  return data;
}
class BsTabContent extends LitElement {
  static get properties() {
    return {
      selectedItem: {
        type: Number,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss];
  }

  render() {
    return html(_templateObject$2S());
  }

  constructor() {
    super();
    this.selectedItem = 0;
  }

  firstUpdated() {
    this._addTabContentItemsIndexAndActivateInitalTabContent();
  }

  updated(changedProperties) {
    super.updated();

    if (changedProperties.has('selectedItem')) {
      this._selectedItemChanged();
    }
  }

  _addTabContentItemsIndexAndActivateInitalTabContent() {
    const tabContentItems = this._retrieveTabContentItemNodes();

    for (let index = 0; index < tabContentItems.length; ++index) {
      const tabContentItem = tabContentItems[index];
      tabContentItem.setAttribute('index', index);

      if (this.selectedItem === index) {
        tabContentItem.setAttribute('active', '');
      }
    }
  }

  _selectedItemChanged() {
    const tabContentItems = this._retrieveTabContentItemNodes();

    for (let index = 0; index < tabContentItems.length; ++index) {
      const tabContentItem = tabContentItems[index];

      if (this.selectedItem === tabContentItem.index) {
        tabContentItem.setAttribute('active', '');
      } else {
        tabContentItem.removeAttribute('active');
      }
    }
  }

  _retrieveTabContentItemNodes() {
    const slotElement = this.shadowRoot.querySelector('slot');
    const slotNodes = slotElement.assignedNodes();
    const tabContentItemNodes = [];

    for (let index = 0; index < slotNodes.length; ++index) {
      const el = slotNodes[index];

      if (this._isTabContentItem(el)) {
        tabContentItemNodes.push(el);
      }
    }

    return tabContentItemNodes;
  }

  _isTabContentItem(el) {
    return el.nodeType === Node.ELEMENT_NODE && el.localName === 'bs-tab-content-item';
  }

}
window.customElements.define('bs-tab-content', BsTabContent);

function _templateObject$2T() {
  const data = _taggedTemplateLiteral(["\n            \n            <slot name=\"tabs\"></slot>\n            \n            <bs-tab-content selectedItem=\"", "\">\n                <slot name=\"tabs-content\"></slot>\n            </bs-tab-content>\n        "]);

  _templateObject$2T = function _templateObject() {
    return data;
  };

  return data;
}
class BsTabs extends LitElement {
  static get properties() {
    return {
      selectedTabId: Number
    };
  }

  render() {
    return html(_templateObject$2T(), this.selectedTabId);
  }

  constructor() {
    super();
    this.selectedTabId = -1;
  }

  firstUpdated() {
    this.addEventListener('list-group-item-selected', event => this._handleListGroupItemSelected(event));
  }

  _handleListGroupItemSelected(event) {
    this.selectedTabId = event.detail.index;
  }

}
window.customElements.define('bs-tabs', BsTabs);

function _templateObject2$1j() {
  const data = _taggedTemplateLiteral(["\n            <div class=\"tab-pane\">\n                <slot></slot>\n            </div>\n        "]);

  _templateObject2$1j = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject$2U() {
  const data = _taggedTemplateLiteral(["\n                .tab-pane {\n                     opacity: 0;\n                     position:absolute;\n                }\n                \n                .tab-pane.fade.show {\n                    opacity: 1;\n                    position: static;\n                }\n                \n                .tab-pane.fade {\n                    opacity: 0;\n                    transition: opacity .15s linear;\n                }\n            "]);

  _templateObject$2U = function _templateObject() {
    return data;
  };

  return data;
}
class BsTabContentItem extends LitElement {
  static get properties() {
    return {
      index: Number,
      fade: {
        type: Boolean,
        reflect: true
      },
      show: {
        type: Boolean,
        reflect: true
      },
      active: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsContentRebootCss, css(_templateObject$2U())];
  }

  render() {
    return html(_templateObject2$1j());
  }

  constructor() {
    super();
    this.index = 0;
    this.fade = false;
    this.show = false;
    this.active = false;
  }

  firstUpdated() {
    this._hideTabPane();
  }

  updated(changedProperties) {
    super.updated();

    if (changedProperties.has('active')) {
      this._activeStatusChanged();
    }
  }

  _hideTabPane() {
    if (this.fade) {
      const tabPaneElement = this.shadowRoot.querySelector('div.tab-pane');
      tabPaneElement.classList.add('fade');
    }
  }

  _activeStatusChanged() {
    const tabPaneElement = this.shadowRoot.querySelector('div.tab-pane');

    if (this.active) {
      tabPaneElement.classList.add('show');
      tabPaneElement.classList.add('active');
    } else {
      tabPaneElement.classList.remove('active');
      tabPaneElement.classList.remove('show');
    }
  }

}
window.customElements.define('bs-tab-content-item', BsTabContentItem);

export { BsAccordion, BsAlert, BsAlertDismiss, BsAlertHr, BsAlertLink, BsBackgroundColorsCss, BsBadge, BsBadgeCss, BsBadgeLink, BsBordersCss, BsBreadcrumb, BsBreadcrumbItem, BsButton, BsButtonGroup, BsButtonGroupCss, BsButtonGroupHorizontalCss, BsButtonGroupLargeCss, BsButtonGroupSmallCss, BsButtonGroupVerticalCss, BsButtonMixin, BsCard, BsCardBody, BsCardColumns, BsCardDeck, BsCardFooter, BsCardGroup, BsCardHeader, BsCardImg, BsCardLink, BsCardLinks, BsCardOverlay, BsCardSubtitle, BsCardText, BsCardTitle, BsCarousel, BsCarouselCaption, BsCarouselControlNext, BsCarouselControlPrev, BsCarouselIndicator, BsCarouselIndicators, BsCarouselItem, BsClearfixCss, BsCollapsable, BsCollapseMixin, BsCollapseMultiToggle, BsCollapseToggle, BsColumn, BsColumnExtraLargeCss, BsColumnExtraSmallCss, BsColumnLargeCss, BsColumnMediumCss, BsColumnSmallCss, BsContenTableCss, BsContentCodeCss, BsContentFiguresCss, BsContentImageCss, BsContentRebootCss, BsContentTypographyCss, BsDisplayCss, BsDropdown, BsDropdownDivider, BsDropdownHeader, BsDropdownItemButton, BsDropdownItemCss, BsDropdownItemLink, BsDropdownItemMixin, BsDropdownItemText, BsDropdownMenu, BsDropdownNavCss, BsDropdownSplitCss, BsDropdownToggleCss, BsEmbeddedCss, BsFlexAlignContentCss, BsFlexAlignItemsCss, BsFlexAlignSelfCss, BsFlexDirectionCss, BsFlexDisplayCss, BsFlexJustifyCss, BsFlexOffsetCss, BsFlexOrderCss, BsFlexWrapCss, BsFloatCss, BsForm, BsFormCheckGroup, BsFormCheckLabel, BsFormCheckboxInput, BsFormControlCss, BsFormControlSizeCss, BsFormFieldset, BsFormFileInput, BsFormGroup, BsFormHelpText, BsFormInput, BsFormInputFeedback, BsFormInputMixin, BsFormInputPlaintext, BsFormLabel, BsFormRadioGroup, BsFormRadioInput, BsFormRange, BsFormRow, BsFormSelect, BsFormTextarea, BsInputGroup, BsInputGroupAppend, BsInputGroupCss, BsInputGroupLargeCss, BsInputGroupPrepend, BsInputGroupSmallCss, BsInputGroupText, BsJumbotron, BsLinkButton, BsListGroup, BsListGroupAction, BsListGroupActionFlush, BsListGroupBadgeItem, BsListGroupCommonCss, BsListGroupFlush, BsListGroupItem, BsListGroupItemActionButton, BsListGroupItemActionCommonCss, BsListGroupItemActionLink, BsListGroupItemCommonCss, BsMedia, BsMediaBody, BsMediaGroup, BsModal, BsModalBody, BsModalFooter, BsModalHeader, BsNav, BsNavItem, BsNavLink, BsNavbar, BsNavbarBrand, BsNavbarBrandLink, BsNavbarCollapse, BsNavbarDarkColorCss, BsNavbarExpandExtraSmallCss, BsNavbarExpandLargeCss, BsNavbarExpandMediumCss, BsNavbarExpandSmallCss, BsNavbarLightColorCss, BsNavbarLink, BsNavbarNav, BsNavbarText, BsNavbarToggler, BsNavbarTogglerIcon, BsPageItem, BsPageLink, BsPagination, BsPositionCss, BsProgress, BsProgressBar, BsScreenreaderCss, BsSizingCss, BsSpacingCss, BsTabContent, BsTabContentItem, BsTabs, BsTextColorCss, BsTextCss, BsVerticalAlignCss, BsVisibilityCss, DefaultThemeCss };
